@@ -41,21 +41,22 @@ void cla_oldportposition(NODEINST*, PORTPROTO*, INTBIG*, INTBIG*);
 void cla_adjustmatrix(NODEINST*, PORTPROTO*, XARRAY);
 
 /* prototypes for local routines */
-static INTSML cla_modifynodeinst(NODEINST*, INTBIG, INTBIG, INTBIG, INTBIG, INTSML, INTSML, INTSML);
-static INTSML cla_modnodearcs(NODEINST*, INTSML, INTSML);
-static void cla_modwithin(NODEINST*, INTSML, INTSML);
-static INTSML cla_modrigid(NODEINST*, INTSML, INTSML);
-static INTSML cla_modflex(NODEINST*, INTSML, INTSML);
-static void cla_nonorthogfixang(ARCINST*, INTSML, INTSML, NODEINST*, INTBIG[2], INTBIG[2]);
-static void cla_ensurearcinst(ARCINST*, INTSML);
-static void cla_updatearc(ARCINST*, INTBIG, INTBIG, INTBIG, INTBIG, INTSML);
-static void cla_domovearcinst(ARCINST*, INTBIG, INTBIG, INTBIG, INTBIG, INTSML);
+static BOOLEAN cla_modifynodeinst(NODEINST *ni, INTBIG deltalx, INTBIG deltaly, INTBIG deltahx,
+				INTBIG deltahy, INTBIG dangle, INTBIG dtrans, BOOLEAN announce);
+static BOOLEAN cla_modnodearcs(NODEINST*, INTBIG, INTBIG);
+static void cla_modwithin(NODEINST*, INTBIG, INTBIG);
+static BOOLEAN cla_modrigid(NODEINST*, INTBIG, INTBIG);
+static BOOLEAN cla_modflex(NODEINST*, INTBIG, INTBIG);
+static void cla_nonorthogfixang(ARCINST*, INTBIG, INTBIG, NODEINST*, INTBIG[2], INTBIG[2]);
+static void cla_ensurearcinst(ARCINST*, INTBIG);
+static void cla_updatearc(ARCINST*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+static void cla_domovearcinst(ARCINST*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 static void cla_makeoldrot(NODEINST*, XARRAY);
 static void cla_makeoldtrans(NODEINST*, XARRAY);
-static void cla_computefacet(NODEPROTO*, INTSML);
-static INTSML cla_lookdown(NODEPROTO*);
+static void cla_computefacet(NODEPROTO*, BOOLEAN);
+static BOOLEAN cla_lookdown(NODEPROTO*);
 
-#define DEBUG 1			/* comment out for normal life */
+#define CLA_DEBUG 1			/* comment out for normal life */
 
 /* command completion table for this constraint solver */
 static KEYWORD layconopt[] =
@@ -67,8 +68,8 @@ COMCOMP cla_layconp = {layconopt, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP,
 	0, " \t", M_("layout constraint system option"), 0};
 
 INTBIG cla_changeclock;
-#ifdef DEBUG
-static INTSML cla_conlaydebug;
+#ifdef CLA_DEBUG
+static BOOLEAN cla_conlaydebug;
 #endif
 CONSTRAINT *cla_constraint;	/* the constraint object for this solver */
 
@@ -80,8 +81,8 @@ void cla_layconinit(CONSTRAINT *con)
 	if (con == NOCONSTRAINT) return;
 	cla_constraint = con;
 	cla_changeclock = 10;
-#ifdef DEBUG
-	cla_conlaydebug = 0;
+#ifdef CLA_DEBUG
+	cla_conlaydebug = FALSE;
 #endif
 }
 
@@ -91,9 +92,9 @@ void cla_layconterm(void)
 	cla_workingarccount = 0;
 }
 
-void cla_layconsetmode(INTSML count, char *par[])
+void cla_layconsetmode(INTBIG count, char *par[])
 {
-	REGISTER INTSML l;
+	REGISTER INTBIG l;
 	REGISTER char *pp;
 
 	if (count == 0)
@@ -113,9 +114,9 @@ void cla_layconsetmode(INTSML count, char *par[])
 	/* debugging switch */
 	if (namesamen(pp, "debug-toggle", l) == 0 && l >= 1)
 	{
-#ifdef DEBUG
-		cla_conlaydebug = 1 - cla_conlaydebug;
-		if (cla_conlaydebug != 0) ttyputmsg(M_("Layout constraint debugging on")); else
+#ifdef CLA_DEBUG
+		cla_conlaydebug = !cla_conlaydebug;
+		if (cla_conlaydebug) ttyputmsg(M_("Layout constraint debugging on")); else
 			ttyputmsg(M_("Layout constraint debugging off"));
 #else
 		ttyputmsg(M_("Sorry, constraint debugging code has been compiled out"));
@@ -132,7 +133,7 @@ void cla_layconsetmode(INTSML count, char *par[])
 INTBIG cla_layconrequest(char *command, INTBIG arg1)
 {
 	REGISTER ARCINST *ai;
-	REGISTER INTSML l;
+	REGISTER INTBIG l;
 
 	l = strlen(command);
 
@@ -168,7 +169,7 @@ void cla_layconsolve(NODEPROTO *np)
 	curbatch = db_getcurrentbatch();
 	if (np != NONODEPROTO)
 	{
-		cla_computefacet(np, 0);
+		cla_computefacet(np, FALSE);
 	} else
 	{
 		/* solve all facets that changed */
@@ -283,66 +284,67 @@ void cla_layconnewvariable(INTBIG addr, INTBIG type, INTBIG skey, INTBIG stype)
 
 /*
  * set layout constraints on arc instance "ai" according to "changetype".
- * the routine returns nonzero if the arc change is not successful (or already
+ * the routine returns true if the arc change is not successful (or already
  * done)
  */
-INTSML cla_layconsetobject(INTBIG addr, INTBIG type, INTBIG changetype, INTBIG changedata)
+BOOLEAN cla_layconsetobject(INTBIG addr, INTBIG type, INTBIG changetype,
+	INTBIG /*@unused@*/ changedata)
 {
 	REGISTER ARCINST *ai;
 
-	if ((type&VTYPE) != VARCINST) return(1);
+	if ((type&VTYPE) != VARCINST) return(TRUE);
 	ai = (ARCINST *)addr;
-	if (ai == NOARCINST) return(1);
+	if (ai == NOARCINST) return(TRUE);
 	switch (changetype)
 	{
 		case CHANGETYPERIGID:				/* arc rigid */
-			if ((ai->userbits & FIXED) != 0) return(1);
+			if ((ai->userbits & FIXED) != 0) return(TRUE);
 			(void)setval((INTBIG)ai, VARCINST, "userbits", ai->userbits|FIXED, VINTEGER);
 			break;
 		case CHANGETYPEUNRIGID:				/* arc un-rigid */
-			if ((ai->userbits & FIXED) == 0) return(1);
+			if ((ai->userbits & FIXED) == 0) return(TRUE);
 			(void)setval((INTBIG)ai, VARCINST, "userbits", ai->userbits & ~FIXED, VINTEGER);
 			break;
 		case CHANGETYPEFIXEDANGLE:			/* arc fixed-angle */
-			if ((ai->userbits & FIXANG) != 0) return(1);
+			if ((ai->userbits & FIXANG) != 0) return(TRUE);
 			(void)setval((INTBIG)ai, VARCINST, "userbits", ai->userbits|FIXANG, VINTEGER);
 			break;
 		case CHANGETYPENOTFIXEDANGLE:		/* arc not fixed-angle */
-			if ((ai->userbits & FIXANG) == 0) return(1);
+			if ((ai->userbits & FIXANG) == 0) return(TRUE);
 			(void)setval((INTBIG)ai, VARCINST, "userbits", ai->userbits & ~FIXANG, VINTEGER);
 			break;
 		case CHANGETYPESLIDABLE:			/* arc slidable */
-			if ((ai->userbits & CANTSLIDE) == 0) return(1);
+			if ((ai->userbits & CANTSLIDE) == 0) return(TRUE);
 			(void)setval((INTBIG)ai, VARCINST, "userbits", ai->userbits & ~CANTSLIDE, VINTEGER);
 			break;
 		case CHANGETYPENOTSLIDABLE:			/* arc nonslidable */
-			if ((ai->userbits & CANTSLIDE) != 0) return(1);
+			if ((ai->userbits & CANTSLIDE) != 0) return(TRUE);
 			(void)setval((INTBIG)ai, VARCINST, "userbits", ai->userbits|CANTSLIDE, VINTEGER);
 			break;
 		case CHANGETYPETEMPRIGID:			/* arc temporarily rigid */
-			if (ai->changed == cla_changeclock + 2) return(1);
+			if (ai->changed == cla_changeclock + 2) return(TRUE);
 			ai->changed = cla_changeclock + 2;
 			break;
 		case CHANGETYPETEMPUNRIGID:			/* arc temporarily un-rigid */
-			if (ai->changed == cla_changeclock + 3) return(1);
+			if (ai->changed == cla_changeclock + 3) return(TRUE);
 			ai->changed = cla_changeclock + 3;
 			break;
 		case CHANGETYPEREMOVETEMP:			/* remove temporarily state */
-			if (ai->changed != cla_changeclock + 3 && ai->changed != cla_changeclock + 2) return(1);
+			if (ai->changed != cla_changeclock + 3 && ai->changed != cla_changeclock + 2) return(TRUE);
 			ai->changed = cla_changeclock - 3;
 			break;
 	}
-	return(0);
+	return(FALSE);
 }
 
 void cla_layconmodifynodeinst(NODEINST *ni, INTBIG dlx, INTBIG dly, INTBIG dhx, INTBIG dhy,
-	INTSML drot, INTSML dtrans)
+	INTBIG drot, INTBIG dtrans)
 {
 	/* advance the change clock */
 	cla_changeclock += 4;
 
 	/* change the nodeinst */
-	if (cla_modifynodeinst(ni, dlx, dly, dhx, dhy, drot, dtrans, 0) != 0)
+	if (cla_modifynodeinst(ni, dlx, dly, dhx, dhy, drot, dtrans, FALSE))
 		db_forcehierarchicalanalysis(ni->parent);
 
 	/* change the arcs on the nodeinst */
@@ -350,17 +352,47 @@ void cla_layconmodifynodeinst(NODEINST *ni, INTBIG dlx, INTBIG dly, INTBIG dhx,
 		db_forcehierarchicalanalysis(ni->parent);
 }
 
-void cla_layconmodifyarcinst(ARCINST *ai, INTBIG oldx0, INTBIG oldy0, INTBIG oldx1,
-	INTBIG oldy1, INTBIG oldwid, INTBIG oldlen) {}
-void cla_layconmodifyportproto(PORTPROTO *pp, NODEINST *oni, PORTPROTO *opp) {}
-void cla_layconmodifynodeproto(NODEPROTO *np) {}
-void cla_layconnewlib(LIBRARY *lib) {}
-void cla_layconkilllib(LIBRARY *lib) {}
-void cla_layconkillvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG saddr,
-	INTBIG stype, UINTBIG *olddes) {}
-void cla_layconinsertvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG aindex) {}
-void cla_laycondeletevariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG aindex,
-	INTBIG oldval) {}
+void cla_layconmodifynodeinsts(INTBIG count, NODEINST **nis, INTBIG *dlxs, INTBIG *dlys,
+	INTBIG *dhxs, INTBIG *dhys, INTBIG *drots, INTBIG *dtranss)
+{
+	REGISTER INTBIG i;
+	REGISTER NODEPROTO *parent;
+
+	/* advance the change clock */
+	cla_changeclock += 4;
+
+	/* change the nodeinst */
+	parent = NONODEPROTO;
+	for(i=0; i<count; i++)
+	{
+		if (cla_modifynodeinst(nis[i], dlxs[i], dlys[i], dhxs[i], dhys[i],
+			drots[i], dtranss[i], FALSE)) parent = nis[i]->parent;
+	}
+
+	/* change the arcs on the nodeinst */
+	for(i=0; i<count; i++)
+	{
+		if (cla_modnodearcs(nis[i], drots[i], dtranss[i]))
+			parent = nis[i]->parent;
+	}
+	if (parent != NONODEPROTO) db_forcehierarchicalanalysis(parent);
+}
+
+void cla_layconmodifyarcinst(ARCINST /*@unused@*/ *ai, INTBIG /*@unused@*/ oldx0,
+	INTBIG /*@unused@*/ oldy0, INTBIG /*@unused@*/ oldx1,
+	INTBIG /*@unused@*/ oldy1, INTBIG /*@unused@*/ oldwid, INTBIG /*@unused@*/ oldlen) {}
+void cla_layconmodifyportproto(PORTPROTO /*@unused@*/ *pp, NODEINST /*@unused@*/ *oni,
+	PORTPROTO /*@unused@*/ *opp) {}
+void cla_layconmodifynodeproto(NODEPROTO /*@unused@*/ *np) {}
+void cla_layconnewlib(LIBRARY /*@unused@*/ *lib) {}
+void cla_layconkilllib(LIBRARY /*@unused@*/ *lib) {}
+void cla_layconkillvariable(INTBIG /*@unused@*/ addr, INTBIG /*@unused@*/ type,
+	INTBIG /*@unused@*/ key, INTBIG /*@unused@*/ saddr,
+	INTBIG /*@unused@*/ stype, UINTBIG /*@unused@*/ *olddes) {}
+void cla_layconinsertvariable(INTBIG /*@unused@*/ addr, INTBIG /*@unused@*/ type,
+	INTBIG /*@unused@*/ key, INTBIG /*@unused@*/ aindex) {}
+void cla_laycondeletevariable(INTBIG /*@unused@*/ addr, INTBIG /*@unused@*/ type,
+	INTBIG /*@unused@*/ key, INTBIG /*@unused@*/ aindex, INTBIG /*@unused@*/ oldval) {}
 void cla_layconsetvariable(void) {}
 
 /******************** TEXT MODIFICATION CODE *************************/
@@ -439,16 +471,16 @@ void cla_layconmodifydescript(INTBIG addr, INTBIG type, INTBIG key, UINTBIG *old
 /*
  * routine to modify nodeinst "ni" by "deltalx" in low X, "deltaly" in low Y,
  * "deltahx" in high X, "deltahy" in high Y, and "dangle" tenth-degrees.  If
- * "announce" is nonzero, report "start" and "end" changes on the node.
+ * "announce" is true, report "start" and "end" changes on the node.
  * If the nodeinst is a portproto of the current facet and has any arcs
  * connected to it, the routine returns nonzero to indicate that the outer
  * facet has ports that moved (the nodeinst has exports).
  */
-INTSML cla_modifynodeinst(NODEINST *ni, INTBIG deltalx, INTBIG deltaly, INTBIG deltahx,
-	INTBIG deltahy, INTSML dangle, INTSML dtrans, INTSML announce)
+BOOLEAN cla_modifynodeinst(NODEINST *ni, INTBIG deltalx, INTBIG deltaly, INTBIG deltahx,
+	INTBIG deltahy, INTBIG dangle, INTBIG dtrans, BOOLEAN announce)
 {
-	REGISTER INTBIG oldlx, oldly, oldhx, oldhy;
-	REGISTER INTSML oldang, oldtrans, change;
+	REGISTER INTBIG oldlx, oldly, oldhx, oldhy, change;
+	REGISTER INTSML oldang, oldtrans;
 
 	/* determine whether this is a position or size change */
 	if (deltalx == deltahx && deltaly == deltahy)
@@ -458,12 +490,12 @@ INTSML cla_modifynodeinst(NODEINST *ni, INTBIG deltalx, INTBIG deltaly, INTBIG d
 	} else change = -1;
 
 	/* reject if this change has already been done */
-	if (ni->changed >= cla_changeclock+change) return(0);
+	if (ni->changed >= cla_changeclock+change) return(FALSE);
 
 	/* if simple rotation on transposed nodeinst, reverse rotation */
 	if (ni->transpose != 0 && dtrans == 0) dangle = (3600 - dangle) % 3600;
 
-	if (ni->changed < cla_changeclock-1 && announce != 0)
+	if (ni->changed < cla_changeclock-1 && announce)
 		(void)db_change((INTBIG)ni, OBJECTSTART, VNODEINST, 0, 0, 0, 0, 0);
 
 	/* make changes to the nodeinst */
@@ -475,9 +507,9 @@ INTSML cla_modifynodeinst(NODEINST *ni, INTBIG deltalx, INTBIG deltaly, INTBIG d
 	oldhy = ni->highy;         ni->highy += deltahy;
 	updategeom(ni->geom, ni->parent);
 
-#ifdef DEBUG
+#ifdef CLA_DEBUG
 	if (cla_conlaydebug)
-		ttyputmsg(M_("Change node %s by X(%s %s) Y(%s %s) r=%d t=%d"),
+		ttyputmsg(M_("Change node %s by X(%s %s) Y(%s %s) r=%ld t=%ld"),
 			describenodeinst(ni), latoa(deltalx), latoa(deltahx), latoa(deltaly),
 				latoa(deltahy), dangle, dtrans);
 #endif
@@ -487,15 +519,15 @@ INTSML cla_modifynodeinst(NODEINST *ni, INTBIG deltalx, INTBIG deltaly, INTBIG d
 	{
 		ni->changeaddr = (char *)db_change((INTBIG)ni, NODEINSTMOD, oldlx,
 			oldly, oldhx, oldhy, oldang, oldtrans);
-		if (announce != 0)
+		if (announce)
 			(void)db_change((INTBIG)ni, OBJECTEND, VNODEINST, 0, 0, 0, 0, 0);
 	}
 
 	ni->changed = cla_changeclock + change;
 
 	/* see if this nodeinst is a port of the current facet */
-	if (ni->firstportexpinst == NOPORTEXPINST) return(0);
-	return(1);
+	if (ni->firstportexpinst == NOPORTEXPINST) return(FALSE);
+	return(TRUE);
 }
 
 /*
@@ -504,21 +536,21 @@ INTSML cla_modifynodeinst(NODEINST *ni, INTBIG deltalx, INTBIG deltaly, INTBIG d
  * some ports on the current facet have moved and the facet must be
  * re-examined for portproto locations.
  */
-INTSML cla_modnodearcs(NODEINST *ni, INTSML dangle, INTSML dtrans)
+BOOLEAN cla_modnodearcs(NODEINST *ni, INTBIG dangle, INTBIG dtrans)
 {
-	REGISTER INTSML examinefacet;
+	REGISTER BOOLEAN examinefacet;
 
 	/* assume facet needs no further looks */
-	examinefacet = 0;
+	examinefacet = FALSE;
 
 	/* next look at arcs that run within this nodeinst */
 	cla_modwithin(ni, dangle, dtrans);
 
 	/* next look at the rest of the rigid arcs on this nodeinst */
-	if (cla_modrigid(ni, dangle, dtrans)) examinefacet++;
+	if (cla_modrigid(ni, dangle, dtrans)) examinefacet = TRUE;
 
 	/* finally, look at rest of the flexible arcs on this nodeinst */
-	if (cla_modflex(ni, dangle, dtrans)) examinefacet++;
+	if (cla_modflex(ni, dangle, dtrans)) examinefacet = TRUE;
 
 	return(examinefacet);
 }
@@ -526,12 +558,11 @@ INTSML cla_modnodearcs(NODEINST *ni, INTSML dangle, INTSML dtrans)
 /*
  * routine to modify the arcs that run within nodeinst "ni"
  */
-void cla_modwithin(NODEINST *ni, INTSML dangle, INTSML dtrans)
+void cla_modwithin(NODEINST *ni, INTBIG dangle, INTBIG dtrans)
 {
 	REGISTER PORTARCINST *pi;
 	REGISTER ARCINST *ai;
-	REGISTER INTBIG ox,oy;
-	REGISTER INTSML i, total;
+	REGISTER INTBIG ox, oy, i, total;
 	INTBIG nox, noy, onox, onoy;
 	XARRAY trans;
 
@@ -587,7 +618,7 @@ void cla_modwithin(NODEINST *ni, INTSML dangle, INTSML dtrans)
 		xform(ai->end[0].xpos-ox, ai->end[0].ypos-oy, &nox, &noy, trans);
 		cla_adjustmatrix(ni, ai->end[1].portarcinst->proto, trans);
 		xform(ai->end[1].xpos-ox, ai->end[1].ypos-oy, &onox, &onoy, trans);
-#ifdef	DEBUG
+#ifdef	CLA_DEBUG
 		if (cla_conlaydebug)
 			ttyputmsg(M_("Internal arc %s moves 0:%s,%s  1:%s,%s"),
 				describearcinst(ai), latoa(nox), latoa(noy), latoa(onox), latoa(onoy));
@@ -603,7 +634,7 @@ void cla_modwithin(NODEINST *ni, INTSML dangle, INTSML dtrans)
  * current facet change position, the routine returns nonzero to indicate
  * that instances of the current facet must be examined for arcinst motion.
  */
-INTSML cla_modrigid(NODEINST *ni, INTSML dangle, INTSML dtrans)
+BOOLEAN cla_modrigid(NODEINST *ni, INTBIG dangle, INTBIG dtrans)
 {
 	REGISTER PORTPROTO *opt;
 	REGISTER PORTARCINST *pi;
@@ -611,9 +642,9 @@ INTSML cla_modrigid(NODEINST *ni, INTSML dangle, INTSML dtrans)
 	REGISTER NODEINST *ono;
 	INTBIG ax[2], ay[2], onox, onoy, dx, dy;
 	XARRAY trans;
-	INTSML i, total, nextangle;
-	REGISTER INTBIG othx, othy, ox, oy;
-	REGISTER INTSML thisend, thatend, examinefacet, locked;
+	REGISTER INTBIG othx, othy, ox, oy, i, total, thisend, thatend;
+	REGISTER INTBIG nextangle;
+	REGISTER BOOLEAN examinefacet, locked;
 
 	/* build a list of the rigid arcs on this nodeinst */
 	total = 0;
@@ -625,9 +656,9 @@ INTSML cla_modrigid(NODEINST *ni, INTSML dangle, INTSML dtrans)
 		if (ai->changed != cla_changeclock-2 && (ai->userbits&FIXED) == 0) continue;
 		total++;
 	}
-	if (total == 0) return(0);
+	if (total == 0) return(FALSE);
 	arclist = (ARCINST **)emalloc(total * (sizeof (ARCINST *)), el_tempcluster);
-	if (arclist == 0) return(0);
+	if (arclist == 0) return(FALSE);
 	i = 0;
 	for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 	{
@@ -648,7 +679,7 @@ INTSML cla_modrigid(NODEINST *ni, INTSML dangle, INTSML dtrans)
 	makeangle(nextangle, dtrans, trans);
 
 	/* look for rigid arcs on this nodeinst */
-	examinefacet = 0;
+	examinefacet = FALSE;
 	for(i=0; i<total; i++)
 	{
 		ai = arclist[i];
@@ -681,7 +712,7 @@ INTSML cla_modrigid(NODEINST *ni, INTSML dangle, INTSML dtrans)
 
 		ono = ai->end[thatend].nodeinst;
 		opt = ai->end[thatend].portarcinst->proto;
-#ifdef	DEBUG
+#ifdef	CLA_DEBUG
 		if (cla_conlaydebug)
 			ttyputmsg(M_("Modify rigid arc %s from %s to %s"),
 				describearcinst(ai), describenodeinst(ni), describenodeinst(ono));
@@ -690,25 +721,24 @@ INTSML cla_modrigid(NODEINST *ni, INTSML dangle, INTSML dtrans)
 		/* figure out the new location of that arcinst connection */
 		xform(ai->end[thatend].xpos-ox, ai->end[thatend].ypos-oy, &ax[thatend],
 			&ay[thatend], trans);
-#ifdef	DEBUG
+#ifdef	CLA_DEBUG
 		if (cla_conlaydebug)
 			ttyputmsg(M_("Other end of arc moves to (%s,%s)"),
 				latoa(ax[thatend]), latoa(ay[thatend]));
 #endif
 
 		/* see if other nodeinst has changed */
-		locked = 0;
-		if (ono->changed == cla_changeclock) locked++;
+		locked = FALSE;
+		if (ono->changed == cla_changeclock) locked = TRUE;
 		if (ono->proto->primindex == 0)
 		{
-			if ((us_useroptions&NOFACETCHANGES) != 0) locked++;
-			if ((ono->parent->userbits&NILOCKED) != 0) locked++;
+			if ((ono->parent->userbits&NILOCKED) != 0) locked = TRUE;
 		} else
 		{
 			if ((us_useroptions&NOPRIMCHANGES) != 0 &&
-				(ono->proto->userbits&LOCKEDPRIM) != 0) locked++;
+				(ono->proto->userbits&LOCKEDPRIM) != 0) locked = TRUE;
 		}
-		if (locked == 0)
+		if (!locked)
 		{
 			/* compute port motion within the other nodeinst (is this right? !!!) */
 			cla_oldportposition(ono, opt, &onox, &onoy);
@@ -731,12 +761,13 @@ INTSML cla_modrigid(NODEINST *ni, INTSML dangle, INTSML dtrans)
 			if (dx != 0 || dy != 0 || nextangle != 0 || dtrans != 0 || ono->changed != cla_changeclock-1)
 			{
 				ai->userbits |= FIXEDMOD;
-				if (cla_modifynodeinst(ono, dx, dy, dx, dy, nextangle, dtrans, 1)) examinefacet++;
+				if (cla_modifynodeinst(ono, dx, dy, dx, dy, nextangle, dtrans, TRUE))
+					examinefacet = TRUE;
 			}
 		}
 
 		/* move the arcinst */
-#ifdef	DEBUG
+#ifdef	CLA_DEBUG
 		if (cla_conlaydebug)
 			ttyputmsg(M_("Now arc runs from (%s,%s) to (%s,%s)"),
 				latoa(ax[0]), latoa(ay[0]), latoa(ax[1]), latoa(ay[1]));
@@ -760,7 +791,7 @@ INTSML cla_modrigid(NODEINST *ni, INTSML dangle, INTSML dtrans)
 		nextangle = dangle;
 		if (dtrans != 0 && ((CHANGE *)ono->changeaddr)->p6 != ((CHANGE *)ni->changeaddr)->p6)
 			nextangle = (3600 - nextangle) % 3600;
-		if (cla_modnodearcs(ono, nextangle, dtrans)) examinefacet++;
+		if (cla_modnodearcs(ono, nextangle, dtrans)) examinefacet = TRUE;
 	}
 	efree((char *)arclist);
 	return(examinefacet);
@@ -771,16 +802,15 @@ INTSML cla_modrigid(NODEINST *ni, INTSML dangle, INTSML dtrans)
  * nodes that are ports move, the routine returns nonzero to indicate that
  * instances of the current facet must be examined for arcinst motion
  */
-INTSML cla_modflex(NODEINST *ni, INTSML dangle, INTSML dtrans)
+BOOLEAN cla_modflex(NODEINST *ni, INTBIG dangle, INTBIG dtrans)
 {
 	REGISTER PORTARCINST *pi;
 	REGISTER ARCINST *ai, **arclist;
 	REGISTER NODEINST *ono;
-	REGISTER INTSML thisend, thatend, examinefacet, mangle, nextangle;
-	REGISTER INTBIG ox, oy;
+	REGISTER INTBIG i, total, ox, oy, odx, ody, thisend, thatend, mangle;
+	REGISTER INTBIG nextangle;
+	REGISTER BOOLEAN examinefacet;
 	XARRAY trans;
-	REGISTER INTBIG odx, ody;
-	REGISTER INTSML i, total;
 	INTBIG ax[2], ay[2], dx, dy, lx, hx, ly, hy;
 	static POLYGON *poly = NOPOLYGON;
 
@@ -794,9 +824,9 @@ INTSML cla_modflex(NODEINST *ni, INTSML dangle, INTSML dtrans)
 		if (ai->changed != cla_changeclock-1 && (ai->userbits&FIXED) != 0) continue;
 		total++;
 	}
-	if (total == 0) return(0);
+	if (total == 0) return(FALSE);
 	arclist = (ARCINST **)emalloc(total * (sizeof (ARCINST *)), el_tempcluster);
-	if (arclist == 0) return(0);
+	if (arclist == 0) return(FALSE);
 	i = 0;
 	for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 	{
@@ -817,17 +847,17 @@ INTSML cla_modflex(NODEINST *ni, INTSML dangle, INTSML dtrans)
 	makeangle(nextangle, dtrans, trans);
 
 	/* look at all of the flexible arcs on this nodeinst */
-	examinefacet = 0;
+	examinefacet = FALSE;
 	for(i=0; i<total; i++)
 	{
 		ai = arclist[i];
 		if ((ai->userbits&DEADA) != 0) continue;
 
 		/* if flexible arcinst has been changed, verify its connectivity */
-#ifdef	DEBUG
+#ifdef	CLA_DEBUG
 		if (cla_conlaydebug)
 		{
-			ttyputmsg(M_("Considering arc %s (clock=%d, curclock=%d)"),
+			ttyputmsg(M_("Considering arc %s (clock=%ld, curclock=%ld)"),
 				describearcinst(ai), ai->changed, cla_changeclock+1);
 		}
 #endif
@@ -845,7 +875,7 @@ INTSML cla_modflex(NODEINST *ni, INTSML dangle, INTSML dtrans)
 
 		/* if nodeinst motion stays within port area, ignore the arcinst */
 		if ((ai->userbits&CANTSLIDE) == 0 &&
-			db_stillinport(ai, thisend, ai->end[thisend].xpos, ai->end[thisend].ypos) != 0)
+			db_stillinport(ai, thisend, ai->end[thisend].xpos, ai->end[thisend].ypos))
 				continue;
 
 		if (((CHANGE *)ni->changeaddr)->changetype == NODEINSTNEW) ox = oy = 0; else
@@ -862,10 +892,8 @@ INTSML cla_modflex(NODEINST *ni, INTSML dangle, INTSML dtrans)
 		/* make sure the arc end is still in the port */
 		if (poly == NOPOLYGON) poly = allocstaticpolygon(4, db_cluster);
 		shapeportpoly(ai->end[thisend].nodeinst, ai->end[thisend].portarcinst->proto,
-			poly, 0);
-		reduceportpoly(poly, ai->end[thisend].nodeinst, ai->end[thisend].portarcinst->proto,
-			ai->width - arcwidthoffset(ai));
-		if (isinside(ax[thisend], ay[thisend], poly) == 0)
+			poly, FALSE);
+		if (!isinside(ax[thisend], ay[thisend], poly))
 		{
 			getbbox(poly, &lx, &hx, &ly, &hy);
 			if (ay[thisend] >= ly && ay[thisend] <= hy)
@@ -889,7 +917,7 @@ INTSML cla_modflex(NODEINST *ni, INTSML dangle, INTSML dtrans)
 		ono = ai->end[thatend].nodeinst;
 		ax[thatend] = ai->end[thatend].xpos;
 		ay[thatend] = ai->end[thatend].ypos;
-#ifdef	DEBUG
+#ifdef	CLA_DEBUG
 		if (cla_conlaydebug)
 		{
 			ttyputmsg(M_("Modify flexible arc %s from %s to %s"),
@@ -902,7 +930,6 @@ INTSML cla_modflex(NODEINST *ni, INTSML dangle, INTSML dtrans)
 		if ((ai->userbits&FIXANG) == 0) mangle = 0;
 		if (ono->proto->primindex == 0)
 		{
-			if ((us_useroptions&NOFACETCHANGES) != 0) mangle = 0;
 			if ((ono->parent->userbits&NILOCKED) != 0) mangle = 0;
 		} else
 		{
@@ -931,24 +958,25 @@ INTSML cla_modflex(NODEINST *ni, INTSML dangle, INTSML dtrans)
 
 					/* see if next nodeinst need not be moved */
 					if (dx != odx && (ai->userbits&CANTSLIDE) == 0 &&
-						db_stillinport(ai, thatend, ax[thatend], ay[thatend]) != 0)
+						db_stillinport(ai, thatend, ax[thatend], ay[thatend]))
 							dx = odx = 0;
 
 					/* if other node already moved, don't move it any more */
 					if (ono->changed >= cla_changeclock) dx = odx = 0;
 
-#ifdef	DEBUG
+#ifdef	CLA_DEBUG
 					if (cla_conlaydebug)
 						ttyputmsg(M_("  Moving other end of arc to (%s,%s), other node by (%s,0)"),
 							latoa(ax[thatend]), latoa(ay[thatend]), latoa(dx-odx));
 #endif
 					if (dx != odx)
 					{
-						if (cla_modifynodeinst(ono, dx-odx, 0, dx-odx, 0, 0, 0, 1)) examinefacet++;
+						if (cla_modifynodeinst(ono, dx-odx, 0, dx-odx, 0, 0, 0, TRUE))
+							examinefacet = TRUE;
 					}
 					cla_domovearcinst(ai, ax[0],ay[0], ax[1],ay[1], 1);
 					if (dx != odx)
-						if (cla_modnodearcs(ono, 0, 0)) examinefacet++;
+						if (cla_modnodearcs(ono, 0, 0)) examinefacet = TRUE;
 					continue;
 				}
 			}
@@ -962,23 +990,24 @@ INTSML cla_modflex(NODEINST *ni, INTSML dangle, INTSML dtrans)
 
 				/* see if next nodeinst need not be moved */
 				if (dy != ody && (ai->userbits&CANTSLIDE) == 0 &&
-					db_stillinport(ai, thatend, ax[thatend], ay[thatend]) != 0)
+					db_stillinport(ai, thatend, ax[thatend], ay[thatend]))
 						dy = ody = 0;
 
 				/* if other node already moved, don't move it any more */
 				if (ono->changed >= cla_changeclock) dx = odx = 0;
 
-#ifdef	DEBUG
+#ifdef	CLA_DEBUG
 				if (cla_conlaydebug)
 					ttyputmsg(M_("  Moving other end of arc to (%s,%s), other node by (0,%s)"),
 						latoa(ax[thatend]), latoa(ay[thatend]), latoa(dy-ody));
 #endif
 				if (dy != ody)
 				{
-					if (cla_modifynodeinst(ono, 0, dy-ody, 0, dy-ody, 0, 0, 1)) examinefacet++;
+					if (cla_modifynodeinst(ono, 0, dy-ody, 0, dy-ody, 0, 0, TRUE))
+						examinefacet = TRUE;
 				}
 				cla_domovearcinst(ai, ax[0],ay[0], ax[1],ay[1], 1);
-				if (dy != ody) if (cla_modnodearcs(ono, 0, 0)) examinefacet++;
+				if (dy != ody) if (cla_modnodearcs(ono, 0, 0)) examinefacet = TRUE;
 				continue;
 			}
 
@@ -997,14 +1026,15 @@ INTSML cla_modflex(NODEINST *ni, INTSML dangle, INTSML dtrans)
 
 			if (dx != 0 || dy != 0)
 			{
-				if (cla_modifynodeinst(ono, dx, dy, dx, dy, 0, 0, 1)) examinefacet++;
-				if (cla_modnodearcs(ono, 0, 0)) examinefacet++;
+				if (cla_modifynodeinst(ono, dx, dy, dx, dy, 0, 0, TRUE))
+					examinefacet = TRUE;
+				if (cla_modnodearcs(ono, 0, 0)) examinefacet = TRUE;
 			}
 			continue;
 		}
 
 		/* other node has changed or arc is funny, just use its position */
-#ifdef	DEBUG
+#ifdef	CLA_DEBUG
 		if (cla_conlaydebug)
 			ttyputmsg(M_("  ! Moving arc %s to (%s,%s)-(%s,%s)"), describearcinst(ai),
 				latoa(ax[0]), latoa(ay[0]), latoa(ax[1]), latoa(ay[1]));
@@ -1020,7 +1050,7 @@ INTSML cla_modflex(NODEINST *ni, INTSML dangle, INTSML dtrans)
  * its "thisend" end has moved to (ax[thisend],ay[thisend]) and its other end must be
  * determined in (ax[thatend],ay[thatend]).  The node on the other end is "ono".
  */
-void cla_nonorthogfixang(ARCINST *ai, INTSML thisend, INTSML thatend, NODEINST *ono,
+void cla_nonorthogfixang(ARCINST *ai, INTBIG thisend, INTBIG thatend, NODEINST *ono,
 	INTBIG ax[2], INTBIG ay[2])
 {
 	REGISTER PORTARCINST *pi;
@@ -1065,35 +1095,31 @@ void cla_nonorthogfixang(ARCINST *ai, INTSML thisend, INTSML thatend, NODEINST *
  * end.  If it is not, it must be jogged or adjusted.  The nature of the
  * arcinst is in "arctyp" (0 for rigid, 1 for flexible)
  */
-void cla_ensurearcinst(ARCINST *ai, INTSML arctyp)
+void cla_ensurearcinst(ARCINST *ai, INTBIG arctyp)
 {
-	REGISTER INTBIG wid;
-	REGISTER INTSML inside0, inside1;
-	INTBIG lx0,lx1,hx0,hx1, ly0,ly1,hy0,hy1, fx, fy, tx, ty;
+	REGISTER BOOLEAN inside0, inside1;
+	INTBIG lx0, lx1, hx0, hx1, ly0, ly1, hy0, hy1, fx, fy, tx, ty;
 	static POLYGON *poly0 = NOPOLYGON, *poly1 = NOPOLYGON;
 
 	/* if nothing is outside port, quit */
 	inside0 = db_stillinport(ai, 0, ai->end[0].xpos, ai->end[0].ypos);
 	inside1 = db_stillinport(ai, 1, ai->end[1].xpos, ai->end[1].ypos);
-	if (inside0 != 0 && inside1 != 0) return;
+	if (inside0 && inside1) return;
 
 	/* make sure there is a polygon */
 	if (poly0 == NOPOLYGON) poly0 = allocstaticpolygon(4, cla_constraint->cluster);
 	if (poly1 == NOPOLYGON) poly1 = allocstaticpolygon(4, cla_constraint->cluster);
 
 	/* get area of the ports */
-	wid = ai->width - arcwidthoffset(ai);
-	shapeportpoly(ai->end[0].nodeinst, ai->end[0].portarcinst->proto, poly0, 0);
-	reduceportpoly(poly0, ai->end[0].nodeinst, ai->end[0].portarcinst->proto, wid);
-	shapeportpoly(ai->end[1].nodeinst, ai->end[1].portarcinst->proto, poly1, 0);
-	reduceportpoly(poly1, ai->end[1].nodeinst, ai->end[1].portarcinst->proto, wid);
+	shapeportpoly(ai->end[0].nodeinst, ai->end[0].portarcinst->proto, poly0, FALSE);
+	shapeportpoly(ai->end[1].nodeinst, ai->end[1].portarcinst->proto, poly1, FALSE);
 
 	/* if arcinst is not fixed-angle, run it directly to the port centers */
 	if ((ai->userbits&FIXANG) == 0)
 	{
 		getcenter(poly0, &fx, &fy);
 		getcenter(poly1, &tx, &ty);
-#ifdef	DEBUG
+#ifdef	CLA_DEBUG
 		if (cla_conlaydebug)
 			ttyputmsg(M_("Ensuring rigid arc %s"), describearcinst(ai));
 #endif
@@ -1113,7 +1139,7 @@ void cla_ensurearcinst(ARCINST *ai, INTSML arctyp)
 		fy = (ly0+hy0) / 2;   ty = (ly1+hy1) / 2;
 		closestpoint(poly0, &fx, &fy);
 		closestpoint(poly1, &tx, &ty);
-#ifdef	DEBUG
+#ifdef	CLA_DEBUG
 		if (cla_conlaydebug)
 			ttyputmsg(M_("Ensuring manhattan arc %s"), describearcinst(ai));
 #endif
@@ -1127,7 +1153,7 @@ void cla_ensurearcinst(ARCINST *ai, INTSML arctyp)
 		fx = (lx0+hx0) / 2;   tx = (lx1+hx1) / 2;
 		closestpoint(poly0, &fx, &fy);
 		closestpoint(poly1, &tx, &ty);
-#ifdef	DEBUG
+#ifdef	CLA_DEBUG
 		if (cla_conlaydebug)
 			ttyputmsg(M_("Ensuring manhattan arc %s"), describearcinst(ai));
 #endif
@@ -1145,7 +1171,7 @@ void cla_ensurearcinst(ARCINST *ai, INTSML arctyp)
  * routine to update arc "ai" so that its ends run from (fx,fy) to (tx,ty).
  * The type of the arc is in "arctyp" for marking the change.
  */
-void cla_updatearc(ARCINST *ai, INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty, INTSML arctyp)
+void cla_updatearc(ARCINST *ai, INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty, INTBIG arctyp)
 {
 	REGISTER INTBIG oldxA, oldyA, oldxB, oldyB, oldlen;
 
@@ -1157,7 +1183,7 @@ void cla_updatearc(ARCINST *ai, INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty, INTS
 	oldlen = ai->length;
 
 	/* set the proper arcinst position */
-#ifdef DEBUG
+#ifdef CLA_DEBUG
 	if (cla_conlaydebug)
 		ttyputmsg(M_("Change arc %s from (%s,%s)-(%s,%s) to (%s,%s)-(%s,%s)"),
 			describearcinst(ai), latoa(ai->end[0].xpos), latoa(ai->end[0].ypos),
@@ -1170,7 +1196,7 @@ void cla_updatearc(ARCINST *ai, INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty, INTS
 	ai->end[1].ypos = ty;
 	ai->length = computedistance(fx,fy, tx,ty);
 	determineangle(ai);
-	(void)setshrinkvalue(ai, 1);
+	(void)setshrinkvalue(ai, TRUE);
 	updategeom(ai->geom, ai->parent);
 
 	/* see if the arc has changed before */
@@ -1184,14 +1210,14 @@ void cla_updatearc(ARCINST *ai, INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty, INTS
 	(void)db_change((INTBIG)ai, OBJECTEND, VARCINST, 0, 0, 0, 0, 0);
 }
 
-void cla_domovearcinst(ARCINST *ai, INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty, INTSML arctyp)
+void cla_domovearcinst(ARCINST *ai, INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty, INTBIG arctyp)
 {
 	REGISTER NODEPROTO *np, *pnt;
 	REGISTER ARCPROTO *ap;
 	REGISTER ARCINST *ar1, *ar2, *ar3;
 	REGISTER PORTPROTO *pp, *fpt, *tpt;
 	REGISTER NODEINST *no1, *no2, *fno, *tno;
-	REGISTER INTBIG oldxA, oldyA, oldxB, oldyB, wid, oldbits, lx,hx, ly,hy;
+	REGISTER INTBIG oldxA, oldyA, oldxB, oldyB, wid, oldbits, lx, hx, ly, hy;
 	INTBIG psx, psy;
 
 	/* check for null arcinst motion */
@@ -1212,7 +1238,7 @@ void cla_domovearcinst(ARCINST *ai, INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty,
 		cla_updatearc(ai, fx, fy, tx, ty, arctyp);
 		return;
 	}
-#ifdef	DEBUG
+#ifdef	CLA_DEBUG
 	if (cla_conlaydebug)
 	{
 		ttyputmsg(M_("Jogging arc %s (0%o) to run from (%s,%s) to (%s,%s)"),
@@ -1323,7 +1349,7 @@ void cla_adjustmatrix(NODEINST *ni, PORTPROTO *pp, XARRAY trans)
 		portposition(ni, pp, &dx, &dy);
 		ox = (((CHANGE *)ni->changeaddr)->p1 + ((CHANGE *)ni->changeaddr)->p3) / 2;
 		oy = (((CHANGE *)ni->changeaddr)->p2 + ((CHANGE *)ni->changeaddr)->p4) / 2;
-#ifdef	DEBUG
+#ifdef	CLA_DEBUG
 		if (cla_conlaydebug)
 		{
 			ttyputmsg(M_("Node %s port %s was at (%s,%s), is at (%s,%s)"), describenodeinst(ni),
@@ -1348,7 +1374,7 @@ void cla_adjustmatrix(NODEINST *ni, PORTPROTO *pp, XARRAY trans)
  */
 void cla_oldportposition(NODEINST *ni, PORTPROTO *pp, INTBIG *x, INTBIG *y)
 {
-	REGISTER INTBIG lox,hix,loy,hiy;
+	REGISTER INTBIG lox, hix, loy, hiy;
 	XARRAY localtran, subrot, temptr;
 	static POLYGON *poly = NOPOLYGON;
 
@@ -1434,7 +1460,7 @@ void cla_makeoldrot(NODEINST *ni, XARRAY trans)
 
 void cla_makeoldtrans(NODEINST *ni, XARRAY trans)
 {
-	REGISTER INTBIG nlx,nly,nhx,nhy, ntlx,ntly,nthx,nthy;
+	REGISTER INTBIG nlx, nly, nhx, nhy, ntlx, ntly, nthx, nthy;
 	REGISTER NODEPROTO *np;
 
 	/* save values */
@@ -1477,23 +1503,23 @@ void cla_makeoldtrans(NODEINST *ni, XARRAY trans)
  * has been added or removed from it) and store these bounds in the nominal
  * size and the size of each instantiation of the facet.  It is also necessary
  * to re-position each instantiation of the facet in its proper position list.
- * If "forcedlook" is nonzero, the facet is re-examined regardless of
+ * If "forcedlook" is true, the facet is re-examined regardless of
  * whether its size changed.
  */
-void cla_computefacet(NODEPROTO *facet, INTSML forcedlook)
+void cla_computefacet(NODEPROTO *facet, BOOLEAN forcedlook)
 {
 	REGISTER NODEINST *ni, *lni;
 	REGISTER NODEPROTO *np, *oneparent;
-	INTBIG nlx,nhx, nly,nhy, offx, offy;
+	INTBIG nlx, nhx, nly, nhy, offx, offy;
 	XARRAY trans;
 	REGISTER INTBIG dlx, dly, dhx, dhy, flx, fhx, fly, fhy;
-	REGISTER INTSML mixed;
+	REGISTER BOOLEAN mixed;
 	REGISTER CHANGE *c;
 	REGISTER LIBRARY *lib;
 
-#ifdef	DEBUG
+#ifdef	CLA_DEBUG
 	if (cla_conlaydebug)
-		ttyputmsg(M_("In computefacet on facet %s (fl=%d)"),
+		ttyputmsg(M_("In computefacet on facet %s (fl=%ld)"),
 			facet->cell->cellname, forcedlook);
 #endif
 	/* get current boundary of facet */
@@ -1501,7 +1527,7 @@ void cla_computefacet(NODEPROTO *facet, INTSML forcedlook)
 
 	/* quit if it has not changed */
 	if (facet->lowx == nlx && facet->highx == nhx && facet->lowy == nly &&
-		facet->highy == nhy && forcedlook == 0) return;
+		facet->highy == nhy && !forcedlook) return;
 
 	/* advance the change clock */
 	cla_changeclock += 4;
@@ -1523,13 +1549,13 @@ void cla_computefacet(NODEPROTO *facet, INTSML forcedlook)
 	facet->changeaddr = (char *)db_change((INTBIG)facet, NODEPROTOMOD, flx, fhx, fly, fhy, 0, 0);
 
 	/* see if all instances of this facet are in the same location */
-	mixed = 0;
+	mixed = FALSE;
 	oneparent = NONODEPROTO;
 	lni = NONODEINST;
 	for(ni = facet->firstinst; ni != NONODEINST; ni = ni->nextinst)
 	{
 		oneparent = ni->parent;
-		if (lni != NONODEINST) if (ni->parent != lni->parent) mixed++;
+		if (lni != NONODEINST) if (ni->parent != lni->parent) mixed = TRUE;
 		lni = ni;
 	}
 
@@ -1537,9 +1563,9 @@ void cla_computefacet(NODEPROTO *facet, INTSML forcedlook)
 	if (oneparent == NONODEPROTO) return;
 
 	/* if all parent facets the same, make changes to the instances */
-	if (mixed == 0 && forcedlook == 0)
+	if (!mixed && !forcedlook)
 	{
-#ifdef	DEBUG
+#ifdef	CLA_DEBUG
 		if (cla_conlaydebug)
 			ttyputmsg(M_("   Recomputing uniform parents of facet %s"),
 				describenodeproto(facet));
@@ -1552,10 +1578,10 @@ void cla_computefacet(NODEPROTO *facet, INTSML forcedlook)
 			xform(dhx+dlx, dhy+dly, &offx, &offy, trans);
 			nlx = (dlx-dhx+offx)/2;  nhx = offx - nlx;
 			nly = (dly-dhy+offy)/2;  nhy = offy - nly;
-			if (cla_modifynodeinst(ni, nlx, nly, nhx, nhy, 0, 0, 1) != 0) forcedlook++;
+			if (cla_modifynodeinst(ni, nlx, nly, nhx, nhy, 0, 0, TRUE)) forcedlook = TRUE;
 		}
 		for(ni = facet->firstinst; ni != NONODEINST; ni = ni->nextinst)
-			if (cla_modnodearcs(ni, 0, 0)) forcedlook++;
+			if (cla_modnodearcs(ni, 0, 0)) forcedlook = TRUE;
 		cla_computefacet(oneparent, forcedlook);
 		return;
 	}
@@ -1564,7 +1590,7 @@ void cla_computefacet(NODEPROTO *facet, INTSML forcedlook)
 	 * if instances are scattered or port motion has occured, examine
 	 * entire database in proper recursive order and adjust facet sizes
 	 */
-#ifdef	DEBUG
+#ifdef	CLA_DEBUG
 	if (cla_conlaydebug)
 		ttyputmsg(M_("   Performing complex tree examination"));
 #endif
@@ -1583,12 +1609,12 @@ void cla_computefacet(NODEPROTO *facet, INTSML forcedlook)
 	}
 }
 
-INTSML cla_lookdown(NODEPROTO *start)
+BOOLEAN cla_lookdown(NODEPROTO *start)
 {
 	REGISTER NODEINST *ni;
 	REGISTER NODEPROTO *np;
 	REGISTER INTBIG dlx, dhx, dly, dhy, flx, fhx, fly, fhy;
-	REGISTER INTSML foundone, forcedlook;
+	REGISTER BOOLEAN forcedlook, foundone;
 	INTBIG nlx, nhx, nly, nhy, offx, offy;
 	XARRAY trans;
 
@@ -1597,10 +1623,10 @@ INTSML cla_lookdown(NODEPROTO *start)
 		if (ni->proto->primindex == 0) ni->userbits |= MARKN; else
 			ni->userbits &= ~MARKN;
 
-	foundone = 1;
-	while (foundone != 0)
+	foundone = TRUE;
+	while (foundone)
 	{
-		foundone = 0;
+		foundone = FALSE;
 		for(ni = start->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		{
 			if ((ni->userbits & MARKN) == 0) continue;
@@ -1618,7 +1644,7 @@ INTSML cla_lookdown(NODEPROTO *start)
 
 			/* look inside nodeinst to see if it changed */
 			if (cla_lookdown(np)) start->userbits |= FACETMOD;
-			foundone++;
+			foundone = TRUE;
 		}
 	}
 
@@ -1626,7 +1652,7 @@ INTSML cla_lookdown(NODEPROTO *start)
 	if ((start->userbits & FACETMOD) == 0)
 	{
 		start->userbits |= FACETNOMOD;
-		return(0);
+		return(FALSE);
 	}
 
 	/* mark those nodes that must change */
@@ -1639,16 +1665,16 @@ INTSML cla_lookdown(NODEPROTO *start)
 		if ((np->userbits & FACETMOD) == 0) continue;
 		ni->userbits |= MARKN | TOUCHN;
 	}
-#ifdef	DEBUG
+#ifdef	CLA_DEBUG
 	if (cla_conlaydebug)
 		ttyputmsg(M_("      Complex tree search at facet %s"), describenodeproto(start));
 #endif
 	/* modify the nodes in this facet that changed */
-	forcedlook = 0;
-	foundone = 1;
+	forcedlook = FALSE;
+	foundone = TRUE;
 	while (foundone)
 	{
-		foundone = 0;
+		foundone = FALSE;
 		for(ni = start->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		{
 			if ((ni->userbits & MARKN) == 0) continue;
@@ -1680,22 +1706,22 @@ INTSML cla_lookdown(NODEPROTO *start)
 				nlx = (dlx-dhx+offx)/2;  nhx = offx - nlx;
 				nly = (dly-dhy+offy)/2;  nhy = offy - nly;
 			}
-			if (cla_modifynodeinst(ni, nlx, nly, nhx, nhy, 0, 0, 1)) forcedlook++;
-			foundone++;
+			if (cla_modifynodeinst(ni, nlx, nly, nhx, nhy, 0, 0, TRUE)) forcedlook = TRUE;
+			foundone = TRUE;
 		}
 	}
 
 	/* now change the arcs in the nodes in this facet that changed */
-	foundone = 1;
+	foundone = TRUE;
 	while (foundone)
 	{
-		foundone = 0;
+		foundone = FALSE;
 		for(ni = start->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		{
 			if ((ni->userbits & TOUCHN) == 0) continue;
 			ni->userbits &= ~TOUCHN;
-			if (cla_modnodearcs(ni, 0, 0)) forcedlook++;
-			foundone++;
+			if (cla_modnodearcs(ni, 0, 0)) forcedlook = TRUE;
+			foundone = TRUE;
 		}
 	}
 
@@ -1704,10 +1730,10 @@ INTSML cla_lookdown(NODEPROTO *start)
 
 	/* quit if it has not changed */
 	if (start->lowx == nlx && start->highx == nhx && start->lowy == nly &&
-		start->highy == nhy && forcedlook == 0)
+		start->highy == nhy && !forcedlook)
 	{
 		start->userbits |= FACETNOMOD;
-		return(0);
+		return(FALSE);
 	}
 
 	/* update the facet size */
@@ -1715,5 +1741,5 @@ INTSML cla_lookdown(NODEPROTO *start)
 		start->lowx, start->highx, start->lowy, start->highy, 0, 0);
 	start->lowx = nlx;  start->highx = nhx;
 	start->lowy = nly;  start->highy = nhy;
-	return(1);
+	return(TRUE);
 }
