@@ -37,8 +37,8 @@ static void cli_addequivcon(ARCINST*);
 static INTBIG cli_findtextconn(ARCINST*);
 static char *cli_makearcline(ARCINST*);
 static char *cli_makeportline(PORTPROTO*);
-static INTSML cli_uniquelayer(ARCINST*);
-static INTSML cli_addcomponentinfo(NODEINST*);
+static BOOLEAN cli_uniquelayer(ARCINST*);
+static INTBIG cli_addcomponentinfo(NODEINST*);
 static void cli_addcomponentdata(COMPONENT*);
 static char *cli_componentname(NODEINST*);
 static void cli_addcomponentline(char*, WINDOWPART*);
@@ -64,7 +64,7 @@ void cli_highlightequivalent(GEOM *geom)
 	if (cli_curfacet != par) return;
 
 	/* handle pointing to graphics */
-	if (geom->entrytype == OBJARCINST)
+	if (!geom->entryisnode)
 	{
 		ai = geom->entryaddr.ai;
 		cindex = cli_findtextconn(ai);
@@ -81,7 +81,7 @@ void cli_highlightequivalent(GEOM *geom)
 		str = (char *)asktool(us_tool, "edit-getline", (INTBIG)cli_curwindow, i);
 		if (str == NOSTRING) break;
 		if (cli_linetype(str) != LINEDECL) continue;
-		dec = cli_parsecomp(str, 0);
+		dec = cli_parsecomp(str, FALSE);
 		if (dec == NOCOMPONENTDEC) continue;
 		if (ni->proto != getnodeproto(dec->protoname))
 		{
@@ -112,11 +112,11 @@ void cli_maketextfacet(NODEPROTO *np)
 	REGISTER PORTPROTO *pp;
 	REGISTER ARCINST *ai;
 	REGISTER INTBIG first, lensofar, len, i, trunclen;
-	INTSML chars, lines;
+	INTBIG chars, lines;
 
 	/* initialize the textual equivalent window */
 	cli_curfacet = np;
-	if (cli_texton == 0)
+	if (!cli_texton)
 	{
 		(void)asktool(us_tool, "edit-describe", (INTBIG)&name);
 		(void)initinfstr();
@@ -221,7 +221,7 @@ void cli_eq_newnode(NODEINST *ni)
 	REGISTER INTBIG i, total;
 
 	/* ignore changes generated by constraint results */
-	if (cli_ownchanges != 0) return;
+	if (cli_ownchanges) return;
 
 	/* ignore changes made to a facet not being equated */
 	if (ni->parent != cli_curfacet) return;
@@ -233,7 +233,7 @@ void cli_eq_newnode(NODEINST *ni)
 		str = (char *)asktool(us_tool, "edit-getline", (INTBIG)cli_curwindow, i);
 		if (str == NOSTRING) break;
 		if (cli_linetype(str) != LINEDECL) continue;
-		dec = cli_parsecomp(str, 0);
+		dec = cli_parsecomp(str, FALSE);
 		if (dec == NOCOMPONENTDEC) continue;
 		if (ni->proto != getnodeproto(dec->protoname))
 		{
@@ -286,7 +286,7 @@ void cli_eq_killnode(NODEINST *ni)
 	REGISTER COMPONENT *compo, *ocomp;
 
 	/* see if node is in graphics facet that has equivalent text */
-	if (cli_ownchanges != 0) return;
+	if (cli_ownchanges) return;
 
 	/* ignore changes made to a facet not being equated */
 	if (ni->parent != cli_curfacet) return;
@@ -299,7 +299,7 @@ void cli_eq_killnode(NODEINST *ni)
 		str = (char *)asktool(us_tool, "edit-getline", (INTBIG)cli_curwindow, i);
 		if (str == NOSTRING) break;
 		if (cli_linetype(str) != LINEDECL) continue;
-		dec = cli_parsecomp(str, 0);
+		dec = cli_parsecomp(str, FALSE);
 		if (dec == NOCOMPONENTDEC) continue;
 		if (ni->proto != getnodeproto(dec->protoname))
 		{
@@ -352,19 +352,19 @@ void cli_eq_killnode(NODEINST *ni)
 void cli_eq_modnode(NODEINST *ni)
 {
 	/* see if node is in graphics facet that has equivalent text */
-	if (cli_ownchanges != 0) return;
+	if (cli_ownchanges) return;
 	if (ni->parent == cli_curfacet) cli_changeequivcomp(ni);
 }
 
 /* handle the creation of new arc "ai" */
 void cli_eq_newarc(ARCINST *ai)
 {
-	REGISTER INTSML i, j;
+	REGISTER INTBIG i, j;
 	REGISTER NODEINST *ni;
 	REGISTER PORTARCINST *pi;
 
 	/* see if arc is in graphics facet that has equivalent text */
-	if (cli_ownchanges != 0) return;
+	if (cli_ownchanges) return;
 	if (ai->parent != cli_curfacet) return;
 
 	cli_addequivcon(ai);
@@ -383,10 +383,10 @@ void cli_eq_newarc(ARCINST *ai)
 void cli_eq_killarc(ARCINST *ai)
 {
 	REGISTER NODEINST *ni;
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 
 	/* see if arc is in graphics facet that has equivalent text */
-	if (cli_ownchanges != 0) return;
+	if (cli_ownchanges) return;
 	if (ai->parent != cli_curfacet) return;
 
 	cli_deleteequivcon(ai);
@@ -410,7 +410,7 @@ void cli_eq_modarc(ARCINST *ai)
 	REGISTER INTBIG cindex;
 
 	/* see if arc is in graphics facet that has equivalent text */
-	if (cli_ownchanges != 0) return;
+	if (cli_ownchanges) return;
 
 	/* ignore changes made to a facet not being equated */
 	if (ai->parent != cli_curfacet) return;
@@ -434,7 +434,7 @@ void cli_eq_modarc(ARCINST *ai)
 void cli_eq_newport(PORTPROTO *pp)
 {
 	/* see if port is in graphics facet that has equivalent text */
-	if (cli_ownchanges != 0) return;
+	if (cli_ownchanges) return;
 	if (pp->parent != cli_curfacet) return;
 	cli_addcomponentline(cli_makeportline(pp), cli_curwindow);
 }
@@ -447,7 +447,7 @@ void cli_eq_killport(PORTPROTO *pp)
 	REGISTER EXPORT *e;
 
 	/* see if port is in graphics facet that has equivalent text */
-	if (cli_ownchanges != 0) return;
+	if (cli_ownchanges) return;
 	if (pp->parent != cli_curfacet) return;
 
 	/* find the export line with this port */
@@ -460,7 +460,7 @@ void cli_eq_killport(PORTPROTO *pp)
 		if (cli_linetype(str) != LINEEXPORT) continue;
 
 		/* see if export line is this one */
-		e = cli_parseexport(str, 0);
+		e = cli_parseexport(str, FALSE);
 		if (e == NOEXPORT) continue;
 		if (namesame(pp->protoname, e->portname) != 0)
 		{
@@ -484,7 +484,7 @@ void cli_eq_modport(PORTPROTO *pp)
 	REGISTER INTBIG i, total;
 
 	/* see if port is in graphics facet that has equivalent text */
-	if (cli_ownchanges != 0) return;
+	if (cli_ownchanges) return;
 	if (pp->parent != cli_curfacet) return;
 
 	/* find the export line with this port */
@@ -497,7 +497,7 @@ void cli_eq_modport(PORTPROTO *pp)
 		if (cli_linetype(str) != LINEEXPORT) continue;
 
 		/* see if export line is this one */
-		e = cli_parseexport(str, 0);
+		e = cli_parseexport(str, FALSE);
 		if (e == NOEXPORT) continue;
 		if (namesame(pp->protoname, e->portname) != 0)
 		{
@@ -520,7 +520,7 @@ void cli_eq_newvar(INTBIG addr, INTBIG type, INTBIG key)
 	char line[50];
 	REGISTER VARIABLE *var;
 
-	if (cli_ownchanges != 0) return;
+	if (cli_ownchanges) return;
 
 	if (type == VNODEINST)
 	{
@@ -529,13 +529,13 @@ void cli_eq_newvar(INTBIG addr, INTBIG type, INTBIG key)
 		if (ni->parent != cli_curfacet) return;
 
 		/* name changes are handled specially */
-		if (key == el_node_name)
+		if (key == el_node_name_key)
 		{
 			/* construct the original name */
 			(void)sprintf(line, M_("NODE%ld"), (INTBIG)ni);
 
 			/* get the new node name */
-			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name);
+			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
 			if (var == NOVARIABLE) return;
 			cli_replacename(line, (char *)var->addr);
 			return;
@@ -566,17 +566,17 @@ void cli_eq_killvar(INTBIG addr, INTBIG type, INTBIG key)
 	REGISTER VARIABLE *var;
 	REGISTER NODEINST *ni;
 
-	if (cli_ownchanges != 0) return;
+	if (cli_ownchanges) return;
 	if (type == VNODEINST)
 	{
 		/* node variable removed: see if this is in a graphics facet */
 		ni = (NODEINST *)addr;
 		if (ni->parent != cli_curfacet) return;
 
-		if (key == el_node_name)
+		if (key == el_node_name_key)
 		{
 			/* get the former name */
-			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name);
+			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
 			if (var == NOVARIABLE) return;
 
 			/* construct the new node name */
@@ -605,7 +605,7 @@ void cli_eq_killvar(INTBIG addr, INTBIG type, INTBIG key)
 
 void cli_eq_solve(void)
 {
-	cli_ownchanges = 0;
+	cli_ownchanges = FALSE;
 }
 
 /***************************** HELPER ROUTINES *****************************/
@@ -666,7 +666,7 @@ void cli_changeequivcomp(NODEINST *ni)
 		str = (char *)asktool(us_tool, "edit-getline", (INTBIG)cli_curwindow, i);
 		if (str == NOSTRING) break;
 		if (cli_linetype(str) != LINEDECL) continue;
-		dec = cli_parsecomp(str, 0);
+		dec = cli_parsecomp(str, FALSE);
 		if (dec == NOCOMPONENTDEC) continue;
 		if (ni->proto != getnodeproto(dec->protoname))
 		{
@@ -734,7 +734,7 @@ void cli_replacename(char *oldname, char *newname)
 		/* search declaration statement */
 		if (cli_linetype(str) == LINEDECL)
 		{
-			dcl = cli_parsecomp(str, 0);
+			dcl = cli_parsecomp(str, FALSE);
 			if (dcl == NOCOMPONENTDEC) continue;
 			for(compo = dcl->firstcomponent; compo != NOCOMPONENT; compo = compo->nextcomponent)
 				if (namesame(oldname, compo->name) == 0) break;
@@ -765,7 +765,7 @@ void cli_replacename(char *oldname, char *newname)
 		/* search export statement */
 		if (cli_linetype(str) == LINEEXPORT)
 		{
-			e = cli_parseexport(str, 0);
+			e = cli_parseexport(str, FALSE);
 			if (e == NOEXPORT) continue;
 			if (namesame(e->component, oldname) != 0)
 			{
@@ -842,7 +842,7 @@ void cli_replacename(char *oldname, char *newname)
 		/* search connection statement */
 		if (cli_linetype(str) == LINECONN)
 		{
-			dec = cli_parseconn(str, 0);
+			dec = cli_parseconn(str, FALSE);
 			if (dec == NOCONNECTION) continue;
 
 			/* see if the connection line needs to be rewriten */
@@ -949,7 +949,7 @@ INTBIG cli_findtextconn(ARCINST *ai)
 		str = (char *)asktool(us_tool, "edit-getline", (INTBIG)cli_curwindow, i);
 		if (str == NOSTRING) break;
 		if (cli_linetype(str) != LINECONN) continue;
-		dec = cli_parseconn(str, 1);
+		dec = cli_parseconn(str, TRUE);
 		if (dec == NOCONNECTION) continue;
 
 		/* must have both ends specified */
@@ -995,44 +995,45 @@ char *cli_makearcline(ARCINST *ai)
 {
 	char line[50];
 	REGISTER VARIABLE *var;
-	REGISTER INTSML i, len, doit, added;
+	REGISTER INTBIG i, len;
+	REGISTER BOOLEAN doit, added;
 	REGISTER INTBIG conx, cony, xcons, ycons, lambda;
 	REGISTER LINCON *conptr;
 
 	(void)initinfstr();
 	(void)addstringtoinfstr("connect ");
-	added = 0;
-	if (cli_uniquelayer(ai) == 0)
+	added = FALSE;
+	if (!cli_uniquelayer(ai))
 	{
 		(void)addstringtoinfstr("[layer=");
 		(void)addstringtoinfstr(describearcproto(ai->proto));
-		added++;
+		added = TRUE;
 	}
 	if (ai->width != ai->proto->nominalwidth)
 	{
-		if (added == 0) (void)addtoinfstr('['); else (void)addtoinfstr(',');
+		if (!added) (void)addtoinfstr('['); else (void)addtoinfstr(',');
 		(void)addstringtoinfstr("width=");
 		(void)addstringtoinfstr(latoa(ai->width));
-		added++;
+		added = TRUE;
 	}
 	if (ai->numvar != 0) for(i=0; i<ai->numvar; i++)
 	{
 		var = &ai->firstvar[i];
 		if ((var->type&VISARRAY) != 0) continue;
-		if (added == 0) (void)addtoinfstr('['); else (void)addtoinfstr(',');
+		if (!added) (void)addtoinfstr('['); else (void)addtoinfstr(',');
 		(void)addstringtoinfstr((char *)var->key);
 		(void)addtoinfstr('=');
 		(void)addstringtoinfstr(describevariable(var, -1, 1));
-		added++;
+		added = TRUE;
 	}
-	if (added != 0) (void)addstringtoinfstr("] ");
+	if (added) (void)addstringtoinfstr("] ");
 	(void)addstringtoinfstr(cli_componentname(ai->end[0].nodeinst));
-	if (cli_uniqueport(ai->end[0].nodeinst, ai->end[0].portarcinst->proto) == 0)
+	if (!cli_uniqueport(ai->end[0].nodeinst, ai->end[0].portarcinst->proto))
 	{
 		(void)addtoinfstr(':');
 		(void)addstringtoinfstr(ai->end[0].portarcinst->proto->protoname);
 	}
-	var = getvalkey((INTBIG)ai, VARCINST, VINTEGER|VISARRAY, cli_properties);
+	var = getvalkey((INTBIG)ai, VARCINST, VINTEGER|VISARRAY, cli_properties_key);
 
 	/* initialize the X constraint to be different from the actual arc size */
 	xcons = ycons = 0;
@@ -1075,12 +1076,12 @@ char *cli_makearcline(ARCINST *ai)
 	}
 
 	/* decide whether to print the arc offset */
-	doit = 0;
-	if (xcons > 1 || ycons > 1) doit++;
-	if (xcons == 0 && ycons == 0) doit++;
+	doit = FALSE;
+	if (xcons > 1 || ycons > 1) doit = TRUE;
+	if (xcons == 0 && ycons == 0) doit = TRUE;
 	if (conx != ai->end[1].xpos - ai->end[0].xpos || cony != ai->end[1].ypos - ai->end[0].ypos)
-		doit++;
-	if (doit != 0)
+		doit = TRUE;
+	if (doit)
 	{
 		(void)sprintf(line, " [%s,%s]", latoa(ai->end[1].xpos - ai->end[0].xpos),
 			latoa(ai->end[1].ypos - ai->end[0].ypos));
@@ -1088,7 +1089,7 @@ char *cli_makearcline(ARCINST *ai)
 	}
 	(void)addstringtoinfstr(" to ");
 	(void)addstringtoinfstr(cli_componentname(ai->end[1].nodeinst));
-	if (cli_uniqueport(ai->end[1].nodeinst, ai->end[1].portarcinst->proto) == 0)
+	if (!cli_uniqueport(ai->end[1].nodeinst, ai->end[1].portarcinst->proto))
 	{
 		(void)addtoinfstr(':');
 		(void)addstringtoinfstr(ai->end[1].portarcinst->proto->protoname);
@@ -1102,7 +1103,8 @@ char *cli_makearcline(ARCINST *ai)
  */
 char *cli_makeportline(PORTPROTO *pp)
 {
-	REGISTER INTSML added, i;
+	REGISTER BOOLEAN added;
+	REGISTER INTBIG i;
 	REGISTER VARIABLE *var;
 
 	(void)initinfstr();
@@ -1127,25 +1129,25 @@ char *cli_makeportline(PORTPROTO *pp)
 			case REFOUTPORT: (void)addstringtoinfstr("refout");        break;
 			case REFINPORT:  (void)addstringtoinfstr("refin");         break;
 		}
-		added = 1;
-	} else added = 0;
+		added = TRUE;
+	} else added = FALSE;
 
 	for(i=0; i<pp->numvar; i++)
 	{
 		var = &pp->firstvar[i];
 		if ((var->type&VISARRAY) != 0) continue;
-		if (added == 0) (void)addtoinfstr('['); else (void)addtoinfstr(',');
+		if (!added) (void)addtoinfstr('['); else (void)addtoinfstr(',');
 		(void)addstringtoinfstr((char *)var->key);
 		(void)addtoinfstr('=');
 		(void)addstringtoinfstr(describevariable(var, -1, 1));
-		added++;
+		added = TRUE;
 	}
-	if (added != 0) (void)addstringtoinfstr("] ");
+	if (added) (void)addstringtoinfstr("] ");
 
 	(void)addstringtoinfstr(pp->protoname);
 	(void)addstringtoinfstr(" is ");
 	(void)addstringtoinfstr(cli_componentname(pp->subnodeinst));
-	if (cli_uniqueport(pp->subnodeinst, pp->subportproto) == 0)
+	if (!cli_uniqueport(pp->subnodeinst, pp->subportproto))
 	{
 		(void)addtoinfstr(':');
 		(void)addstringtoinfstr(pp->subportproto->protoname);
@@ -1156,9 +1158,9 @@ char *cli_makeportline(PORTPROTO *pp)
 
 /*
  * routine to tell whether port "pp" of node "ni" is unique on its node
- * returns nonzero if the port is unique
+ * returns true if the port is unique
  */
-INTSML cli_uniqueport(NODEINST *ni, PORTPROTO *pp)
+BOOLEAN cli_uniqueport(NODEINST *ni, PORTPROTO *pp)
 {
 	REGISTER PORTPROTO *opp;
 	static POLYGON *poly1 = NOPOLYGON, *poly2 = NOPOLYGON;
@@ -1168,32 +1170,32 @@ INTSML cli_uniqueport(NODEINST *ni, PORTPROTO *pp)
 	if (poly2 == NOPOLYGON) poly2 = allocstaticpolygon(4, cli_constraint->cluster);
 
 	/* get polygon for original port */
-	shapeportpoly(ni, pp, poly1, 0);
+	shapeportpoly(ni, pp, poly1, FALSE);
 
 	/* look for a different port */
 	for(opp = ni->proto->firstportproto; opp != NOPORTPROTO; opp = opp->nextportproto)
 	{
 		if (opp == pp) continue;
-		shapeportpoly(ni, opp, poly2, 0);
+		shapeportpoly(ni, opp, poly2, FALSE);
 
 		/* if the polygons differ, this port is not unique */
-		if (polysame(poly1, poly2) == 0) return(0);
+		if (!polysame(poly1, poly2)) return(FALSE);
 	}
 
 	/* all polygons the same: port is unique */
-	return(1);
+	return(TRUE);
 }
 
 /*
  * routine to tell whether arc "ai" could be in any other layer
- * Returns nonzero if the layer is unique
+ * Returns true if the layer is unique
  */
-INTSML cli_uniquelayer(ARCINST *ai)
+BOOLEAN cli_uniquelayer(ARCINST *ai)
 {
 	REGISTER TECHNOLOGY *tech;
 	REGISTER ARCPROTO *ap;
 	REGISTER PORTPROTO *pp;
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 
 	/* clear all bits on arcs in this technology */
 	tech = ai->proto->tech;
@@ -1216,8 +1218,8 @@ INTSML cli_uniquelayer(ARCINST *ai)
 		if (ap->temp1 == 2) i++;
 
 	/* arc layer is not unique if more than one arc can make the connection */
-	if (i > 1) return(0);
-	return(1);
+	if (i > 1) return(FALSE);
+	return(TRUE);
 }
 
 /*
@@ -1225,11 +1227,11 @@ INTSML cli_uniquelayer(ARCINST *ai)
  * the component "ni" if it is not the default.  Returns the number of characters
  * that were added to the string
  */
-INTSML cli_addcomponentinfo(NODEINST *ni)
+INTBIG cli_addcomponentinfo(NODEINST *ni)
 {
 	char line[50];
 	REGISTER char *st;
-	REGISTER INTSML added, i;
+	REGISTER INTBIG added, i;
 	REGISTER VARIABLE *var;
 	INTBIG plx, phx, ply, phy;
 
@@ -1273,7 +1275,7 @@ INTSML cli_addcomponentinfo(NODEINST *ni)
 	if (ni->numvar != 0) for(i=0; i<ni->numvar; i++)
 	{
 		var = &ni->firstvar[i];
-		if (var->key == el_node_name) continue;
+		if (var->key == el_node_name_key) continue;
 		if ((var->type&VISARRAY) != 0) continue;
 
 		if (added != 0) (void)addtoinfstr(','); else (void)addtoinfstr('[');
@@ -1341,7 +1343,7 @@ char *cli_componentname(NODEINST *ni)
 	static char line[50];
 	REGISTER VARIABLE *var;
 
-	var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name);
+	var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
 	if (var == NOVARIABLE)
 	{
 		(void)sprintf(line, "NODE%ld", (INTBIG)ni);
