@@ -31,28 +31,29 @@
 #include "database.h"
 #include "conlin.h"
 
-static INTSML (*cli_realcharhandler)(WINDOWPART*, INTSML);
+static BOOLEAN (*cli_realcharhandler)(WINDOWPART*, INTSML, INTBIG);
 static void (*cli_oldttermhandler)(WINDOWPART*);	/* former text editor termination routine */
 
 /* prototypes for local routines */
-static INTSML cli_charhandler(WINDOWPART*, INTSML);
+static BOOLEAN cli_charhandler(WINDOWPART*, INTSML, INTBIG);
 static void cli_termhandler(WINDOWPART*);
-static void cli_changehandler(WINDOWPART*, INTSML, char*, char*, INTBIG);
-static void cli_changeexport(char*, char*, INTSML, WINDOWPART*);
-static void cli_changedeclaration(char*, char*, INTSML, WINDOWPART*);
-static void cli_changeconnection(char*, char*, INTSML, WINDOWPART*);
+static void cli_changehandler(WINDOWPART*, INTBIG, char*, char*, INTBIG);
+static void cli_changeexport(char*, char*, INTBIG, WINDOWPART*);
+static void cli_changedeclaration(char*, char*, INTBIG, WINDOWPART*);
+static void cli_changeconnection(char*, char*, INTBIG, WINDOWPART*);
 static void cli_updateattrs(ATTR*, ATTR*, INTBIG, INTBIG);
 static void cli_deletedeclaration(char*);
 static void cli_deletewire(char*);
 static void cli_deleteexportline(char*);
-static INTSML cli_adddeclaration(char*, INTSML, WINDOWPART*);
-static INTSML cli_addwire(char*, INTSML, WINDOWPART*);
-static void cli_addexport(char*, INTSML, WINDOWPART*);
+static BOOLEAN cli_adddeclaration(char*, INTBIG, WINDOWPART*);
+static BOOLEAN cli_addwire(char*, INTBIG, WINDOWPART*);
+static void cli_addexport(char*, INTBIG, WINDOWPART*);
 static PORTPROTO *cli_getexportsubport(EXPORT*, NODEINST*);
-static void cli_getfactors(NODEINST*, NODEPROTO*, COMPONENT*, INTBIG*, INTBIG*, INTBIG*, INTBIG*, INTSML*, INTSML*, INTBIG, INTBIG);
+static void cli_getfactors(NODEINST*, NODEPROTO*, COMPONENT*, INTBIG*, INTBIG*, INTBIG*,
+				INTBIG*, INTBIG*, INTBIG*, INTBIG, INTBIG);
 static void cli_killthenode(NODEINST*);
-static void cli_commentline(INTSML, WINDOWPART*);
-static void cli_restoreline(char*, INTSML, WINDOWPART*);
+static void cli_commentline(INTBIG, WINDOWPART*);
+static void cli_restoreline(char*, INTBIG, WINDOWPART*);
 
 /************************ EDITOR WINDOW CONTROL ************************/
 
@@ -61,7 +62,7 @@ static void cli_restoreline(char*, INTSML, WINDOWPART*);
  * title is in "header" and the number of characters/lines are returned
  * in "chars" and "lines".  Returns NOWINDOWPART if there is an error.
  */
-WINDOWPART *cli_makeeditorwindow(char *header, INTSML *chars, INTSML *lines)
+WINDOWPART *cli_makeeditorwindow(char *header, INTBIG *chars, INTBIG *lines)
 {
 	REGISTER WINDOWPART *win;
 
@@ -75,7 +76,7 @@ WINDOWPART *cli_makeeditorwindow(char *header, INTSML *chars, INTSML *lines)
 	win->charhandler = cli_charhandler;
 	win->changehandler = cli_changehandler;
 	win->termhandler = cli_termhandler;
-	cli_texton = 1;
+	cli_texton = TRUE;
 	return(win);
 }
 
@@ -84,26 +85,26 @@ WINDOWPART *cli_makeeditorwindow(char *header, INTSML *chars, INTSML *lines)
  * passes all commands to the editing character handler.  However, it
  * interprets M(=) which is for highlighting the equivalent graphics
  */
-INTSML cli_charhandler(WINDOWPART *win, INTSML i)
+BOOLEAN cli_charhandler(WINDOWPART *win, INTSML i, INTBIG special)
 {
 	REGISTER char *line;
 	REGISTER ARCINST *ai;
 	REGISTER NODEINST *ni;
 	REGISTER COMPONENTDEC *comd;
 	REGISTER COMPONENT *compo;
-	REGISTER INTSML count, type;
+	REGISTER INTBIG count, type;
 
 	/* simply pass most characters to the real editor character handler */
-	if ((i&0200) == 0 || ((i&0177) != '=' && cli_realcharhandler != 0))
+	if (special == 0 || (i != '=' && cli_realcharhandler != 0))
 	{
-		return((*cli_realcharhandler)(win, i));
+		return((*cli_realcharhandler)(win, i, special));
 	}
 
 	/* M(=) typed: highlight the equivalent line */
 	if (cli_curfacet == NONODEPROTO)
 	{
 		ttyputmsg(M_("No valid facet to associate"));
-		return(0);
+		return(FALSE);
 	}
 	line = (char *)asktool(us_tool, "edit-getline", (INTBIG)win, -1);
 	if (line == NOSTRING) type = LINEUNKN; else type = cli_linetype(line);
@@ -138,11 +139,11 @@ INTSML cli_charhandler(WINDOWPART *win, INTSML i)
 			break;
 
 		case LINEDECL:
-			comd = cli_parsecomp(line, 1);
+			comd = cli_parsecomp(line, TRUE);
 			if (comd == NOCOMPONENTDEC)
 			{
 				ttyputmsg(M_("Cannot parse this declaration line"));
-				return(0);
+				return(FALSE);
 			}
 			count = 0;
 			for(compo = comd->firstcomponent; compo != NOCOMPONENT; compo = compo->nextcomponent)
@@ -156,11 +157,11 @@ INTSML cli_charhandler(WINDOWPART *win, INTSML i)
 			if (count == 0)
 			{
 				ttyputmsg(M_("Cannot find equivalent node(s) for this line"));
-				return(0);
+				return(FALSE);
 			}
 			break;
 	}
-	return(0);
+	return(FALSE);
 }
 
 /*
@@ -168,7 +169,7 @@ INTSML cli_charhandler(WINDOWPART *win, INTSML i)
  */
 void cli_termhandler(WINDOWPART *win)
 {
-	cli_texton = 0;
+	cli_texton = FALSE;
 	cli_curfacet = NONODEPROTO;
 	if (cli_oldttermhandler!= 0) (*cli_oldttermhandler)(win);
 }
@@ -176,12 +177,12 @@ void cli_termhandler(WINDOWPART *win)
 /*
  * routine to handle changes to the text window.
  */
-void cli_changehandler(WINDOWPART *win, INTSML nature, char *oldline, char *newline,
+void cli_changehandler(WINDOWPART *win, INTBIG nature, char *oldline, char *newline,
 	INTBIG changed)
 {
 	char *newpar[3];
 	REGISTER char *oldname, *newname, **newlist;
-	REGISTER INTSML otype, ntype;
+	REGISTER INTBIG otype, ntype;
 	REGISTER INTBIG i, count;
 	REGISTER NODEPROTO *np;
 	REGISTER WINDOWPART *w;
@@ -208,8 +209,8 @@ void cli_changehandler(WINDOWPART *win, INTSML nature, char *oldline, char *newl
 	if (ntype == LINEUNKN)
 	{
 		ttyputerr(M_("Unrecognized line '%s' commented out"), newline);
-		if (otype == LINEUNKN || otype == LINECOMM) cli_commentline((INTSML)changed, win); else
-			cli_restoreline(oldline, (INTSML)changed, win);
+		if (otype == LINEUNKN || otype == LINECOMM) cli_commentline(changed, win); else
+			cli_restoreline(oldline, changed, win);
 		return;
 	}
 
@@ -222,17 +223,17 @@ void cli_changehandler(WINDOWPART *win, INTSML nature, char *oldline, char *newl
 		switch (otype)
 		{
 			case LINEDECL:
-				cli_changedeclaration(oldline, newline, (INTSML)changed, win);
+				cli_changedeclaration(oldline, newline, changed, win);
 				break;
 			case LINECONN:
-				cli_changeconnection(oldline, newline, (INTSML)changed, win);
+				cli_changeconnection(oldline, newline, changed, win);
 				break;
 			case LINEEXPORT:
-				cli_changeexport(oldline, newline, (INTSML)changed, win);
+				cli_changeexport(oldline, newline, changed, win);
 				break;
 			case LINEBEGIN:
-				oldname = cli_parsebeginfacet(oldline, 0);
-				newname = cli_parsebeginfacet(newline, 0);
+				oldname = cli_parsebeginfacet(oldline, FALSE);
+				newname = cli_parsebeginfacet(newline, FALSE);
 				if (oldname != NOSTRING && newname != NOSTRING)
 				{
 					if (namesame(oldname, newname) != 0)
@@ -243,7 +244,7 @@ void cli_changehandler(WINDOWPART *win, INTSML nature, char *oldline, char *newl
 				} else if (newname == NOSTRING)
 				{
 					ttyputmsg(M_("Erroneous BEGINFACET line"));
-					cli_restoreline(oldline, (INTSML)changed, win);
+					cli_restoreline(oldline, changed, win);
 				}
 				if (oldname != NOSTRING) efree(oldname);
 				if (newname != NOSTRING) efree(newname);
@@ -288,7 +289,7 @@ void cli_changehandler(WINDOWPART *win, INTSML nature, char *oldline, char *newl
 			case LINEDECL:
 				if (cli_curfacet != NONODEPROTO)
 				{
-					if (cli_adddeclaration(newline, (INTSML)changed, win) != 0) break;
+					if (cli_adddeclaration(newline, changed, win)) break;
 				}
 				cli_textlines++;
 				break;
@@ -296,14 +297,14 @@ void cli_changehandler(WINDOWPART *win, INTSML nature, char *oldline, char *newl
 			case LINECONN:
 				if (cli_curfacet != NONODEPROTO)
 				{
-					if (cli_addwire(newline, (INTSML)changed, win) != 0) break;
+					if (cli_addwire(newline, changed, win)) break;
 				}
 				cli_textlines++;
 				break;
 
 			case LINEEXPORT:
 				if (cli_curfacet != NONODEPROTO)
-					(void)cli_addexport(newline, (INTSML)changed, win);
+					(void)cli_addexport(newline, changed, win);
 				break;
 
 			case LINEBEGIN:
@@ -311,16 +312,16 @@ void cli_changehandler(WINDOWPART *win, INTSML nature, char *oldline, char *newl
 				if (cli_textlines > 0)
 				{
 					ttyputmsg(M_("Already a valid facet definition"));
-					cli_commentline((INTSML)changed, win);
+					cli_commentline(changed, win);
 					return;
 				}
 
 				/* get the facet name */
-				newname = cli_parsebeginfacet(newline, 0);
+				newname = cli_parsebeginfacet(newline, FALSE);
 				if (newname == NOSTRING)
 				{
 					ttyputmsg(M_("Erroneous BEGINFACET line removed"));
-					cli_commentline((INTSML)changed, win);
+					cli_commentline(changed, win);
 					return;
 				}
 
@@ -330,7 +331,7 @@ void cli_changehandler(WINDOWPART *win, INTSML nature, char *oldline, char *newl
 				{
 					newpar[0] = "killfacet";
 					newpar[1] = newname;
-					(void)telltool(us_tool, 2, newpar);
+					telltool(us_tool, 2, newpar);
 				}
 
 				/* find a window in which to place the facet */
@@ -348,10 +349,10 @@ void cli_changehandler(WINDOWPART *win, INTSML nature, char *oldline, char *newl
 					newpar[0] = "window";
 					newpar[1] = "use";
 					newpar[2] = w->location;
-					(void)telltool(us_tool, 3, newpar);
+					telltool(us_tool, 3, newpar);
 					newpar[0] = "editfacet";
 					newpar[1] = newname;
-					(void)telltool(us_tool, 2, newpar);
+					telltool(us_tool, 2, newpar);
 					cli_curfacet = getcurfacet();
 				} else cli_curfacet = newnodeproto(newname, el_curlib);
 				efree(newname);
@@ -375,18 +376,18 @@ void cli_changehandler(WINDOWPART *win, INTSML nature, char *oldline, char *newl
  * The index of the line that changed is in "changed".  Text was changed
  * in window "win".
  */
-void cli_changeexport(char *oldline, char *newline, INTSML changed, WINDOWPART *win)
+void cli_changeexport(char *oldline, char *newline, INTBIG changed, WINDOWPART *win)
 {
 	REGISTER EXPORT *olde, *newe;
 	REGISTER NODEINST *oldni, *newni;
 	REGISTER PORTPROTO *oldpp, *oldsubpp, *newsubpp;
 
 	/* parse the old line */
-	olde = cli_parseexport(oldline, 0);
+	olde = cli_parseexport(oldline, FALSE);
 	if (olde == NOEXPORT) return;
 
 	/* parse the new line */
-	newe = cli_parseexport(newline, 0);
+	newe = cli_parseexport(newline, FALSE);
 
 	/* if the new line has an error, restore the old line */
 	if (newe == NOEXPORT)
@@ -449,18 +450,18 @@ void cli_changeexport(char *oldline, char *newline, INTSML changed, WINDOWPART *
 			return;
 		}
 		if (oldni == newni && oldsubpp == newsubpp)
-			(void)db_change((INTBIG)oldni, OBJECTSTART, VNODEINST,0,0,0,0,0);
+			(void)db_change((INTBIG)oldni, OBJECTSTART, VNODEINST, 0, 0, 0, 0, 0);
 		(void)reallocstring(&oldpp->protoname, newe->portname, oldpp->parent->cell->cluster);
 		if (oldni == newni && oldsubpp == newsubpp)
-			(void)db_change((INTBIG)oldni, OBJECTEND, VNODEINST, 0,0,0,0,0);
+			(void)db_change((INTBIG)oldni, OBJECTEND, VNODEINST, 0, 0, 0, 0, 0);
 	}
 
 	/* see if the port moved */
 	if (oldni != newni || oldsubpp != newsubpp)
 	{
-		cli_ownchanges = 1;
+		cli_ownchanges = TRUE;
 		(void)moveportproto(cli_curfacet, oldpp, newni, newsubpp);
-		cli_ownchanges = 0;
+		cli_ownchanges = FALSE;
 	}
 }
 
@@ -469,24 +470,24 @@ void cli_changeexport(char *oldline, char *newline, INTSML changed, WINDOWPART *
  * The index of the line that changed is in "changed".  Text was changed
  * in window "win".
  */
-void cli_changedeclaration(char *oldline, char *newline, INTSML changed,
+void cli_changedeclaration(char *oldline, char *newline, INTBIG changed,
 	WINDOWPART *win)
 {
 	REGISTER COMPONENTDEC *oldcd, *newcd;
 	REGISTER COMPONENT *newcomp, *oldcomp;
 	REGISTER NODEPROTO *newnp, *oldnp;
 	REGISTER NODEINST *ni;
-	REGISTER INTSML newun, oldun;
+	REGISTER INTBIG newun, oldun;
 	REGISTER VARIABLE *var;
 	INTBIG newlx, newly, newhx, newhy, oldlx, oldly, oldhx, oldhy, lx, hx, ly, hy;
-	INTSML newrot, oldrot, newtrans, oldtrans, rot, trn;
+	INTBIG newrot, oldrot, newtrans, oldtrans, rot, trn;
 
 	/* parse the old line */
-	oldcd = cli_parsecomp(oldline, 0);
+	oldcd = cli_parsecomp(oldline, FALSE);
 	if (oldcd == NOCOMPONENTDEC) return;
 
 	/* parse the new line */
-	newcd = cli_parsecomp(newline, 0);
+	newcd = cli_parsecomp(newline, FALSE);
 
 	/* if the new line has an error, restore the old line */
 	if (newcd == NOCOMPONENTDEC)
@@ -602,9 +603,9 @@ void cli_changedeclaration(char *oldline, char *newline, INTSML changed,
 		ni = cli_findnodename(oldcomp->name);
 		if (ni != NONODEINST)
 		{
-			cli_ownchanges = 1;
+			cli_ownchanges = TRUE;
 			cli_killthenode(ni);
-			cli_ownchanges = 0;
+			cli_ownchanges = FALSE;
 		}
 	}
 
@@ -624,17 +625,17 @@ void cli_changedeclaration(char *oldline, char *newline, INTSML changed,
 		}
 		cli_getfactors(NONODEINST, newnp, newcomp, &lx, &hx, &ly, &hy, &rot, &trn, 0, 0);
 
-		cli_ownchanges = 1;
+		cli_ownchanges = TRUE;
 		ni = newnodeinst(newnp, lx, hx, ly, hy, trn, rot, cli_curfacet);
 		if (ni != NONODEINST)
 		{
-			var = setvalkey((INTBIG)ni, VNODEINST, el_node_name, (INTBIG)newcomp->name,
+			var = setvalkey((INTBIG)ni, VNODEINST, el_node_name_key, (INTBIG)newcomp->name,
 				VSTRING|VDISPLAY);
 			if (var != NOVARIABLE)
 				defaulttextsize(3, var->textdescript);
 			endobjectchange((INTBIG)ni, VNODEINST);
 		}
-		cli_ownchanges = 0;
+		cli_ownchanges = FALSE;
 
 		/* should also add attributes here!!! */
 	}
@@ -652,11 +653,11 @@ void cli_changedeclaration(char *oldline, char *newline, INTSML changed,
 		/* component changed prototype */
 		if (newnp != oldnp)
 		{
-			cli_ownchanges = 1;
+			cli_ownchanges = TRUE;
 			startobjectchange((INTBIG)ni, VNODEINST);
-			ni = replacenodeinst(ni, newnp, 0, 0);
+			ni = replacenodeinst(ni, newnp, FALSE, FALSE);
 			endobjectchange((INTBIG)ni, VNODEINST);
-			cli_ownchanges = 0;
+			cli_ownchanges = FALSE;
 			if (ni == NONODEINST)
 			{
 				/*
@@ -681,14 +682,14 @@ void cli_changedeclaration(char *oldline, char *newline, INTSML changed,
 				cli_restoreline(oldline, changed, win);
 				return;
 			}
-			(void)db_change((INTBIG)ni, OBJECTSTART, VNODEINST, 0,0,0,0,0);
-			cli_ownchanges = 1;
-			var = setvalkey((INTBIG)ni, VNODEINST, el_node_name, (INTBIG)newcomp->name,
+			(void)db_change((INTBIG)ni, OBJECTSTART, VNODEINST, 0, 0, 0, 0, 0);
+			cli_ownchanges = TRUE;
+			var = setvalkey((INTBIG)ni, VNODEINST, el_node_name_key, (INTBIG)newcomp->name,
 				VSTRING|VDISPLAY);
 			if (var != NOVARIABLE)
 				defaulttextsize(3, var->textdescript);
-			cli_ownchanges = 0;
-			(void)db_change((INTBIG)ni, OBJECTEND, VNODEINST, 0,0,0,0,0);
+			cli_ownchanges = FALSE;
+			(void)db_change((INTBIG)ni, OBJECTEND, VNODEINST, 0, 0, 0, 0, 0);
 
 			/* rewrite the name elsewhere in the text */
 			cli_replacename(oldcomp->name, newcomp->name);
@@ -704,12 +705,12 @@ void cli_changedeclaration(char *oldline, char *newline, INTSML changed,
 		if (newlx != oldlx || newly != oldly || newhx != oldhx ||
 			newhy != oldhy || newrot != oldrot || newtrans != oldtrans)
 		{
-			cli_ownchanges = 1;
+			cli_ownchanges = TRUE;
 			startobjectchange((INTBIG)ni, VNODEINST);
 			modifynodeinst(ni, newlx - oldlx, newly - oldly, newhx - oldhx,
-				newhy - oldhy, (INTSML)(newrot - oldrot), (INTSML)(newtrans != oldtrans));
+				newhy - oldhy, newrot - oldrot, newtrans != oldtrans);
 			endobjectchange((INTBIG)ni, VNODEINST);
-			cli_ownchanges = 0;
+			cli_ownchanges = FALSE;
 		}
 	}
 	cli_deletecomponentdec(oldcd);
@@ -721,7 +722,7 @@ void cli_changedeclaration(char *oldline, char *newline, INTSML changed,
  * The index of the line that changed is in "changed".  Text was changed
  * in window "win".
  */
-void cli_changeconnection(char *oldline, char *newline, INTSML changed, WINDOWPART *win)
+void cli_changeconnection(char *oldline, char *newline, INTBIG changed, WINDOWPART *win)
 {
 	REGISTER CONNECTION *oldcon, *newcon;
 	REGISTER ARCINST *ai, *newai;
@@ -730,17 +731,18 @@ void cli_changeconnection(char *oldline, char *newline, INTSML changed, WINDOWPA
 	PORTPROTO *oldport1, *oldport2, *newport1, *newport2;
 	REGISTER INTBIG newxoff, newyoff, lambda;
 	REGISTER VARIABLE *var;
-	REGISTER INTSML resolve, variable, varx, vary, offchanged;
+	REGISTER BOOLEAN resolve, offchanged;
+	REGISTER INTBIG variable, varx, vary;
 	INTBIG x1, y1, x2, y2, widnew, widold;
-	INTSML ret;
+	BOOLEAN ret;
 	REGISTER CONS *oldcons, *newcons;
 
 	/* parse the old line */
-	oldcon = cli_parseconn(oldline, 0);
+	oldcon = cli_parseconn(oldline, FALSE);
 	if (oldcon == NOCONNECTION) return;
 
 	/* parse the new line */
-	newcon = cli_parseconn(newline, 0);
+	newcon = cli_parseconn(newline, FALSE);
 
 	/* if the new line has an error, restore the old line */
 	if (newcon == NOCONNECTION)
@@ -762,7 +764,7 @@ void cli_changeconnection(char *oldline, char *newline, INTSML changed, WINDOWPA
 
 	/* evaluate the elements of the former wire */
 	if (cli_pickwire(oldcon, &oldend1, &oldport1, &oldend2, &oldport2, &oldap,
-		&widold, ai, NONODEINST, NONODEINST) != 0)
+		&widold, ai, NONODEINST, NONODEINST))
 	{
 		cli_restoreline(oldline, changed, win);
 		cli_deleteconnection(oldcon);   cli_deleteconnection(newcon);
@@ -771,7 +773,7 @@ void cli_changeconnection(char *oldline, char *newline, INTSML changed, WINDOWPA
 
 	/* evaluate the elements of the former wire */
 	if (cli_pickwire(newcon, &newend1, &newport1, &newend2, &newport2, &newap,
-		&widnew, NOARCINST, oldend1, oldend2) != 0)
+		&widnew, NOARCINST, oldend1, oldend2))
 	{
 		cli_restoreline(oldline, changed, win);
 		cli_deleteconnection(oldcon);   cli_deleteconnection(newcon);
@@ -779,7 +781,7 @@ void cli_changeconnection(char *oldline, char *newline, INTSML changed, WINDOWPA
 	}
 
 	/* initially assume that constraints do not need to be re-solved */
-	resolve = 0;
+	resolve = FALSE;
 
 	/* determine the correct extent of the arc */
 	if ((newcon->flag&OFFSETVALID) != 0)
@@ -792,7 +794,7 @@ void cli_changeconnection(char *oldline, char *newline, INTSML changed, WINDOWPA
 		newyoff = ai->end[1].ypos - ai->end[0].ypos;
 
 		/* if offsets were deleted, re-solve circuit */
-		if ((oldcon->flag&OFFSETVALID) != 0) resolve++;
+		if ((oldcon->flag&OFFSETVALID) != 0) resolve = TRUE;
 	}
 
 	/* associate the constraint lists */
@@ -831,14 +833,14 @@ void cli_changeconnection(char *oldline, char *newline, INTSML changed, WINDOWPA
 		}
 
 		/* make the change */
-		(void)db_change((INTBIG)oldend1, OBJECTSTART, VNODEINST, 0,0,0,0,0);
-		cli_ownchanges = 1;
-		var = setvalkey((INTBIG)oldend1, VNODEINST, el_node_name, (INTBIG)newcon->end1,
+		(void)db_change((INTBIG)oldend1, OBJECTSTART, VNODEINST, 0, 0, 0, 0, 0);
+		cli_ownchanges = TRUE;
+		var = setvalkey((INTBIG)oldend1, VNODEINST, el_node_name_key, (INTBIG)newcon->end1,
 			VSTRING|VDISPLAY);
 		if (var != NOVARIABLE)
 			defaulttextsize(3, var->textdescript);
-		cli_ownchanges = 0;
-		(void)db_change((INTBIG)oldend1, OBJECTEND, VNODEINST, 0,0,0,0,0);
+		cli_ownchanges = FALSE;
+		(void)db_change((INTBIG)oldend1, OBJECTEND, VNODEINST, 0, 0, 0, 0, 0);
 
 		/* replace the name wherever it appears */
 		cli_replacename(oldcon->end1, newcon->end1);
@@ -854,14 +856,14 @@ void cli_changeconnection(char *oldline, char *newline, INTSML changed, WINDOWPA
 		}
 
 		/* make the change */
-		(void)db_change((INTBIG)oldend2, OBJECTSTART, VNODEINST, 0,0,0,0,0);
-		cli_ownchanges = 1;
-		var = setvalkey((INTBIG)oldend2, VNODEINST, el_node_name, (INTBIG)newcon->end2,
+		(void)db_change((INTBIG)oldend2, OBJECTSTART, VNODEINST, 0, 0, 0, 0, 0);
+		cli_ownchanges = TRUE;
+		var = setvalkey((INTBIG)oldend2, VNODEINST, el_node_name_key, (INTBIG)newcon->end2,
 			VSTRING|VDISPLAY);
 		if (var != NOVARIABLE)
 			defaulttextsize(3, var->textdescript);
-		cli_ownchanges = 0;
-		(void)db_change((INTBIG)oldend2, OBJECTEND, VNODEINST, 0,0,0,0,0);
+		cli_ownchanges = FALSE;
+		(void)db_change((INTBIG)oldend2, OBJECTEND, VNODEINST, 0, 0, 0, 0, 0);
 
 		/* replace the name wherever it appears */
 		cli_replacename(oldcon->end2, newcon->end2);
@@ -872,10 +874,10 @@ void cli_changeconnection(char *oldline, char *newline, INTSML changed, WINDOWPA
 	{
 		portposition(newend1, newport1, &x1, &y1);
 		portposition(newend2, newport2, &x2, &y2);
-		cli_ownchanges = 1;
+		cli_ownchanges = TRUE;
 		newai = newarcinst(newap, widnew, 0, newend1, newport1, x1, y1,
 			newend2, newport2, x2, y2, cli_curfacet);
-		cli_ownchanges = 0;
+		cli_ownchanges = FALSE;
 		if (newai == NOARCINST)
 		{
 			ttyputerr(M_("Cannot create this new wire"));
@@ -884,12 +886,12 @@ void cli_changeconnection(char *oldline, char *newline, INTSML changed, WINDOWPA
 			return;
 		}
 		endobjectchange((INTBIG)newai, VARCINST);
-		cli_ownchanges = 1;
+		cli_ownchanges = TRUE;
 		startobjectchange((INTBIG)ai, VARCINST);
 		(void)killarcinst(ai);
-		cli_ownchanges = 0;
+		cli_ownchanges = FALSE;
 		ai = newai;
-		resolve++;
+		resolve = TRUE;
 
 		/* should set attributes and copy lists so that they are equal!!! */
 
@@ -908,11 +910,11 @@ void cli_changeconnection(char *oldline, char *newline, INTSML changed, WINDOWPA
 	/* replace the arc type if that was requested */
 	if (oldap != newap)
 	{
-		cli_ownchanges = 1;
+		cli_ownchanges = TRUE;
 		startobjectchange((INTBIG)ai, VARCINST);
 		ai = replacearcinst(ai, newap);
 		endobjectchange((INTBIG)ai, VARCINST);
-		cli_ownchanges = 0;
+		cli_ownchanges = FALSE;
 		if (ai == NOARCINST)
 		{
 			ttyputerr(M_("Cannot change the type of this wire"));
@@ -929,12 +931,12 @@ void cli_changeconnection(char *oldline, char *newline, INTSML changed, WINDOWPA
 	/* change the arc width if that was requested */
 	if (widold != widnew)
 	{
-		cli_ownchanges = 1;
+		cli_ownchanges = TRUE;
 		startobjectchange((INTBIG)ai, VARCINST);
 		ret = modifyarcinst(ai, widnew-widold, 0, 0, 0, 0);
 		endobjectchange((INTBIG)ai, VARCINST);
-		cli_ownchanges = 0;
-		if (ret != 0)
+		cli_ownchanges = FALSE;
+		if (ret)
 		{
 			ttyputerr(M_("Cannot change the width of this wire"));
 			cli_restoreline(oldline, changed, win);
@@ -947,40 +949,40 @@ void cli_changeconnection(char *oldline, char *newline, INTSML changed, WINDOWPA
 	for(oldcons = oldcon->firstcons; oldcons != NOCONS; oldcons = oldcons->nextcons)
 	{
 		if (oldcons->assoc != NOCONS) continue;
-		resolve++;
+		resolve = TRUE;
 		if (namesame(oldcons->direction, "left") == 0) variable = CLLEFT; else
 			if (namesame(oldcons->direction, "right") == 0) variable = CLRIGHT; else
 				if (namesame(oldcons->direction, "down") == 0) variable = CLDOWN; else
 					if (namesame(oldcons->direction, "up") == 0) variable = CLUP;
-		cli_ownchanges = 1;
+		cli_ownchanges = TRUE;
 		cli_deletearcconstraint(ai, variable, oldcons->flag, oldcons->amount);
-		cli_ownchanges = 0;
+		cli_ownchanges = FALSE;
 	}
 
 	/* see which constraints were added */
 	for(newcons = newcon->firstcons; newcons != NOCONS; newcons = newcons->nextcons)
 	{
 		if (newcons->assoc != NOCONS) continue;
-		resolve++;
+		resolve = TRUE;
 		if (namesame(newcons->direction, "left") == 0) variable = CLLEFT; else
 			if (namesame(newcons->direction, "right") == 0) variable = CLRIGHT; else
 				if (namesame(newcons->direction, "down") == 0) variable = CLDOWN; else
 					if (namesame(newcons->direction, "up") == 0) variable = CLUP;
-		cli_ownchanges = 1;
+		cli_ownchanges = TRUE;
 		(void)cli_addarcconstraint(ai, variable, newcons->flag, newcons->amount, 1);
-		cli_ownchanges = 0;
+		cli_ownchanges = FALSE;
 	}
 
 	/* free the parsing structures */
 	cli_deleteconnection(oldcon);   cli_deleteconnection(newcon);
 
 	/* add temporary forcing constraints if the offset was changed */
-	offchanged = 0;
+	offchanged = FALSE;
 	if (newxoff != ai->end[1].xpos - ai->end[0].xpos ||
 		newyoff != ai->end[1].ypos - ai->end[0].ypos)
 	{
-		offchanged = 1;
-		resolve++;
+		offchanged = TRUE;
+		resolve = TRUE;
 
 		/* compute the constraint in X */
 		if (newxoff >= 0) varx = CLRIGHT; else
@@ -1005,10 +1007,10 @@ void cli_changeconnection(char *oldline, char *newline, INTSML changed, WINDOWPA
 	}
 
 	/* make sure all constraints are met */
-	if (resolve != 0) cli_solvefacet(cli_curfacet, 0, 1);
+	if (resolve) cli_solvefacet(cli_curfacet, FALSE, TRUE);
 
 	/* remove temporary constraints to handle offset specification */
-	if (offchanged != 0)
+	if (offchanged)
 	{
 		(void)cli_deletearcconstraint(ai, varx, CLEQUALS, newxoff);
 		(void)cli_deletearcconstraint(ai, vary, CLEQUALS, newyoff);
@@ -1044,18 +1046,18 @@ void cli_updateattrs(ATTR *oldlist, ATTR *newlist, INTBIG addr, INTBIG type)
 	for(a = oldlist; a != NOATTR; a = a->nextattr)
 		if (a->equiv == NOATTR)
 	{
-		cli_ownchanges = 1;
+		cli_ownchanges = TRUE;
 		(void)delval(addr, type, a->name);
-		cli_ownchanges = 0;
+		cli_ownchanges = FALSE;
 	}
 
 	/* look for the added attributes */
 	for(a = newlist; a != NOATTR; a = a->nextattr)
 		if (a->equiv == NOATTR)
 	{
-		cli_ownchanges = 1;
+		cli_ownchanges = TRUE;
 		(void)setval(addr, type, a->name, a->value, a->type);
-		cli_ownchanges = 0;
+		cli_ownchanges = FALSE;
 	}
 
 	/* look for changed attributes */
@@ -1073,10 +1075,10 @@ void cli_updateattrs(ATTR *oldlist, ATTR *newlist, INTBIG addr, INTBIG type)
 				if (namesame((char *)a->value, (char *)b->value) == 0) continue;
 			}
 		}
-		cli_ownchanges = 1;
+		cli_ownchanges = TRUE;
 		(void)delval(addr, type, a->name);
 		(void)setval(addr, type, b->name, b->value, b->type);
-		cli_ownchanges = 0;
+		cli_ownchanges = FALSE;
 	}
 }
 
@@ -1094,7 +1096,7 @@ void cli_deletedeclaration(char *oldline)
 	REGISTER NODEINST *ni;
 
 	/* parse the declaration statement */
-	dec = cli_parsecomp(oldline, 0);
+	dec = cli_parsecomp(oldline, FALSE);
 	if (dec == NOCOMPONENTDEC) return;
 
 	/* determine the prototype of the node */
@@ -1129,10 +1131,10 @@ void cli_deletewire(char *oldline)
 
 	ai = cli_findarcname(oldline);
 	if (ai == NOARCINST) return;
-	cli_ownchanges = 1;
+	cli_ownchanges = TRUE;
 	startobjectchange((INTBIG)ai, VARCINST);
 	(void)killarcinst(ai);
-	cli_ownchanges = 0;
+	cli_ownchanges = FALSE;
 }
 
 /*
@@ -1144,7 +1146,7 @@ void cli_deleteexportline(char *oldline)
 	REGISTER PORTPROTO *pp;
 
 	/* parse the export statement */
-	e = cli_parseexport(oldline, 0);
+	e = cli_parseexport(oldline, FALSE);
 	if (e == NOEXPORT) return;
 
 	/* find the exported port name */
@@ -1157,9 +1159,9 @@ void cli_deleteexportline(char *oldline)
 	}
 
 	/* remove the port prototype */
-	cli_ownchanges = 1;
+	cli_ownchanges = TRUE;
 	(void)killportproto(cli_curfacet, pp);
-	cli_ownchanges = 0;
+	cli_ownchanges = FALSE;
 	cli_deleteexport(e);
 }
 
@@ -1168,9 +1170,9 @@ void cli_deleteexportline(char *oldline)
 /*
  * routine to add graphics equivalent to the new text declaration "newline"
  * with the line index "changed".  Text was changed in window "win".  Returns
- * nonzero on error
+ * true on error
  */
-INTSML cli_adddeclaration(char *newline, INTSML changed, WINDOWPART *win)
+BOOLEAN cli_adddeclaration(char *newline, INTBIG changed, WINDOWPART *win)
 {
 	REGISTER COMPONENTDEC *dec;
 	REGISTER COMPONENT *compo, *ocomp;
@@ -1178,14 +1180,14 @@ INTSML cli_adddeclaration(char *newline, INTSML changed, WINDOWPART *win)
 	REGISTER NODEINST *ni;
 	REGISTER VARIABLE *var;
 	INTBIG lx, hx, ly, hy;
-	INTSML rot, trn;
+	INTBIG rot, trn;
 
 	/* parse the declaration statement */
-	dec = cli_parsecomp(newline, 0);
+	dec = cli_parsecomp(newline, FALSE);
 	if (dec == NOCOMPONENTDEC)
 	{
 		cli_commentline(changed, win);
-		return(1);
+		return(TRUE);
 	}
 
 	/* determine the prototype being created */
@@ -1195,7 +1197,7 @@ INTSML cli_adddeclaration(char *newline, INTSML changed, WINDOWPART *win)
 		ttyputerr(M_("Unknown component type: %s"), dec->protoname);
 		cli_commentline(changed, win);
 		cli_deletecomponentdec(dec);
-		return(1);
+		return(TRUE);
 	}
 
 	/* check for duplicate component names */
@@ -1208,7 +1210,7 @@ INTSML cli_adddeclaration(char *newline, INTSML changed, WINDOWPART *win)
 			ttyputerr(M_("Already a component called '%s'"), compo->name);
 			cli_commentline(changed, win);
 			cli_deletecomponentdec(dec);
-			return(1);
+			return(TRUE);
 		}
 
 		/* now see if the name is duplicated in this statement */
@@ -1219,7 +1221,7 @@ INTSML cli_adddeclaration(char *newline, INTSML changed, WINDOWPART *win)
 				ttyputerr(M_("Duplicate component name '%s'"), compo->name);
 				cli_commentline(changed, win);
 				cli_deletecomponentdec(dec);
-				return(1);
+				return(TRUE);
 			}
 		}
 	}
@@ -1230,28 +1232,28 @@ INTSML cli_adddeclaration(char *newline, INTSML changed, WINDOWPART *win)
 		/* get the size/location/orientation of the component */
 		cli_getfactors(NONODEINST, np, compo, &lx, &hx, &ly, &hy, &rot, &trn, 0, 0);
 
-		cli_ownchanges = 1;
+		cli_ownchanges = TRUE;
 		ni = newnodeinst(np, lx, hx, ly, hy, trn, rot, cli_curfacet);
 		if (ni != NONODEINST)
 		{
-			var = setvalkey((INTBIG)ni, VNODEINST, el_node_name, (INTBIG)compo->name,
+			var = setvalkey((INTBIG)ni, VNODEINST, el_node_name_key, (INTBIG)compo->name,
 				VSTRING|VDISPLAY);
 			if (var != NOVARIABLE)
 				defaulttextsize(3, var->textdescript);
 			endobjectchange((INTBIG)ni, VNODEINST);
 		}
-		cli_ownchanges = 0;
+		cli_ownchanges = FALSE;
 	}
 	cli_deletecomponentdec(dec);
-	return(0);
+	return(FALSE);
 }
 
 /*
  * routine to add graphics equivalent to the new text connection "newline"
  * with the line index "changed".  Text was changed in window "win".  Returns
- * nonzero on error
+ * true on error
  */
-INTSML cli_addwire(char *newline, INTSML changed, WINDOWPART *win)
+BOOLEAN cli_addwire(char *newline, INTBIG changed, WINDOWPART *win)
 {
 	REGISTER CONNECTION *dcl;
 	REGISTER CONS *cons;
@@ -1260,93 +1262,94 @@ INTSML cli_addwire(char *newline, INTSML changed, WINDOWPART *win)
 	ARCPROTO *ap;
 	REGISTER ARCINST *ai;
 	INTBIG xA, yA, xB, yB, wid;
-	REGISTER INTSML variable, gothor, gotver, addedmanhattan;
+	REGISTER INTBIG variable;
+	REGISTER BOOLEAN gothor, gotver, addedmanhattan;
 
 	/* parse the line and get the endpoints */
-	dcl = cli_parseconn(newline, 0);
+	dcl = cli_parseconn(newline, FALSE);
 	if (dcl == NOCONNECTION)
 	{
 		cli_commentline(changed, win);
-		return(1);
+		return(TRUE);
 	}
 
-	if (cli_pickwire(dcl, &nA, &pA, &nB, &pB, &ap, &wid, NOARCINST, NONODEINST, NONODEINST) != 0)
+	if (cli_pickwire(dcl, &nA, &pA, &nB, &pB, &ap, &wid, NOARCINST, NONODEINST, NONODEINST))
 	{
 		cli_commentline(changed, win);
 		cli_deleteconnection(dcl);
-		return(1);
+		return(TRUE);
 	}
 
 	/* create the arc */
 	portposition(nA, pA, &xA, &yA);
 	portposition(nB, pB, &xB, &yB);
-	cli_ownchanges = 1;
+	cli_ownchanges = TRUE;
 	ai = newarcinst(ap, wid, 0, nA,pA,xA,yA, nB,pB,xB,yB, cli_curfacet);
-	cli_ownchanges = 0;
+	cli_ownchanges = FALSE;
 	if (ai == NOARCINST)
 	{
 		ttyputerr(M_("Cannot make the wire"));
 		cli_commentline(changed, win);
 		cli_deleteconnection(dcl);
-		return(1);
+		return(TRUE);
 	}
 
 	/* set constraints on the arc */
-	gothor = gotver = 0;
+	gothor = gotver = FALSE;
 	for(cons = dcl->firstcons; cons != NOCONS; cons = cons->nextcons)
 	{
 		if (namesame(cons->direction, "left") == 0)
 		{
 			variable = CLLEFT;
-			gothor++;
+			gothor = TRUE;
 		} else if (namesame(cons->direction, "right") == 0)
 		{
 			variable = CLRIGHT;
-			gothor++;
+			gothor = TRUE;
 		} else if (namesame(cons->direction, "down") == 0)
 		{
 			variable = CLDOWN;
-			gotver++;
+			gotver = TRUE;
 		} else if (namesame(cons->direction, "up") == 0)
 		{
 			variable = CLUP;
-			gotver++;
+			gotver = TRUE;
 		}
-		cli_ownchanges = 1;
+		cli_ownchanges = TRUE;
 		(void)cli_addarcconstraint(ai, variable, cons->flag, cons->amount, 1);
-		cli_ownchanges = 0;
+		cli_ownchanges = FALSE;
 	}
 	cli_deleteconnection(dcl);
 	endobjectchange((INTBIG)ai, VARCINST);
 
 	/* add in manhattan constraints (temporarily) if applicable */
-	addedmanhattan = 0;
-	if (((gothor == 0 && gotver != 0) || (gothor != 0 && gotver == 0)) && cli_manhattan != 0)
+	addedmanhattan = FALSE;
+	if (((!gothor && gotver) || (gothor && !gotver)) && cli_manhattan)
 	{
-		if (gothor == 0) variable = CLLEFT; else variable = CLDOWN;
+		if (!gothor) variable = CLLEFT; else variable = CLDOWN;
 	}
 
 	/* make sure all constraints are met */
-	cli_solvefacet(cli_curfacet, 0, 1);
+	cli_solvefacet(cli_curfacet, FALSE, TRUE);
 
 	/* remove temporary manhattan constraint if it was added */
-	if (addedmanhattan != 0)
+	if (addedmanhattan)
 		(void)cli_deletearcconstraint(ai, variable, CLEQUALS, 0);
-	return(0);
+	return(FALSE);
 }
 
 /*
  * routine to add graphics equivalent to the new text connection "newline"
  * with the line index "changed".  Text was changed in window "win".
  */
-void cli_addexport(char *newline, INTSML changed, WINDOWPART *win)
+void cli_addexport(char *newline, INTBIG changed, WINDOWPART *win)
 {
 	REGISTER EXPORT *e;
 	REGISTER PORTPROTO *pp, *newpp;
 	REGISTER NODEINST *ni;
 
 	/* parse the export statement */
-	e = cli_parseexport(newline, 0);
+	e = cli_parseexport(newline, FALSE);
 	if (e == NOEXPORT)
 	{
 		cli_commentline(changed, win);
@@ -1383,9 +1386,9 @@ void cli_addexport(char *newline, INTSML changed, WINDOWPART *win)
 	}
 
 	/* create the port */
-	cli_ownchanges = 1;
+	cli_ownchanges = TRUE;
 	newpp = newportproto(cli_curfacet, ni, pp, e->portname);
-	cli_ownchanges = 0;
+	cli_ownchanges = FALSE;
 	if (newpp == NOPORTPROTO)
 	{
 		ttyputerr(M_("Could not create the port"));
@@ -1407,7 +1410,7 @@ PORTPROTO *cli_getexportsubport(EXPORT *e, NODEINST *ni)
 	} else
 	{
 		pp = ni->proto->firstportproto;
-		if (cli_uniqueport(ni, pp) == 0)
+		if (!cli_uniqueport(ni, pp))
 		{
 			ttyputerr(M_("Ambiguous port on node %s"), e->component);
 			pp = NOPORTPROTO;
@@ -1425,7 +1428,7 @@ PORTPROTO *cli_getexportsubport(EXPORT *e, NODEINST *ni)
  * any defaults (and use "defcx/defcy" as the default location).
  */
 void cli_getfactors(NODEINST *ni, NODEPROTO *np, COMPONENT *compo, INTBIG *lx,
-	INTBIG *hx, INTBIG *ly, INTBIG *hy, INTSML *rot, INTSML *trn, INTBIG defcx, INTBIG defcy)
+	INTBIG *hx, INTBIG *ly, INTBIG *hy, INTBIG *rot, INTBIG *trn, INTBIG defcx, INTBIG defcy)
 {
 	REGISTER INTBIG xc, yc, xs, ys;
 	INTBIG plx, phx, ply, phy;
@@ -1500,7 +1503,7 @@ void cli_killthenode(NODEINST *ni)
 {
 	REGISTER PORTARCINST *pi, *nextpi;
 	REGISTER ARCINST *ai;
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 	REGISTER NODEINST *oni;
 
 	for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = nextpi)
@@ -1515,24 +1518,24 @@ void cli_killthenode(NODEINST *ni)
 			if (oni == ni) continue;
 			if (oni->firstportarcinst == NOPORTARCINST) cli_changeequivcomp(oni);
 		}
-		cli_ownchanges = 1;
+		cli_ownchanges = TRUE;
 		startobjectchange((INTBIG)ai, VARCINST);
 		(void)killarcinst(ai);
-		cli_ownchanges = 0;
+		cli_ownchanges = FALSE;
 	}
 
 	/* delete the node */
-	cli_ownchanges = 1;
+	cli_ownchanges = TRUE;
 	startobjectchange((INTBIG)ni, VNODEINST);
 	(void)killnodeinst(ni);
-	cli_ownchanges = 0;
+	cli_ownchanges = FALSE;
 }
 
 /*
  * routine to insert a comment to remove the text line with the index
  * "cindex".  Text was changed in window "win".
  */
-void cli_commentline(INTSML cindex, WINDOWPART *win)
+void cli_commentline(INTBIG cindex, WINDOWPART *win)
 {
 	(void)initinfstr();
 	(void)addstringtoinfstr("; ");
@@ -1544,7 +1547,7 @@ void cli_commentline(INTSML cindex, WINDOWPART *win)
  * routine to comment line "cindex" and restore line "str" of text.  Text
  * was changed in window "win".
  */
-void cli_restoreline(char *str, INTSML cindex, WINDOWPART *win)
+void cli_restoreline(char *str, INTBIG cindex, WINDOWPART *win)
 {
 	/* first insert this old line */
 	(void)asktool(us_tool, "edit-addline", (INTBIG)win, cindex+1, (INTBIG)str);
@@ -1558,9 +1561,9 @@ void cli_restoreline(char *str, INTSML cindex, WINDOWPART *win)
 
 void cli_replaceendfacet(char *str, WINDOWPART *win)
 {
-	REGISTER INTSML i, maxlines, type;
+	REGISTER INTBIG i, maxlines, type;
 
-	maxlines = (INTSML)asktool(us_tool, "edit-totallines", (INTBIG)win);
+	maxlines = asktool(us_tool, "edit-totallines", (INTBIG)win);
 
 	/* search for all other "beginfacet" lines */
 	for(i = 0; i < maxlines; i++)
