@@ -33,17 +33,19 @@
  * sample routines and their arguments:
  *
  * aa_init(INTBIG *argc, char *argv[], TOOL *tool) {}
- * INTSML aa_set(INTSML count, char *par[]) {}
+ * BOOLEAN aa_set(INTBIG count, char *par[]) {}
  * INTBIG aa_request(char *command,...) {}
  * aa_examinenodeproto(NODEPROTO *np) {}
  * aa_slice() {}
  * aa_done() {}
- * aa_startbatch(INTSML source, INTSML undoredo) {}
+ * aa_startbatch(TOOL *source, BOOLEAN undoredo) {}
  * aa_endbatch() {}
  * aa_startobjectchange(INTBIG addr, INTBIG type) {}
  * aa_endobjectchange(INTBIG addr, INTBIG type) {}
  * aa_modifynodeinst(NODEINST *ni, INTBIG olx, INTBIG oly, INTBIG ohx, INTBIG ohy,
- *    INTSML orot, INTSML otran) {}
+ *    INTBIG orot, INTBIG otran) {}
+ * aa_modifynodeinsts(INTBIG count, NODEINST **ni, INTBIG *olx, INTBIG *oly, INTBIG *ohx,
+ *    INTBIG *ohy, INTBIG *orot, INTBIG *otran) {}
  * aa_modifyarcinst(ARCINST *ai, INTBIG oxA, INTBIG oyA, INTBIG oxB, INTBIG oyB,
  *    INTBIG owid, INTBIG olen) {}
  * aa_modifyportproto(PORTPROTO *pp) {}
@@ -61,7 +63,7 @@
  *    INTBIG ovalue) {}
  * aa_readlibrary(LIBRARY *lib) {}
  * aa_eraselibrary(LIBRARY *lib) {}
- * aa_writelibrary(LIBRARY *lib, INTSML pass) {}
+ * aa_writelibrary(LIBRARY *lib, BOOLEAN pass2) {}
  */
 
 /*
@@ -176,8 +178,8 @@ TOOL el_tools[] =
 	us_request,            us_examinenodeproto,  us_slice,				/* request/examine/slice */
 	us_startbatch,         us_endbatch,									/* startbatch/endbatch */
 	us_startobjectchange,  us_endobjectchange,							/* startobject/endobject */
-	us_modifynodeinst,     0,                    0,						/* modnode/modarc/modport */
-	us_modifynodeproto,    us_modifydescript,							/* modnodeproto/moddescript */
+	us_modifynodeinst,     0,                    0,						/* modnode/modnodes/modarc */
+	0,                     us_modifynodeproto,   us_modifydescript,		/* modport/modnodeproto/moddescript */
 	us_newobject,          us_killobject,								/* newobject/killobject */
 	us_newvariable,        us_killvariable,								/* newvariable/killvariable */
 	us_modifyvariable,     0,                    0,						/* modvar/insvar/delvar */
@@ -190,8 +192,8 @@ TOOL el_tools[] =
 	io_request,            0,                    io_slice,				/* request/examine/slice */
 	0,                     0,											/* startbatch/endbatch */
 	0,                     0,											/* startobject/endobject */
-	0,                     0,                    0,						/* modnode/modarc/modport */
-	0,                     0,											/* modnodeproto/moddescript */
+	0,                     0,                    0,						/* modnode/modnodes/modarc */
+	0,                     0,                    0,						/* modport/modnodeproto/moddescript */
 	0,                     0,											/* newobject/killobject */
 	0,                     0,											/* newvariable/killvariable */
 	0,                     0,                    0,						/* modvar/insvar/delvar */
@@ -205,8 +207,8 @@ TOOL el_tools[] =
 	0,                     0,                    com_slice,				/* request/examine/slice */
 	0,                     0,											/* startbatch/endbatch */
 	0,                     0,											/* startobject/endobject */
-	0,                     0,                    0,						/* modnode/modarc/modport */
-	0,                     0,											/* modnodeproto/moddescript */
+	0,                     0,                    0,						/* modnode/modnodes/modarc */
+	0,                     0,                    0,						/* modport/modnodeproto/moddescript */
 	0,                     0,											/* newobject/killobject */
 	0,                     0,											/* newvariable/killvariable */
 	0,                     0,                    0,						/* modvar/insvar/delvar */
@@ -221,8 +223,8 @@ TOOL el_tools[] =
 	0,                     0,                    pla_slice,				/* request/examine/slice */
 	0,                     0,											/* startbatch/endbatch */
 	0,                     0,											/* startobject/endobject */
-	0,                     0,                    0,						/* modnode/modarc/modport */
-	0,                     0,											/* modnodeproto/moddescript */
+	0,                     0,                    0,						/* modnode/modnodes/modarc */
+	0,                     0,                    0,						/* modport/modnodeproto/moddescript */
 	0,                     0,											/* newobject/killobject */
 	0,                     0,											/* newvariable/killvariable */
 	0,                     0,                    0,						/* modvar/insvar/delvar */
@@ -237,8 +239,8 @@ TOOL el_tools[] =
 	0,                     0,                    ro_slice,				/* request/examine/slice */
 	ro_startbatch,         0,											/* startbatch/endbatch */
 	0,                     0,											/* startobject/endobject */
-	ro_modifynodeinst,     ro_modifyarcinst,     ro_modifyportproto,	/* modnode/modarc/modport */
-	0,                     0,											/* modnodeproto/moddescript */
+	ro_modifynodeinst,     0,                    ro_modifyarcinst,		/* modnode/modnodes/modarc */
+	ro_modifyportproto,    0,                    0,						/* modport/modnodeproto/moddescript */
 	ro_newobject,          ro_killobject,								/* newobject/killobject */
 	ro_newvariable,        0,											/* newvariable/killvariable */
 	0,                     0,                    0,						/* modvar/insvar/delvar */
@@ -253,8 +255,8 @@ TOOL el_tools[] =
 	sc_request,            0,                    sc_slice,				/* request/examine/slice */
 	0,                     0,											/* startbatch/endbatch */
 	0,                     0,											/* startobject/endobject */
-	0,                     0,                    0,						/* modnode/modarc/modport */
-	0,                     0,											/* modnodeproto/moddescript */
+	0,                     0,                    0,						/* modnode/modnodes/modarc */
+	0,                     0,                    0,						/* modport/modnodeproto/moddescript */
 	0,                     0,											/* newobject/killobject */
 	0,                     0,											/* newvariable/killvariable */
 	0,                     0,                    0,						/* modvar/insvar/delvar */
@@ -269,8 +271,8 @@ TOOL el_tools[] =
 	map_request,           map_examinenodeproto, map_slice,				/* request/examine/slice */
 	map_startbatch,        map_endbatch,								/* startbatch/endbatch */
 	map_startobjectchange, map_endobjectchange,							/* startobject/endobject */
-	map_modifynodeinst,    map_modifyarcinst,    map_modifyportproto,	/* modnode/modarc/modport */
-	map_modifynodeproto,   map_modifydescript,							/* modnodeproto/moddescript */
+	map_modifynodeinst,    0,                    map_modifyarcinst,		/* modnode/modnodes/modarc */
+	map_modifyportproto,   map_modifynodeproto,  map_modifydescript,	/* modport/modnodeproto/moddescript */
 	map_newobject,         map_killobject,								/* newobject/killobject */
 	map_newvariable,       map_killvariable,							/* newvariable/killvariable */
 	map_modifyvariable,    map_insertvariable,   map_deletevariable,	/* modvar/insvar/delvar */
@@ -285,8 +287,8 @@ TOOL el_tools[] =
 	vhdl_request,          0,                    vhdl_slice,			/* request/examine/slice */
 	0,                     0,											/* startbatch/endbatch */
 	0,                     0,											/* startobject/endobject */
-	0,                     0,                    0,						/* modnode/modarc/modport */
-	0,                     0,											/* modnodeproto/moddescript */
+	0,                     0,                    0,						/* modnode/modnodes/modarc */
+	0,                     0,                    0,						/* modport/modnodeproto/moddescript */
 	0,                     0,											/* newobject/killobject */
 	0,                     0,											/* newvariable/killvariable */
 	0,                     0,                    0,						/* modvar/insvar/delvar */
@@ -301,8 +303,8 @@ TOOL el_tools[] =
 	0,                     0,                    compen_slice,			/* request/examine/slice */
 	0,                     0,											/* startbatch/endbatch */
 	0,                     0,											/* startobject/endobject */
-	compen_modifynodeinst, 0,                    0,						/* modnode/modarc/modport */
-	0,                     0,											/* modnodeproto/moddescript */
+	compen_modifynodeinst, 0,                    0,						/* modnode/modnodes/modarc */
+	0,                     0,                    0,						/* modport/modnodeproto/moddescript */
 	0,                     compen_killobject,							/* newobject/killobject */
 	0,                     0,											/* newvariable/killvariable */
 	0,                     0,                    0,						/* modvar/insvar/delvar */
@@ -317,8 +319,8 @@ TOOL el_tools[] =
 	0,                     0,                    0,						/* request/examine/slice */
 	0,                     0,											/* startbatch/endbatch */
 	0,                     0,											/* startobject/endobject */
-	0,                     0,                    0,						/* modnode/modarc/modport */
-	0,                     0,											/* modnodeproto/moddescript */
+	0,                     0,                    0,						/* modnode/modnodes/modarc */
+	0,                     0,                    0,						/* modport/modnodeproto/moddescript */
 	0,                     0,											/* newobject/killobject */
 	0,                     0,											/* newvariable/killvariable */
 	0,                     0,                    0,						/* modvar/insvar/delvar */
@@ -332,8 +334,8 @@ TOOL el_tools[] =
 	net_request,           net_examinenodeproto, net_slice,				/* request/examine/slice */
 	net_startbatch,        net_endbatch,								/* startbatch/endbatch */
 	0,                     0,											/* startobject/endobject */
-	0,                     0,                    net_modifyportproto,	/* modnode/modarc/modport */
-	0,                     0,											/* modnodeproto/moddescript */
+	0,                     0,                    0,						/* modnode/modnodes/modarc */
+	net_modifyportproto,   0,                    0,						/* modport/modnodeproto/moddescript */
 	net_newobject,         net_killobject,								/* newobject/killobject */
 	net_newvariable,       net_killvariable,							/* newvariable/killvariable */
 	0,                     0,                    0,						/* modvar/insvar/delvar */
@@ -347,8 +349,8 @@ TOOL el_tools[] =
 	0,                     dr_examinenodeproto,  dr_slice,				/* request/examine/slice */
 	0,                     0,											/* startbatch/endbatch */
 	0,                     0,											/* startobject/endobject */
-	dr_modifynodeinst,     dr_modifyarcinst,     0,						/* modnode/modarc/modport */
-	0,                     0,											/* modnodeproto/moddescript */
+	dr_modifynodeinst,     0,                    dr_modifyarcinst,		/* modnode/modnodes/modarc */
+	0,                     0,                    0,						/* modport/modnodeproto/moddescript */
 	dr_newobject,          dr_killobject,								/* newobject/killobject */
 	dr_newvariable,        0,											/* newvariable/killvariable */
 	0,                     0,                    0,						/* modvar/insvar/delvar */
@@ -363,8 +365,8 @@ TOOL el_tools[] =
 	0,                     0,                    0,						/* request/examine/slice */
 	0,                     0,											/* startbatch/endbatch */
 	0,                     0,											/* startobject/endobject */
-	0,                     0,                    0,						/* modnode/modarc/modport */
-	0,                     0,											/* modnodeproto/moddescript */
+	0,                     0,                    0,						/* modnode/modnodes/modarc */
+	0,                     0,                    0,						/* modport/modnodeproto/moddescript */
 	0,                     0,											/* newobject/killobject */
 	0,                     0,											/* newvariable/killvariable */
 	0,                     0,                    0,						/* modvar/insvar/delvar */
@@ -379,12 +381,12 @@ TOOL el_tools[] =
 	0,                     0,                    sim_slice,				/* request/examine/slice */
 	sim_startbatch,        0,											/* startbatch/endbatch */
 	0,                     0,											/* startobject/endobject */
-	sim_modifynodeinst,    sim_modifyarcinst,    sim_modifyportproto,	/* modnode/modarc/modport */
-	0,                     0,											/* modnodeproto/moddescript */
+	sim_modifynodeinst,    0,                    sim_modifyarcinst,		/* modnode/modnodes/modarc */
+	sim_modifyportproto,   0,                    0,						/* modport/modnodeproto/moddescript */
 	sim_newobject,         sim_killobject,								/* newobject/killobject */
 	sim_newvariable,       sim_killvariable,							/* newvariable/killvariable */
 	sim_modifyvariable,    sim_insertvariable,   sim_deletevariable,	/* modvar/insvar/delvar */
-	0,                     0,                    0,						/* readlib/eraselib/writelib */
+	sim_readlibrary,       0,                    0,						/* readlib/eraselib/writelib */
 	NOVARIABLE, 0},
 #endif
 
@@ -395,8 +397,8 @@ TOOL el_tools[] =
 	0,                     0,                    proj_slice,			/* request/examine/slice */
 	proj_startbatch,       0,											/* startbatch/endbatch */
 	0,                     0,											/* startobject/endobject */
-	proj_modifynodeinst,   proj_modifyarcinst,   proj_modifyportproto,	/* modnode/modarc/modport */
-	0,                     proj_modifydescript,							/* modnodeproto/moddescript */
+	proj_modifynodeinst,   0,                    proj_modifyarcinst,	/* modnode/modnodes/modarc */
+	proj_modifyportproto,  0,                    proj_modifydescript,	/* modport/modnodeproto/moddescript */
 	proj_newobject,        proj_killobject,								/* newobject/killobject */
 	proj_newvariable,      proj_killvariable,							/* newvariable/killvariable */
 	proj_modifyvariable,   proj_insertvariable,  proj_deletevariable,	/* modvar/insvar/delvar */
@@ -406,15 +408,15 @@ TOOL el_tools[] =
 
 	/* termination */
 	{NULL, 0, 0, NULL, NULL,
-	 NULL, NULL, NULL,
-	 NULL, NULL, NULL,
-	 NULL, NULL,
-	 NULL, NULL,
-	 NULL, NULL, NULL,
-	 NULL, NULL,
-	 NULL, NULL,
-	 NULL, NULL,
-	 NULL, NULL, NULL,
-	 NULL, NULL, NULL,
+	 NULL, NULL, NULL,													/* init/done/set */
+	 NULL, NULL, NULL,													/* request/examine/slice */
+	 NULL, NULL,														/* startbatch/endbatch */
+	 NULL, NULL,														/* startobject/endobject */
+	 NULL, NULL, NULL,													/* modnode/modnodes/modarc */
+	 NULL, NULL, NULL,													/* modport/modnodeproto/moddescript */
+	 NULL, NULL,														/* newobject/killobject */
+	 NULL, NULL,														/* newvariable/killvariable */
+	 NULL, NULL, NULL,													/* modvar/insvar/delvar */
+	 NULL, NULL, NULL,													/* readlib/eraselib/writelib */
 	 NULL, 0}
 };
