@@ -44,10 +44,10 @@ static CHANGEBATCH *db_changebatchfree;			/* head of free change batches */
 static CHANGE      *db_changefree;				/* head of free change modules */
 static CHANGEFACET *db_changefacetfree;			/* head of free change facet modules */
 static TOOL        *db_currenttool;				/* current tool being given a slice */
-       INTSML       db_donextchangequietly = 0;	/* nonzero to do next change quietly */
-       INTSML       db_dochangesquietly = 0;	/* nonzero to do changes quietly */
+       BOOLEAN      db_donextchangequietly = FALSE;	/* true to do next change quietly */
+       BOOLEAN      db_dochangesquietly = FALSE;/* true to do changes quietly */
        UINTBIG      db_changetimestamp = 0;		/* timestamp for changes to database */
-       INTSML       db_broadcasting = 0;		/* nonzero if broadcasting */
+       INTBIG       db_broadcasting = 0;		/* nonzero if broadcasting */
 
 /* prototypes for local routines */
 static CHANGE      *db_allocchange(void);
@@ -56,14 +56,13 @@ static CHANGEFACET *db_allocchangefacet(void);
 static CHANGEBATCH *db_allocchangebatch(void);
 static void         db_freechangebatch(CHANGEBATCH*);
 static void         db_killbatch(CHANGEBATCH*);
-static char        *db_namevariable(INTBIG, INTBIG);
 static CHANGEBATCH *db_preparenewbatch(void);
 static void         db_erasebatch(CHANGEBATCH*);
 static void         db_freechangefacet(CHANGEFACET*);
-static void         db_loadhistorylist(short);
-static void         db_broadcastchange(CHANGE*, INTSML, INTSML);
-static INTSML       db_reversechange(CHANGE*);
-static char        *db_describechange(INTSML, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+static void         db_loadhistorylist(INTBIG);
+static void         db_broadcastchange(CHANGE*, BOOLEAN, BOOLEAN);
+static BOOLEAN      db_reversechange(CHANGE*);
+static char        *db_describechange(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 
 /*
  * Routine to free all memory associated with this module.
@@ -118,22 +117,23 @@ void db_initializechanges(void)
  * change is in "change".  The arguments to the change depend on the type, and are in "a1"
  * through "a6".  Returns NOCHANGE upon error
  */
-CHANGE *db_change(INTBIG obj, INTSML change, INTBIG a1, INTBIG a2, INTBIG a3, INTBIG a4,
+CHANGE *db_change(INTBIG obj, INTBIG change, INTBIG a1, INTBIG a2, INTBIG a3, INTBIG a4,
 	INTBIG a5, INTBIG a6)
 {
-	REGISTER INTSML i, firstchange, major;
+	REGISTER BOOLEAN firstchange;
+	REGISTER INTBIG i, major;
 	REGISTER PORTPROTO *pp;
 	REGISTER NODEPROTO *np;
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
 	REGISTER CHANGE *c;
 	REGISTER LIBRARY *lib;
-	static char *broadcasttype[] = {N_("nodeinstnew"), N_("nodeinstkill"), N_("nodeinstmod"),
-		N_("arcinstnew"), N_("arcinstkill"), N_("arcinstmod"), N_("portprotonew"),
-		N_("portprotokill"), N_("portprotomod"), N_("nodeprotonew"), N_("nodeprotokill"),
-		N_("nodeprotomod"), N_("objectstart"), N_("objectend"), N_("objectnew"), N_("objectkill"),
-		N_("variablenew"), N_("variablekill"), N_("variablemod"), N_("variableinsert"),
-		N_("variabledelete"), N_("descriptmod")};
+	static char *broadcasttype[] = {M_("nodeinstnew"), M_("nodeinstkill"), M_("nodeinstmod"),
+		M_("arcinstnew"), M_("arcinstkill"), M_("arcinstmod"), M_("portprotonew"),
+		M_("portprotokill"), M_("portprotomod"), M_("nodeprotonew"), M_("nodeprotokill"),
+		M_("nodeprotomod"), M_("objectstart"), M_("objectend"), M_("objectnew"), M_("objectkill"),
+		M_("variablenew"), M_("variablekill"), M_("variablemod"), M_("variableinsert"),
+		M_("variabledelete"), M_("descriptmod")};
 
 	if (db_broadcasting != 0)
 	{
@@ -186,7 +186,7 @@ CHANGE *db_change(INTBIG obj, INTSML change, INTBIG a1, INTBIG a2, INTBIG a3, IN
 		case OBJECTNEW:
 		case OBJECTKILL:
 			np = db_whichnodeproto(obj, a1);
-			lib = db_whichlibrary(obj, a1);
+			lib = whichlibrary(obj, a1);
 			break;
 		case VARIABLENEW:
 		case VARIABLEMOD:
@@ -195,25 +195,38 @@ CHANGE *db_change(INTBIG obj, INTSML change, INTBIG a1, INTBIG a2, INTBIG a3, IN
 			if ((a3&VDONTSAVE) != 0) { lib = NOLIBRARY;   np = NONODEPROTO; } else
 			{
 				np = db_whichnodeproto(obj, a1);
-				lib = db_whichlibrary(obj, a1);
+				lib = whichlibrary(obj, a1);
 
-				/* special case: when changing text in text-only facet, this is major */
-				if (a1 == VNODEPROTO && a2 == el_facet_message)
-					major = 1;
+				/* special cases that make the change "major" */
+				switch (a1)
+				{
+					case VNODEPROTO:
+						/* when changing text in text-only facet */
+						if (a2 == el_facet_message_key) major = 1;
+						break;
+					case VNODEINST:
+						/* when changing node name */
+						if (a2 == el_node_name_key) major = 1;
+						break;
+					case VARCINST:
+						/* when changing arc name */
+						if (a2 == el_arc_name_key) major = 1;
+						break;
+				}
 			}
 			break;
 		case VARIABLEKILL:
 			if ((a4&VDONTSAVE) != 0) { lib = NOLIBRARY;   np = NONODEPROTO; } else
 			{
 				np = db_whichnodeproto(obj, a1);
-				lib = db_whichlibrary(obj, a1);
+				lib = whichlibrary(obj, a1);
 			}
 			break;
 		case DESCRIPTMOD:
 			if ((a3&VDONTSAVE) != 0) { lib = NOLIBRARY;   np = NONODEPROTO; } else
 			{
 				np = db_whichnodeproto(obj, a1);
-				lib = db_whichlibrary(obj, a1);
+				lib = whichlibrary(obj, a1);
 			}
 			break;
 	}
@@ -241,7 +254,7 @@ CHANGE *db_change(INTBIG obj, INTSML change, INTBIG a1, INTBIG a2, INTBIG a3, IN
 	}
 
 	/* insert new change module into linked list */
-	firstchange = 0;
+	firstchange = FALSE;
 	if (db_currentbatch == NOCHANGEBATCH)
 	{
 		db_currentbatch = db_preparenewbatch();
@@ -250,7 +263,7 @@ CHANGE *db_change(INTBIG obj, INTSML change, INTBIG a1, INTBIG a2, INTBIG a3, IN
 			ttyputnomemory();
 			return(NOCHANGE);
 		}
-		firstchange = 1;
+		firstchange = TRUE;
 		db_currentbatch->changehead = c;
 		c->prevchange = NOCHANGE;
 	} else
@@ -262,12 +275,12 @@ CHANGE *db_change(INTBIG obj, INTSML change, INTBIG a1, INTBIG a2, INTBIG a3, IN
 	c->nextchange = NOCHANGE;
 
 	/* save the change information */
-	c->entryaddr = obj;         c->changetype = change;
+	c->changetype = change;     c->entryaddr = obj;
 	c->p1 = a1;   c->p2 = a2;   c->p3 = a3;
 	c->p4 = a4;   c->p5 = a5;   c->p6 = a6;
 
 	/* broadcast the change */
-	db_broadcastchange(c, firstchange, 0);
+	db_broadcastchange(c, firstchange, FALSE);
 	return(c);
 }
 
@@ -277,14 +290,14 @@ CHANGE *db_change(INTBIG obj, INTSML change, INTBIG a1, INTBIG a2, INTBIG a3, IN
  */
 void nextchangequiet(void)
 {
-	db_donextchangequietly = 1;
+	db_donextchangequietly = TRUE;
 }
 
 /*
- * Routine to set the nature of subsequent changes to be "quiet".  Nonzero
+ * Routine to set the nature of subsequent changes to be "quiet".  TRUE
  * means no constraints, change control, or broadcast are done.
  */
-void changesquiet(INTSML quiet)
+void changesquiet(BOOLEAN quiet)
 {
 	db_dochangesquietly = quiet;
 }
@@ -292,17 +305,17 @@ void changesquiet(INTSML quiet)
 /*
  * Routine to broadcast change "c" to all tools that are on.  If "firstchange" is nonzero,
  * this is the first change of a batch, and a "startbatch" change will also be broadcast.
- * "undoredo" is nonzero if this is an undo/redo batch.
+ * "undoredo" is true if this is an undo/redo batch.
  */
-void db_broadcastchange(CHANGE *c, INTSML firstchange, INTSML undoredo)
+void db_broadcastchange(CHANGE *c, BOOLEAN firstchange, BOOLEAN undoredo)
 {
-	REGISTER INTSML i, oldbroadcasting;
+	REGISTER INTBIG i, oldbroadcasting;
 	UINTBIG descript[TEXTDESCRIPTSIZE];
 
 	/* start the batch if this is the first change */
 	oldbroadcasting = db_broadcasting;
 	db_broadcasting = c->changetype+1;
-	if (firstchange != 0)
+	if (firstchange)
 	{
 		/* broadcast a start-batch on the first change */
 		for(i=0; i<el_maxtools; i++)
@@ -325,7 +338,7 @@ void db_broadcastchange(CHANGE *c, INTSML firstchange, INTSML undoredo)
 			for(i=0; i<el_maxtools; i++)
 				if ((el_tools[i].toolstate & TOOLON) != 0 && el_tools[i].modifynodeinst != 0)
 					(*el_tools[i].modifynodeinst)((NODEINST *)c->entryaddr, c->p1, c->p2,
-						c->p3, c->p4, (INTSML)c->p5, (INTSML)c->p6);
+						c->p3, c->p4, c->p5, c->p6);
 			break;
 		case ARCINSTNEW:
 			for(i=0; i<el_maxtools; i++)
@@ -438,7 +451,7 @@ void db_broadcastchange(CHANGE *c, INTSML firstchange, INTSML undoredo)
  */
 void db_endbatch(void)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 
 	/* if no changes were recorded, stop */
 	if (db_currentbatch == NOCHANGEBATCH) return;
@@ -471,7 +484,7 @@ CHANGEBATCH *db_preparenewbatch(void)
 	if (thisbatch == NOCHANGEBATCH) return(NOCHANGEBATCH);
 	thisbatch->changehead = NOCHANGE;
 	thisbatch->batchnumber = db_batchnumber++;
-	thisbatch->done = 1;
+	thisbatch->done = TRUE;
 	thisbatch->nextchangebatch = NOCHANGEBATCH;
 
 	/* put at head of list */
@@ -571,7 +584,7 @@ void db_erasebatch(CHANGEBATCH *batch)
 					{
 						e = w->editor;
 						if ((w->state&WINDOWTYPE) == POPTEXTWINDOW)
-							(void)screenrestorebox(e->savedbox, -1);
+							screenrestorebox(e->savedbox, -1);
 						us_freeeditor(e);
 					}
 					freewindowpart(w);
@@ -582,7 +595,8 @@ void db_erasebatch(CHANGEBATCH *batch)
 					freecell(cell);
 					break;
 			}
-		} else if (c->changetype == VARIABLEDEL)
+		} else if (c->changetype == VARIABLEDEL ||
+			c->changetype == VARIABLEMOD)
 		{
 			/* free the array entry if it is allocated */
 			if ((c->p3&(VCODE1|VCODE2)) != 0 || (c->p3&VTYPE) == VSTRING)
@@ -655,7 +669,7 @@ INTBIG historylistsize(INTBIG newsize)
 	REGISTER CHANGEBATCH *batch;
 	REGISTER INTBIG oldsize;
 
-	if (newsize <= 0) return((INTSML)db_maximumbatches);
+	if (newsize <= 0) return(db_maximumbatches);
 
 	oldsize = db_maximumbatches;
 	db_maximumbatches = newsize;
@@ -708,18 +722,18 @@ void setactivity(char *message)
 
 /*
  * Routine to return the nature of the next possible undo/redo batch.
- * If "undo" is nonzero, examine the next undo batch, otherwise the next redo batch.
+ * If "undo" is true, examine the next undo batch, otherwise the next redo batch.
  * Returns zero if there is no batch available.
  * Returns positive if there is a batch with major changes in it.
  * Returns negative if there is a batch with minor changes in it.
  */
-INTSML undonature(INTSML undo)
+INTBIG undonature(BOOLEAN undo)
 {
 	REGISTER CHANGEBATCH *batch;
 	REGISTER CHANGE *c;
-	REGISTER INTSML retval;
+	REGISTER INTBIG retval;
 
-	if (undo != 0)
+	if (undo)
 	{
 		/* examine the next batch to be undone */
 		if (db_donebatch == NOCHANGEBATCH) return(0);
@@ -768,11 +782,12 @@ INTSML undonature(INTSML undo)
  * nodes/arcs/ports/facets or the negative batch number if the batch only involves minor
  * changes (variables, etc.).  The tool that produced the batch is returned in "tool".
  */
-INTSML undoabatch(TOOL **tool)
+INTBIG undoabatch(TOOL **tool)
 {
 	REGISTER CHANGEBATCH *batch, *savebatch;
 	REGISTER CHANGE *c;
-	REGISTER INTSML retval, firstchange, i;
+	REGISTER INTBIG i, retval;
+	REGISTER BOOLEAN firstchange;
 
 	/* get the most recent batch of changes */
 	if (db_donebatch == NOCHANGEBATCH) return(0);
@@ -781,19 +796,19 @@ INTSML undoabatch(TOOL **tool)
 	*tool = batch->tool;
 
 	/* look through the changes in this batch */
-	firstchange = 1;
-	retval = (INTSML)(-batch->batchnumber);
+	firstchange = TRUE;
+	retval = -batch->batchnumber;
 	savebatch = db_currentbatch;
 	for(c = batch->changetail; c != NOCHANGE; c = c->prevchange)
 	{
 		/* reverse the change */
-		if (db_reversechange(c) != 0)
-			retval = (INTSML)batch->batchnumber;
+		if (db_reversechange(c))
+			retval = batch->batchnumber;
 
 		/* now broadcast this change */
 		db_currentbatch = batch;
-		db_broadcastchange(c, firstchange, 1);
-		firstchange = 0;
+		db_broadcastchange(c, firstchange, TRUE);
+		firstchange = FALSE;
 	}
 
 	/* broadcast the end-batch */
@@ -803,7 +818,7 @@ INTSML undoabatch(TOOL **tool)
 	db_currentbatch = savebatch;
 
 	/* mark that this batch is undone */
-	batch->done = 0;
+	batch->done = FALSE;
 	return(retval);
 }
 
@@ -814,11 +829,12 @@ INTSML undoabatch(TOOL **tool)
  * nodes/arcs/ports/facets or the negative batch number if the batch only involves minor
  * changes (variables, etc.).  The tool that produced the batch is returned in "tool".
  */
-INTSML redoabatch(TOOL **tool)
+INTBIG redoabatch(TOOL **tool)
 {
 	REGISTER CHANGEBATCH *batch, *savebatch;
 	REGISTER CHANGE *c;
-	REGISTER INTSML retval, firstchange, i;
+	REGISTER BOOLEAN firstchange;
+	REGISTER INTBIG i, retval;
 
 	/* get the most recent batch of changes */
 	if (db_donebatch == NOCHANGEBATCH)
@@ -834,19 +850,19 @@ INTSML redoabatch(TOOL **tool)
 	*tool = batch->tool;
 
 	/* look through the changes in this batch */
-	firstchange = 1;
-	retval = (INTSML)(-batch->batchnumber);
+	firstchange = TRUE;
+	retval = -batch->batchnumber;
 	savebatch = db_currentbatch;
 	for(c = batch->changehead; c != NOCHANGE; c = c->nextchange)
 	{
 		/* reverse the change */
-		if (db_reversechange(c) != 0)
-			retval = (INTSML)batch->batchnumber;
+		if (db_reversechange(c))
+			retval = batch->batchnumber;
 
 		/* now broadcast this change */
 		db_currentbatch = batch;
-		db_broadcastchange(c, firstchange, 1);
-		firstchange = 0;
+		db_broadcastchange(c, firstchange, TRUE);
+		firstchange = FALSE;
 	}
 
 	/* broadcast the end-batch */
@@ -856,15 +872,15 @@ INTSML redoabatch(TOOL **tool)
 	db_currentbatch = savebatch;
 
 	/* mark that this batch is redone */
-	batch->done = 1;
+	batch->done = TRUE;
 	return(retval);
 }
 
 /*
  * Routine to undo the effects of change "c".
- * Returns nonzero if the change is important.
+ * Returns true if the change is important.
  */
-INTSML db_reversechange(CHANGE *c)
+BOOLEAN db_reversechange(CHANGE *c)
 {
 	REGISTER PORTPROTO *pp, *oldsubpp;
 	REGISTER NODEPROTO *np;
@@ -875,6 +891,7 @@ INTSML db_reversechange(CHANGE *c)
 	REGISTER WINDOWPART *w;
 	REGISTER char *attname;
 	INTBIG oldval;
+	REGISTER INTSML oldshort;
 
 	switch (c->changetype)
 	{
@@ -882,34 +899,34 @@ INTSML db_reversechange(CHANGE *c)
 			ni = (NODEINST *)c->entryaddr;
 			db_retractnodeinst(ni);
 			c->changetype = NODEINSTKILL;
-			return(1);
+			return(TRUE);
 		case NODEINSTKILL:
 			ni = (NODEINST *)c->entryaddr;
 			db_enternodeinst(ni);
 			c->changetype = NODEINSTNEW;
-			return(1);
+			return(TRUE);
 		case NODEINSTMOD:
 			ni = (NODEINST *)c->entryaddr;
 			oldval = ni->lowx;       ni->lowx = c->p1;       c->p1 = oldval;
 			oldval = ni->lowy;       ni->lowy = c->p2;       c->p2 = oldval;
 			oldval = ni->highx;      ni->highx = c->p3;      c->p3 = oldval;
 			oldval = ni->highy;      ni->highy = c->p4;      c->p4 = oldval;
-			oldval = ni->rotation;   ni->rotation = (INTSML)c->p5;   c->p5 = oldval;
-			oldval = ni->transpose;  ni->transpose = (INTSML)c->p6;  c->p6 = oldval;
+			oldshort = ni->rotation;   ni->rotation = (INTSML)c->p5;   c->p5 = oldshort;
+			oldshort = ni->transpose;  ni->transpose = (INTSML)c->p6;  c->p6 = oldshort;
 			/* don't need to call "updategeom()" because it is done by "OBJECTSTART" */
-			return(1);
+			return(TRUE);
 		case ARCINSTNEW:
 			ai = (ARCINST *)c->entryaddr;
 			db_retractarcinst(ai);
 			c->changetype = ARCINSTKILL;
-			return(1);
+			return(TRUE);
 		case ARCINSTKILL:
 			ai = (ARCINST *)c->entryaddr;
 			db_addportarcinst(ai->end[0].nodeinst, ai->end[0].portarcinst);
 			db_addportarcinst(ai->end[1].nodeinst, ai->end[1].portarcinst);
 			db_enterarcinst(ai);
 			c->changetype = ARCINSTNEW;
-			return(1);
+			return(TRUE);
 		case ARCINSTMOD:
 			ai = (ARCINST *)c->entryaddr;
 			oldval = ai->end[0].xpos;  ai->end[0].xpos = c->p1;   c->p1 = oldval;
@@ -919,43 +936,43 @@ INTSML db_reversechange(CHANGE *c)
 			oldval = ai->width;        ai->width = c->p5;         c->p5 = oldval;
 			oldval = ai->length;       ai->length = c->p6;        c->p6 = oldval;
 			determineangle(ai);
-			(void)setshrinkvalue(ai, 1);
+			(void)setshrinkvalue(ai, TRUE);
 			/* don't need to call "updategeom()" because it is done by "OBJECTSTART" */
-			return(1);
+			return(TRUE);
 		case PORTPROTONEW:
 			pp = (PORTPROTO *)c->entryaddr;
 			db_retractportproto(pp);
 			c->changetype = PORTPROTOKILL;
-			return(1);
+			return(TRUE);
 		case PORTPROTOKILL:
 			pp = (PORTPROTO *)c->entryaddr;
 			db_enterportproto(pp);
 			c->changetype = PORTPROTONEW;
-			return(1);
+			return(TRUE);
 		case PORTPROTOMOD:
 			pp = (PORTPROTO *)c->entryaddr;
 			oldsubni = pp->subnodeinst;
 			oldsubpp = pp->subportproto;
 			db_changeport(pp, (NODEINST *)c->p1, (PORTPROTO *)c->p2);
 			c->p1 = (INTBIG)oldsubni;   c->p2 = (INTBIG)oldsubpp;
-			return(1);
+			return(TRUE);
 		case NODEPROTONEW:
 			np = (NODEPROTO *)c->entryaddr;
 			db_retractnodeproto(np);
 			c->changetype = NODEPROTOKILL;
-			return(1);
+			return(TRUE);
 		case NODEPROTOKILL:
 			np = (NODEPROTO *)c->entryaddr;
 			db_insertnodeproto(np);
 			c->changetype = NODEPROTONEW;
-			return(1);
+			return(TRUE);
 		case NODEPROTOMOD:
 			np = (NODEPROTO *)c->entryaddr;
 			oldval = np->lowx;    np->lowx = c->p1;    c->p1 = oldval;
 			oldval = np->highx;   np->highx = c->p2;   c->p2 = oldval;
 			oldval = np->lowy;    np->lowy = c->p3;    c->p3 = oldval;
 			oldval = np->highy;   np->highy = c->p4;   c->p4 = oldval;
-			return(1);
+			return(TRUE);
 		case OBJECTSTART:
 			c->changetype = OBJECTEND;
 			if (c->p1 == VNODEINST)
@@ -1024,7 +1041,7 @@ INTSML db_reversechange(CHANGE *c)
 				if (var == NOVARIABLE)
 				{
 					ttyputmsg(_("Warning: Could not find attribute %s on object %s"),
-						attname, db_namevariable(c->entryaddr, c->p1));
+						attname, describeobject(c->entryaddr, c->p1));
 					break;
 				}
 				c->p3 = var->addr;
@@ -1032,12 +1049,12 @@ INTSML db_reversechange(CHANGE *c)
 				c->p5 = var->textdescript[0];
 				c->p6 = var->textdescript[1];
 				c->changetype = VARIABLEKILL;
-				if (c->p1 == VNODEINST || c->p1 == VARCINST) return(1);
+				if (c->p1 == VNODEINST || c->p1 == VARCINST) return(TRUE);
 				if (c->p1 == VPORTPROTO)
 				{
 					if (strcmp(attname, "textdescript") == 0 ||
 						strcmp(attname, "userbits") == 0 ||
-						strcmp(attname, "protoname") == 0) return(1);
+						strcmp(attname, "protoname") == 0) return(TRUE);
 				}
 				break;
 			}
@@ -1047,7 +1064,7 @@ INTSML db_reversechange(CHANGE *c)
 			if (var == NOVARIABLE)
 			{
 				ttyputmsg(_("Warning: Could not find attribute %s on object %s"),
-					makename(c->p2), db_namevariable(c->entryaddr, c->p1));
+					makename(c->p2), describeobject(c->entryaddr, c->p1));
 				break;
 			}
 			c->p3 = var->addr;
@@ -1058,7 +1075,7 @@ INTSML db_reversechange(CHANGE *c)
 			var->type = VINTEGER;		/* fake it out so no memory is deallocated */
 			nextchangequiet();
 			(void)delvalkey(c->entryaddr, c->p1, c->p2);
-			if (c->p1 == VNODEINST || c->p1 == VARCINST) return(1);
+			if (c->p1 == VNODEINST || c->p1 == VARCINST) return(TRUE);
 			break;
 		case VARIABLEKILL:
 			/* args: addr, type, key, oldaddr, oldtype, olddescript */
@@ -1070,7 +1087,7 @@ INTSML db_reversechange(CHANGE *c)
 				if (var == NOVARIABLE)
 				{
 					ttyputmsg(_("Warning: Could not set attribute %s on object %s"),
-						attname, db_namevariable(c->entryaddr, c->p1));
+						attname, describeobject(c->entryaddr, c->p1));
 					break;
 				}
 			} else
@@ -1079,7 +1096,7 @@ INTSML db_reversechange(CHANGE *c)
 				if (var == NOVARIABLE)
 				{
 					ttyputmsg(_("Warning: Could not set attribute %s on object %s"),
-						makename(c->p2), db_namevariable(c->entryaddr, c->p1));
+						makename(c->p2), describeobject(c->entryaddr, c->p1));
 					break;
 				}
 				var->textdescript[0] = c->p5;
@@ -1088,7 +1105,7 @@ INTSML db_reversechange(CHANGE *c)
 			db_freevar(c->p3, c->p4);
 			c->p3 = c->p4;
 			c->changetype = VARIABLENEW;
-			if (c->p1 == VNODEINST || c->p1 == VARCINST) return(1);
+			if (c->p1 == VNODEINST || c->p1 == VARCINST) return(TRUE);
 			break;
 		case VARIABLEMOD:
 			/* args: addr, type, key, vartype, aindex, oldvalue */
@@ -1096,60 +1113,60 @@ INTSML db_reversechange(CHANGE *c)
 			if ((c->p3&VCREF) != 0)
 			{
 				attname = changedvariablename(c->p1, c->p2, c->p3);
-				if (getind(c->entryaddr, c->p1, attname, c->p4, &oldval) != 0)
+				if (getind(c->entryaddr, c->p1, attname, c->p4, &oldval))
 				{
 					ttyputmsg(_("Warning: Could not find index %ld of attribute %s on object %s"),
-						c->p4, attname, db_namevariable(c->entryaddr, c->p1));
+						c->p4, attname, describeobject(c->entryaddr, c->p1));
 					break;
 				}
 				(void)setind(c->entryaddr, c->p1, attname, c->p4, c->p5);
 				c->p5 = oldval;
 				if (c->p1 == VPORTPROTO)
 				{
-					if (strcmp(attname, "textdescript") == 0) return(1);
+					if (strcmp(attname, "textdescript") == 0) return(TRUE);
 				}
 			} else
 			{
-				if (getindkey(c->entryaddr, c->p1, c->p2, c->p4, &oldval) != 0)
+				if (getindkey(c->entryaddr, c->p1, c->p2, c->p4, &oldval))
 				{
 					ttyputmsg(_("Warning: Could not find index %ld of attribute %s on object %s"),
-						c->p4, makename(c->p2), db_namevariable(c->entryaddr, c->p1));
+						c->p4, makename(c->p2), describeobject(c->entryaddr, c->p1));
 					break;
 				}
 				(void)setindkey(c->entryaddr, c->p1, c->p2, c->p4, c->p5);
 				c->p5 = oldval;
 			}
-			if (c->p1 == VNODEINST || c->p1 == VARCINST) return(1);
+			if (c->p1 == VNODEINST || c->p1 == VARCINST) return(TRUE);
 			break;
 		case VARIABLEINS:
 			/* args: addr, type, key, vartype, aindex */
-			if (getindkey(c->entryaddr, c->p1, c->p2, c->p4, &oldval) != 0)
+			if (getindkey(c->entryaddr, c->p1, c->p2, c->p4, &oldval))
 			{
 				ttyputmsg(_("Warning: Could not find index %ld of attribute %s on object %s"),
-					c->p4, makename(c->p2), db_namevariable(c->entryaddr, c->p1));
+					c->p4, makename(c->p2), describeobject(c->entryaddr, c->p1));
 				break;
 			}
 			nextchangequiet();
 			(void)delindkey(c->entryaddr, c->p1, c->p2, c->p4);
 			c->changetype = VARIABLEDEL;
 			c->p5 = oldval;
-			if (c->p1 == VNODEINST || c->p1 == VARCINST) return(1);
+			if (c->p1 == VNODEINST || c->p1 == VARCINST) return(TRUE);
 			break;
 		case VARIABLEDEL:
 			/* args: addr, type, key, vartype, aindex, oldvalue */
 			nextchangequiet();
 			(void)insindkey(c->entryaddr, c->p1, c->p2, c->p4, c->p5);
 			c->changetype = VARIABLEINS;
-			if (c->p1 == VNODEINST || c->p1 == VARCINST) return(1);
+			if (c->p1 == VNODEINST || c->p1 == VARCINST) return(TRUE);
 			break;
 		case DESCRIPTMOD:
 			var = getvalkey(c->entryaddr, c->p1, -1, c->p2);
 			if (var == NOVARIABLE) break;
 			oldval = var->textdescript[0];   var->textdescript[0] = c->p4;   c->p4 = oldval;
 			oldval = var->textdescript[1];   var->textdescript[1] = c->p5;   c->p5 = oldval;
-			return(1);
+			return(TRUE);
 	}
-	return(0);
+	return(FALSE);
 }
 
 /************************* CHANGE FACETS *************************/
@@ -1170,7 +1187,7 @@ void db_setchangefacet(NODEPROTO *facet)
 		cc->nextchangefacet = db_currentbatch->firstchangefacet;
 		db_currentbatch->firstchangefacet = cc;
 		cc->changefacet = facet;
-		cc->forcedlook = 0;
+		cc->forcedlook = FALSE;
 	}
 }
 
@@ -1206,7 +1223,7 @@ void db_forcehierarchicalanalysis(NODEPROTO *np)
 	for(cc = db_currentbatch->firstchangefacet; cc != NOCHANGEFACET; cc = cc->nextchangefacet)
 		if (cc->changefacet == np)
 	{
-		cc->forcedlook = 1;
+		cc->forcedlook = TRUE;
 		return;
 	}
 
@@ -1221,9 +1238,9 @@ void db_forcehierarchicalanalysis(NODEPROTO *np)
  * routine to display history list entry "which" (if "which" is negative,
  * display the entire list
  */
-void showhistorylist(INTSML which)
+void showhistorylist(INTBIG which)
 {
-	REGISTER INTSML node, arcinst, portproto, nproto, object, variable;
+	REGISTER INTBIG node, arcinst, portproto, nproto, object, variable;
 	REGISTER INTBIG lobatch, hibatch;
 	REGISTER CHANGEBATCH *batchreport;
 	REGISTER CHANGE *c;
@@ -1252,7 +1269,7 @@ void showhistorylist(INTSML which)
 					c->p3, c->p4, c->p5, c->p6));
 			return;
 		}
-		ttyputmsg(M_("Batch %d is not in the list (range is %d to %d)"), which, lobatch, hibatch);
+		ttyputmsg(M_("Batch %ld is not in the list (range is %ld to %ld)"), which, lobatch, hibatch);
 		return;
 	}
 
@@ -1311,39 +1328,39 @@ void showhistorylist(INTSML which)
 
 		if (node != 0)
 		{
-			(void)sprintf(line, " %d %s", node, makeplural(M_("node"), node));
+			(void)sprintf(line, " %ld %s", node, makeplural(M_("node"), node));
 			(void)addstringtoinfstr(line);
 		}
 		if (arcinst != 0)
 		{
-			(void)sprintf(line, " %d %s", arcinst, makeplural(M_("arc"), arcinst));
+			(void)sprintf(line, " %ld %s", arcinst, makeplural(M_("arc"), arcinst));
 			(void)addstringtoinfstr(line);
 		}
 		if (portproto != 0)
 		{
-			(void)sprintf(line, " %d %s", portproto, makeplural(M_("port"), portproto));
+			(void)sprintf(line, " %ld %s", portproto, makeplural(M_("port"), portproto));
 			(void)addstringtoinfstr(line);
 		}
 		if (nproto != 0)
 		{
-			(void)sprintf(line, " %d %s", nproto, makeplural(M_("facet"), nproto));
+			(void)sprintf(line, " %ld %s", nproto, makeplural(M_("facet"), nproto));
 			(void)addstringtoinfstr(line);
 		}
 		if (object != 0)
 		{
-			(void)sprintf(line, " %d %s", object, makeplural(M_("object"), object));
+			(void)sprintf(line, " %ld %s", object, makeplural(M_("object"), object));
 			(void)addstringtoinfstr(line);
 		}
 		if (variable != 0)
 		{
-			(void)sprintf(line, " %d %s", variable, makeplural(M_("variable"), variable));
+			(void)sprintf(line, " %ld %s", variable, makeplural(M_("variable"), variable));
 			(void)addstringtoinfstr(line);
 		}
 		ttyputmsg("%s", returninfstr());
 	}
 }
 
-char *db_describechange(INTSML changetype, INTBIG entryaddr, INTBIG p1, INTBIG p2,
+char *db_describechange(INTBIG changetype, INTBIG entryaddr, INTBIG p1, INTBIG p2,
 	INTBIG p3, INTBIG p4, INTBIG p5, INTBIG p6)
 {
 	REGISTER NODEINST *ni;
@@ -1432,41 +1449,41 @@ char *db_describechange(INTSML changetype, INTBIG entryaddr, INTBIG p1, INTBIG p
 		case OBJECTSTART:
 			/* args: addr, type */
 			(void)initinfstr();
-			(void)formatinfstr(M_(" Start change to object %s"), db_namevariable(entryaddr, p1));
+			(void)formatinfstr(M_(" Start change to object %s"), describeobject(entryaddr, p1));
 			return(returninfstr());
 		case OBJECTEND:
 			/* args: addr, type */
 			(void)initinfstr();
-			(void)formatinfstr(M_(" End change to object %s"), db_namevariable(entryaddr, p1));
+			(void)formatinfstr(M_(" End change to object %s"), describeobject(entryaddr, p1));
 			return(returninfstr());
 		case OBJECTNEW:
 			/* args: addr, type */
 			(void)initinfstr();
-			(void)formatinfstr(M_(" Object %s created"), db_namevariable(entryaddr, p1));
+			(void)formatinfstr(M_(" Object %s created"), describeobject(entryaddr, p1));
 			return(returninfstr());
 		case OBJECTKILL:
 			/* args: addr, type */
 			(void)initinfstr();
-			(void)formatinfstr(M_(" Object %s deleted"), db_namevariable(entryaddr, p1));
+			(void)formatinfstr(M_(" Object %s deleted"), describeobject(entryaddr, p1));
 			return(returninfstr());
 		case VARIABLENEW:
 			/* args: addr, type, key, newtype */
 			(void)initinfstr();
 			(void)formatinfstr(M_(" Variable '%s' created on %s"), changedvariablename(p1, p2, p3),
-				db_namevariable(entryaddr, p1));
+				describeobject(entryaddr, p1));
 			return(returninfstr());
 		case VARIABLEKILL:
 			/* args: addr, type, key, oldaddr, oldtype, olddescript[0], olddescript[1] */
 			(void)initinfstr();
 			myvar.key = p2;  myvar.type = p4;  myvar.addr = p3;
 			(void)formatinfstr(M_(" Variable '%s' killed on %s [was %s]"), changedvariablename(p1, p2, p4),
-				db_namevariable(entryaddr, p1), describevariable(&myvar, -1, -1));
+				describeobject(entryaddr, p1), describevariable(&myvar, -1, -1));
 			return(returninfstr());
 		case VARIABLEMOD:
 			/* args: addr, type, key, vartype, aindex, oldvalue */
 			(void)initinfstr();
 			(void)formatinfstr(M_(" Variable '%s[%ld]' changed on %s"), changedvariablename(p1, p2, p3), p4,
-				db_namevariable(entryaddr, p1));
+				describeobject(entryaddr, p1));
 			if ((p3&VCREF) == 0)
 			{
 				myvar.key = p2;  myvar.type = p3 & ~VISARRAY;
@@ -1478,13 +1495,13 @@ char *db_describechange(INTSML changetype, INTBIG entryaddr, INTBIG p1, INTBIG p
 			/* args: addr, type, key, vartype, aindex */
 			(void)initinfstr();
 			(void)formatinfstr(M_(" Variable '%s[%ld]' inserted on %s"), changedvariablename(p1, p2, p3), p4,
-				db_namevariable(entryaddr, p1));
+				describeobject(entryaddr, p1));
 			return(returninfstr());
 		case VARIABLEDEL:
 			/* args: addr, type, key, vartype, aindex, oldvalue */
 			(void)initinfstr();
 			(void)formatinfstr(M_(" Variable '%s[%ld]' deleted on %s"), changedvariablename(p1, p2, p3), p4,
-				db_namevariable(entryaddr, p1));
+				describeobject(entryaddr, p1));
 			return(returninfstr());
 		case DESCRIPTMOD:
 			(void)initinfstr();
@@ -1495,132 +1512,6 @@ char *db_describechange(INTSML changetype, INTBIG entryaddr, INTBIG p1, INTBIG p
 	return("?");
 }
 
-/*
- * routine to name the variable at "addr" of type "type".  It is assumed
- * to be an object that can hold other variables
- */
-char *db_namevariable(INTBIG addr, INTBIG type)
-{
-	REGISTER NODEINST *ni;
-	REGISTER NODEPROTO *np;
-	REGISTER PORTARCINST *pi;
-	REGISTER PORTEXPINST *pe;
-	REGISTER PORTPROTO *pp;
-	REGISTER ARCINST *ai;
-	REGISTER ARCPROTO *ap;
-	REGISTER GEOM *geom;
-	REGISTER LIBRARY *lib;
-	REGISTER TECHNOLOGY *tech;
-	REGISTER TOOL *tool;
-	REGISTER RTNODE *rtn;
-	REGISTER CELL *c;
-	REGISTER VIEW *v;
-	REGISTER WINDOWPART *win;
-	REGISTER WINDOWFRAME *wf;
-	REGISTER GRAPHICS *gra;
-	REGISTER CONSTRAINT *con;
-	REGISTER POLYGON *poly;
-
-	(void)initinfstr();
-	switch (type&VTYPE)
-	{
-		case VNODEINST:
-			ni = (NODEINST *)addr;
-			(void)formatinfstr("NodeInstance(%s)", describenodeinst(ni));
-			break;
-		case VNODEPROTO:
-			np = (NODEPROTO *)addr;
-			if (np->primindex == 0) (void)formatinfstr("Facet(%s)", describenodeproto(np)); else
-				(void)formatinfstr("Primitive(%s)", describenodeproto(np));
-			break;
-		case VPORTARCINST:
-			pi = (PORTARCINST *)addr;
-			if (pi == NOPORTARCINST) (void)addstringtoinfstr("PortArcInstance(NULL)"); else
-				(void)formatinfstr("PortArcInstance(%ld)", (INTBIG)pi);
-			break;
-		case VPORTEXPINST:
-			pe = (PORTEXPINST *)addr;
-			if (pe == NOPORTEXPINST) (void)addstringtoinfstr("PortExpInstance(NULL)"); else
-				(void)formatinfstr("PortExpInstance(%ld)", (INTBIG)pe);
-			break;
-		case VPORTPROTO:
-			pp = (PORTPROTO *)addr;
-			if (pp == NOPORTPROTO) (void)addstringtoinfstr("PortPrototype(NULL)"); else
-				(void)formatinfstr("PortPrototype(%s)", pp->protoname);
-			break;
-		case VARCINST:
-			ai = (ARCINST *)addr;
-			(void)formatinfstr("ArcInstance(%s)", describearcinst(ai));
-			break;
-		case VARCPROTO:
-			ap = (ARCPROTO *)addr;
-			(void)formatinfstr("ArcPrototype(%s)", describearcproto(ap));
-			break;
-		case VGEOM:
-			geom = (GEOM *)addr;
-			if (geom == NOGEOM) (void)addstringtoinfstr("Geom(NULL)"); else
-				(void)formatinfstr("Geom(%ld)", (INTBIG)geom);
-			break;
-		case VLIBRARY:
-			lib = (LIBRARY *)addr;
-			if (lib == NOLIBRARY) (void)addstringtoinfstr("Library(NULL)"); else
-				(void)formatinfstr("Library(%s)", lib->libname);
-			break;
-		case VTECHNOLOGY:
-			tech = (TECHNOLOGY *)addr;
-			if (tech == NOTECHNOLOGY) (void)addstringtoinfstr("Technology(NULL)"); else
-				(void)formatinfstr("Technology(%s)", tech->techname);
-			break;
-		case VTOOL:
-			tool = (TOOL *)addr;
-			if (tool == NOTOOL) (void)addstringtoinfstr("Tool(NULL)"); else
-				(void)formatinfstr("Tool(%s)", tool->toolname);
-			break;
-		case VRTNODE:
-			rtn = (RTNODE *)addr;
-			if (rtn == NORTNODE) (void)addstringtoinfstr("Rtnode(NULL)"); else
-				(void)formatinfstr("Rtnode(%ld)", (INTBIG)rtn);
-			break;
-		case VCELL:
-			c = (CELL *)addr;
-			if (c == NOCELL) (void)addstringtoinfstr("Cell(NULL)"); else
-				(void)formatinfstr("Cell(%s)", c->cellname);
-			break;
-		case VVIEW:
-			v = (VIEW *)addr;
-			if (v == NOVIEW) (void)addstringtoinfstr("View(NULL)"); else
-				(void)formatinfstr("View(%s)", v->viewname);
-			break;
-		case VWINDOWPART:
-			win = (WINDOWPART *)addr;
-			if (win != NOWINDOWPART) (void)formatinfstr("WindowPart(%s)", win->location); else
-				(void)formatinfstr("WindowPart(%ld)", (INTBIG)win);
-			break;
-		case VGRAPHICS:
-			gra = (GRAPHICS *)addr;
-			if (gra == NOGRAPHICS) (void)addstringtoinfstr("Graphics(NULL)"); else
-				(void)formatinfstr("Graphics(%ld)", (INTBIG)gra);
-			break;
-		case VCONSTRAINT:
-			con = (CONSTRAINT *)addr;
-			if (con == NOCONSTRAINT) (void)addstringtoinfstr("Constraint(NULL)"); else
-				(void)formatinfstr("Constraint(%s)", con->conname);
-			break;
-		case VWINDOWFRAME:
-			wf = (WINDOWFRAME *)addr;
-			(void)formatinfstr("WindowFrame(%ld)", (INTBIG)wf);
-			break;
-		case VPOLYGON:
-			poly = (POLYGON *)addr;
-			(void)formatinfstr("Polygon(%ld)", (INTBIG)poly);
-			break;
-		default:
-			(void)addstringtoinfstr("UNKNOWN(?)");
-			break;
-	}
-	return(returninfstr());
-}
-
 /* Undo dialog */
 static DIALOGITEM db_undodialogitems[] =
 {
@@ -1641,12 +1532,11 @@ static DIALOG db_undodialog = {{50,75,555,774}, N_("Change History"), 0, 6, db_u
 
 void db_undodlog(void)
 {
-	INTBIG itemHit;
-	INTSML details;
+	INTBIG itemHit, details;
 	TOOL *tool;
 
 	/* display the undo dialog box */
-	if (DiaInitDialog(&db_undodialog) != 0) return;
+	if (DiaInitDialog(&db_undodialog)) return;
 	DiaInitTextDialog(DUND_CHGLIST, DiaNullDlogList, DiaNullDlogItem, DiaNullDlogDone,
 		-1, SCHORIZBAR|SCSMALLFONT);
 	details = 0;
@@ -1669,13 +1559,13 @@ void db_undodlog(void)
 		}
 		if (itemHit == DUND_UNDO)
 		{
-			undoabatch(&tool);
+			(void)undoabatch(&tool);
 			db_loadhistorylist(details);
 			continue;
 		}
 		if (itemHit == DUND_REDO)
 		{
-			redoabatch(&tool);
+			(void)redoabatch(&tool);
 			db_loadhistorylist(details);
 			continue;
 		}
@@ -1687,9 +1577,9 @@ void db_undodlog(void)
 /*
  * helper routines for undo dialog
  */
-void db_loadhistorylist(short details)
+void db_loadhistorylist(INTBIG details)
 {
-	REGISTER INTSML node, arcinst, portproto, nproto, object, variable, lineno, curline;
+	REGISTER INTBIG node, arcinst, portproto, nproto, object, variable, lineno, curline;
 	REGISTER CHANGE *c;
 	char line[50];
 	CHANGEBATCH *batch;
@@ -1746,32 +1636,32 @@ void db_loadhistorylist(short details)
 
 		if (node != 0)
 		{
-			(void)sprintf(line, " %d %s", node, makeplural(M_("node"), node));
+			(void)sprintf(line, " %ld %s", node, makeplural(M_("node"), node));
 			(void)addstringtoinfstr(line);
 		}
 		if (arcinst != 0)
 		{
-			(void)sprintf(line, " %d %s", arcinst, makeplural(M_("arc"), arcinst));
+			(void)sprintf(line, " %ld %s", arcinst, makeplural(M_("arc"), arcinst));
 			(void)addstringtoinfstr(line);
 		}
 		if (portproto != 0)
 		{
-			(void)sprintf(line, " %d %s", portproto, makeplural(M_("port"), portproto));
+			(void)sprintf(line, " %ld %s", portproto, makeplural(M_("port"), portproto));
 			(void)addstringtoinfstr(line);
 		}
 		if (nproto != 0)
 		{
-			(void)sprintf(line, " %d %s", nproto, makeplural(M_("facet"), nproto));
+			(void)sprintf(line, " %ld %s", nproto, makeplural(M_("facet"), nproto));
 			(void)addstringtoinfstr(line);
 		}
 		if (object != 0)
 		{
-			(void)sprintf(line, " %d %s", object, makeplural(M_("object"), object));
+			(void)sprintf(line, " %ld %s", object, makeplural(M_("object"), object));
 			(void)addstringtoinfstr(line);
 		}
 		if (variable != 0)
 		{
-			(void)sprintf(line, " %d %s", variable, makeplural(M_("variable"), variable));
+			(void)sprintf(line, " %ld %s", variable, makeplural(M_("variable"), variable));
 			(void)addstringtoinfstr(line);
 		}
 		DiaStuffLine(DUND_CHGLIST, returninfstr());
