@@ -32,35 +32,45 @@
 #include "database.h"
 #include "tech.h"
 #include "edialogs.h"
+#include "usr.h"
 
-char *el_version = "6.04";		/* the current Electric version */
+#ifdef INTERNATIONAL
+#  ifdef MACOS
+#    define PACKAGE "macelectric"
+#    define LOCALEDIR "lib:international"
+#  else
+#    define PACKAGE "electric"
+#    define LOCALEDIR "lib/international"
+#  endif
+#endif
+
+/*
+ * The current Electric version.
+ * Version numbering consists of 3 parts: the major number, the minor number,
+ * and the detail.  The detail part is optional lettering at the end which
+ * runs from "a" to "z", then "aa" to "az", then "ba" to "bz", etc.
+ * A released version has no detail, and is considered to be a HIGHER version
+ * than those with detail (which are prereleases).  For example:
+ *    version "6.04a"  has major=6, minor=4, detail=1 ("a")
+ *    version "6.05bc" has major=6, minor=5, detail=55 ("bc")
+ *    version "6.03"   has major=6, minor=3, and detail=1000
+ * The routine "io_getversion()" parses these version strings.
+ */
+char *el_version = "6.05";
 
 /* miscellaneous defaults */
-#define DEFTECH     "nmos"        /* default technology */
-#define DEFCONSTR   "layout"      /* default constraint system */
+#define DEFTECH     "mocmos"		/* default technology */
+#define DEFCONSTR   "layout"		/* default constraint system */
 
 /* prototypes for local routines */
 static void db_freeallmemory(void);
 
-#if 0		/* for testing "gettext" (the internationalization macro) */
-char *testgettext(char *text)
-{
-	char *foolbuf;
-
-	foolbuf = (char *)emalloc(strlen(text)+5, db_cluster);
-	strcpy(foolbuf, "{{");
-	strcat(foolbuf, text);
-	strcat(foolbuf, "}}");
-	return(foolbuf);
-}
-#endif
-
 /*
  * the primary initialization of Electric
  */
 void osprimaryosinit(void)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 	REGISTER TECHNOLOGY *tech, *lasttech, *realtech;
 	REGISTER CONSTRAINT *constr;
 	REGISTER CLUSTER *clus;
@@ -68,12 +78,17 @@ void osprimaryosinit(void)
 	char libname[10], libfile[10];
 	extern TECHNOLOGY el_technologylist[];
 
-#if 0	/* for internationalization */
+#ifdef INTERNATIONAL
+#  if HAVE_SETLOCALE
 	setlocale(LC_ALL, "");
+#  endif
 	bindtextdomain(PACKAGE, LOCALEDIR);
 	textdomain(PACKAGE);
+
+	/* a test */
+	strcpy(libname, gettext("Redo"));
 #endif
-  
+
 	/* initialize the memory allocation system */
 	db_initclusters();
 
@@ -168,10 +183,10 @@ void osprimaryosinit(void)
 	{
 		if (tech->init != 0)
 		{
-			if ((*tech->init)(tech, 0) != 0)
+			if ((*tech->init)(tech, 0))
 				error(_("User pass 1 error initializing %s technology"), tech->techname);
 		}
-		if (tech_doinitprocess(tech) != 0)
+		if (tech_doinitprocess(tech))
 			error(_("Pass 1 error initializing %s technology"), tech->techname);
 	}
 
@@ -195,7 +210,7 @@ void osprimaryosinit(void)
  */
 void ossecondaryinit(INTBIG argc, char *argv[])
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 	REGISTER TECHNOLOGY *tech;
 
 	/* pass 2 initialization of the constraint solvers */
@@ -207,7 +222,7 @@ void ossecondaryinit(INTBIG argc, char *argv[])
 	{
 		if (tech->init != 0)
 		{
-			if ((*tech->init)(tech, 1) != 0)
+			if ((*tech->init)(tech, 1))
 				error(_("User pass 2 error initializing %s technology"), tech->techname);
 		}
 		if (tech_doaddportsandvars(tech))
@@ -222,7 +237,7 @@ void ossecondaryinit(INTBIG argc, char *argv[])
 	{
 		if (tech->init != 0)
 		{
-			if ((*tech->init)(tech, 2) != 0)
+			if ((*tech->init)(tech, 2))
 				error(_("User pass 3 error initializing %s technology"), tech->techname);
 		}
 	}
@@ -235,12 +250,23 @@ void ossecondaryinit(INTBIG argc, char *argv[])
 
 	/* delete initialization change batches so it is ready for real changes */
 	noundoallowed();
+
+	/* make sure the integer sizes are correct */
+	if (sizeof(INTHUGE) < 8)
+		error("INTHUGE must be 64 bits wide (fix 'global.h')\n");
+	if (sizeof(INTBIG) < 4)
+		error("INTBIG must be 32 bits wide (fix 'global.h')\n");
+	if (sizeof(INTSML) < 2)
+		error("INTSML must be 16 bits wide (fix 'global.h')\n");
+	if (sizeof(INTBIG) < sizeof(char *))
+		error("INTBIG must be able to hold a pointer (%d bytes) bits wide (fix 'global.h')\n",
+			sizeof(char *));
 }
 
 /* the body of the main loop of Electric */
 void tooltimeslice(void)
 {
-	REGISTER INTSML s;
+	REGISTER INTBIG s;
 	REGISTER TOOL *tool;
 
 	for(s=0; s<el_maxtools; s++)
@@ -258,10 +284,10 @@ void tooltimeslice(void)
 	}
 }
 
-INTSML telltool(TOOL *tool, INTSML count, char *par[])
+void telltool(TOOL *tool, INTBIG count, char *par[])
 {
-	if (tool->setmode == 0) return(0);
-	return((*tool->setmode)(count, par));
+	if (tool->setmode == 0) return;
+	(*tool->setmode)(count, par);
 }
 
 INTBIG asktool(TOOL *tool, char *command, ...)
@@ -279,9 +305,9 @@ INTBIG asktool(TOOL *tool, char *command, ...)
 /*
  * routine to turn tool "tool" back on.  It will also inform the tool of each
  * facet that changed while the tool was off (via "examinenodeproto").  If
- * "nocatchup" is nonzero, this informing will not occur.
+ * "nocatchup" is true, this informing will not occur.
  */
-void toolturnon(TOOL *tool, INTSML nocatchup)
+void toolturnon(TOOL *tool, BOOLEAN nocatchup)
 {
 	REGISTER INTBIG bit;
 	REGISTER NODEPROTO *np;
@@ -294,14 +320,14 @@ void toolturnon(TOOL *tool, INTSML nocatchup)
 	if ((tool->toolstate & TOOLINCREMENTAL) == 0) return;
 
 	/* if catch-up action is supressed, quit now */
-	if (nocatchup != 0) return;
+	if (nocatchup) return;
 
 	/* look through all facets and update those that need it */
 	bit = 1 << tool->toolindex;
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 	{
-		if (np->adirty & bit)
+		if ((np->adirty & bit) != 0)
 		{
 			if (tool->examinenodeproto != 0)
 				(*tool->examinenodeproto)(np);
@@ -311,13 +337,13 @@ void toolturnon(TOOL *tool, INTSML nocatchup)
 }
 
 /*
- * routine to turn tool "tool" off.  If "permanently" is nonzero, this change
+ * routine to turn tool "tool" off.  If "permanently" is true, this change
  * will not be undoable
  */
-void toolturnoff(TOOL *tool, INTSML permanently)
+void toolturnoff(TOOL *tool, BOOLEAN permanently)
 {
 	/* turn off the tool */
-	if (permanently != 0) tool->toolstate &= ~TOOLON; else
+	if (permanently) tool->toolstate &= ~TOOLON; else
 		(void)setval((INTBIG)tool, VTOOL, "toolstate", tool->toolstate & ~TOOLON, VINTEGER);
 }
 
@@ -326,7 +352,7 @@ void toolturnoff(TOOL *tool, INTSML permanently)
  */
 void bringdown(void)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 	REGISTER TECHNOLOGY *tech;
 	REGISTER TOOL *tool;
 	REGISTER CONSTRAINT *con;
@@ -410,22 +436,24 @@ void db_freeallmemory(void)
 	db_freemergememory();
 	db_freegeomemory();
 	db_freeerrormemory();
-	initerrorlogging("", NONODEPROTO, NONODEPROTO);
+	initerrorlogging("");
 #  if LANGTCL
 	db_freetclmemory();
 #  endif
 #endif
 }
 
-INTSML stopping(INTBIG reason)
+BOOLEAN stopping(INTBIG reason)
 {
 	extern char *db_stoppingreason[];
 
+	if ((us_tool->toolstate&TERMNOINTERRUPT) != 0) return(FALSE);
 	checkforinterrupt();
-	if (el_pleasestop != 1) return(el_pleasestop);
-	el_pleasestop = 0;
-	flushscreen();
-	ttyputmsg(_("%s stopped"), db_stoppingreason[reason]);
-	el_pleasestop = 2;
-	return(el_pleasestop);
+	if (el_pleasestop == 1)
+	{
+		flushscreen();
+		ttyputmsg(_("%s stopped"), db_stoppingreason[reason]);
+		el_pleasestop = 2;
+	}
+	return(el_pleasestop != 0);
 }
