@@ -34,7 +34,7 @@
 
 /* prototypes for local routines */
 static ARCPROTO *db_allocarcproto(CLUSTER*);
-static INTSML    db_checkshortening(NODEINST*, PORTPROTO*);
+static INTBIG    db_checkshortening(NODEINST*, PORTPROTO*);
 static void      db_killportproto(PORTPROTO*);
 
 /************************* NODES *************************/
@@ -49,25 +49,27 @@ NODEINST *allocnodeinst(CLUSTER *cluster)
 
 	ni = (NODEINST *)emalloc((sizeof (NODEINST)), cluster);
 	if (ni == 0) return(NONODEINST);
-	ni->changed = 0;   ni->changeaddr = (char *)NOCHANGE;
-	ni->numvar = 0;
-	ni->userbits = ni->temp1 = ni->temp2 = 0;
-	ni->firstvar = NOVARIABLE;
-	ni->nextnodeinst = NONODEINST;
-	ni->geom = NOGEOM;
-	ni->nextinst = NONODEINST;
-	ni->firstportarcinst = NOPORTARCINST;
-	ni->firstportexpinst = NOPORTEXPINST;
-	TDCLEAR(ni->textdescript);
-	defaulttextsize(5, ni->textdescript);
-	TDSETPOS(ni->textdescript, VTPOSBOXED);
 	ni->lowx = ni->highx = ni->lowy = ni->highy = 0;
 	ni->transpose = 0;
 	ni->rotation = 0;
 	ni->proto = NONODEPROTO;
 	ni->parent = NONODEPROTO;
 	ni->lastnodeinst = NONODEINST;
+	ni->nextnodeinst = NONODEINST;
+	ni->geom = NOGEOM;
 	ni->lastinst = NONODEINST;
+	ni->nextinst = NONODEINST;
+	ni->firstportarcinst = NOPORTARCINST;
+	ni->firstportexpinst = NOPORTEXPINST;
+	TDCLEAR(ni->textdescript);
+	defaulttextsize(5, ni->textdescript);
+	TDSETPOS(ni->textdescript, VTPOSBOXED);
+	ni->arraysize = 0;
+	ni->changeaddr = (char *)NOCHANGE;
+	ni->changed = 0;
+	ni->userbits = ni->temp1 = ni->temp2 = 0;
+	ni->firstvar = NOVARIABLE;
+	ni->numvar = 0;
 	return(ni);
 }
 
@@ -84,21 +86,21 @@ void freenodeinst(NODEINST *ni)
 void startobjectchange(INTBIG addr, INTBIG type)
 {
 	/* handle change control and broadcast */
-	if (db_donextchangequietly == 0 && db_dochangesquietly == 0)
+	if (!db_donextchangequietly && !db_dochangesquietly)
 	{
 		(void)db_change(addr, OBJECTSTART, type, 0, 0, 0, 0, 0);
 	}
-	db_donextchangequietly = 0;
+	db_donextchangequietly = FALSE;
 }
 
 void endobjectchange(INTBIG addr, INTBIG type)
 {
 	/* handle change control and broadcast */
-	if (db_donextchangequietly == 0 && db_dochangesquietly == 0)
+	if (!db_donextchangequietly && !db_dochangesquietly)
 	{
 		(void)db_change(addr, OBJECTEND, type, 0, 0, 0, 0, 0);
 	}
-	db_donextchangequietly = 0;
+	db_donextchangequietly = FALSE;
 }
 
 /*
@@ -108,37 +110,37 @@ void endobjectchange(INTBIG addr, INTBIG type)
  * If NONODEINST is returned, there is an error creating the nodeinst.
  */
 NODEINST *newnodeinst(NODEPROTO *np, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy,
-	INTSML trans, INTSML angle, NODEPROTO *parnt)
+	INTBIG trans, INTBIG angle, NODEPROTO *parnt)
 {
 	/* make sure values are correct */
 	if (trans != 0 && trans != 1)
 	{
-		db_donextchangequietly = 0;
+		db_donextchangequietly = FALSE;
 		return((NODEINST *)db_error(DBBADTRANS|DBNEWNODEINST));
 	}
 	if (angle < 0 || angle >= 3600)
 	{
-		db_donextchangequietly = 0;
+		db_donextchangequietly = FALSE;
 		return((NODEINST *)db_error(DBBADROT|DBNEWNODEINST));
 	}
 	if (np == NONODEPROTO)
 	{
-		db_donextchangequietly = 0;
+		db_donextchangequietly = FALSE;
 		return((NODEINST *)db_error(DBBADPROTO|DBNEWNODEINST));
 	}
 	if (parnt == NONODEPROTO)
 	{
-		db_donextchangequietly = 0;
+		db_donextchangequietly = FALSE;
 		return((NODEINST *)db_error(DBBADPARENT|DBNEWNODEINST));
 	}
 	if (isachildof(parnt, np))
 	{
-		db_donextchangequietly = 0;
+		db_donextchangequietly = FALSE;
 		return((NODEINST *)db_error(DBRECURSIVE|DBNEWNODEINST));
 	}
 
 	/* build the nodeinst */
-	return(db_newnodeinst(np, lx,hx,ly,hy, trans, angle, parnt));
+	return(db_newnodeinst(np, lx, hx, ly, hy, trans, angle, parnt));
 }
 
 /*
@@ -148,7 +150,7 @@ NODEINST *newnodeinst(NODEPROTO *np, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy,
  * returned.  NONODEINST is returned upon error.
  */
 NODEINST *db_newnodeinst(NODEPROTO *np, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy,
-	INTSML trans, INTSML angle, NODEPROTO *parnt)
+	INTBIG trans, INTBIG angle, NODEPROTO *parnt)
 {
 	REGISTER NODEINST *ni;
 
@@ -156,12 +158,13 @@ NODEINST *db_newnodeinst(NODEPROTO *np, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG
 	ni = allocnodeinst(parnt->cell->cluster);
 	if (ni == NONODEINST)
 	{
-		db_donextchangequietly = 0;
+		db_donextchangequietly = FALSE;
 		return(NONODEINST);
 	}
 
 	/* initialize the nodeinst */
-	ni->proto = np;      ni->rotation = angle;   ni->transpose = trans;
+	ni->proto = np;
+	ni->rotation = (INTSML)angle;   ni->transpose = (INTSML)trans;
 	ni->lowx = lx;       ni->highx = hx;
 	ni->lowy = ly;       ni->highy = hy;
 	ni->parent = parnt;
@@ -173,13 +176,13 @@ NODEINST *db_newnodeinst(NODEPROTO *np, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG
 	/* make a geometry module for this nodeinst */
 	ni->geom = allocgeom(parnt->cell->cluster);
 	if (ni->geom == NOGEOM) return(NONODEINST);
-	ni->geom->entrytype = OBJNODEINST;   ni->geom->entryaddr.ni = ni;
+	ni->geom->entryisnode = TRUE;   ni->geom->entryaddr.ni = ni;
 
 	/* put it in appropriate lists */
 	db_enternodeinst(ni);
 
 	/* handle change control, constraint, and broadcast */
-	if (db_donextchangequietly == 0 && db_dochangesquietly == 0)
+	if (!db_donextchangequietly && !db_dochangesquietly)
 	{
 		/* set the change facet environment */
 		db_setchangefacet(parnt);
@@ -190,7 +193,7 @@ NODEINST *db_newnodeinst(NODEPROTO *np, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG
 		/* tell constraint system about new node */
 		(*el_curconstraint->newobject)((INTBIG)ni, VNODEINST);
 	}
-	db_donextchangequietly = 0;
+	db_donextchangequietly = FALSE;
 
 	/* report nodeinst address */
 	return(ni);
@@ -233,36 +236,36 @@ void db_enternodeinst(NODEINST *ni)
 
 /*
  * free up network nodeinst pointed to by "ni".
- * Returns nonzero if the nodeinst has arcs still connected to it (an error)
+ * Returns true if the nodeinst has arcs still connected to it (an error)
  */
-INTSML killnodeinst(NODEINST *ni)
+BOOLEAN killnodeinst(NODEINST *ni)
 {
 	/* error if nodeinst is not valid */
 	if (ni == NONODEINST)
 	{
-		db_donextchangequietly = 0;
-		return((INTSML)db_error(DBBADINST|DBKILLNODEINST));
+		db_donextchangequietly = FALSE;
+		return(db_error(DBBADINST|DBKILLNODEINST) != 0);
 	}
 
 	/* error if any arcs still connected to this nodeinst */
 	if (ni->firstportarcinst != NOPORTARCINST)
 	{
-		db_donextchangequietly = 0;
-		return((INTSML)db_error(DBHASARCS|DBKILLNODEINST));
+		db_donextchangequietly = FALSE;
+		return(db_error(DBHASARCS|DBKILLNODEINST) != 0);
 	}
 
 	/* error if any exports */
 	if (ni->firstportexpinst != NOPORTEXPINST)
 	{
-		db_donextchangequietly = 0;
-		return((INTSML)db_error(DBHASPORTS|DBKILLNODEINST));
+		db_donextchangequietly = FALSE;
+		return(db_error(DBHASPORTS|DBKILLNODEINST) != 0);
 	}
 
 	/* remove nodeinst from lists */
 	db_killnodeinst(ni);
 
 	/* freeing of the nodeinst and ports will be done later */
-	return(0);
+	return(FALSE);
 }
 
 /*
@@ -275,7 +278,7 @@ void db_killnodeinst(NODEINST *ni)
 	db_retractnodeinst(ni);
 
 	/* handle change control, constraint, and broadcast */
-	if (db_donextchangequietly == 0 && db_dochangesquietly == 0)
+	if (!db_donextchangequietly && !db_dochangesquietly)
 	{
 		/* set the change facet environment */
 		db_setchangefacet(ni->parent);
@@ -291,7 +294,7 @@ void db_killnodeinst(NODEINST *ni)
 		freegeom(ni->geom);
 		freenodeinst(ni);
 	}
-	db_donextchangequietly = 0;
+	db_donextchangequietly = FALSE;
 }
 
 /*
@@ -336,7 +339,7 @@ void defaultnodesize(NODEPROTO *np, INTBIG *xs, INTBIG *ys)
 	if (np->primindex == 0) return;
 
 	/* see if there is an override on the node */
-	var = getvalkey((INTBIG)np, VNODEPROTO, VINTEGER|VISARRAY, el_node_size_default);
+	var = getvalkey((INTBIG)np, VNODEPROTO, VINTEGER|VISARRAY, el_node_size_default_key);
 	if (var != NOVARIABLE)
 	{
 		*xs = ((INTBIG *)var->addr)[0] * el_curlib->lambda[np->tech->techindex] / WHOLE;
@@ -350,7 +353,7 @@ void defaultnodesize(NODEPROTO *np, INTBIG *xs, INTBIG *ys)
  * "deltatrans" in transgeometry.
  */
 void modifynodeinst(NODEINST *ni, INTBIG deltalx, INTBIG deltaly, INTBIG deltahx,
-	INTBIG deltahy, INTSML deltarot, INTSML deltatrans)
+	INTBIG deltahy, INTBIG deltarot, INTBIG deltatrans)
 {
 	/* examine the nature of the changes */
 	deltarot = deltarot % 3600;
@@ -359,11 +362,11 @@ void modifynodeinst(NODEINST *ni, INTBIG deltalx, INTBIG deltaly, INTBIG deltahx
 	if (deltalx == 0 && deltahx == 0 && deltaly == 0 && deltahy == 0 && deltarot == 0 &&
 		deltatrans == 0)
 	{
-		db_donextchangequietly = 0;
+		db_donextchangequietly = FALSE;
 		return;
 	}
 
-	if (db_donextchangequietly == 0 && db_dochangesquietly == 0)
+	if (!db_donextchangequietly && !db_dochangesquietly)
 	{
 		/* tell constraint system about modified node */
 		(*el_curconstraint->modifynodeinst)(ni, deltalx, deltaly, deltahx, deltahy, deltarot, deltatrans);
@@ -372,10 +375,10 @@ void modifynodeinst(NODEINST *ni, INTBIG deltalx, INTBIG deltaly, INTBIG deltahx
 		/* make the change now: no constraint system */
 		ni->lowx += deltalx;   ni->highx += deltahx;
 		ni->lowy += deltaly;   ni->highy += deltahy;
-		ni->rotation += deltarot;
-		ni->transpose += deltatrans;
+		ni->rotation += (INTSML)deltarot;
+		ni->transpose += (INTSML)deltatrans;
 	}
-	db_donextchangequietly = 0;
+	db_donextchangequietly = FALSE;
 
 	/* set the change facet environment */
 	db_setchangefacet(ni->parent);
@@ -384,6 +387,58 @@ void modifynodeinst(NODEINST *ni, INTBIG deltalx, INTBIG deltaly, INTBIG deltahx
 	db_changetimestamp++;
 }
 
+/*
+ * routine to modify "count" nodeinsts "ni" by "deltalx" in low X, "deltaly" in low Y,
+ * "deltahx" in high X, "deltahy" in high Y, "deltarot" in rotation, and
+ * "deltatrans" in transgeometry.
+ */
+void modifynodeinsts(INTBIG count, NODEINST **nis, INTBIG *deltalxs, INTBIG *deltalys,
+	INTBIG *deltahxs, INTBIG *deltahys, INTBIG *deltarots, INTBIG *deltatranss)
+{
+	REGISTER INTBIG i, deltalx, deltaly, deltahx, deltahy;
+	REGISTER INTBIG deltarot, deltatrans;
+	REGISTER NODEINST *ni;
+
+	if (!db_donextchangequietly && !db_dochangesquietly)
+	{
+		/* tell constraint system about modified node */
+		(*el_curconstraint->modifynodeinsts)(count, nis, deltalxs, deltalys, deltahxs, deltahys, deltarots, deltatranss);
+		for(i=0; i<count; i++)
+			db_setchangefacet(nis[i]->parent);
+	} else
+	{
+		for(i=0; i<count; i++)
+		{
+			ni = nis[i];
+			deltalx = deltalxs[i];
+			deltaly = deltalys[i];
+			deltahx = deltahxs[i];
+			deltahy = deltahys[i];
+			deltarot = deltarots[i];
+			deltatrans = deltatranss[i];
+
+			/* examine the nature of the changes */
+			deltarot = deltarot % 3600;
+			if (deltarot < 0) deltarot += 3600;
+			if (deltatrans != 0) deltatrans = 1;
+			if (deltalx == 0 && deltahx == 0 && deltaly == 0 && deltahy == 0 && deltarot == 0 &&
+				deltatrans == 0) continue;
+
+			/* make the change now: no constraint system */
+			ni->lowx += deltalx;   ni->highx += deltahx;
+			ni->lowy += deltaly;   ni->highy += deltahy;
+			ni->rotation += (INTSML)deltarot;
+			ni->transpose += (INTSML)deltatrans;
+		}
+	}
+
+	/* turn off temp flag for quiet changes */
+	db_donextchangequietly = FALSE;
+
+	/* mark a change to the database */
+	db_changetimestamp++;
+}
+
 /*
  * routine to return the address of a nodeinst that it not in the
  * database for miscellaneous use
@@ -448,7 +503,7 @@ void db_freearcproto(ARCPROTO *ap)
  * prototype has successfully been created.  It returns NOARCPROTO if the arc
  * prototype cannot be created.
  */
-ARCPROTO *db_newarcproto(TECHNOLOGY *tech, char *name, INTBIG nomwidth, INTSML ind)
+ARCPROTO *db_newarcproto(TECHNOLOGY *tech, char *name, INTBIG nomwidth, INTBIG ind)
 {
 	REGISTER ARCPROTO *ap;
 	REGISTER ARCPROTO *lat, *tat;
@@ -464,7 +519,7 @@ ARCPROTO *db_newarcproto(TECHNOLOGY *tech, char *name, INTBIG nomwidth, INTSML i
 	if (lat == NOARCPROTO) tech->firstarcproto = ap; else
 		lat->nextarcproto = ap;
 	ap->nextarcproto = NOARCPROTO;
-	if (allocstring(&ap->protoname, name, tech->cluster) != 0) return(NOARCPROTO);
+	if (allocstring(&ap->protoname, name, tech->cluster)) return(NOARCPROTO);
 	ap->nominalwidth = nomwidth;
 	ap->arcindex = ind;
 	ap->tech = tech;
@@ -552,46 +607,47 @@ ARCINST *newarcinst(ARCPROTO *typ, INTBIG wid, INTBIG initialbits, NODEINST *nA,
 	PORTPROTO *pA, INTBIG xA, INTBIG yA, NODEINST *nB, PORTPROTO *pB, INTBIG xB, INTBIG yB,
 	NODEPROTO *parnt)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 	REGISTER PORTPROTO *pp;
+	REGISTER ARCINST *ai;
 	static POLYGON *poly = NOPOLYGON;
 
 	/* check for missing specifications */
 	if (typ == NOARCPROTO)
 	{
-		db_donextchangequietly = 0;
+		db_donextchangequietly = FALSE;
 		return((ARCINST *)db_error(DBBADPROTO|DBNEWARCINST));
 	}
 	if (parnt == NONODEPROTO)
 	{
-		db_donextchangequietly = 0;
+		db_donextchangequietly = FALSE;
 		return((ARCINST *)db_error(DBBADPARENT|DBNEWARCINST));
 	}
 	if (wid < 0)
 	{
-		db_donextchangequietly = 0;
+		db_donextchangequietly = FALSE;
 		return((ARCINST *)db_error(DBBADWIDTH|DBNEWARCINST));
 	}
 	if (nA == NONODEINST || pA == NOPORTPROTO)
 	{
-		db_donextchangequietly = 0;
+		db_donextchangequietly = FALSE;
 		return((ARCINST *)db_error(DBBADENDAN|DBNEWARCINST));
 	}
 	if (nB == NONODEINST || pB == NOPORTPROTO)
 	{
-		db_donextchangequietly = 0;
+		db_donextchangequietly = FALSE;
 		return((ARCINST *)db_error(DBBADENDBN|DBNEWARCINST));
 	}
 
 	/* make sure that the node is in the facet */
 	if (nA->parent != parnt)
 	{
-		db_donextchangequietly = 0;
+		db_donextchangequietly = FALSE;
 		return((ARCINST *)db_error(DBBADENDAN|DBNEWARCINST));
 	}
 	if (nB->parent != parnt)
 	{
-		db_donextchangequietly = 0;
+		db_donextchangequietly = FALSE;
 		return((ARCINST *)db_error(DBBADENDBN|DBNEWARCINST));
 	}
 
@@ -600,14 +656,14 @@ ARCINST *newarcinst(ARCPROTO *typ, INTBIG wid, INTBIG initialbits, NODEINST *nA,
 		if (pp == pA) break;
 	if (pp == NOPORTPROTO)
 	{
-		db_donextchangequietly = 0;
+		db_donextchangequietly = FALSE;
 		return((ARCINST *)db_error(DBBADENDAN|DBNEWARCINST));
 	}
 	for(pp = nB->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		if (pp == pB) break;
 	if (pp == NOPORTPROTO)
 	{
-		db_donextchangequietly = 0;
+		db_donextchangequietly = FALSE;
 		return((ARCINST *)db_error(DBBADENDBN|DBNEWARCINST));
 	}
 
@@ -617,10 +673,10 @@ ARCINST *newarcinst(ARCPROTO *typ, INTBIG wid, INTBIG initialbits, NODEINST *nA,
 	if (pA->connects[i] == NOARCPROTO)
 	{
 		(void)db_error(DBBADENDAC|DBNEWARCINST);
-		if (db_printerrors != 0)
+		if (db_printerrors)
 			ttyputmsg(_("Port %s of node %s in facet %s cannot connect to arc %s"), pA->protoname,
 				describenodeinst(nA), describenodeproto(parnt), describearcproto(typ));
-		db_donextchangequietly = 0;
+		db_donextchangequietly = FALSE;
 		return(NOARCINST);
 	}
 	for(i=0; pB->connects[i] != NOARCPROTO; i++)
@@ -628,38 +684,48 @@ ARCINST *newarcinst(ARCPROTO *typ, INTBIG wid, INTBIG initialbits, NODEINST *nA,
 	if (pB->connects[i] == NOARCPROTO)
 	{
 		(void)db_error(DBBADENDBC|DBNEWARCINST);
-		if (db_printerrors != 0)
+		if (db_printerrors)
 			ttyputmsg(_("Port %s of node %s in facet %s cannot connect to arc %s"), pB->protoname,
 				describenodeinst(nB), describenodeproto(parnt), describearcproto(typ));
-		db_donextchangequietly = 0;
+		db_donextchangequietly = FALSE;
 		return(NOARCINST);
 	}
 
 	/* check that arcinst ends in proper portinst area */
 	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, db_cluster);
-	shapeportpoly(nA, pA, poly, 0);
-	if (isinside(xA, yA, poly) == 0)
+	shapeportpoly(nA, pA, poly, FALSE);
+	if (!isinside(xA, yA, poly))
 	{
 		(void)db_error(DBBADENDAP|DBNEWARCINST);
-		if (db_printerrors != 0)
+		if (db_printerrors)
 			ttyputmsg(_("Point (%s,%s) not inside port %s of node %s in facet %s"), latoa(xA),
 				latoa(yA), pA->protoname, describenodeinst(nA), describenodeproto(parnt));
-		db_donextchangequietly = 0;
+		db_donextchangequietly = FALSE;
 		return(NOARCINST);
 	}
-	shapeportpoly(nB, pB, poly, 0);
-	if (isinside(xB, yB, poly) == 0)
+	shapeportpoly(nB, pB, poly, FALSE);
+	if (!isinside(xB, yB, poly))
 	{
 		(void)db_error(DBBADENDBP|DBNEWARCINST);
-		if (db_printerrors != 0)
+		if (db_printerrors)
 			ttyputmsg(_("Point (%s,%s) not inside port %s of node %s in facet %s"), latoa(xB),
 				latoa(yB), pB->protoname, describenodeinst(nB), describenodeproto(parnt));
-		db_donextchangequietly = 0;
+		db_donextchangequietly = FALSE;
 		return(NOARCINST);
 	}
 
+	/* mark the start of a change to any facet instances that this arc connects */
+	if (nA->proto->primindex == 0) startobjectchange((INTBIG)nA, VNODEINST);
+	if (nB->proto->primindex == 0) startobjectchange((INTBIG)nB, VNODEINST);
+
 	/* create the arcinst */
-	return(db_newarcinst(typ, wid, initialbits, nA,pA,xA,yA, nB,pB,xB,yB, parnt));
+	ai = db_newarcinst(typ, wid, initialbits, nA,pA,xA,yA, nB,pB,xB,yB, parnt);
+
+	/* mark the start of a change to any facet instances that this arc connects */
+	if (nA->proto->primindex == 0) endobjectchange((INTBIG)nA, VNODEINST);
+	if (nB->proto->primindex == 0) endobjectchange((INTBIG)nB, VNODEINST);
+
+	return(ai);
 }
 
 /*
@@ -679,7 +745,7 @@ ARCINST *db_newarcinst(ARCPROTO *typ, INTBIG wid, INTBIG initialbits, NODEINST *
 	ai = allocarcinst(parnt->cell->cluster);
 	if (ai == NOARCINST)
 	{
-		db_donextchangequietly = 0;
+		db_donextchangequietly = FALSE;
 		return(NOARCINST);
 	}
 	ai->proto = typ;
@@ -707,14 +773,14 @@ ARCINST *db_newarcinst(ARCPROTO *typ, INTBIG wid, INTBIG initialbits, NODEINST *
 	/* create a geometry module for this arcinst */
 	ai->geom = allocgeom(parnt->cell->cluster);
 	if (ai->geom == NOGEOM) return(NOARCINST);
-	ai->geom->entrytype = OBJARCINST;
+	ai->geom->entryisnode = FALSE;
 	ai->geom->entryaddr.ai = ai;
 
 	/* enter arcinst in appropriate lists */
 	db_enterarcinst(ai);
 
 	/* handle change control, constraint, and broadcast */
-	if (db_donextchangequietly == 0 && db_dochangesquietly == 0)
+	if (!db_donextchangequietly && !db_dochangesquietly)
 	{
 		/* set the change facet environment */
 		db_setchangefacet(parnt);
@@ -725,7 +791,7 @@ ARCINST *db_newarcinst(ARCPROTO *typ, INTBIG wid, INTBIG initialbits, NODEINST *
 		/* tell constraint system about new arc */
 		(*el_curconstraint->newobject)((INTBIG)ai, VARCINST);
 	}
-	db_donextchangequietly = 0;
+	db_donextchangequietly = FALSE;
 
 	/* report arcinst address */
 	return(ai);
@@ -738,7 +804,7 @@ ARCINST *db_newarcinst(ARCPROTO *typ, INTBIG wid, INTBIG initialbits, NODEINST *
  */
 void db_enterarcinst(ARCINST *ai)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 	REGISTER NODEPROTO *np;
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *oai;
@@ -753,7 +819,7 @@ void db_enterarcinst(ARCINST *ai)
 	ai->nextarcinst = np->firstarcinst;
 	ai->lastarcinst = NOARCINST;
 	np->firstarcinst = ai;
-	(void)setshrinkvalue(ai, 1);
+	(void)setshrinkvalue(ai, TRUE);
 
 	/* link the geometry entry for this arcinst */
 	linkgeom(ai->geom, np);
@@ -772,7 +838,7 @@ void db_enterarcinst(ARCINST *ai)
 		{
 			oai = pi->conarcinst;
 			if (oai == ai) continue;
-			if (setshrinkvalue(oai, 1) != 0)
+			if (setshrinkvalue(oai, TRUE) != 0)
 				updategeom(oai->geom, oai->parent);
 		}
 	}
@@ -817,21 +883,32 @@ void db_addportarcinst(NODEINST *ni, PORTARCINST *npi)
 
 /*
  * routine to remove arcinst "ai" from the database.  The routine returns
- * 0 if successful, nonzero if an error.
+ * FALSE if successful, TRUE if an error.
  */
-INTSML killarcinst(ARCINST *ai)
+BOOLEAN killarcinst(ARCINST *ai)
 {
+	REGISTER NODEINST *ni1, *ni2;
+
 	if (ai == NOARCINST)
 	{
-		db_donextchangequietly = 0;
-		return((INTSML)db_error(DBBADINST|DBKILLARCINST));
+		db_donextchangequietly = FALSE;
+		return(db_error(DBBADINST|DBKILLARCINST) != 0);
 	}
 
+	/* mark the start of a change to any facet instances that this arc connects */
+	ni1 = ai->end[0].nodeinst;   ni2 = ai->end[1].nodeinst;
+	if (ni1->proto->primindex == 0) startobjectchange((INTBIG)ni1, VNODEINST);
+	if (ni2->proto->primindex == 0) startobjectchange((INTBIG)ni2, VNODEINST);
+
 	/* remove arcinst from appropriate lists */
 	db_killarcinst(ai);
 
+	/* mark the start of a change to any facet instances that this arc connects */
+	if (ni1->proto->primindex == 0) endobjectchange((INTBIG)ni1, VNODEINST);
+	if (ni2->proto->primindex == 0) endobjectchange((INTBIG)ni2, VNODEINST);
+
 	/* freeing of the arcinst will be done later */
-	return(0);
+	return(FALSE);
 }
 
 void db_killarcinst(ARCINST *ai)
@@ -839,7 +916,7 @@ void db_killarcinst(ARCINST *ai)
 	db_retractarcinst(ai);
 
 	/* handle change control, constraint, and broadcast */
-	if (db_donextchangequietly == 0 && db_dochangesquietly == 0)
+	if (!db_donextchangequietly && !db_dochangesquietly)
 	{
 		/* set the change facet environment */
 		db_setchangefacet(ai->parent);
@@ -857,12 +934,12 @@ void db_killarcinst(ARCINST *ai)
 		freegeom(ai->geom);
 		freearcinst(ai);
 	}
-	db_donextchangequietly = 0;
+	db_donextchangequietly = FALSE;
 }
 
 void db_retractarcinst(ARCINST *ai)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 	REGISTER NODEINST *ni;
 	REGISTER PORTARCINST *pi, *lpi;
 	REGISTER ARCINST *oai;
@@ -895,7 +972,7 @@ void db_retractarcinst(ARCINST *ai)
 		{
 			oai = pi->conarcinst;
 			if (oai == ai) continue;
-			if (setshrinkvalue(oai, 1) != 0)
+			if (setshrinkvalue(oai, TRUE) != 0)
 				updategeom(oai->geom, oai->parent);
 		}
 
@@ -923,7 +1000,7 @@ INTBIG defaultarcwidth(ARCPROTO *ap)
 	width = ap->nominalwidth;
 
 	/* see if there is an override on the arc */
-	var = getvalkey((INTBIG)ap, VARCPROTO, VINTEGER, el_arc_width_default);
+	var = getvalkey((INTBIG)ap, VARCPROTO, VINTEGER, el_arc_width_default_key);
 	if (var != NOVARIABLE)
 		width = var->addr * el_curlib->lambda[ap->tech->techindex] / WHOLE;
 
@@ -934,31 +1011,31 @@ INTBIG defaultarcwidth(ARCPROTO *ap)
  * routine to modify arcinst "ai" by "deltawid" in width, "deltax" in both
  * ends X geometry and "deltay" in both ends Y position.  The X and Y
  * motion must not cause the connecting nodes to move.  The routine
- * returns nonzero if an error is detected.  Null arc motion is allowed
+ * returns true if an error is detected.  Null arc motion is allowed
  * to queue some other change to the arc.
  */
-INTSML modifyarcinst(ARCINST *ai, INTBIG deltawid, INTBIG deltax1, INTBIG deltay1,
+BOOLEAN modifyarcinst(ARCINST *ai, INTBIG deltawid, INTBIG deltax1, INTBIG deltay1,
 	INTBIG deltax2, INTBIG deltay2)
 {
-	REGISTER INTBIG oldwid, oldlen, oldx0,oldy0, oldx1,oldy1;
-	REGISTER INTSML e1, e2;
+	REGISTER INTBIG oldwid, oldlen, oldx0, oldy0, oldx1, oldy1;
+	REGISTER BOOLEAN e1, e2;
 
 	if (ai == NOARCINST)
 	{
-		db_donextchangequietly = 0;
-		return((INTSML)db_error(DBBADINST|DBMODIFYARCINST));
+		db_donextchangequietly = FALSE;
+		return(db_error(DBBADINST|DBMODIFYARCINST) != 0);
 	}
 	if (ai->width + deltawid < 0)
 	{
-		db_donextchangequietly = 0;
-		return((INTSML)db_error(DBBADNEWWID|DBMODIFYARCINST));
+		db_donextchangequietly = FALSE;
+		return(db_error(DBBADNEWWID|DBMODIFYARCINST) != 0);
 	}
 	if (deltax1 != 0 || deltay1 != 0 || deltax2 != 0 || deltay2 != 0)
 	{
 		if ((ai->userbits&(FIXED|CANTSLIDE)) != 0)
 		{
-			db_donextchangequietly = 0;
-			return((INTSML)db_error(DBNOSLIDING|DBMODIFYARCINST));
+			db_donextchangequietly = FALSE;
+			return(db_error(DBNOSLIDING|DBMODIFYARCINST) != 0);
 		}
 
 		/* temporarily set the width and check for port validity */
@@ -966,10 +1043,10 @@ INTSML modifyarcinst(ARCINST *ai, INTBIG deltawid, INTBIG deltax1, INTBIG deltay
 		e1 = db_stillinport(ai, 0, ai->end[0].xpos+deltax1, ai->end[0].ypos+deltay1);
 		e2 = db_stillinport(ai, 1, ai->end[1].xpos+deltax2, ai->end[1].ypos+deltay2);
 		ai->width -= deltawid;
-		if (e1 == 0 || e2 == 0)
+		if (!e1 || !e2)
 		{
-			db_donextchangequietly = 0;
-			return((INTSML)db_error(DBNOTINPORT|DBMODIFYARCINST));
+			db_donextchangequietly = FALSE;
+			return(db_error(DBNOTINPORT|DBMODIFYARCINST) != 0);
 		}
 	}
 
@@ -981,11 +1058,11 @@ INTSML modifyarcinst(ARCINST *ai, INTBIG deltawid, INTBIG deltax1, INTBIG deltay
 	oldx1 = ai->end[1].xpos;   ai->end[1].xpos += deltax2;
 	oldy1 = ai->end[1].ypos;   ai->end[1].ypos += deltay2;
 	ai->length = computedistance(ai->end[0].xpos, ai->end[0].ypos, ai->end[1].xpos, ai->end[1].ypos);
-	(void)setshrinkvalue(ai, 1);
+	(void)setshrinkvalue(ai, TRUE);
 	updategeom(ai->geom, ai->parent);
 
 	/* handle change control, constraint, and broadcast */
-	if (db_donextchangequietly == 0 && db_dochangesquietly == 0)
+	if (!db_donextchangequietly && !db_dochangesquietly)
 	{
 		/* tell all tools about this arcinst */
 		ai->changeaddr = (char *)db_change((INTBIG)ai, ARCINSTMOD, oldx0, oldy0, oldx1, oldy1,
@@ -997,23 +1074,22 @@ INTSML modifyarcinst(ARCINST *ai, INTBIG deltawid, INTBIG deltax1, INTBIG deltay
 		/* set the change facet environment */
 		db_setchangefacet(ai->parent);
 	}
-	db_donextchangequietly = 0;
+	db_donextchangequietly = FALSE;
 
 	/* mark a change to the database */
 	db_changetimestamp++;
 
-	return(0);
+	return(FALSE);
 }
 
 /*
  * Routine to set the "endshrink" value for arcinst "ai".  Returns
  * nonzero if the value changed.
  */
-INTBIG setshrinkvalue(ARCINST *ai, INTSML extend)
+INTBIG setshrinkvalue(ARCINST *ai, BOOLEAN extend)
 {
-	REGISTER INTSML i;
-	REGISTER INTBIG result, ret;
-	INTSML shorter[2];
+	REGISTER INTBIG i, result, ret;
+	INTBIG shorter[2];
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *oar;
 	REGISTER INTBIG newshrink;
@@ -1039,7 +1115,7 @@ INTBIG setshrinkvalue(ARCINST *ai, INTSML extend)
 		{
 			ni = ai->end[i].nodeinst;
 			if ((ni->proto->userbits&NODESHRINK) != 0) ni->userbits |= NSHORT;
-			if (extend == 0) continue;
+			if (!extend) continue;
 			if ((ni->proto->userbits&ARCSHRINK) != 0)
 			{
 
@@ -1074,13 +1150,13 @@ INTBIG setshrinkvalue(ARCINST *ai, INTSML extend)
  * routine returns the angle between the nonmanhattan objects.
  */
 #define MAXANGLES 3
-INTSML db_checkshortening(NODEINST *ni, PORTPROTO *pp)
+INTBIG db_checkshortening(NODEINST *ni, PORTPROTO *pp)
 {
 	REGISTER PORTARCINST *pi;
 	REGISTER NODEPROTO *np;
 	REGISTER ARCINST *ai;
-	REGISTER INTSML ang, off90, total;
-	INTSML angles[MAXANGLES];
+	REGISTER INTBIG ang, off90, total;
+	INTBIG angles[MAXANGLES];
 
 	/* quit now if we don't have to worry about this kind of nodeinst */
 	np = ni->proto;
@@ -1100,7 +1176,7 @@ INTSML db_checkshortening(NODEINST *ni, PORTPROTO *pp)
 		if ((np->userbits&ARCSHRINK) == 0 && pi->proto != pp) continue;
 
 		/* compute the angle */
-		ang = (INTSML)(ai->userbits&AANGLE) >> AANGLESH;
+		ang = (ai->userbits&AANGLE) >> AANGLESH;
 		if (ai->end[1].portarcinst->proto == pi->proto && ai->end[1].nodeinst == ni) ang += 180;
 		ang %= 360;
 		if ((ang%90) != 0) off90++;
@@ -1111,7 +1187,7 @@ INTSML db_checkshortening(NODEINST *ni, PORTPROTO *pp)
 	/* throw in the nodeinst rotation factor if it is important */
 	if ((np->userbits&NODESHRINK) != 0)
 	{
-		ang = (INTSML)((pp->userbits & PORTANGLE) >> PORTANGLESH);
+		ang = (pp->userbits & PORTANGLE) >> PORTANGLESH;
 		ang += (ni->rotation+5) / 10;
 		if (ni->transpose != 0) { ang = 270 - ang; if (ang < 0) ang += 360; }
 		ang = (ang+180)%360;
@@ -1139,12 +1215,33 @@ INTSML db_checkshortening(NODEINST *ni, PORTPROTO *pp)
  */
 void determineangle(ARCINST *ai)
 {
-	INTSML ang;
+	INTBIG ang;
+	REGISTER NODEINST *ni;
+	REGISTER INTBIG cx0, cy0, cx1, cy1;
 
-	/* cannot compute angle if length is zero */
-	if (ai->end[0].xpos == ai->end[1].xpos && ai->end[0].ypos == ai->end[1].ypos) return;
-
-	ang = figureangle(ai->end[0].xpos, ai->end[0].ypos, ai->end[1].xpos, ai->end[1].ypos);
+	/* if length is zero, look at nodes */
+	if (ai->end[0].xpos == ai->end[1].xpos && ai->end[0].ypos == ai->end[1].ypos)
+	{
+		ni = ai->end[0].nodeinst;
+		cx0 = (ni->lowx + ni->highx) / 2;
+		cy0 = (ni->lowy + ni->highy) / 2;
+		ni = ai->end[1].nodeinst;
+		cx1 = (ni->lowx + ni->highx) / 2;
+		cy1 = (ni->lowy + ni->highy) / 2;
+		if (abs(cx0-cx1) > abs(cy0-cy1))
+		{
+			/* horizontal nodes */
+			if (cx0 > cx1) ang = 1800; else
+				ang = 0;
+		} else
+		{
+			if (cy0 > cy1) ang = 900; else
+				ang = 2700;
+		}
+	} else
+	{
+		ang = figureangle(ai->end[0].xpos, ai->end[0].ypos, ai->end[1].xpos, ai->end[1].ypos);
+	}
 	ai->userbits = (ai->userbits & ~AANGLE) | ((ang+5)/10 << AANGLESH);
 }
 
@@ -1254,17 +1351,17 @@ PORTPROTO *newportproto(NODEPROTO *np, NODEINST *nodeinst, PORTPROTO *portaddres
 	/* error checks */
 	if (np == NONODEPROTO)
 	{
-		db_donextchangequietly = 0;
+		db_donextchangequietly = FALSE;
 		return((PORTPROTO *)db_error(DBBADFACET|DBNEWPORTPROTO));
 	}
 	if (*name == 0)
 	{
-		db_donextchangequietly = 0;
+		db_donextchangequietly = FALSE;
 		return((PORTPROTO *)db_error(DBBADNAME|DBNEWPORTPROTO));
 	}
 	for(ptr = name; *ptr != 0; ptr++) if (*ptr <= ' ' || *ptr >= 0177)
 	{
-		db_donextchangequietly = 0;
+		db_donextchangequietly = FALSE;
 		return((PORTPROTO *)db_error(DBBADNAME|DBNEWPORTPROTO));
 	}
 
@@ -1273,7 +1370,7 @@ PORTPROTO *newportproto(NODEPROTO *np, NODEINST *nodeinst, PORTPROTO *portaddres
 		if (pp == portaddress) break;
 	if (pp == NOPORTPROTO)
 	{
-		db_donextchangequietly = 0;
+		db_donextchangequietly = FALSE;
 		return((PORTPROTO *)db_error(DBBADSUBPORT|DBNEWPORTPROTO));
 	}
 
@@ -1281,7 +1378,7 @@ PORTPROTO *newportproto(NODEPROTO *np, NODEINST *nodeinst, PORTPROTO *portaddres
 	for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		if (namesame(pp->protoname, name) == 0)
 	{
-		db_donextchangequietly = 0;
+		db_donextchangequietly = FALSE;
 		return((PORTPROTO *)db_error(DBDUPLICATE|DBNEWPORTPROTO));
 	}
 
@@ -1301,7 +1398,7 @@ PORTPROTO *db_newportproto(NODEPROTO *np, NODEINST *nodeinst, PORTPROTO *portadd
 	pp = allocportproto(np->cell->cluster);
 	if (pp == NOPORTPROTO)
 	{
-		db_donextchangequietly = 0;
+		db_donextchangequietly = FALSE;
 		return(NOPORTPROTO);
 	}
 
@@ -1314,9 +1411,9 @@ PORTPROTO *db_newportproto(NODEPROTO *np, NODEINST *nodeinst, PORTPROTO *portadd
 	TDCLEAR(pp->textdescript);
 	defaulttextdescript(pp->textdescript, nodeinst->geom);
 	defaulttextsize(1, pp->textdescript);
-	if (allocstring(&pp->protoname, name, np->cell->cluster) != 0)
+	if (allocstring(&pp->protoname, name, np->cell->cluster))
 	{
-		db_donextchangequietly = 0;
+		db_donextchangequietly = FALSE;
 		return(NOPORTPROTO);
 	}
 
@@ -1324,7 +1421,7 @@ PORTPROTO *db_newportproto(NODEPROTO *np, NODEINST *nodeinst, PORTPROTO *portadd
 	db_enterportproto(pp);
 
 	/* handle change control, constraint, and broadcast */
-	if (db_donextchangequietly == 0 && db_dochangesquietly == 0)
+	if (!db_donextchangequietly && !db_dochangesquietly)
 	{
 		/* set the change facet environment */
 		db_setchangefacet(np);
@@ -1335,7 +1432,7 @@ PORTPROTO *db_newportproto(NODEPROTO *np, NODEINST *nodeinst, PORTPROTO *portadd
 		/* tell constraint system about new port */
 		(*el_curconstraint->newobject)((INTBIG)pp, VPORTPROTO);
 	}
-	db_donextchangequietly = 0;
+	db_donextchangequietly = FALSE;
 
 	return(pp);
 }
@@ -1452,45 +1549,45 @@ PORTPROTO *db_newprimportproto(NODEPROTO *np, ARCPROTO **arcs, char *name)
 	pp->network = NONETWORK;
 	pp->parent = np;       pp->connects = arcs;
 	pp->subnodeinst = NONODEINST;  pp->subportproto = NOPORTPROTO;
-	if (allocstring(&pp->protoname, name, np->tech->cluster) != 0) return(NOPORTPROTO);
+	if (allocstring(&pp->protoname, name, np->tech->cluster)) return(NOPORTPROTO);
 
 	return(pp);
 }
 
 /*
- * routine to delete portproto "pp" from nodeproto "np".  Returns 0 if
- * successful, nonzero if the portproto could not be deleted (does not
+ * routine to delete portproto "pp" from nodeproto "np".  Returns FALSE if
+ * successful, TRUE if the portproto could not be deleted (does not
  * exist).  If the portproto has arcs connected to it in instances of the
  * facet, the arcs are deleted.  If the portproto is an export of
  * the facet, those exports are deleted (recursively).
  */
-INTSML killportproto(NODEPROTO *np, PORTPROTO *pp)
+BOOLEAN killportproto(NODEPROTO *np, PORTPROTO *pp)
 {
 	REGISTER PORTPROTO *spt;
 
 	/* look at all portprotos to ensure it exists */
 	if (np == NONODEPROTO)
 	{
-		db_donextchangequietly = 0;
-		return((INTSML)db_error(DBBADFACET|DBKILLPORTPROTO));
+		db_donextchangequietly = FALSE;
+		return(db_error(DBBADFACET|DBKILLPORTPROTO) != 0);
 	}
 	for(spt = np->firstportproto; spt != NOPORTPROTO; spt = spt->nextportproto)
 		if (spt == pp) break;
 	if (spt == NOPORTPROTO)
 	{
-		db_donextchangequietly = 0;
-		return((INTSML)db_error(DBBADPROTO|DBKILLPORTPROTO));
+		db_donextchangequietly = FALSE;
+		return(db_error(DBBADPROTO|DBKILLPORTPROTO) != 0);
 	}
 
 	/* cannot delete port on primitive nodeproto */
 	if (pp->subnodeinst == NONODEINST)
 	{
-		db_donextchangequietly = 0;
-		return((INTSML)db_error(DBPRIMITIVE|DBKILLPORTPROTO));
+		db_donextchangequietly = FALSE;
+		return(db_error(DBPRIMITIVE|DBKILLPORTPROTO) != 0);
 	}
 
 	db_killportproto(pp);
-	return(0);
+	return(FALSE);
 }
 
 void db_killportproto(PORTPROTO *pp)
@@ -1530,7 +1627,7 @@ void db_killportproto(PORTPROTO *pp)
 	db_retractportproto(pp);
 
 	/* handle change control, constraint, and broadcast */
-	if (db_donextchangequietly == 0 && db_dochangesquietly == 0)
+	if (!db_donextchangequietly && !db_dochangesquietly)
 	{
 		/* set the change facet environment */
 		db_setchangefacet(np);
@@ -1546,7 +1643,7 @@ void db_killportproto(PORTPROTO *pp)
 		efree(pp->protoname);
 		freeportproto(pp);
 	}
-	db_donextchangequietly = 0;
+	db_donextchangequietly = FALSE;
 }
 
 void db_retractportproto(PORTPROTO *pp)
