@@ -32,8 +32,8 @@
 #include "database.h"
 #include "usr.h"
 
-INTBIG db_lasterror;			/* last error message */
-INTSML db_printerrors;			/* flag for printing internal errors */
+INTBIG  db_lasterror;			/* last error message */
+BOOLEAN db_printerrors;			/* flag for printing internal errors */
 
 static char *db_errortype[] =
 {
@@ -139,7 +139,7 @@ static char *db_routines[] =
 INTBIG db_error(INTBIG code)
 {
 	db_lasterror = code;
-	if (db_printerrors != 0) telldatabaseerror();
+	if (db_printerrors) telldatabaseerror();
 	return(-1);
 }
 
@@ -148,7 +148,7 @@ INTBIG db_error(INTBIG code)
  */
 void telldatabaseerror(void)
 {
-	REGISTER INTSML routine, error;
+	REGISTER INTBIG routine, error;
 
 	routine = (db_lasterror >> 16) - 1;
 	error = db_lasterror & 0xFFFF;
@@ -160,21 +160,20 @@ void telldatabaseerror(void)
 
 /*
  * These are the routines to log errors:
- *   initerrorlogging(char *s, NODEPROTO *f1, NODEPROTO *f2) initialize for subsystem "s"
+ *   initerrorlogging(char *s)                   initialize for subsystem "s"
  *   e = logerror(char *msg, NODEPROTO *f, k)    log message "msg" in facet "f", sort key "k"
- *   addgeomtoerror(void *e, GEOM *g, INTSML s, INTSML l, NODEINST **p)
+ *   addgeomtoerror(void *e, GEOM *g, BOOLEAN s, INTBIG l, NODEINST **p)
  *                                               add geom "g" to error "e" (show if "s" nonzero)
- *   addexporttoerror(void *e, PORTPROTO *p, INTSML s)  add export "pp" to error "e"
+ *   addexporttoerror(void *e, PORTPROTO *p, BOOLEAN s)  add export "pp" to error "e"
  *   addlinetoerror(void *e, x1, y1, x2, y2)     add line to error "e"
  *   addpolytoerror(void *e, POLYGON *p)         add polygon to error "e"
  *   addpointtoerror(void *e, x, y)              add point to error "e"
  * To report errors, call:
- *   termerrorlogging()                          complete error accumulation
+ *   termerrorlogging(explain)                   complete error accumulation
  *   sorterrors()                                sort errors by key
  *   n = numerrors()                             returns number of errors
  *   s = reportnexterror(show, &g1, &g2)         report next error
  *   s = reportpreverror()                       report previous error
- *   s = reportcurrenterror(show, &g1, &g2)      report current error
  */
 
 typedef enum {ERRORTYPEGEOM, ERRORTYPEEXPORT, ERRORTYPELINE, ERRORTYPEPOINT} ERRORHIGHLIGHTTYPE;
@@ -186,10 +185,10 @@ typedef struct
 	ERRORHIGHLIGHTTYPE type;
 	GEOM              *geom;
 	PORTPROTO         *pp;
-	INTBIG             showgeom;
+	BOOLEAN            showgeom;
 	INTBIG             x1, y1;
 	INTBIG             x2, y2;
-	INTSML             pathlen;
+	INTBIG             pathlen;
 	NODEINST         **path;
 } ERRORHIGHLIGHT;
 
@@ -201,6 +200,7 @@ typedef struct iErrorList
 	char              *message;
 	NODEPROTO         *facet;
 	INTBIG             sortkey;
+	INTBIG             index;
 	INTBIG             numhighlights;
 	ERRORHIGHLIGHT   **highlights;
 	struct iErrorList *preverrorlist;
@@ -213,27 +213,33 @@ static ERRORLIST *db_curerrorlist = NOERRORLIST;
 static ERRORLIST *db_nexterrorlist = NOERRORLIST;
 static ERRORLIST *db_preverrorlist = NOERRORLIST;
 static char       db_errorsystem[100] = "";
-static NODEPROTO *db_errorfacet1 = NONODEPROTO;
-static NODEPROTO *db_errorfacet2 = NONODEPROTO;
+static INTBIG     db_numerrors;
+static INTBIG     db_truenumerrors;
+static INTBIG     db_maxerrors = 0;
 
 
-static INTSML db_addtoerrorlist(ERRORLIST *el, ERRORHIGHLIGHT *eh);
-static int    db_errorlistascending(const void *e1, const void *e2);
+static BOOLEAN db_addtoerrorlist(ERRORLIST *el, ERRORHIGHLIGHT *eh);
+static int     db_errorlistascending(const void *e1, const void *e2);
+char          *db_reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2);
 
 /*
  * Routine to free all previously stored errors and initialize the system.
  * The errors are described by "system" and up to two facets "facet1" and
  * "facet2" (may be NONODEPROTO).
  */
-void initerrorlogging(char *system, NODEPROTO *facet1, NODEPROTO *facet2)
+void initerrorlogging(char *system)
 {
+	REGISTER VARIABLE *var;
+
 	db_freeerrormemory();
 	db_curerrorlist = NOERRORLIST;
 	db_nexterrorlist = NOERRORLIST;
 	db_preverrorlist = NOERRORLIST;
 	strncpy(db_errorsystem, system, 100);
-	db_errorfacet1 = facet1;
-	db_errorfacet2 = facet2;
+	db_numerrors = db_truenumerrors = 0;
+	var = getval((INTBIG)us_tool, VTOOL, VINTEGER, "USER_maximum_errors");
+	if (var == NOVARIABLE) db_maxerrors = 0; else
+		db_maxerrors = var->addr;
 }
 
 void db_freeerrormemory(void)
@@ -266,6 +272,17 @@ void *logerror(char *message, NODEPROTO *facet, INTBIG sortkey)
 {
 	REGISTER ERRORLIST *el;
 
+	/* if too many errors, don't save it */
+	db_numerrors++;
+	if (db_maxerrors > 0 && db_numerrors > db_maxerrors)
+	{
+		if (db_numerrors == db_maxerrors+1)
+			ttyputmsg(_("WARNING: more than %ld errors found, ignoring the rest"),
+				db_maxerrors);
+		return(0);
+	}
+
+	/* save the error */
 	if (db_errorlistfree != NOERRORLIST)
 	{
 		el = db_errorlistfree;
@@ -275,7 +292,7 @@ void *logerror(char *message, NODEPROTO *facet, INTBIG sortkey)
 		el = (ERRORLIST *)emalloc(sizeof (ERRORLIST), db_cluster);
 		if (el == 0) return(0);
 	}
-	if (allocstring(&el->message, message, db_cluster) != 0) return(0);
+	if (allocstring(&el->message, message, db_cluster)) return(0);
 	el->facet = facet;
 	el->sortkey = sortkey;
 	el->numhighlights = 0;
@@ -283,23 +300,24 @@ void *logerror(char *message, NODEPROTO *facet, INTBIG sortkey)
 	el->nexterrorlist = db_firsterrorlist;
 	if (db_firsterrorlist != NOERRORLIST) db_firsterrorlist->preverrorlist = el;
 	db_firsterrorlist = el;
+	db_truenumerrors++;
 	return((void *)el);
 }
 
 /*
  * Routine to add "geom" to the error in "errorlist".  Also adds a
  * hierarchical traversal path "path" (which is "pathlen" long).
- * Returns nonzero on error.
  */
-INTSML addgeomtoerror(void *errorlist, GEOM *geom, INTSML showit, INTSML pathlen, NODEINST **path)
+void addgeomtoerror(void *errorlist, GEOM *geom, BOOLEAN showit, INTBIG pathlen, NODEINST **path)
 {
 	REGISTER ERRORLIST *el;
 	REGISTER ERRORHIGHLIGHT *eh;
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 
+	if (errorlist == 0) return;
 	el = (ERRORLIST *)errorlist;
 	eh = (ERRORHIGHLIGHT *)emalloc(sizeof (ERRORHIGHLIGHT), db_cluster);
-	if (eh == 0) return(1);
+	if (eh == 0) return;
 	eh->type = ERRORTYPEGEOM;
 	eh->geom = geom;
 	eh->showgeom = showit;
@@ -307,162 +325,159 @@ INTSML addgeomtoerror(void *errorlist, GEOM *geom, INTSML showit, INTSML pathlen
 	if (pathlen > 0)
 	{
 		eh->path = (NODEINST **)emalloc(pathlen * (sizeof (NODEINST *)), db_cluster);
-		if (eh->path == 0) return(1);
+		if (eh->path == 0) return;
 		for(i=0; i<pathlen; i++)
 			eh->path[i] = path[i];
 	}
-	if (db_addtoerrorlist(el, eh) != 0) return(1);
-	return(0);	
+	(void)db_addtoerrorlist(el, eh);
 }
 
 /*
- * Routine to add "pp" to the error in "errorlist".  Returns nonzero on error.
+ * Routine to add "pp" to the error in "errorlist".
  */
-INTSML addexporttoerror(void *errorlist, PORTPROTO *pp, INTSML showit)
+void addexporttoerror(void *errorlist, PORTPROTO *pp, BOOLEAN showit)
 {
 	REGISTER ERRORLIST *el;
 	REGISTER ERRORHIGHLIGHT *eh;
 
+	if (errorlist == 0) return;
 	el = (ERRORLIST *)errorlist;
 	eh = (ERRORHIGHLIGHT *)emalloc(sizeof (ERRORHIGHLIGHT), db_cluster);
-	if (eh == 0) return(1);
+	if (eh == 0) return;
 	eh->type = ERRORTYPEEXPORT;
 	eh->pp = pp;
 	eh->showgeom = showit;
 	eh->pathlen = 0;
-	if (db_addtoerrorlist(el, eh) != 0) return(1);
-	return(0);	
+	(void)db_addtoerrorlist(el, eh);	
 }
 
 /*
  * Routine to add line (x1,y1)=>(x2,y2) to the error in "errorlist".
- * Returns nonzero on error.
  */
-INTSML addlinetoerror(void *errorlist, INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2)
+void addlinetoerror(void *errorlist, INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2)
 {
 	REGISTER ERRORLIST *el;
 	REGISTER ERRORHIGHLIGHT *eh;
 
+	if (errorlist == 0) return;
 	el = (ERRORLIST *)errorlist;
 	eh = (ERRORHIGHLIGHT *)emalloc(sizeof (ERRORHIGHLIGHT), db_cluster);
-	if (eh == 0) return(1);
+	if (eh == 0) return;
 	eh->type = ERRORTYPELINE;
 	eh->x1 = x1;
 	eh->y1 = y1;
 	eh->x2 = x2;
 	eh->y2 = y2;
 	eh->pathlen = 0;
-	if (db_addtoerrorlist(el, eh) != 0) return(1);
-	return(0);	
+	(void)db_addtoerrorlist(el, eh);	
 }
 
 /*
  * Routine to add polygon "poly" to the error in "errorlist".
- * Returns nonzero on error.
  */
-INTSML addpolytoerror(void *errorlist, POLYGON *poly)
+void addpolytoerror(void *errorlist, POLYGON *poly)
 {
 	REGISTER INTBIG i, prev;
 	INTBIG lx, hx, ly, hy;
 
-	if (isbox(poly, &lx, &hx, &ly, &hy) != 0)
+	if (errorlist == 0) return;
+	if (isbox(poly, &lx, &hx, &ly, &hy))
 	{
-		if (addlinetoerror(errorlist, lx, ly, lx, hy) != 0) return(1);
-		if (addlinetoerror(errorlist, lx, hy, hx, hy) != 0) return(1);
-		if (addlinetoerror(errorlist, hx, hy, hx, ly) != 0) return(1);
-		if (addlinetoerror(errorlist, hx, ly, lx, ly) != 0) return(1);
+		(void)addlinetoerror(errorlist, lx, ly, lx, hy);
+		(void)addlinetoerror(errorlist, lx, hy, hx, hy);
+		(void)addlinetoerror(errorlist, hx, hy, hx, ly) ;
+		(void)addlinetoerror(errorlist, hx, ly, lx, ly);;
 	} else
 	{
 		for(i=0; i<poly->count; i++)
 		{
 			if (i == 0) prev = poly->count-1; else prev = i-1;
-			if (addlinetoerror(errorlist, poly->xv[prev], poly->yv[prev],
-				poly->xv[i], poly->yv[i]) != 0) return(1);
+			(void)addlinetoerror(errorlist, poly->xv[prev], poly->yv[prev],
+				poly->xv[i], poly->yv[i]);
 		}
 	}
-	return(0);	
 }
 
 /*
  * Routine to add point (x,y) to the error in "errorlist".
- * Returns nonzero on error.
  */
-INTSML addpointtoerror(void *errorlist, INTBIG x, INTBIG y)
+void addpointtoerror(void *errorlist, INTBIG x, INTBIG y)
 {
 	REGISTER ERRORLIST *el;
 	REGISTER ERRORHIGHLIGHT *eh;
 
+	if (errorlist == 0) return;
 	el = (ERRORLIST *)errorlist;
 	eh = (ERRORHIGHLIGHT *)emalloc(sizeof (ERRORHIGHLIGHT), db_cluster);
-	if (eh == 0) return(1);
+	if (eh == 0) return;
 	eh->type = ERRORTYPEPOINT;
 	eh->x1 = x;
 	eh->y1 = y;
 	eh->pathlen = 0;
-	if (db_addtoerrorlist(el, eh) != 0) return(1);
-	return(0);	
+	(void)db_addtoerrorlist(el, eh);	
 }
 
-INTSML db_addtoerrorlist(ERRORLIST *el, ERRORHIGHLIGHT *eh)
+BOOLEAN db_addtoerrorlist(ERRORLIST *el, ERRORHIGHLIGHT *eh)
 {
 	REGISTER ERRORHIGHLIGHT **neweh;
 	REGISTER INTBIG i;
 
 	neweh = (ERRORHIGHLIGHT **)emalloc((sizeof (ERRORHIGHLIGHT *)) * (el->numhighlights+1),
 		db_cluster);
-	if (neweh == 0) return(1);
+	if (neweh == 0) return(TRUE);
 	for(i=0; i<el->numhighlights; i++)
 		neweh[i] = el->highlights[i];
 	neweh[el->numhighlights] = eh;
 	if (el->numhighlights > 0) efree((char *)el->highlights);
 	el->highlights = neweh;
 	el->numhighlights++;
-	return(0);
+	return(FALSE);
 }
 
 /*
  * Routine called when all errors are logged.  Initializes pointers for replay of errors.
  */
-void termerrorlogging(void)
+void termerrorlogging(BOOLEAN explain)
 {
-	REGISTER INTBIG errs, olderrs;
-	REGISTER VARIABLE *var;
+	REGISTER INTBIG errs;
+	REGISTER ERRORLIST *ep;
 
 	db_curerrorlist = NOERRORLIST;
 	db_nexterrorlist = db_firsterrorlist;
 	db_preverrorlist = NOERRORLIST;
 
-	/* save the number of errors in "%V" */
-	errs = numerrors();
-	var = getval((INTBIG)us_tool, VTOOL, VINTEGER, "USER_local_capv");
-	if (var == NOVARIABLE) olderrs = -1; else
-		olderrs = var->addr;
-	if (errs != olderrs)
+	/* enumerate the errors */
+	errs = 0;
+	for(ep = db_firsterrorlist; ep != NOERRORLIST; ep = ep->nexterrorlist)
+		ep->index = ++errs;
+
+	if (errs > 0 && explain)
 	{
-		setval((INTBIG)us_tool, VTOOL, "USER_local_capv", errs, VINTEGER|VDONTSAVE);
+		ttyputmsg(_("To review errors, type:"));
+		ttyputmsg(_(" >  Show the next error"));
+		ttyputmsg(_(" <  Show the previous error"));
 	}
 }
 
 void sorterrors(void)
 {
 	REGISTER ERRORLIST *ep, **sortedlist;
-	REGISTER INTBIG total, i;
+	REGISTER INTBIG i;
 
-	total = 0;
-	for(ep = db_firsterrorlist; ep != NOERRORLIST; ep = ep->nexterrorlist) total++;
-	if (total == 0) return;
-	sortedlist = (ERRORLIST **)emalloc(total * (sizeof (ERRORLIST *)), db_cluster);
+	if (db_truenumerrors == 0) return;
+	sortedlist = (ERRORLIST **)emalloc(db_truenumerrors * (sizeof (ERRORLIST *)), db_cluster);
 	if (sortedlist == 0) return;
 	i = 0;
 	for(ep = db_firsterrorlist; ep != NOERRORLIST; ep = ep->nexterrorlist)
 		sortedlist[i++] = ep;
-	esort(sortedlist, total, sizeof (ERRORLIST *), db_errorlistascending);
-	for(i=0; i<total; i++)
+	esort(sortedlist, db_truenumerrors, sizeof (ERRORLIST *), db_errorlistascending);
+	for(i=0; i<db_truenumerrors; i++)
 	{
 		ep = sortedlist[i];
+		ep->index = i+1;
 		if (i == 0) ep->preverrorlist = NOERRORLIST; else
 			ep->preverrorlist = sortedlist[i-1];
-		if (i < total-1) ep->nexterrorlist = sortedlist[i+1]; else
+		if (i < db_truenumerrors-1) ep->nexterrorlist = sortedlist[i+1]; else
 			ep->nexterrorlist = NOERRORLIST;
 	}
 	db_firsterrorlist = sortedlist[0];
@@ -486,13 +501,7 @@ int db_errorlistascending(const void *e1, const void *e2)
  */
 INTBIG numerrors(void)
 {
-	REGISTER INTBIG errors;
-	REGISTER ERRORLIST *el;
-
-	errors = 0;
-	for(el = db_firsterrorlist; el != NOERRORLIST; el = el->nexterrorlist)
-		errors++;
-	return(errors);
+	return(db_numerrors);
 }
 
 /*
@@ -500,16 +509,13 @@ INTBIG numerrors(void)
  */
 char *reportnexterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 {
-	if (db_nexterrorlist == NOERRORLIST)
+	if (db_nexterrorlist != NOERRORLIST)
 	{
-		(void)initinfstr();
-		(void)formatinfstr(_("No more %s errors"), db_errorsystem);
-		return(returninfstr());
+		db_curerrorlist = db_nexterrorlist;
+		db_nexterrorlist = db_curerrorlist->nexterrorlist;
+		db_preverrorlist = db_curerrorlist->preverrorlist;
 	}
-	db_curerrorlist = db_nexterrorlist;
-	db_nexterrorlist = db_curerrorlist->nexterrorlist;
-	db_preverrorlist = db_curerrorlist->preverrorlist;
-	return(reportcurrenterror(showhigh, g1, g2));
+	return(db_reportcurrenterror(showhigh, g1, g2));
 }
 
 /*
@@ -517,16 +523,13 @@ char *reportnexterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
  */
 char *reportpreverror(void)
 {
-	if (db_preverrorlist == NOERRORLIST)
+	if (db_preverrorlist != NOERRORLIST)
 	{
-		(void)initinfstr();
-		(void)formatinfstr(_("No more %s errors"), db_errorsystem);
-		return(returninfstr());
+		db_curerrorlist = db_preverrorlist;
+		db_nexterrorlist = db_curerrorlist->nexterrorlist;
+		db_preverrorlist = db_curerrorlist->preverrorlist;
 	}
-	db_curerrorlist = db_preverrorlist;
-	db_nexterrorlist = db_curerrorlist->nexterrorlist;
-	db_preverrorlist = db_curerrorlist->preverrorlist;
-	return(reportcurrenterror(1, 0, 0));
+	return(db_reportcurrenterror(1, 0, 0));
 }
 
 /*
@@ -536,13 +539,12 @@ char *reportpreverror(void)
  */
 #define MAXFACETS 20
 
-char *reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
+char *db_reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 {
 	REGISTER ERRORLIST *el;
 	REGISTER NODEPROTO *facet, *np;
 	NODEPROTO *facetlist[MAXFACETS];
-	REGISTER INTBIG i, j, consize, numfacets, havegeoms, newwindows, count;
-	REGISTER INTSML hierpathcount;
+	REGISTER INTBIG i, j, consize, numfacets, havegeoms, newwindows, count, hierpathcount;
 	REGISTER NODEINST **hierpath;
 	INTBIG lx, hx, ly, hy;
 	REGISTER ERRORHIGHLIGHT *eh;
@@ -573,7 +575,7 @@ char *reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 			switch (eh->type)
 			{
 				case ERRORTYPEGEOM:
-					if (eh->showgeom == 0) facet = NONODEPROTO; else
+					if (!eh->showgeom) facet = NONODEPROTO; else
 					{
 						facet = geomparent(eh->geom);
 						if (eh->pathlen > 0)
@@ -584,7 +586,7 @@ char *reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 					}
 					break;
 				case ERRORTYPEEXPORT:
-					if (eh->showgeom == 0) facet = NONODEPROTO; else
+					if (!eh->showgeom) facet = NONODEPROTO; else
 						facet = eh->pp->parent;
 					break;
 			}
@@ -599,7 +601,7 @@ char *reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 			np = facet;
 			for(j=hierpathcount-1; j>=0; j--)
 			{
-				(void)setvalkey((INTBIG)np, VNODEPROTO, us_facet_descent_path, (INTBIG)hierpath[j],
+				(void)setvalkey((INTBIG)np, VNODEPROTO, us_descent_path_key, (INTBIG)hierpath[j],
 					VNODEINST|VDONTSAVE);
 				np = hierpath[j]->parent;
 			}
@@ -620,26 +622,6 @@ char *reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 				continue;
 			}
 
-			/* not displayed: find a window to use */
-			for(w = el_topwindowpart; w != NOWINDOWPART; w = w->nextwindowpart)
-			{
-				if (w->curnodeproto == NONODEPROTO) break;
-				if (w->curnodeproto == db_errorfacet1 ||
-					w->curnodeproto == db_errorfacet2) continue;
-				for(j=0; j<numfacets; j++)
-					if (w->curnodeproto == facetlist[j]) break;
-				if (j >= numfacets) break;
-			}
-			if (w != NOWINDOWPART)
-			{
-				/* found a window: show the facet there */
-				el_curwindowpart = w;
-				us_fullview(facetlist[i], &lx, &hx, &ly, &hy);
-				us_switchtofacet(facetlist[i], lx, hx, ly, hy, NONODEINST, NOPORTPROTO, 0, 0);
-				facetlist[i] = NONODEPROTO;
-				continue;
-			}
-
 			/* keep a count of the number of new windows needed */
 			newwindows++;
 		}
@@ -650,19 +632,19 @@ char *reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 			if (newwindows > 0)
 			{
 				el_curwindowpart = neww[0];
-				neww[1] = us_splitcurrentwindow(2, 0, &neww[0]);
+				neww[1] = us_splitcurrentwindow(2, FALSE, &neww[0]);
 				newwindows--;
 			}
 			if (newwindows > 0)
 			{
 				el_curwindowpart = neww[0];
-				neww[2] = us_splitcurrentwindow(1, 0, &neww[0]);
+				neww[2] = us_splitcurrentwindow(1, FALSE, &neww[0]);
 				newwindows--;
 			}
 			if (newwindows > 0)
 			{
 				el_curwindowpart = neww[1];
-				neww[3] = us_splitcurrentwindow(1, 0, &neww[1]);
+				neww[3] = us_splitcurrentwindow(1, FALSE, &neww[1]);
 				newwindows--;
 			}
 			count = 0;
@@ -671,7 +653,7 @@ char *reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 				if (facetlist[i] == NONODEPROTO) continue;
 				el_curwindowpart = neww[count++];
 				us_fullview(facetlist[i], &lx, &hx, &ly, &hy);
-				us_switchtofacet(facetlist[i], lx, hx, ly, hy, NONODEINST, NOPORTPROTO, 0, 0);
+				us_switchtofacet(facetlist[i], lx, hx, ly, hy, NONODEINST, NOPORTPROTO, FALSE, 0);
 				facetlist[i] = NONODEPROTO;
 				if (count >= 4) break;
 			}
@@ -689,7 +671,7 @@ char *reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 			case ERRORTYPEGEOM:
 				if (geom1 == NOGEOM) geom1 = eh->geom; else
 					if (geom2 == NOGEOM) geom2 = eh->geom;
-				if (showhigh == 0 || eh->showgeom == 0) continue;
+				if (showhigh == 0 || !eh->showgeom) continue;
 
 				/* include this geometry module in list to show */
 				if (havegeoms == 0) (void)initinfstr(); else
@@ -742,8 +724,7 @@ char *reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 
 	/* return the error message */
 	(void)initinfstr();
-	(void)addstringtoinfstr(db_errorsystem);
-	(void)addstringtoinfstr(": ");
-	(void)addstringtoinfstr(el->message);
+	(void)formatinfstr(_("%s error %ld of %ld: %s"), db_errorsystem,
+		el->index, db_numerrors, el->message);
 	return(returninfstr());
 }
