@@ -47,23 +47,20 @@
 typedef struct
 {
 	RTNODE  *rtn[MAXDEPTH];
-	INTSML   position[MAXDEPTH];
-	INTSML   depth;
+	INTBIG   position[MAXDEPTH];
+	INTBIG   depth;
 	INTBIG   lx, hx, ly, hy;
 } RSEARCH;
 
 static RSEARCH *db_rsearchfree = NORSEARCH;
 
-INTSML db_minrtnodesize = 4;
-INTSML db_maxrtnodesize = 8;
-
 /* prototypes for local routines */
 static RSEARCH *db_allocrsearch(void);
 static void     db_freersearch(RSEARCH*);
-static void     db_removertnode(RTNODE*, INTSML, NODEPROTO*);
+static void     db_removertnode(RTNODE*, INTBIG, NODEPROTO*);
 static void     db_reinsert(RTNODE*, NODEPROTO*);
-static INTSML   db_findgeom(RTNODE*, GEOM*, RTNODE**, INTSML*);
-static INTSML   db_findgeomanywhere(RTNODE*, GEOM*, RTNODE**, INTSML*);
+static BOOLEAN  db_findgeom(RTNODE*, GEOM*, RTNODE**, INTBIG*);
+static BOOLEAN  db_findgeomanywhere(RTNODE*, GEOM*, RTNODE**, INTBIG*);
 static void     db_figbounds(RTNODE*);
 
 /*
@@ -90,7 +87,7 @@ void db_freegeomemory(void)
 RTNODE *allocrtnode(CLUSTER *cluster)
 {
 	REGISTER RTNODE *rtn;
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 
 	rtn = (RTNODE *)emalloc((sizeof (RTNODE)), cluster);
 	if (rtn == 0) return(NORTNODE);
@@ -126,7 +123,7 @@ GEOM *allocgeom(CLUSTER *cluster)
 	if (geom == 0) return(NOGEOM);
 	geom->numvar = 0;
 	geom->firstvar = NOVARIABLE;
-	geom->entrytype = 0;
+	geom->entryisnode = FALSE;
 	geom->entryaddr.ni = NONODEINST;
 	geom->entryaddr.ai = NOARCINST;
 	geom->entryaddr.blind = 0;
@@ -180,20 +177,20 @@ void db_freersearch(RSEARCH *rs)
 
 /*
  * routine to build geometry module structure in facet "np".
- * returns nonzero upon error.
+ * returns true upon error.
  */
-INTSML geomstructure(NODEPROTO *np)
+BOOLEAN geomstructure(NODEPROTO *np)
 {
 	REGISTER RTNODE *top;
 
 	top = allocrtnode(np->cell->cluster);
-	if (top == NORTNODE) return(1);
+	if (top == NORTNODE) return(TRUE);
 	top->lowx = top->highx = top->lowy = top->highy = 0;
 	top->total = 0;
 	top->flag = 1;
 	top->parent = NORTNODE;
 	np->rtree = top;
-	return(0);
+	return(FALSE);
 }
 
 /*
@@ -220,7 +217,7 @@ void db_freertree(RTNODE *rtn)
 void linkgeom(GEOM *geom, NODEPROTO *parnt)
 {
 	REGISTER RTNODE *rtn, *subrtn;
-	REGISTER INTSML i, bestsubnode;
+	REGISTER INTBIG i, bestsubnode;
 #ifdef	USEFLOATS
 	REGISTER float area, newarea, bestexpand, expand;
 #else
@@ -299,10 +296,10 @@ void linkgeom(GEOM *geom, NODEPROTO *parnt)
  * routine to add "object" to R-tree node "rtn".  Routine may have to
  * split the node and recurse up the tree
  */
-INTSML db_addtortnode(UINTBIG object, RTNODE *rtn, NODEPROTO *facet)
+BOOLEAN db_addtortnode(UINTBIG object, RTNODE *rtn, NODEPROTO *facet)
 {
 	RTNODE temp;
-	REGISTER INTSML i, oldcount, oldn, newn, bestoldnode, bestnewnode;
+	REGISTER INTBIG i, oldcount, oldn, newn, bestoldnode, bestnewnode;
 #ifdef	USEFLOATS
 	REGISTER float bestoldexpand, bestnewexpand, newareaplus, oldareaplus, newarea, oldarea;
 #else
@@ -313,7 +310,7 @@ INTSML db_addtortnode(UINTBIG object, RTNODE *rtn, NODEPROTO *facet)
 	REGISTER RTNODE *newroot, *newrtn, *r;
 
 	/* see if there is room in the R-tree node */
-	if (rtn->total >= db_maxrtnodesize)
+	if (rtn->total >= MAXRTNODESIZE)
 	{
 		/*
 		 * no room: find the element farthest from new object
@@ -364,7 +361,7 @@ INTSML db_addtortnode(UINTBIG object, RTNODE *rtn, NODEPROTO *facet)
 
 		/* allocate a new R-tree node and put in first seed element */
 		newrtn = allocrtnode(facet->cell->cluster);
-		if (newrtn == NORTNODE) return(-1);
+		if (newrtn == NORTNODE) return(TRUE);
 		newrtn->flag = rtn->flag;
 		newrtn->parent = rtn->parent;
 		newrtn->pointers[0] = temp.pointers[newn];
@@ -504,7 +501,7 @@ INTSML db_addtortnode(UINTBIG object, RTNODE *rtn, NODEPROTO *facet)
 
 		/* sensibility check */
 		if (oldcount != rtn->total + newrtn->total)
-			ttyputerr(_("R-trees: %d nodes split to %d and %d!"),
+			ttyputerr(_("R-trees: %ld nodes split to %d and %d!"),
 				oldcount, rtn->total, newrtn->total);
 
 		/* now recursively insert this new element up the tree */
@@ -512,7 +509,7 @@ INTSML db_addtortnode(UINTBIG object, RTNODE *rtn, NODEPROTO *facet)
 		{
 			/* at top of tree: create a new level */
 			newroot = allocrtnode(facet->cell->cluster);
-			if (newroot == 0) return(-1);
+			if (newroot == 0) return(TRUE);
 			newroot->total = 2;
 			newroot->pointers[0] = (UINTBIG)rtn;
 			newroot->pointers[1] = (UINTBIG)newrtn;
@@ -530,7 +527,7 @@ INTSML db_addtortnode(UINTBIG object, RTNODE *rtn, NODEPROTO *facet)
 			for(r = rtn->parent; r != NORTNODE; r = r->parent) db_figbounds(r);
 
 			/* now add the new node up the tree */
-			if (db_addtortnode((UINTBIG)newrtn, rtn->parent, facet) != 0) return(-1);
+			if (db_addtortnode((UINTBIG)newrtn, rtn->parent, facet)) return(TRUE);
 		}
 	}
 
@@ -546,7 +543,7 @@ INTSML db_addtortnode(UINTBIG object, RTNODE *rtn, NODEPROTO *facet)
 		rtn->highx = hxv;
 		rtn->lowy = lyv;
 		rtn->highy = hyv;
-		return(0);
+		return(FALSE);
 	}
 
 	/* recursively update node sizes */
@@ -559,7 +556,7 @@ INTSML db_addtortnode(UINTBIG object, RTNODE *rtn, NODEPROTO *facet)
 		if (rtn->parent == NORTNODE) break;
 		rtn = rtn->parent;
 	}
-	return(0);
+	return(FALSE);
 }
 
 /*********************** DELETING FROM AN R-TREE ***********************/
@@ -570,12 +567,12 @@ INTSML db_addtortnode(UINTBIG object, RTNODE *rtn, NODEPROTO *facet)
 void undogeom(GEOM *geom, NODEPROTO *parnt)
 {
 	RTNODE *whichrtn;
-	INTSML whichind;
+	INTBIG whichind;
 
 	/* find this node in the tree */
-	if (db_findgeom(parnt->rtree, geom, &whichrtn, &whichind) == 0)
+	if (!db_findgeom(parnt->rtree, geom, &whichrtn, &whichind))
 	{
-		if (db_findgeomanywhere(parnt->rtree, geom, &whichrtn, &whichind) == 0)
+		if (!db_findgeomanywhere(parnt->rtree, geom, &whichrtn, &whichind))
 		{
 			ttyputerr(_("Internal warning: cannot find %s in R-Tree of %s"),
 				geomname(geom), describenodeproto(parnt));
@@ -592,20 +589,20 @@ void undogeom(GEOM *geom, NODEPROTO *parnt)
 /*
  * routine to remove entry "ind" from R-tree node "rtn" in facet "facet"
  */
-void db_removertnode(RTNODE *rtn, INTSML ind, NODEPROTO *facet)
+void db_removertnode(RTNODE *rtn, INTBIG ind, NODEPROTO *facet)
 {
 	REGISTER RTNODE *prtn;
 	RTNODE temp;
-	REGISTER INTSML i, j, t;
+	REGISTER INTBIG i, j, t;
 
 	/* delete entry from this R-tree node */
 	j = 0;
 	for(i=0; i<rtn->total; i++)
 		if (i != ind) rtn->pointers[j++] = rtn->pointers[i];
-	rtn->total = j;
+	rtn->total = (INTSML)j;
 
 	/* see if node is now too small */
-	if (rtn->total < db_minrtnodesize)
+	if (rtn->total < MINRTNODESIZE)
 	{
 		/* if recursed to top, shorten R-tree */
 		prtn = rtn->parent;
@@ -659,7 +656,7 @@ void db_removertnode(RTNODE *rtn, INTSML ind, NODEPROTO *facet)
  */
 void db_reinsert(RTNODE *rtn, NODEPROTO *facet)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 
 	if (rtn->flag != 0)
 	{
@@ -676,11 +673,11 @@ void db_reinsert(RTNODE *rtn, NODEPROTO *facet)
  * routine to find the location of geometry module "geom" in the R-tree
  * at "rtn".  The subnode that contains this module is placed in "subrtn"
  * and the index in that subnode is placed in "subind".  The routine returns
- * zero if it is unable to find the geometry module.
+ * false if it is unable to find the geometry module.
  */
-INTSML db_findgeom(RTNODE *rtn, GEOM *geom, RTNODE **subrtn, INTSML *subind)
+BOOLEAN db_findgeom(RTNODE *rtn, GEOM *geom, RTNODE **subrtn, INTBIG *subind)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 	INTBIG lxv, hxv, lyv, hyv;
 
 	/* if R-tree node contains primitives, search for direct hit */
@@ -692,10 +689,10 @@ INTSML db_findgeom(RTNODE *rtn, GEOM *geom, RTNODE **subrtn, INTSML *subind)
 			{
 				*subrtn = rtn;
 				*subind = i;
-				return(1);
+				return(TRUE);
 			}
 		}
-		return(0);
+		return(FALSE);
 	}
 
 	/* recurse on all sub-nodes that would contain this geometry module */
@@ -705,20 +702,20 @@ INTSML db_findgeom(RTNODE *rtn, GEOM *geom, RTNODE **subrtn, INTSML *subind)
 		db_rtnbbox(rtn, i, &lxv, &hxv, &lyv, &hyv);
 		if (geom->lowx < lxv || geom->highx > hxv || geom->lowy < lyv || geom->highy > hyv)
 			continue;
-		if (db_findgeom((RTNODE *)rtn->pointers[i], geom, subrtn, subind) != 0) return(1);
+		if (db_findgeom((RTNODE *)rtn->pointers[i], geom, subrtn, subind)) return(TRUE);
 	}
-	return(0);
+	return(FALSE);
 }
 
 /*
  * routine to find the location of geometry module "geom" anywhere in the R-tree
  * at "rtn".  The subnode that contains this module is placed in "subrtn"
  * and the index in that subnode is placed in "subind".  The routine returns
- * zero if it is unable to find the geometry module.
+ * false if it is unable to find the geometry module.
  */
-INTSML db_findgeomanywhere(RTNODE *rtn, GEOM *geom, RTNODE **subrtn, INTSML *subind)
+BOOLEAN db_findgeomanywhere(RTNODE *rtn, GEOM *geom, RTNODE **subrtn, INTBIG *subind)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 
 	/* if R-tree node contains primitives, search for direct hit */
 	if (rtn->flag != 0)
@@ -732,14 +729,14 @@ INTSML db_findgeomanywhere(RTNODE *rtn, GEOM *geom, RTNODE **subrtn, INTSML *sub
 				return(1);
 			}
 		}
-		return(0);
+		return(FALSE);
 	}
 
 	/* recurse on all sub-nodes */
 	for(i=0; i<rtn->total; i++)
-		if (db_findgeomanywhere((RTNODE *)rtn->pointers[i], geom, subrtn, subind) != 0)
-			return(1);
-	return(0);
+		if (db_findgeomanywhere((RTNODE *)rtn->pointers[i], geom, subrtn, subind))
+			return(TRUE);
+	return(FALSE);
 }
 
 /************************ CHANGING AN R-TREE ************************/
@@ -759,9 +756,9 @@ void updategeom(GEOM *geom, NODEPROTO *parnt)
 
 /*********************** INFORMATION ***********************/
 
-void db_printrtree(RTNODE *expectedparent, RTNODE *rtn, INTSML indent)
+void db_printrtree(RTNODE *expectedparent, RTNODE *rtn, INTBIG indent)
 {
-	REGISTER INTSML i, j;
+	REGISTER INTBIG i, j;
 	INTBIG lx, hx, ly, hy, lowestxv, highestxv, lowestyv, highestyv;
 	char line[100];
 
@@ -773,8 +770,8 @@ void db_printrtree(RTNODE *expectedparent, RTNODE *rtn, INTSML indent)
 
 	/* sensibility check of this R-tree node */
 	if (rtn->parent != expectedparent) (void)addstringtoinfstr(M_(" WRONG-PARENT"));
-	if (rtn->total > db_maxrtnodesize) (void)addstringtoinfstr(M_(" TOO-MANY"));
-	if (rtn->total < db_minrtnodesize && rtn->parent != NORTNODE)
+	if (rtn->total > MAXRTNODESIZE) (void)addstringtoinfstr(M_(" TOO-MANY"));
+	if (rtn->total < MINRTNODESIZE && rtn->parent != NORTNODE)
 		(void)addstringtoinfstr(M_(" TOO-FEW"));
 	if (rtn->total != 0)
 	{
@@ -808,7 +805,7 @@ void db_printrtree(RTNODE *expectedparent, RTNODE *rtn, INTSML indent)
 			(void)sprintf(line, " X(%s-%s) Y(%s-%s)", latoa(lx), latoa(hx), latoa(ly), latoa(hy));
 			(void)addstringtoinfstr(line);
 			ttyputmsg("%s", returninfstr());
-		} else db_printrtree(rtn, (RTNODE *)rtn->pointers[j], (INTSML)(indent+3));
+		} else db_printrtree(rtn, (RTNODE *)rtn->pointers[j], indent+3);
 	}
 }
 
@@ -817,7 +814,7 @@ void db_printrtree(RTNODE *expectedparent, RTNODE *rtn, INTSML indent)
  */
 void db_figbounds(RTNODE *rtn)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 	INTBIG lx, hx, ly, hy;
 
 	if (rtn->total == 0)
@@ -840,7 +837,7 @@ void db_figbounds(RTNODE *rtn)
  * routine to get the bounding box of child "child" of R-tree node "rtn" and
  * place it in the reference parameters "lx", "hx", "ly", and "hy".
  */
-void db_rtnbbox(RTNODE *rtn, INTSML child, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy)
+void db_rtnbbox(RTNODE *rtn, INTBIG child, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy)
 {
 	REGISTER RTNODE *subrtn;
 	REGISTER GEOM *geom;
@@ -882,7 +879,111 @@ void boundobj(GEOM *geom, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy)
 	/* create the polygon if it doesn't exist */
 	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, db_cluster);
 
-	if (geom->entrytype == OBJARCINST)
+	if (geom->entryisnode)
+	{
+		ni = geom->entryaddr.ni;
+
+		/* handle special cases primitives */
+		if (ni->proto->primindex != 0)
+		{
+			/* special case for arcs of circles: compute precise bounding box */
+			if (ni->proto == art_circleprim || ni->proto == art_thickcircleprim)
+			{
+				/* see if there this circle is only a partial one */
+				getarcdegrees(ni, &startoffset, &endangle);
+				if (startoffset != 0.0 || endangle != 0.0)
+				{
+					/* get center of ellipse */
+					ctx = (ni->lowx + ni->highx) / 2;
+					cty = (ni->lowy + ni->highy) / 2;
+
+					/* compute the length of the semi-major and semi-minor axes */
+					a = (ni->highx - ni->lowx) / 2;
+					b = (ni->highy - ni->lowy) / 2;
+
+					pts = (INTBIG)(endangle * ELLIPSEPOINTS / (EPI * 2.0));
+					makerot(ni, trans);
+					for(j=0; j<pts; j++)
+					{
+						p = startoffset + j * endangle / (pts-1);
+						xv = rounddouble(ctx + a * cos(p));
+						yv = rounddouble(cty + b * sin(p));
+						xform(xv, yv, &xp, &yp, trans);
+						if (j == 0)
+						{
+							*lx = *hx = xp;
+							*ly = *hy = yp;
+						} else
+						{
+							if (xp < *lx) *lx = xp;
+							if (xp > *hx) *hx = xp;
+							if (yp < *ly) *ly = yp;
+							if (yp > *hy) *hy = yp;
+						}
+					}
+					return;
+				}
+			}
+
+			/* special case for pins that become steiner points */
+#if 1
+			if ((ni->proto->userbits&WIPEON1OR2) != 0 &&
+				ni->firstportexpinst == NOPORTEXPINST)
+#else
+			if ((ni->proto->userbits&WIPEON1OR2) != 0)
+#endif
+			{
+				if (tech_pinusecount(ni, NOWINDOWPART))
+				{
+					*lx = *hx = (ni->lowx + ni->highx) / 2;
+					*ly = *hy = (ni->lowy + ni->highy) / 2;
+					return;
+				}
+			}
+
+			/* special case for polygonally-defined nodes: compute precise geometry */
+			if ((ni->proto->userbits&HOLDSTRACE) != 0)
+			{
+				var = getvalkey((INTBIG)ni, VNODEINST, VINTEGER|VISARRAY, el_trace_key);
+				if (var != NOVARIABLE)
+				{
+					makerot(ni, trans);
+					num = nodepolys(ni, 0, NOWINDOWPART);
+					for(j=0; j<num; j++)
+					{
+						shapenodepoly(ni, j, poly);
+						xformpoly(poly, trans);
+						getbbox(poly, &plx, &phx, &ply, &phy);
+						if (j == 0)
+						{
+							*lx = plx;   *hx = phx;
+							*ly = ply;   *hy = phy;
+						} else
+						{
+							if (plx < *lx) *lx = plx;
+							if (phx > *hx) *hx = phx;
+							if (ply < *ly) *ly = ply;
+							if (phy > *hy) *hy = phy;
+						}
+					}
+					return;
+				}
+			}
+		}
+
+		/* standard bounds computation */
+		if (ni->rotation == 0 && ni->transpose == 0)
+		{
+			*lx = ni->lowx;   *hx = ni->highx;
+			*ly = ni->lowy;   *hy = ni->highy;
+		} else
+		{
+			makerot(ni, trans);
+			*lx = ni->lowx;   *hx = ni->highx;
+			*ly = ni->lowy;   *hy = ni->highy;
+			xformbox(lx, hx, ly, hy, trans);
+		}
+	} else
 	{
 		ai = geom->entryaddr.ai;
 
@@ -890,7 +991,7 @@ void boundobj(GEOM *geom, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy)
 		if ((ai->proto->userbits&CANCURVE) != 0)
 		{
 			/* prototype can curve...does this one have curvature? */
-			var = getvalkey((INTBIG)ai, VARCINST, VINTEGER, el_arc_radius);
+			var = getvalkey((INTBIG)ai, VARCINST, VINTEGER, el_arc_radius_key);
 			if (var != NOVARIABLE)
 			{
 				/* this one has curvature...verify its sensibility */
@@ -898,9 +999,9 @@ void boundobj(GEOM *geom, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy)
 				if (abs(radius)*2 >= ai->length)
 				{
 					/* arc is sensible...determine possible circle centers */
-					if (findcenters(abs(radius), ai->end[0].xpos,
+					if (!findcenters(abs(radius), ai->end[0].xpos,
 						ai->end[0].ypos, ai->end[1].xpos, ai->end[1].ypos,
-							ai->length, &x1, &y1, &x2, &y2) == 0)
+							ai->length, &x1, &y1, &x2, &y2))
 					{
 						/* determine center */
 						if (radius < 0)
@@ -960,107 +1061,6 @@ void boundobj(GEOM *geom, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy)
 
 		/* get the bounding box of the polygon as the arc extent */
 		getbbox(poly, lx, hx, ly, hy);
-		return;
-	}
-	if (geom->entrytype == OBJNODEINST)
-	{
-		ni = geom->entryaddr.ni;
-
-		/* handle special cases primitives */
-		if (ni->proto->primindex != 0)
-		{
-			/* special case for arcs of circles: compute precise bounding box */
-			if (ni->proto == art_circleprim)
-			{
-				/* see if there this circle is only a partial one */
-				getarcdegrees(ni, &startoffset, &endangle);
-				if (startoffset != 0.0 || endangle != 0.0)
-				{
-					/* get center of ellipse */
-					ctx = (ni->lowx + ni->highx) / 2;
-					cty = (ni->lowy + ni->highy) / 2;
-
-					/* compute the length of the semi-major and semi-minor axes */
-					a = (ni->highx - ni->lowx) / 2;
-					b = (ni->highy - ni->lowy) / 2;
-
-					pts = (INTSML)(endangle * ELLIPSEPOINTS / (EPI * 2.0));
-					makerot(ni, trans);
-					for(j=0; j<pts; j++)
-					{
-						p = startoffset + j * endangle / (pts-1);
-						xv = rounddouble(ctx + a * cos(p));
-						yv = rounddouble(cty + b * sin(p));
-						xform(xv, yv, &xp, &yp, trans);
-						if (j == 0)
-						{
-							*lx = *hx = xp;
-							*ly = *hy = yp;
-						} else
-						{
-							if (xp < *lx) *lx = xp;
-							if (xp > *hx) *hx = xp;
-							if (yp < *ly) *ly = yp;
-							if (yp > *hy) *hy = yp;
-						}
-					}
-					return;
-				}
-			}
-
-			/* special case for pins that become steiner points */
-			if ((ni->proto->userbits&WIPEON1OR2) != 0)
-			{
-				if (tech_pinusecount(ni, NOARCPROTO) != 0)
-				{
-					*lx = *hx = (ni->lowx + ni->highx) / 2;
-					*ly = *hy = (ni->lowy + ni->highy) / 2;
-					return;
-				}
-			}
-
-			/* special case for polygonally-defined nodes: compute precise geometry */
-			if ((ni->proto->userbits&HOLDSTRACE) != 0)
-			{
-				var = getvalkey((INTBIG)ni, VNODEINST, VINTEGER|VISARRAY, el_trace);
-				if (var != NOVARIABLE)
-				{
-					makerot(ni, trans);
-					num = nodepolys(ni, 0, NOWINDOWPART);
-					for(j=0; j<num; j++)
-					{
-						shapenodepoly(ni, j, poly);
-						xformpoly(poly, trans);
-						getbbox(poly, &plx, &phx, &ply, &phy);
-						if (j == 0)
-						{
-							*lx = plx;   *hx = phx;
-							*ly = ply;   *hy = phy;
-						} else
-						{
-							if (plx < *lx) *lx = plx;
-							if (phx > *hx) *hx = phx;
-							if (ply < *ly) *ly = ply;
-							if (phy > *hy) *hy = phy;
-						}
-					}
-					return;
-				}
-			}
-		}
-
-		/* standard bounds computation */
-		if (ni->rotation == 0 && ni->transpose == 0)
-		{
-			*lx = ni->lowx;   *hx = ni->highx;
-			*ly = ni->lowy;   *hy = ni->highy;
-		} else
-		{
-			makerot(ni, trans);
-			*lx = ni->lowx;   *hx = ni->highx;
-			*ly = ni->lowy;   *hy = ni->highy;
-			xformbox(lx, hx, ly, hy, trans);
-		}
 	}
 }
 
@@ -1074,14 +1074,15 @@ void db_boundfacet(NODEPROTO *facet, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
 	REGISTER VARIABLE *var;
-	REGISTER INTSML first, i;
+	REGISTER BOOLEAN first;
+	REGISTER INTBIG i;
 
 	/* cannot compute bounds if facet has nothing in it */
 	*lx = *hx = *ly = *hy = 0;
 	if (facet->firstnodeinst == NONODEINST) return;
 
 	/* include all nodes in the facet */
-	first = 1;
+	first = TRUE;
 	for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		/* special case: do not include "facet center" primitive from Generic */
@@ -1099,13 +1100,13 @@ void db_boundfacet(NODEPROTO *facet, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG
 			if (i < ni->numvar) continue;
 		}
 
-		if (first != 0)
+		if (first)
 		{
 			*lx = ni->geom->lowx;
 			*hx = ni->geom->highx;
 			*ly = ni->geom->lowy;
 			*hy = ni->geom->highy;
-			first = 0;
+			first = FALSE;
 			continue;
 		}
 		*lx = mmini(*lx, ni->geom->lowx);
@@ -1117,13 +1118,13 @@ void db_boundfacet(NODEPROTO *facet, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG
 	/* include all arcs in the facet */
 	for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 	{
-		if (first != 0)
+		if (first)
 		{
 			*lx = ai->geom->lowx;
 			*hx = ai->geom->highx;
 			*ly = ai->geom->lowy;
 			*hy = ai->geom->highy;
-			first = 0;
+			first = FALSE;
 			continue;
 		}
 		*lx = mmini(*lx, ai->geom->lowx);
@@ -1166,7 +1167,7 @@ GEOM *nextobject(INTBIG rsin)
 {
 	RSEARCH *rs;
 	REGISTER RTNODE *rtn;
-	REGISTER INTSML i, depth;
+	REGISTER INTBIG i, depth;
 	INTBIG lxv, hxv, lyv, hyv;
 
 	rs = (RSEARCH *)rsin;
