@@ -33,8 +33,9 @@
 
 #include "global.h"
 #include "dblang.h"
+
 static ELKObject lsp_displayablesym;
-static INTSML    lsp_strportinited = 0;
+static BOOLEAN   lsp_strportinited = FALSE;
 static ELKObject lsp_strport;
 
 #define Ensure_Type(x,t) if (TYPE(x) != t) { Wrong_Type(x, t); return(Null); }
@@ -79,15 +80,21 @@ static ELKObject P_EWindowP(ELKObject);
 static ELKObject P_EGraphicsP(ELKObject);
 static ELKObject P_EConstraintP(ELKObject);
 static ELKObject P_EWindowFrameP(ELKObject);
-static ELKObject Make_EElectric(INTBIG, INTSML);
+static ELKObject Make_EElectric(INTBIG, INTBIG);
 static void init_lib_electric(void);
-static INTSML lsp_getnumericobject(ELKObject, INTBIG*);
+static BOOLEAN lsp_getnumericobject(ELKObject, INTBIG*);
 static char *lsp_getstringobject(ELKObject);
 static void lsp_getaddrandtype(ELKObject, INTBIG*, INTBIG*);
 static ELKObject lsp_makevarobject(INTBIG, INTBIG);
 static ELKObject lsp_curlib(void);
 static ELKObject lsp_curtech(void);
 static ELKObject lsp_getval(ELKObject, ELKObject);
+static ELKObject lsp_getparentval(ELKObject, ELKObject, ELKObject);
+static ELKObject lsp_dogetparentval(char*, ELKObject, INTBIG);
+static ELKObject lsp_P(ELKObject oname);
+static ELKObject lsp_PD(ELKObject oname, ELKObject odefault);
+static ELKObject lsp_PAR(ELKObject oname);
+static ELKObject lsp_PARD(ELKObject oname, ELKObject odefault);
 static ELKObject lsp_setval(ELKObject, ELKObject, ELKObject, ELKObject);
 static ELKObject lsp_setind(ELKObject, ELKObject, ELKObject, ELKObject);
 static ELKObject lsp_delval(ELKObject, ELKObject);
@@ -145,7 +152,7 @@ static long T_ENodeInst, T_ENodeProto, T_EPortArcInst, T_EPortExpInst, T_EPortPr
 	T_EWindowFrame;
 
 /* the LISP structures */
-struct S_Electric     { INTBIG        handle; };
+struct S_Electric     { INTBIG       handle; };
 struct S_ENodeInst    { NODEINST    *handle; };
 struct S_ENodeProto   { NODEPROTO   *handle; };
 struct S_EPortArcInst { PORTARCINST *handle; };
@@ -255,7 +262,7 @@ ELKObject P_EGraphicsP(ELKObject x)    { return(TYPE(x) == T_EGraphics    ? True
 ELKObject P_EConstraintP(ELKObject x)  { return(TYPE(x) == T_EConstraint  ? Trueob : Falseob); }
 ELKObject P_EWindowFrameP(ELKObject x) { return(TYPE(x) == T_EWindowFrame ? Trueob : Falseob); }
 
-ELKObject Make_EElectric(INTBIG obj, INTSML type)
+ELKObject Make_EElectric(INTBIG obj, INTBIG type)
 {
 	char *p;
 	ELKObject w;
@@ -272,8 +279,8 @@ void lsp_init(void)
 {
 	char *av[1], progname[30];
 
-	if (lsp_strportinited != 0) return;
-	lsp_strportinited = 1;
+	if (lsp_strportinited) return;
+	lsp_strportinited = TRUE;
 
 	/* initialize Lisp (must do it this way to give it stack base info) */
 	strcpy(progname, "electric");
@@ -337,17 +344,16 @@ ELKObject lsp_makeobject(char *str)
 
 /*
  * routine to convert Lisp ELKObject "obj" into an Electric address of type "type" and return
- * it in "retval".  Returns nonzero on error.
+ * it in "retval".  Returns true on error.
  */
-INTSML lsp_describeobject(ELKObject obj, INTBIG type, INTBIG *retval)
+BOOLEAN lsp_describeobject(ELKObject obj, INTBIG type, INTBIG *retval)
 {
 	static char retstr[100];
 	static INTBIG retarray[1];
-	INTSML len;
+	INTBIG len;
 	INTBIG t;
 	ELKObject strobj;
 	char *str, *p;
-	void Print_Bignum(ELKObject port, ELKObject x);
 	void Pr_List(ELKObject port, ELKObject list, int raw, int depth, int length);
 	void Pr_Vector(ELKObject port, ELKObject vec, int raw, int depth, int length);
 	int Print_Char(ELKObject port, int c);
@@ -381,7 +387,7 @@ INTSML lsp_describeobject(ELKObject obj, INTBIG type, INTBIG *retval)
 					*retval = (INTBIG)FLONUM(obj)->val;
 					break;
 				default:
-					return(1);
+					return(TRUE);
 			}
 			if ((type&VTYPE) == VFRACT) *retval *= WHOLE;
 			break;
@@ -410,12 +416,12 @@ INTSML lsp_describeobject(ELKObject obj, INTBIG type, INTBIG *retval)
 					*retval = castint((float)FLONUM(obj)->val);
 					break;
 				default:
-					return(1);
+					return(TRUE);
 			}
 			break;
 
 		case VCHAR:
-			if (t != T_Character) return(1);
+			if (t != T_Character) return(TRUE);
 			*retval = CHAR(obj);
 			break;
 
@@ -617,7 +623,7 @@ INTSML lsp_describeobject(ELKObject obj, INTBIG type, INTBIG *retval)
 			break;
 
 		default:
-			return(1);
+			return(TRUE);
 	}
 
 	if ((type&VISARRAY) != 0)
@@ -625,26 +631,24 @@ INTSML lsp_describeobject(ELKObject obj, INTBIG type, INTBIG *retval)
 		retarray[0] = *retval;
 		*retval = (INTBIG)retarray;
 	}
-	return(0);
+	return(FALSE);
 }
 
 /*
- * routine to convert a numeric Lisp ELKObject into an integer.  Returns nonzero on error
+ * routine to convert a numeric Lisp ELKObject into an integer.  Returns true on error
  */
-INTSML lsp_getnumericobject(ELKObject obj, INTBIG *val)
+BOOLEAN lsp_getnumericobject(ELKObject obj, INTBIG *val)
 {
-	int Bignum_To_Integer(ELKObject x);
-
 	switch (TYPE(obj))
 	{
-		case T_Fixnum: *val = FIXNUM(obj);              return(0);
-		case T_Bignum: *val = Bignum_To_Integer(obj);   return(0);
-		case T_Flonum: *val = (INTBIG)FLONUM(obj)->val; return(0);
+		case T_Fixnum: *val = FIXNUM(obj);              return(FALSE);
+		case T_Bignum: *val = Bignum_To_Integer(obj);   return(FALSE);
+		case T_Flonum: *val = (INTBIG)FLONUM(obj)->val; return(FALSE);
 		case T_Symbol:
-			if (EQ(obj, lsp_displayablesym)) { *val = VDISPLAY;   return(0); }
+			if (EQ(obj, lsp_displayablesym)) { *val = VDISPLAY;   return(FALSE); }
 			break;
 	}
-	return(1);
+	return(TRUE);
 }
 
 /*
@@ -677,11 +681,10 @@ char *lsp_getstringobject(ELKObject obj)
  */
 void lsp_getaddrandtype(ELKObject oaddr, INTBIG *addr, INTBIG *type)
 {
-	INTSML otype;
+	INTBIG otype;
 	static char retval[256];
 	char *str;
 	INTBIG len;
-	int Bignum_To_Integer(ELKObject x);
 
 	*type = VUNKNOWN;
 	otype = TYPE(oaddr);
@@ -752,61 +755,61 @@ ELKObject lsp_makevarobject(INTBIG type, INTBIG addr)
 		case VFLOAT:
 		case VDOUBLE:      return(Make_Reduced_Flonum((double)castfloat(addr)));
 		case VNODEINST:
-			ret = Make_EElectric(addr, (INTSML)T_ENodeInst);
+			ret = Make_EElectric(addr, T_ENodeInst);
 			if (ENODEINST(ret)->handle == NONODEINST) return(Null); else return(ret);
 		case VNODEPROTO:
-			ret = Make_EElectric(addr, (INTSML)T_ENodeProto);
+			ret = Make_EElectric(addr, T_ENodeProto);
 			if (ENODEPROTO(ret)->handle == NONODEPROTO) return(Null); else return(ret);
 		case VPORTARCINST:
-			ret = Make_EElectric(addr, (INTSML)T_EPortArcInst);
+			ret = Make_EElectric(addr, T_EPortArcInst);
 			if (EPORTARCINST(ret)->handle == NOPORTARCINST) return(Null); else return(ret);
 		case VPORTEXPINST:
-			ret = Make_EElectric(addr, (INTSML)T_EPortExpInst);
+			ret = Make_EElectric(addr, T_EPortExpInst);
 			if (EPORTEXPINST(ret)->handle == NOPORTEXPINST) return(Null); else return(ret);
 		case VPORTPROTO:
-			ret = Make_EElectric(addr, (INTSML)T_EPortProto);
+			ret = Make_EElectric(addr, T_EPortProto);
 			if (EPORTPROTO(ret)->handle == NOPORTPROTO) return(Null); else return(ret);
 		case VARCINST:
-			ret = Make_EElectric(addr, (INTSML)T_EArcInst);
+			ret = Make_EElectric(addr, T_EArcInst);
 			if (EARCINST(ret)->handle == NOARCINST) return(Null); else return(ret);
 		case VARCPROTO:
-			ret = Make_EElectric(addr, (INTSML)T_EArcProto);
+			ret = Make_EElectric(addr, T_EArcProto);
 			if (EARCPROTO(ret)->handle == NOARCPROTO) return(Null); else return(ret);
 		case VGEOM:
-			ret = Make_EElectric(addr, (INTSML)T_EGeom);
+			ret = Make_EElectric(addr, T_EGeom);
 			if (EGEOM(ret)->handle == NOGEOM) return(Null); else return(ret);
 		case VLIBRARY:
-			ret = Make_EElectric(addr, (INTSML)T_ELibrary);
+			ret = Make_EElectric(addr, T_ELibrary);
 			if (ELIBRARY(ret)->handle == NOLIBRARY) return(Null); else return(ret);
 		case VTECHNOLOGY:
-			ret = Make_EElectric(addr, (INTSML)T_ETechnology);
+			ret = Make_EElectric(addr, T_ETechnology);
 			if (ETECHNOLOGY(ret)->handle == NOTECHNOLOGY) return(Null); else return(ret);
 		case VTOOL:
-			ret = Make_EElectric(addr, (INTSML)T_ETool);
+			ret = Make_EElectric(addr, T_ETool);
 			if (ETOOL(ret)->handle == NOTOOL) return(Null); else return(ret);
 		case VRTNODE:
-			ret = Make_EElectric(addr, (INTSML)T_ERTNode);
+			ret = Make_EElectric(addr, T_ERTNode);
 			if (ERTNODE(ret)->handle == NORTNODE) return(Null); else return(ret);
 		case VNETWORK:
-			ret = Make_EElectric(addr, (INTSML)T_ENetwork);
+			ret = Make_EElectric(addr, T_ENetwork);
 			if (ENETWORK(ret)->handle == NONETWORK) return(Null); else return(ret);
 		case VCELL:
-			ret = Make_EElectric(addr, (INTSML)T_ECell);
+			ret = Make_EElectric(addr, T_ECell);
 			if (ECELL(ret)->handle == NOCELL) return(Null); else return(ret);
 		case VVIEW:
-			ret = Make_EElectric(addr, (INTSML)T_EView);
+			ret = Make_EElectric(addr, T_EView);
 			if (EVIEW(ret)->handle == NOVIEW) return(Null); else return(ret);
 		case VWINDOWPART:
-			ret = Make_EElectric(addr, (INTSML)T_EWindow);
+			ret = Make_EElectric(addr, T_EWindow);
 			if (EWINDOW(ret)->handle == NOWINDOWPART) return(Null); else return(ret);
 		case VGRAPHICS:
-			ret = Make_EElectric(addr, (INTSML)T_EGraphics);
+			ret = Make_EElectric(addr, T_EGraphics);
 			if (EGRAPHICS(ret)->handle == NOGRAPHICS) return(Null); else return(ret);
 		case VCONSTRAINT:
-			ret = Make_EElectric(addr, (INTSML)T_EConstraint);
+			ret = Make_EElectric(addr, T_EConstraint);
 			if (ECONSTRAINT(ret)->handle == NOCONSTRAINT) return(Null); else return(ret);
 		case VWINDOWFRAME:
-			ret = Make_EElectric(addr, (INTSML)T_EWindowFrame);
+			ret = Make_EElectric(addr, T_EWindowFrame);
 			if (EWINDOWFRAME(ret)->handle == NOWINDOWFRAME) return(Null); else return(ret);
 	}
 	return(Null);
@@ -816,12 +819,12 @@ ELKObject lsp_makevarobject(INTBIG type, INTBIG addr)
 
 ELKObject lsp_curlib(void)
 {
-	return(Make_EElectric((INTBIG)el_curlib, (INTSML)T_ELibrary));
+	return(Make_EElectric((INTBIG)el_curlib, T_ELibrary));
 }
 
 ELKObject lsp_curtech(void)
 {
-	return(Make_EElectric((INTBIG)el_curtech, (INTSML)T_ETechnology));
+	return(Make_EElectric((INTBIG)el_curtech, T_ETechnology));
 }
 
 ELKObject lsp_getval(ELKObject oaddr, ELKObject oattr)
@@ -852,6 +855,93 @@ ELKObject lsp_getval(ELKObject oaddr, ELKObject oattr)
 	return(v);
 }
 
+ELKObject lsp_getparentval(ELKObject oname, ELKObject odef, ELKObject oheight)
+{
+	INTBIG height;
+	char *name;
+
+	/* get inputs from LISP */
+	name = lsp_getstringobject(oname);
+	if (name == 0) return(Null);
+	if (lsp_getnumericobject(oheight, &height)) return(Null);
+
+	/* call common evaluation code */
+	return(lsp_dogetparentval(name, odef, height));
+}
+
+ELKObject lsp_dogetparentval(char *name, ELKObject odef, INTBIG height)
+{
+	INTBIG len, i;
+	ELKObject v;
+	VARIABLE *var;
+	GC_Node;
+
+	/* get the variable */
+	var = getparentval(name, height);
+	if (var == NOVARIABLE) return(odef);
+	if ((var->type&VISARRAY) == 0)
+		return(lsp_makevarobject(var->type, var->addr));
+	len = getlength(var);
+	v = Make_Vector(len, Null);
+	GC_Link(v);
+	for(i=0; i<len; i++)
+		VECTOR(v)->data[i] = lsp_makevarobject(var->type, ((INTBIG *)var->addr)[i]);
+	GC_Unlink;
+	return(v);
+}
+
+ELKObject lsp_P(ELKObject oname)
+{
+	char *name, fullname[300];
+
+	/* get inputs from LISP */
+	name = lsp_getstringobject(oname);
+	if (name == 0) return(Null);
+	sprintf(fullname, "ATTR_%s", name);
+
+	/* call common evaluation code */
+	return(lsp_dogetparentval(fullname, Null, 1));
+}
+
+ELKObject lsp_PD(ELKObject oname, ELKObject odef)
+{
+	char *name, fullname[300];
+
+	/* get inputs from LISP */
+	name = lsp_getstringobject(oname);
+	if (name == 0) return(Null);
+	sprintf(fullname, "ATTR_%s", name);
+
+	/* call common evaluation code */
+	return(lsp_dogetparentval(fullname, odef, 1));
+}
+
+ELKObject lsp_PAR(ELKObject oname)
+{
+	char *name, fullname[300];
+
+	/* get inputs from LISP */
+	name = lsp_getstringobject(oname);
+	if (name == 0) return(Null);
+	sprintf(fullname, "ATTR_%s", name);
+
+	/* call common evaluation code */
+	return(lsp_dogetparentval(fullname, Null, 0));
+}
+
+ELKObject lsp_PARD(ELKObject oname, ELKObject odef)
+{
+	char *name, fullname[300];
+
+	/* get inputs from LISP */
+	name = lsp_getstringobject(oname);
+	if (name == 0) return(Null);
+	sprintf(fullname, "ATTR_%s", name);
+
+	/* call common evaluation code */
+	return(lsp_dogetparentval(fullname, odef, 0));
+}
+
 ELKObject lsp_setval(ELKObject oaddr, ELKObject oname, ELKObject onaddr, ELKObject ontypebits)
 {
 	INTBIG type, addr, len, i, ntype, naddr, ntypebits, lasttype, thisaddr, ifloat;
@@ -913,7 +1003,7 @@ ELKObject lsp_setval(ELKObject oaddr, ELKObject oname, ELKObject onaddr, ELKObje
 		lsp_getaddrandtype(onaddr, &naddr, &ntype);
 		if (ntype == VUNKNOWN) return(Null);
 	}
-	if (lsp_getnumericobject(ontypebits, &ntypebits) != 0) return(Null);
+	if (lsp_getnumericobject(ontypebits, &ntypebits)) return(Null);
 	ntype |= ntypebits;
 
 	/* set the variable */
@@ -937,7 +1027,7 @@ ELKObject lsp_setind(ELKObject oaddr, ELKObject oname, ELKObject oindex, ELKObje
 	if (type == VUNKNOWN) return(Null);
 	name = lsp_getstringobject(oname);
 	if (name == 0) return(Null);
-	if (lsp_getnumericobject(oindex, &aindex) != 0) return(Null);
+	if (lsp_getnumericobject(oindex, &aindex)) return(Null);
 	lsp_getaddrandtype(onaddr, &naddr, &ntype);
 	if (ntype == VUNKNOWN) return(Null);
 
@@ -966,10 +1056,10 @@ ELKObject lsp_initsearch(ELKObject olx, ELKObject ohx, ELKObject oly, ELKObject
 	REGISTER NODEPROTO *np;
 
 	/* get inputs from LISP */
-	if (lsp_getnumericobject(olx, &lx) != 0) return(Null);
-	if (lsp_getnumericobject(ohx, &hx) != 0) return(Null);
-	if (lsp_getnumericobject(oly, &ly) != 0) return(Null);
-	if (lsp_getnumericobject(ohy, &hy) != 0) return(Null);
+	if (lsp_getnumericobject(olx, &lx)) return(Null);
+	if (lsp_getnumericobject(ohx, &hx)) return(Null);
+	if (lsp_getnumericobject(oly, &ly)) return(Null);
+	if (lsp_getnumericobject(ohy, &hy)) return(Null);
 	Ensure_Type(onp, T_ENodeProto);   np = ENODEPROTO(onp)->handle;
 
 	sea = initsearch(lx, hx, ly, hy, np);
@@ -983,11 +1073,11 @@ ELKObject lsp_nextobject(ELKObject osea)
 	REGISTER GEOM *g;
 
 	/* get inputs from LISP */
-	if (lsp_getnumericobject(osea, &sea) != 0) return(Null);
+	if (lsp_getnumericobject(osea, &sea)) return(Null);
 
 	g = nextobject(sea);
 	if (g == NOGEOM) return(Null);
-	return(Make_EElectric((INTBIG)g, (INTSML)T_EGeom));
+	return(Make_EElectric((INTBIG)g, T_EGeom));
 }
 
 /****************************** TOOL ROUTINES ******************************/
@@ -1003,7 +1093,7 @@ ELKObject lsp_gettool(ELKObject oname)
 
 	tool = gettool(name);
 	if (tool == NOTOOL) return(Null);
-	return(Make_EElectric((INTBIG)tool, (INTSML)T_ETool));
+	return(Make_EElectric((INTBIG)tool, T_ETool));
 }
 
 ELKObject lsp_maxtool(void)
@@ -1016,22 +1106,24 @@ ELKObject lsp_indextool(ELKObject oindex)
 	INTBIG aindex;
 
 	/* get inputs from LISP */
-	if (lsp_getnumericobject(oindex, &aindex) != 0) return(Null);
+	if (lsp_getnumericobject(oindex, &aindex)) return(Null);
 
 	if (aindex < 0 || aindex >= el_maxtools) return(Null);
-	return(Make_EElectric((INTBIG)&el_tools[aindex], (INTSML)T_ETool));
+	return(Make_EElectric((INTBIG)&el_tools[aindex], T_ETool));
 }
 
 ELKObject lsp_toolturnon(ELKObject otool, ELKObject onocatchup)
 {
 	REGISTER TOOL *tool;
-	INTBIG nocatchup;
+	INTBIG nocatchupn;
+	BOOLEAN nocatchup;
 
 	/* get inputs from LISP */
 	Ensure_Type(otool, T_ETool);   tool = ETOOL(otool)->handle;
-	if (lsp_getnumericobject(onocatchup, &nocatchup) != 0) return(Null);
+	if (lsp_getnumericobject(onocatchup, &nocatchupn)) return(Null);
+	nocatchup = (nocatchupn != 0 ? TRUE : FALSE);
 
-	toolturnon(tool, (INTSML)nocatchup);
+	toolturnon(tool, nocatchup);
 	return(Null);
 }
 
@@ -1042,7 +1134,7 @@ ELKObject lsp_toolturnoff(ELKObject otool)
 	/* get inputs from LISP */
 	Ensure_Type(otool, T_ETool);   tool = ETOOL(otool)->handle;
 
-	toolturnoff(tool, 1);
+	toolturnoff(tool, TRUE);
 	return(Null);
 }
 
@@ -1059,7 +1151,7 @@ ELKObject lsp_getlibrary(ELKObject oname)
 
 	lib = getlibrary(name);
 	if (lib == NOLIBRARY) return(Null);
-	return(Make_EElectric((INTBIG)lib, (INTSML)T_ELibrary));
+	return(Make_EElectric((INTBIG)lib, T_ELibrary));
 }
 
 ELKObject lsp_newlibrary(ELKObject oname, ELKObject ofile)
@@ -1075,7 +1167,7 @@ ELKObject lsp_newlibrary(ELKObject oname, ELKObject ofile)
 
 	lib = newlibrary(name, file);
 	if (lib == NOLIBRARY) return(Null);
-	return(Make_EElectric((INTBIG)lib, (INTSML)T_ELibrary));
+	return(Make_EElectric((INTBIG)lib, T_ELibrary));
 }
 
 ELKObject lsp_killlibrary(ELKObject olib)
@@ -1124,7 +1216,7 @@ ELKObject lsp_getnodeproto(ELKObject oname)
 
 	np = getnodeproto(name);
 	if (np == NONODEPROTO) return(Null);
-	return(Make_EElectric((INTBIG)np, (INTSML)T_ENodeProto));
+	return(Make_EElectric((INTBIG)np, T_ENodeProto));
 }
 
 ELKObject lsp_newnodeproto(ELKObject oname, ELKObject olib)
@@ -1140,7 +1232,7 @@ ELKObject lsp_newnodeproto(ELKObject oname, ELKObject olib)
 
 	np = newnodeproto(name, lib);
 	if (np == NONODEPROTO) return(Null);
-	return(Make_EElectric((INTBIG)np, (INTSML)T_ENodeProto));
+	return(Make_EElectric((INTBIG)np, T_ENodeProto));
 }
 
 ELKObject lsp_killnodeproto(ELKObject onp)
@@ -1150,7 +1242,7 @@ ELKObject lsp_killnodeproto(ELKObject onp)
 	/* get inputs from LISP */
 	Ensure_Type(onp, T_ENodeProto);   np = ENODEPROTO(onp)->handle;
 
-	return(Make_Fixnum(killnodeproto(np)));
+	return(Make_Fixnum(killnodeproto(np)?1:0));
 }
 
 ELKObject lsp_copynodeproto(ELKObject onp, ELKObject otlib, ELKObject otname)
@@ -1167,7 +1259,7 @@ ELKObject lsp_copynodeproto(ELKObject onp, ELKObject otlib, ELKObject otname)
 
 	nnp = copynodeproto(np, tlib, tname);
 	if (nnp == NONODEPROTO) return(Null);
-	return(Make_EElectric((INTBIG)nnp, (INTSML)T_ENodeProto));
+	return(Make_EElectric((INTBIG)nnp, T_ENodeProto));
 }
 
 ELKObject lsp_iconview(ELKObject onp)
@@ -1179,7 +1271,7 @@ ELKObject lsp_iconview(ELKObject onp)
 
 	inp = iconview(np);
 	if (inp == NONODEPROTO) return(Null);
-	return(Make_EElectric((INTBIG)inp, (INTSML)T_ENodeProto));
+	return(Make_EElectric((INTBIG)inp, T_ENodeProto));
 }
 
 ELKObject lsp_contentsview(ELKObject onp)
@@ -1191,7 +1283,7 @@ ELKObject lsp_contentsview(ELKObject onp)
 
 	cnp = contentsview(np);
 	if (cnp == NONODEPROTO) return(Null);
-	return(Make_EElectric((INTBIG)cnp, (INTSML)T_ENodeProto));
+	return(Make_EElectric((INTBIG)cnp, T_ENodeProto));
 }
 
 /****************************** NODEINST ROUTINES ******************************/
@@ -1206,16 +1298,16 @@ ELKObject lsp_newnodeinst(ELKObject opro, ELKObject olx, ELKObject ohx, ELKObjec
 	/* get inputs from LISP */
 	Ensure_Type(opro, T_ENodeProto);   pro = ENODEPROTO(opro)->handle;
 	Ensure_Type(onp, T_ENodeProto);    np = ENODEPROTO(onp)->handle;
-	if (lsp_getnumericobject(olx, &lx) != 0) return(Null);
-	if (lsp_getnumericobject(ohx, &hx) != 0) return(Null);
-	if (lsp_getnumericobject(oly, &ly) != 0) return(Null);
-	if (lsp_getnumericobject(ohy, &hy) != 0) return(Null);
-	if (lsp_getnumericobject(otr, &tr) != 0) return(Null);
-	if (lsp_getnumericobject(orot, &rot) != 0) return(Null);
+	if (lsp_getnumericobject(olx, &lx)) return(Null);
+	if (lsp_getnumericobject(ohx, &hx)) return(Null);
+	if (lsp_getnumericobject(oly, &ly)) return(Null);
+	if (lsp_getnumericobject(ohy, &hy)) return(Null);
+	if (lsp_getnumericobject(otr, &tr)) return(Null);
+	if (lsp_getnumericobject(orot, &rot)) return(Null);
 
-	ni = newnodeinst(pro, lx, hx, ly, hy, (INTSML)tr, (INTSML)rot, np);
+	ni = newnodeinst(pro, lx, hx, ly, hy, tr, rot, np);
 	if (ni == NONODEINST) return(Null);
-	return(Make_EElectric((INTBIG)ni, (INTSML)T_ENodeInst));
+	return(Make_EElectric((INTBIG)ni, T_ENodeInst));
 }
 
 ELKObject lsp_modifynodeinst(ELKObject oni, ELKObject odlx, ELKObject odly, ELKObject odhx, ELKObject odhy,
@@ -1226,14 +1318,14 @@ ELKObject lsp_modifynodeinst(ELKObject oni, ELKObject odlx, ELKObject odly, ELKO
 
 	/* get inputs from LISP */
 	Ensure_Type(oni, T_ENodeInst);   ni = ENODEINST(oni)->handle;
-	if (lsp_getnumericobject(odlx, &dlx) != 0) return(Null);
-	if (lsp_getnumericobject(odly, &dly) != 0) return(Null);
-	if (lsp_getnumericobject(odhx, &dhx) != 0) return(Null);
-	if (lsp_getnumericobject(odhy, &dhy) != 0) return(Null);
-	if (lsp_getnumericobject(odrot, &drot) != 0) return(Null);
-	if (lsp_getnumericobject(odtr, &dtr) != 0) return(Null);
+	if (lsp_getnumericobject(odlx, &dlx)) return(Null);
+	if (lsp_getnumericobject(odly, &dly)) return(Null);
+	if (lsp_getnumericobject(odhx, &dhx)) return(Null);
+	if (lsp_getnumericobject(odhy, &dhy)) return(Null);
+	if (lsp_getnumericobject(odrot, &drot)) return(Null);
+	if (lsp_getnumericobject(odtr, &dtr)) return(Null);
 
-	modifynodeinst(ni, dlx, dly, dhx, dhy, (INTSML)drot, (INTSML)dtr);
+	modifynodeinst(ni, dlx, dly, dhx, dhy, drot, dtr);
 	return(Null);
 }
 
@@ -1256,9 +1348,9 @@ ELKObject lsp_replacenodeinst(ELKObject oni, ELKObject opr)
 	Ensure_Type(oni, T_ENodeInst);   ni = ENODEINST(oni)->handle;
 	Ensure_Type(opr, T_ENodeProto);  pr = ENODEPROTO(opr)->handle;
 
-	nni = replacenodeinst(ni, pr, 0, 0);
+	nni = replacenodeinst(ni, pr, FALSE, FALSE);
 	if (nni == NONODEINST) return(Null);
-	return(Make_EElectric((INTBIG)nni, (INTSML)T_ENodeInst));
+	return(Make_EElectric((INTBIG)nni, T_ENodeInst));
 }
 
 ELKObject lsp_nodefunction(ELKObject oni)
@@ -1285,21 +1377,21 @@ ELKObject lsp_newarcinst(ELKObject opro, ELKObject owid, ELKObject obit, ELKObje
 
 	/* get inputs from LISP */
 	Ensure_Type(opro, T_EArcProto);   pro = EARCPROTO(opro)->handle;
-	if (lsp_getnumericobject(owid, &wid) != 0) return(Null);
-	if (lsp_getnumericobject(obit, &bit) != 0) return(Null);
+	if (lsp_getnumericobject(owid, &wid)) return(Null);
+	if (lsp_getnumericobject(obit, &bit)) return(Null);
 	Ensure_Type(ona, T_ENodeInst);    na = ENODEINST(ona)->handle;
 	Ensure_Type(opa, T_EPortProto);   pa = EPORTPROTO(opa)->handle;
-	if (lsp_getnumericobject(oxa, &xa) != 0) return(Null);
-	if (lsp_getnumericobject(oya, &ya) != 0) return(Null);
+	if (lsp_getnumericobject(oxa, &xa)) return(Null);
+	if (lsp_getnumericobject(oya, &ya)) return(Null);
 	Ensure_Type(onb, T_ENodeInst);    nb = ENODEINST(onb)->handle;
 	Ensure_Type(opb, T_EPortProto);   pb = EPORTPROTO(opb)->handle;
-	if (lsp_getnumericobject(oxb, &xb) != 0) return(Null);
-	if (lsp_getnumericobject(oyb, &yb) != 0) return(Null);
+	if (lsp_getnumericobject(oxb, &xb)) return(Null);
+	if (lsp_getnumericobject(oyb, &yb)) return(Null);
 	Ensure_Type(onp, T_ENodeProto);   np = ENODEPROTO(onp)->handle;
 
 	ai = newarcinst(pro, wid, bit, na, pa, xa, ya, nb, pb, xb, yb, np);
 	if (ai == NOARCINST) return(Null);
-	return(Make_EElectric((INTBIG)ai, (INTSML)T_EArcInst));
+	return(Make_EElectric((INTBIG)ai, T_EArcInst));
 }
 
 ELKObject lsp_modifyarcinst(ELKObject oai, ELKObject odw, ELKObject odx1, ELKObject ody1, ELKObject odx2,
@@ -1310,13 +1402,13 @@ ELKObject lsp_modifyarcinst(ELKObject oai, ELKObject odw, ELKObject odx1, ELKObj
 
 	/* get inputs from LISP */
 	Ensure_Type(oai, T_EArcInst);   ai = EARCINST(oai)->handle;
-	if (lsp_getnumericobject(odw, &dw) != 0) return(Null);
-	if (lsp_getnumericobject(odx1, &dx1) != 0) return(Null);
-	if (lsp_getnumericobject(ody1, &dy1) != 0) return(Null);
-	if (lsp_getnumericobject(odx2, &dx2) != 0) return(Null);
-	if (lsp_getnumericobject(ody2, &dy2) != 0) return(Null);
+	if (lsp_getnumericobject(odw, &dw)) return(Null);
+	if (lsp_getnumericobject(odx1, &dx1)) return(Null);
+	if (lsp_getnumericobject(ody1, &dy1)) return(Null);
+	if (lsp_getnumericobject(odx2, &dx2)) return(Null);
+	if (lsp_getnumericobject(ody2, &dy2)) return(Null);
 
-	return(Make_Fixnum(modifyarcinst(ai, dw, dx1, dy1, dx2, dy2)));
+	return(Make_Fixnum(modifyarcinst(ai, dw, dx1, dy1, dx2, dy2)?1:0));
 }
 
 ELKObject lsp_killarcinst(ELKObject oai)
@@ -1326,7 +1418,7 @@ ELKObject lsp_killarcinst(ELKObject oai)
 	/* get inputs from LISP */
 	Ensure_Type(oai, T_EArcInst);   ai = EARCINST(oai)->handle;
 
-	return(Make_Fixnum(killarcinst(ai)));
+	return(Make_Fixnum(killarcinst(ai)?1:0));
 }
 
 ELKObject lsp_replacearcinst(ELKObject oai, ELKObject opr)
@@ -1340,7 +1432,7 @@ ELKObject lsp_replacearcinst(ELKObject oai, ELKObject opr)
 
 	nai = replacearcinst(ai, pr);
 	if (nai == NOARCINST) return(Null);
-	return(Make_EElectric((INTBIG)nai, (INTSML)T_EArcInst));
+	return(Make_EElectric((INTBIG)nai, T_EArcInst));
 }
 
 /****************************** PORTPROTO ROUTINES ******************************/
@@ -1361,7 +1453,7 @@ ELKObject lsp_newportproto(ELKObject onp, ELKObject oni, ELKObject opp, ELKObjec
 
 	pp = newportproto(np, ni, pp, name);
 	if (pp == NOPORTPROTO) return(Null);
-	return(Make_EElectric((INTBIG)pp, (INTSML)T_EPortProto));
+	return(Make_EElectric((INTBIG)pp, T_EPortProto));
 }
 
 ELKObject lsp_portposition(ELKObject oni, ELKObject opp)
@@ -1398,7 +1490,7 @@ ELKObject lsp_getportproto(ELKObject onp, ELKObject oname)
 
 	pp = getportproto(np, name);
 	if (pp == NOPORTPROTO) return(Null);
-	return(Make_EElectric((INTBIG)pp, (INTSML)T_EPortProto));
+	return(Make_EElectric((INTBIG)pp, T_EPortProto));
 }
 
 ELKObject lsp_killportproto(ELKObject onp, ELKObject opp)
@@ -1410,7 +1502,7 @@ ELKObject lsp_killportproto(ELKObject onp, ELKObject opp)
 	Ensure_Type(opp, T_EPortProto);   pp = EPORTPROTO(opp)->handle;
 	Ensure_Type(onp, T_ENodeProto);   np = ENODEPROTO(onp)->handle;
 
-	return(Make_Fixnum(killportproto(np, pp)));
+	return(Make_Fixnum(killportproto(np, pp)?1:0));
 }
 
 ELKObject lsp_moveportproto(ELKObject onp, ELKObject oopp, ELKObject onni, ELKObject onpp)
@@ -1425,7 +1517,7 @@ ELKObject lsp_moveportproto(ELKObject onp, ELKObject oopp, ELKObject onni, ELKOb
 	Ensure_Type(onni, T_ENodeInst);    nni = ENODEINST(onni)->handle;
 	Ensure_Type(onpp, T_EPortProto);   npp = EPORTPROTO(onpp)->handle;
 
-	return(Make_Fixnum(moveportproto(np, opp, nni, npp)));
+	return(Make_Fixnum(moveportproto(np, opp, nni, npp)?1:0));
 }
 
 /*************************** CHANGE CONTROL ROUTINES ***************************/
@@ -1457,7 +1549,7 @@ ELKObject lsp_getview(ELKObject oname)
 
 	v = getview(name);
 	if (v == NOVIEW) return(Null);
-	return(Make_EElectric((INTBIG)v, (INTSML)T_EView));
+	return(Make_EElectric((INTBIG)v, T_EView));
 }
 
 ELKObject lsp_newview(ELKObject oname, ELKObject osname)
@@ -1473,7 +1565,7 @@ ELKObject lsp_newview(ELKObject oname, ELKObject osname)
 
 	v = newview(name, sname);
 	if (v == NOVIEW) return(Null);
-	return(Make_EElectric((INTBIG)v, (INTSML)T_EView));
+	return(Make_EElectric((INTBIG)v, T_EView));
 }
 
 ELKObject lsp_killview(ELKObject ov)
@@ -1483,7 +1575,7 @@ ELKObject lsp_killview(ELKObject ov)
 	/* get inputs from LISP */
 	Ensure_Type(ov, T_EView);   v = EVIEW(ov)->handle;
 
-	return(Make_Fixnum(killview(v)));
+	return(Make_Fixnum(killview(v)?1:0));
 }
 
 /*************************** MISCELLANEOUS ROUTINES ***************************/
@@ -1491,7 +1583,7 @@ ELKObject lsp_killview(ELKObject ov)
 ELKObject lsp_telltool(long argc, ELKObject argv[])
 {
 	REGISTER TOOL *tool;
-	REGISTER INTSML i, val;
+	REGISTER INTBIG i;
 	char *par[20], *ret;
 
 	/* get inputs from LISP */
@@ -1505,9 +1597,9 @@ ELKObject lsp_telltool(long argc, ELKObject argv[])
 		(void)allocstring(&par[i], ret, el_tempcluster);
 	}
 
-	val = telltool(tool, (INTSML)argc, par);
+	telltool(tool, argc, par);
 	for(i=0; i<argc; i++) efree(par[i]);
-	return(Make_Fixnum(val));
+	return(Make_Fixnum(0));		/* !!! actually should not return a value */
 }
 
 ELKObject lsp_getarcproto(ELKObject oname)
@@ -1521,7 +1613,7 @@ ELKObject lsp_getarcproto(ELKObject oname)
 
 	ap = getarcproto(name);
 	if (ap == NOARCPROTO) return(Null);
-	return(Make_EElectric((INTBIG)ap, (INTSML)T_EArcProto));
+	return(Make_EElectric((INTBIG)ap, T_EArcProto));
 }
 
 ELKObject lsp_getcell(ELKObject oname)
@@ -1535,7 +1627,7 @@ ELKObject lsp_getcell(ELKObject oname)
 
 	c = getcell(name);
 	if (c == NOCELL) return(Null);
-	return(Make_EElectric((INTBIG)c, (INTSML)T_ECell));
+	return(Make_EElectric((INTBIG)c, T_ECell));
 }
 
 ELKObject lsp_gettechnology(ELKObject oname)
@@ -1549,7 +1641,7 @@ ELKObject lsp_gettechnology(ELKObject oname)
 
 	tech = gettechnology(name);
 	if (tech == NOTECHNOLOGY) return(Null);
-	return(Make_EElectric((INTBIG)tech, (INTSML)T_ETechnology));
+	return(Make_EElectric((INTBIG)tech, T_ETechnology));
 }
 
 ELKObject lsp_getpinproto(ELKObject oap)
@@ -1562,7 +1654,7 @@ ELKObject lsp_getpinproto(ELKObject oap)
 
 	np = getpinproto(ap);
 	if (np == NONODEPROTO) return(Null);
-	return(Make_EElectric((INTBIG)np, (INTSML)T_ENodeProto));
+	return(Make_EElectric((INTBIG)np, T_ENodeProto));
 }
 
 ELKObject lsp_getnetwork(ELKObject oname, ELKObject onp)
@@ -1578,7 +1670,7 @@ ELKObject lsp_getnetwork(ELKObject oname, ELKObject onp)
 
 	net = getnetwork(name, np);
 	if (net == NONETWORK) return(Null);
-	return(Make_EElectric((INTBIG)net, (INTSML)T_ENetwork));
+	return(Make_EElectric((INTBIG)net, T_ENetwork));
 }
 
 /****************************** INITIALIZATION ******************************/
@@ -1649,9 +1741,14 @@ void init_lib_electric(void)
 	Define_Symbol(&lsp_displayablesym, "displayable");
 
 	/* define the database examination predicates */
-	Define_Primitive(lsp_curlib, "curlib", 0, 0, EVAL);
-	Define_Primitive(lsp_curtech, "curtech", 0, 0, EVAL);
+	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_curlib, "curlib", 0, 0, EVAL);
+	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_curtech, "curtech", 0, 0, EVAL);
 	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_getval, "getval", 2, 2, EVAL);
+	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_getparentval, "getparentval", 3, 3, EVAL);
+	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_P, "P", 1, 1, EVAL);
+	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_PD, "PD", 2, 2, EVAL);
+	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_PAR, "PAR", 1, 1, EVAL);
+	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_PARD, "PARD", 2, 2, EVAL);
 	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_setval, "setval", 4, 4, EVAL);
 	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_setind, "setind", 4, 4, EVAL);
 	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_delval, "delval", 2, 2, EVAL);
