@@ -66,6 +66,11 @@ static void tcl_tkconsolewatch(ClientData instanceData, int mask);
 static int tcl_curlib(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
 static int tcl_curtech(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
 static int tcl_getval(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_getparentval(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_P(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_PD(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_PAR(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
+static int tcl_PARD(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
 static int tcl_setval(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
 static int tcl_setind(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
 static int tcl_delval(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
@@ -246,6 +251,11 @@ void el_tclinterpreter(Tcl_Interp *interp)
 	Tcl_CreateCommand(tcl_interp, "curlib",          tcl_curlib,          (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
 	Tcl_CreateCommand(tcl_interp, "curtech",         tcl_curtech,         (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
 	Tcl_CreateCommand(tcl_interp, "getval",          tcl_getval,          (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
+	Tcl_CreateCommand(tcl_interp, "getparentval",    tcl_getparentval,    (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
+	Tcl_CreateCommand(tcl_interp, "P",               tcl_P,               (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
+	Tcl_CreateCommand(tcl_interp, "PD",              tcl_PD,              (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
+	Tcl_CreateCommand(tcl_interp, "PAR",             tcl_PAR,             (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
+	Tcl_CreateCommand(tcl_interp, "PARD",            tcl_PARD,            (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
 	Tcl_CreateCommand(tcl_interp, "setval",          tcl_setval,          (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
 	Tcl_CreateCommand(tcl_interp, "setind",          tcl_setind,          (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
 	Tcl_CreateCommand(tcl_interp, "delval",          tcl_delval,          (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
@@ -304,7 +314,7 @@ void tcl_converttoanyelectric(char *tclstr, INTBIG *addr, INTBIG *type)
 	REGISTER float fval;
 
 	/* simple if it is a number */
-	if (isanumber(tclstr) != 0)
+	if (isanumber(tclstr))
 	{
 		for(pt = tclstr; *pt != 0; pt++)
 			if (*pt == '.')
@@ -620,6 +630,126 @@ int tcl_getval(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 	return TCL_OK;
 }
 
+int tcl_getparentval(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
+{
+	INTBIG height;
+	char *retval;
+	REGISTER VARIABLE *var;
+
+	/* get input */
+	if (argc != 4)
+	{
+		Tcl_AppendResult(interp, "Usage: getparentval OBJECT DEFAULT HEIGHT", (char *)NULL);
+		return TCL_ERROR;
+	}
+	height = myatoi(argv[3]);
+
+	/* call Electric */
+	var = getparentval(argv[1], height);
+
+	/* convert result */
+	if (var == NOVARIABLE) retval = argv[2]; else
+		retval = tcl_converttotcl(var->addr, var->type);
+	Tcl_AppendResult(interp, retval, (char *)NULL);
+	return TCL_OK;
+}
+
+int tcl_P(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
+{
+	char *retval, line[300];
+	REGISTER VARIABLE *var;
+
+	/* get input */
+	if (argc != 2)
+	{
+		Tcl_AppendResult(interp, "Usage: P OBJECT", (char *)NULL);
+		return TCL_ERROR;
+	}
+
+	/* call Electric */
+	sprintf(line, "ATTR_%s", argv[1]);
+	var = getparentval(line, 1);
+
+	/* convert result */
+	if (var != NOVARIABLE)
+	{
+		retval = tcl_converttotcl(var->addr, var->type);
+		Tcl_AppendResult(interp, retval, (char *)NULL);
+	}
+	return TCL_OK;
+}
+
+int tcl_PD(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
+{
+	char *retval, line[300];
+	REGISTER VARIABLE *var;
+
+	/* get input */
+	if (argc != 3)
+	{
+		Tcl_AppendResult(interp, "Usage: PD OBJECT DEFAULT", (char *)NULL);
+		return TCL_ERROR;
+	}
+
+	/* call Electric */
+	sprintf(line, "ATTR_%s", argv[1]);
+	var = getparentval(line, 1);
+
+	/* convert result */
+	if (var == NOVARIABLE) retval = argv[2]; else
+		retval = tcl_converttotcl(var->addr, var->type);
+	Tcl_AppendResult(interp, retval, (char *)NULL);
+	return TCL_OK;
+}
+
+int tcl_PAR(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
+{
+	char *retval, line[300];
+	REGISTER VARIABLE *var;
+
+	/* get input */
+	if (argc != 2)
+	{
+		Tcl_AppendResult(interp, "Usage: PAR OBJECT", (char *)NULL);
+		return TCL_ERROR;
+	}
+
+	/* call Electric */
+	sprintf(line, "ATTR_%s", argv[1]);
+	var = getparentval(line, 0);
+
+	/* convert result */
+	if (var != NOVARIABLE)
+	{
+		retval = tcl_converttotcl(var->addr, var->type);
+		Tcl_AppendResult(interp, retval, (char *)NULL);
+	}
+	return TCL_OK;
+}
+
+int tcl_PARD(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
+{
+	char *retval, line[300];
+	REGISTER VARIABLE *var;
+
+	/* get input */
+	if (argc != 3)
+	{
+		Tcl_AppendResult(interp, "Usage: PARD OBJECT DEFAULT", (char *)NULL);
+		return TCL_ERROR;
+	}
+
+	/* call Electric */
+	sprintf(line, "ATTR_%s", argv[1]);
+	var = getparentval(line, 0);
+
+	/* convert result */
+	if (var == NOVARIABLE) retval = argv[2]; else
+		retval = tcl_converttotcl(var->addr, var->type);
+	Tcl_AppendResult(interp, retval, (char *)NULL);
+	return TCL_OK;
+}
+
 int tcl_setval(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 {
 	INTBIG addr, type, naddr, ntype, i, *naddrlist;
@@ -690,7 +820,8 @@ int tcl_setval(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 
 int tcl_setind(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 {
-	INTBIG addr, type, ret, aindex, naddr, ntype;
+	INTBIG addr, type, aindex, naddr, ntype;
+	BOOLEAN ret;
 
 	/* get input */
 	if (argc != 5)
@@ -712,7 +843,8 @@ int tcl_setind(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 
 int tcl_delval(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 {
-	INTBIG addr, type, ret;
+	INTBIG addr, type;
+	BOOLEAN ret;
 
 	/* get input */
 	if (argc != 3)
@@ -836,7 +968,8 @@ int tcl_indextool(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 int tcl_toolturnon(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 {
 	REGISTER TOOL *tool;
-	REGISTER INTBIG nocatchup;
+	REGISTER INTBIG nocatchupn;
+	REGISTER BOOLEAN nocatchup;
 
 	/* get input */
 	if (argc != 3)
@@ -846,10 +979,11 @@ int tcl_toolturnon(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 	}
 	tool = (TOOL *)tcl_converttowarnedelectric(argv[1], VTOOL, "first");
 	if (tool == NOTOOL) return TCL_ERROR;
-	nocatchup = myatoi(argv[2]);
+	nocatchupn = myatoi(argv[2]);
+	nocatchup = nocatchupn != 0 ? TRUE : FALSE;
 
 	/* call Electric */
-	toolturnon(tool, (INTSML)nocatchup);
+	toolturnon(tool, nocatchup);
 	return TCL_OK;
 }
 
@@ -867,7 +1001,7 @@ int tcl_toolturnoff(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 	if (tool == NOTOOL) return TCL_ERROR;
 
 	/* call Electric */
-	toolturnoff(tool, 1);
+	toolturnoff(tool, TRUE);
 	return TCL_OK;
 }
 
@@ -1011,7 +1145,7 @@ int tcl_newnodeproto(ClientData dummy, Tcl_Interp *interp, int argc, char **argv
 int tcl_killnodeproto(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 {
 	REGISTER NODEPROTO *np;
-	REGISTER INTBIG ret;
+	REGISTER BOOLEAN ret;
 
 	/* get input */
 	if (argc != 2)
@@ -1026,7 +1160,7 @@ int tcl_killnodeproto(ClientData dummy, Tcl_Interp *interp, int argc, char **arg
 	ret = killnodeproto(np);
 
 	/* convert result */
-	Tcl_AppendResult(interp, tcl_converttotcl(ret, VINTEGER), (char *) NULL);
+	Tcl_AppendResult(interp, tcl_converttotcl(ret?1:0, VINTEGER), (char *) NULL);
 	return TCL_OK;
 }
 
@@ -1120,7 +1254,7 @@ int tcl_newnodeinst(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 	if (np == NONODEPROTO || facet == NONODEPROTO) return TCL_ERROR;
 
 	/* call Electric */
-	ni = newnodeinst(np, lx, hx, ly, hy, (INTSML)tran, (INTSML)rot, facet);
+	ni = newnodeinst(np, lx, hx, ly, hy, tran, rot, facet);
 
 	/* convert result */
 	Tcl_AppendResult(interp, tcl_converttotcl((INTBIG)ni, VNODEINST), (char *) NULL);
@@ -1148,14 +1282,14 @@ int tcl_modifynodeinst(ClientData dummy, Tcl_Interp *interp, int argc, char **ar
 	if (ni == NONODEINST) return TCL_ERROR;
 
 	/* call Electric */
-	modifynodeinst(ni, dlx, dly, dhx, dhy, (INTSML)drot, (INTSML)dtran);
+	modifynodeinst(ni, dlx, dly, dhx, dhy, drot, dtran);
 	return TCL_OK;
 }
 
 int tcl_killnodeinst(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 {
 	REGISTER NODEINST *ni;
-	REGISTER INTBIG ret;
+	REGISTER BOOLEAN ret;
 
 	/* get input */
 	if (argc != 2)
@@ -1170,7 +1304,7 @@ int tcl_killnodeinst(ClientData dummy, Tcl_Interp *interp, int argc, char **argv
 	ret = killnodeinst(ni);
 
 	/* convert result */
-	Tcl_AppendResult(interp, tcl_converttotcl(ret, VINTEGER), (char *) NULL);
+	Tcl_AppendResult(interp, tcl_converttotcl(ret?1:0, VINTEGER), (char *) NULL);
 	return TCL_OK;
 }
 
@@ -1190,7 +1324,7 @@ int tcl_replacenodeinst(ClientData dummy, Tcl_Interp *interp, int argc, char **a
 	if (ni == NONODEINST || np == NONODEPROTO) return TCL_ERROR;
 
 	/* call Electric */
-	nni = replacenodeinst(ni, np, 0, 0);
+	nni = replacenodeinst(ni, np, FALSE, FALSE);
 
 	/* convert result */
 	Tcl_AppendResult(interp, tcl_converttotcl((INTBIG)nni, VNODEINST), (char *) NULL);
@@ -1264,7 +1398,7 @@ int tcl_modifyarcinst(ClientData dummy, Tcl_Interp *interp, int argc, char **arg
 {
 	REGISTER ARCINST *ai;
 	REGISTER INTBIG dw, dx1, dy1, dx2, dy2;
-	REGISTER INTBIG ret;
+	REGISTER BOOLEAN ret;
 
 	/* get input */
 	if (argc != 7)
@@ -1284,14 +1418,14 @@ int tcl_modifyarcinst(ClientData dummy, Tcl_Interp *interp, int argc, char **arg
 	ret = modifyarcinst(ai, dw, dx1, dy1, dx2, dy2);
 
 	/* convert result */
-	Tcl_AppendResult(interp, tcl_converttotcl(ret, VINTEGER), (char *) NULL);
+	Tcl_AppendResult(interp, tcl_converttotcl(ret?1:0, VINTEGER), (char *) NULL);
 	return TCL_OK;
 }
 
 int tcl_killarcinst(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 {
 	REGISTER ARCINST *ai;
-	REGISTER INTBIG ret;
+	REGISTER BOOLEAN ret;
 
 	/* get input */
 	if (argc != 2)
@@ -1306,7 +1440,7 @@ int tcl_killarcinst(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 	ret = killarcinst(ai);
 
 	/* convert result */
-	Tcl_AppendResult(interp, tcl_converttotcl(ret, VINTEGER), (char *) NULL);
+	Tcl_AppendResult(interp, tcl_converttotcl(ret?1:0, VINTEGER), (char *) NULL);
 	return TCL_OK;
 }
 
@@ -1412,7 +1546,7 @@ int tcl_killportproto(ClientData dummy, Tcl_Interp *interp, int argc, char **arg
 {
 	REGISTER NODEPROTO *np;
 	REGISTER PORTPROTO *pp;
-	REGISTER INTBIG ret;
+	REGISTER BOOLEAN ret;
 
 	/* get input */
 	if (argc != 3)
@@ -1428,7 +1562,7 @@ int tcl_killportproto(ClientData dummy, Tcl_Interp *interp, int argc, char **arg
 	ret = killportproto(np, pp);
 
 	/* convert result */
-	Tcl_AppendResult(interp, tcl_converttotcl(ret, VINTEGER), (char *) NULL);
+	Tcl_AppendResult(interp, tcl_converttotcl(ret?1:0, VINTEGER), (char *) NULL);
 	return TCL_OK;
 }
 
@@ -1437,7 +1571,7 @@ int tcl_moveportproto(ClientData dummy, Tcl_Interp *interp, int argc, char **arg
 	REGISTER NODEPROTO *np;
 	REGISTER PORTPROTO *opp, *npp;
 	REGISTER NODEINST *nni;
-	REGISTER INTBIG ret;
+	REGISTER BOOLEAN ret;
 
 	/* get input */
 	if (argc != 5)
@@ -1455,7 +1589,7 @@ int tcl_moveportproto(ClientData dummy, Tcl_Interp *interp, int argc, char **arg
 	ret = moveportproto(np, opp, nni, npp);
 
 	/* convert result */
-	Tcl_AppendResult(interp, tcl_converttotcl(ret, VINTEGER), (char *) NULL);
+	Tcl_AppendResult(interp, tcl_converttotcl(ret?1:0, VINTEGER), (char *) NULL);
 	return TCL_OK;
 }
 
@@ -1539,7 +1673,7 @@ int tcl_newview(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 int tcl_killview(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 {
 	REGISTER VIEW *v;
-	REGISTER INTBIG ret;
+	REGISTER BOOLEAN ret;
 
 	/* get input */
 	if (argc != 2)
@@ -1554,7 +1688,7 @@ int tcl_killview(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 	ret = killview(v);
 
 	/* convert result */
-	Tcl_AppendResult(interp, tcl_converttotcl(ret, VINTEGER), (char *) NULL);
+	Tcl_AppendResult(interp, tcl_converttotcl(ret?1:0, VINTEGER), (char *) NULL);
 	return TCL_OK;
 }
 
@@ -1577,10 +1711,11 @@ int tcl_telltool(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 	if (tool == NOTOOL || ret != TCL_OK) return TCL_ERROR;
 
 	/* call Electric */
-	ret = telltool(tool, (INTSML)toolArgc, toolArgv);
+	telltool(tool, toolArgc, toolArgv);
 	ckfree((char *)toolArgv);
 
 	/* convert result */
+	ret = 0;		/* actually should not return a value!!! */
 	Tcl_AppendResult(interp, tcl_converttotcl(ret, VINTEGER), (char *) NULL);
 	return TCL_OK;
 }
@@ -1767,7 +1902,7 @@ int tcl_getnetwork(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 
 #ifdef USETK
 
-static INTSML              tcl_pulldownmenucount;	/* number of pulldown menus */
+static INTBIG             tcl_pulldownmenucount;	/* number of pulldown menus */
 static TkMenuReferences **tcl_pulldownmenus;		/* the current pulldown menu handles */
 static POPUPMENU        **tcl_pulldowns;			/* the current pulldown menus */
 
@@ -1778,10 +1913,10 @@ static POPUPMENU        **tcl_pulldowns;			/* the current pulldown menus */
    MenuHandle tkEditMenu  = 0;
 #endif
 
-INTSML tcl_loadtclmsg(char*, ...);
-INTSML tcl_pulldownindex(POPUPMENU *pm, char *prevmenu);
-TkMenuReferences *tcl_makepdmenu(POPUPMENU *pm, INTSML value, char *prevmenu);
-void tcl_nativemenurename(POPUPMENU*, INTSML);
+BOOLEAN tcl_loadtclmsg(char*, ...);
+INTBIG tcl_pulldownindex(POPUPMENU *pm, char *prevmenu);
+TkMenuReferences *tcl_makepdmenu(POPUPMENU *pm, INTBIG value, char *prevmenu);
+void tcl_nativemenurename(POPUPMENU*, INTBIG);
 
 /*
  * Routine to initialize TK menus.
@@ -1794,9 +1929,9 @@ void tcl_nativemenuinitialize(void)
 /*
  * Routine to redraw entry "aindex" of popupmenu "pm" because it changed.
  */
-void tcl_nativemenurename(POPUPMENU *pm, INTSML aindex)
+void tcl_nativemenurename(POPUPMENU *pm, INTBIG aindex)
 {
-	INTSML i;
+	INTBIG i;
 	char line[100], *menuName, *slashpt, *anglept, *command, *pt,
 		*acceleratorstring, *acceleratorprefix;
 	USERCOM *uc;
@@ -1811,7 +1946,7 @@ void tcl_nativemenurename(POPUPMENU *pm, INTSML aindex)
 	/* if this command is another menu, just change the label */
 	if (uc->menu != NOPOPUPMENU)
 	{
-		(void)tcl_loadtclmsg("%s entryconfigure %d -label \"%s\"", menuName, aindex, line);
+		(void)tcl_loadtclmsg("%s entryconfigure %ld -label \"%s\"", menuName, aindex, line);
 		return;
 	}
 
@@ -1827,17 +1962,17 @@ void tcl_nativemenurename(POPUPMENU *pm, INTSML aindex)
 	/* change the accelerator key */
 	if (slashpt == 0)
 	{
-		if (tcl_loadtclmsg("%s entryconfigure %d -accelerator \"\"",
-			menuName, aindex) != 0) return;
+		if (tcl_loadtclmsg("%s entryconfigure %ld -accelerator \"\"",
+			menuName, aindex)) return;
 	} else
 	{
 		getacceleratorstrings(&acceleratorstring, &acceleratorprefix);
 		*slashpt++ = 0;
-		if (tcl_loadtclmsg("%s entryconfigure %d -accelerator \"%s+%c\"",
-			menuName, aindex, acceleratorstring, *slashpt) != 0) return;
+		if (tcl_loadtclmsg("%s entryconfigure %ld -accelerator \"%s+%c\"",
+			menuName, aindex, acceleratorstring, *slashpt)) return;
 #ifdef WIN32
-		if (tcl_loadtclmsg("bind .graphics <%s-KeyPress-%c> \"domenu %d %d\"",
-			acceleratorstring, tolower(*slashpt), i, aindex+1) != 0) return;
+		if (tcl_loadtclmsg("bind .graphics <%s-KeyPress-%c> \"domenu %ld %ld\"",
+			acceleratorstring, tolower(*slashpt), i, aindex+1)) return;
 #endif
 	}
 
@@ -1848,44 +1983,44 @@ void tcl_nativemenurename(POPUPMENU *pm, INTSML aindex)
 		if (*command == '>')
 		{
 			command++;
-			if (tcl_loadtclmsg("%s entryconfigure %d -variable etrue",
-				menuName, aindex) != 0) return;
+			if (tcl_loadtclmsg("%s entryconfigure %ld -variable etrue",
+				menuName, aindex)) return;
 		} else
 		{
-			if (tcl_loadtclmsg("%s entryconfigure %d -variable efalse",
-				menuName, aindex) != 0) return;
+			if (tcl_loadtclmsg("%s entryconfigure %ld -variable efalse",
+				menuName, aindex)) return;
 		}
-		if (tcl_loadtclmsg("set etrue 1") != 0) return;
-		if (tcl_loadtclmsg("set efalse 0") != 0) return;
+		if (tcl_loadtclmsg("set etrue 1")) return;
+		if (tcl_loadtclmsg("set efalse 0")) return;
 	}
 
 	/* change the menu label */
-	if (tcl_loadtclmsg("%s entryconfigure %d -label \"%s\"",
-		menuName, aindex, command) != 0) return;
+	if (tcl_loadtclmsg("%s entryconfigure %ld -label \"%s\"",
+		menuName, aindex, command)) return;
 
 	/* change the menu command */
-	if (tcl_loadtclmsg("%s entryconfigure %d -command \"domenu %d %d\"",
-		menuName, aindex, i, aindex+1) != 0) return;
+	if (tcl_loadtclmsg("%s entryconfigure %ld -command \"domenu %ld %ld\"",
+		menuName, aindex, i, aindex+1)) return;
 }
 
 /*
  * Routine to establish the "count" pulldown menu names in "par" as the pulldown menu bar.
- * Returns nonzero on error.
+ * Returns true on error.
  */
-INTSML tcl_nativemenuload(INTSML count, char *par[])
+BOOLEAN tcl_nativemenuload(INTBIG count, char *par[])
 {
-	REGISTER INTSML i, menuindex;
+	REGISTER INTBIG i, menuindex;
 	REGISTER POPUPMENU *pm;
 	POPUPMENU *pulls[25];
 
-	if (tcl_loadtclmsg("menu .menus -type menubar") != 0) return(1);
-	if (tcl_loadtclmsg("set etrue 1") != 0) return(1);
-	if (tcl_loadtclmsg("set efalse 0") != 0) return(1);
+	if (tcl_loadtclmsg("menu .menus -type menubar")) return(TRUE);
+	if (tcl_loadtclmsg("set etrue 1")) return(TRUE);
+	if (tcl_loadtclmsg("set efalse 0")) return(TRUE);
 
 #ifdef MACOS
-	if (tcl_loadtclmsg("menu .menus.apple -tearoff 0") != 0) return(1);
-	if (tcl_loadtclmsg(".menus.apple add command -label \"About Electric...\" -command \"domenu -1 -1\"") != 0) return(1);
-	if (tcl_loadtclmsg(".menus add cascade -menu .menus.apple") != 0) return(1);
+	if (tcl_loadtclmsg("menu .menus.apple -tearoff 0")) return(TRUE);
+	if (tcl_loadtclmsg(".menus.apple add command -label \"About Electric...\" -command \"domenu -1 -1\"")) return(TRUE);
+	if (tcl_loadtclmsg(".menus add cascade -menu .menus.apple")) return(TRUE);
 #endif
 
 	/* build the pulldown menu bar */
@@ -1895,9 +2030,9 @@ INTSML tcl_nativemenuload(INTSML count, char *par[])
 		if (pm == NOPOPUPMENU) continue;
 		pulls[i] = pm;
 		menuindex = tcl_pulldownindex(pm, "");
-		if (menuindex < 0) return(1);
+		if (menuindex < 0) return(TRUE);
 	}
-	return(0);
+	return(FALSE);
 }
 
 /*
@@ -1905,9 +2040,9 @@ INTSML tcl_nativemenuload(INTSML count, char *par[])
  * toplevel menu if "prevmenu" is empty, otherwise it is the name of
  * the higher-level menu.  Returns an index to the table of pulldown menus (-1 on error).
  */
-INTSML tcl_pulldownindex(POPUPMENU *pm, char *prevmenu)
+INTBIG tcl_pulldownindex(POPUPMENU *pm, char *prevmenu)
 {
-	REGISTER INTSML i, aindex;
+	REGISTER INTBIG i, aindex;
 	TkMenuReferences **newpulldownmenus;
 	POPUPMENU **newpulldowns;
 
@@ -1948,9 +2083,9 @@ INTSML tcl_pulldownindex(POPUPMENU *pm, char *prevmenu)
  * Routine to create pulldown menu number "value" from the popup menu in "pm" and return
  * the menu handle.  If "prevmenu" is not null, this is a submenu of that one.
  */
-TkMenuReferences *tcl_makepdmenu(POPUPMENU *pm, INTSML value, char *prevmenu)
+TkMenuReferences *tcl_makepdmenu(POPUPMENU *pm, INTBIG value, char *prevmenu)
 {
-	REGISTER INTSML i, submenuindex;
+	REGISTER INTBIG i, submenuindex;
 	char myline[256], *pt, *anglept, *command, cmdkey;
 	REGISTER USERCOM *uc;
 	REGISTER POPUPMENUITEM *mi;
@@ -1959,14 +2094,14 @@ TkMenuReferences *tcl_makepdmenu(POPUPMENU *pm, INTSML value, char *prevmenu)
 
 	strcpy(&myline[1], pm->header);
 	myline[0] = strlen(pm->header);
-	sprintf(thismenuname, "%s.%d", prevmenu, value);
-	if (tcl_loadtclmsg("menu .menus%s -tearoff 0", thismenuname) != 0) return(0);
+	sprintf(thismenuname, "%s.%ld", prevmenu, value);
+	if (tcl_loadtclmsg("menu .menus%s -tearoff 0", thismenuname)) return(0);
 	sprintf(myline, ".menus%s", thismenuname);
 	thismenu = TkFindMenuReferences(tcl_interp, myline);
 	if (*prevmenu == 0)
 	{
 		if (tcl_loadtclmsg(".menus add cascade -label \"%s\" -menu .menus%s",	/*  -underline 0 */
-			pm->header, thismenuname) != 0) return(0);
+			pm->header, thismenuname)) return(0);
 	}
 
 	/* build the actual menu */
@@ -1976,18 +2111,18 @@ TkMenuReferences *tcl_makepdmenu(POPUPMENU *pm, INTSML value, char *prevmenu)
 		uc = mi->response;
 		if (uc->active < 0)
 		{
-			if (tcl_loadtclmsg(".menus%s add separator", thismenuname) != 0) return(0);
+			if (tcl_loadtclmsg(".menus%s add separator", thismenuname)) return(0);
 			continue;
 		}
 
 		/* see if this command is another menu */
 		if (uc->menu != NOPOPUPMENU)
 		{
-			sprintf(myline, "%s.%d", prevmenu, value);
+			sprintf(myline, "%s.%ld", prevmenu, value);
 			submenuindex = tcl_pulldownindex(uc->menu, myline);
 			if (submenuindex < 0) continue;
-			if (tcl_loadtclmsg(".menus%s add cascade -label \"%s\" -menu .menus%s.%d",
-				thismenuname, mi->attribute, thismenuname, submenuindex) != 0) return(0);
+			if (tcl_loadtclmsg(".menus%s add cascade -label \"%s\" -menu .menus%s.%ld",
+				thismenuname, mi->attribute, thismenuname, submenuindex)) return(0);
 			continue;
 		}
 
@@ -2018,7 +2153,7 @@ TkMenuReferences *tcl_makepdmenu(POPUPMENU *pm, INTSML value, char *prevmenu)
 		(void)addstringtoinfstr(" -label \"");
 		(void)addstringtoinfstr(command);
 		(void)addtoinfstr('"');
-		sprintf(myline, " -command \"domenu %d %d\"", value, i+1);
+		sprintf(myline, " -command \"domenu %ld %ld\"", value, i+1);
 		(void)addstringtoinfstr(myline);
 		if (cmdkey != 0)
 		{
@@ -2026,19 +2161,19 @@ TkMenuReferences *tcl_makepdmenu(POPUPMENU *pm, INTSML value, char *prevmenu)
 			sprintf(myline, " -accelerator \"%s+%c\"", acceleratorstring, cmdkey);
 			(void)addstringtoinfstr(myline);
 #ifdef WIN32
-			if (tcl_loadtclmsg("bind .graphics <%s-KeyPress-%c> \"domenu %d %d\"",
-				acceleratorstring, tolower(cmdkey), value, i+1) != 0) return(0);
+			if (tcl_loadtclmsg("bind .graphics <%s-KeyPress-%c> \"domenu %ld %ld\"",
+				acceleratorstring, tolower(cmdkey), value, i+1)) return(0);
 #endif
 		}
-		if (tcl_loadtclmsg("%s", returninfstr()) != 0) return(0);
+		if (tcl_loadtclmsg("%s", returninfstr())) return(0);
 	}
 	return(thismenu);
 }
 
 /*
- * Routine to load a string into the interpreter.  Returns nonzero on error.
+ * Routine to load a string into the interpreter.  Returns true on error.
  */
-INTSML tcl_loadtclmsg(char *s, ...)
+BOOLEAN tcl_loadtclmsg(char *s, ...)
 {
 	va_list ap;
 	char line[256];
@@ -2050,9 +2185,9 @@ INTSML tcl_loadtclmsg(char *s, ...)
 	if (Tcl_VarEval(tcl_interp, line, 0) == TCL_ERROR)
 	{
 		ttyputerr(_("'%s' gave error '%s'"), line, tcl_interp->result);
-		return(1);
+		return(TRUE);
 	}
-	return(0);
+	return(FALSE);
 }
 
 /*
@@ -2061,7 +2196,8 @@ INTSML tcl_loadtclmsg(char *s, ...)
 int tcl_domenu(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 {
 	REGISTER INTBIG menu, entry;
-	INTSML j;
+	INTBIG j;
+	BOOLEAN verbose;
 	POPUPMENU *pm;
 
 	/* get input */
@@ -2076,7 +2212,7 @@ int tcl_domenu(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 #ifdef MACOS
 	if (menu == -1 && entry == -1)
 	{
-		void gra_applemenu(INTSML);
+		void gra_applemenu(INTBIG);
 
 		gra_applemenu(1);
 		return(TCL_OK);
@@ -2096,7 +2232,9 @@ int tcl_domenu(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 			setdefaultcursortype(NULLCURSOR);
 #endif
 			us_forceeditchanges();
-			us_execute(pm->list[j].response, us_tool->toolstate&ECHOBIND, 1, 1);
+			if ((us_tool->toolstate&ECHOBIND) != 0) verbose = TRUE; else
+				verbose = FALSE;
+			us_execute(pm->list[j].response, verbose, TRUE, TRUE);
 			setactivity(pm->list[j].attribute);
 		}
 	}
