@@ -30,9 +30,10 @@
 
 #include "global.h"
 #include "database.h"
+#include "network.h"
 
 /* prototypes for local routines */
-static void   db_scalefacet(NODEPROTO*, INTBIG, TECHNOLOGY**, INTBIG*, INTBIG*);
+static void   db_scalefacet(NODEPROTO*, INTBIG, TECHNOLOGY**, INTBIG*);
 static void   db_validatearcinst(ARCINST*);
 static void   db_setarcinst(ARCINST*, INTBIG, INTBIG, INTBIG, INTBIG);
 static INTBIG db_scaleunits(INTBIG *value, INTBIG num, INTBIG den);
@@ -113,19 +114,19 @@ LIBRARY *newlibrary(char *name, char *file)
 {
 	REGISTER LIBRARY *lib;
 	REGISTER char *ch, nc;
-	REGISTER INTSML renamed;
+	REGISTER BOOLEAN renamed;
 
 	/* error checks */
-	renamed = 0;
+	renamed = FALSE;
 	for(ch = name; *ch != 0; ch++)
 	{
 		nc = *ch;
 		if (nc == ' ') nc = '-';
 		if (nc == '\t' || nc == ':') nc = '-';
-		if (nc != *ch) renamed++;
+		if (nc != *ch) renamed = TRUE;
 		*ch = nc;
 	}
-	if (renamed != 0) ttyputerr(_("Warning: library renamed to '%s'"), name);
+	if (renamed) ttyputerr(_("Warning: library renamed to '%s'"), name);
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 		if (namesame(name, lib->libname) == 0)
 			return((LIBRARY *)db_error(DBBADLIB|DBNEWLIBRARY));
@@ -137,8 +138,8 @@ LIBRARY *newlibrary(char *name, char *file)
 	(void)strncpy(&lib->cluster->clustername[4], name, 25);
 
 	/* set library name and file */
-	if (allocstring(&lib->libname, name, lib->cluster) != 0) return(NOLIBRARY);
-	if (allocstring(&lib->libfile, file, lib->cluster) != 0) return(NOLIBRARY);
+	if (allocstring(&lib->libname, name, lib->cluster)) return(NOLIBRARY);
+	if (allocstring(&lib->libfile, file, lib->cluster)) return(NOLIBRARY);
 
 	/* set units */
 	lib->userbits |= (((el_units & INTERNALUNITS) >> INTERNALUNITSSH) << LIBUNITSSH);
@@ -242,7 +243,7 @@ void eraselibrary(LIBRARY *lib)
 	REGISTER PORTEXPINST *pe, *lpe;
 	REGISTER NETWORK *net, *nnet;
 	REGISTER CELL *c, *nextc;
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 
 	/* see if this library exists */
 	if (lib == NOLIBRARY) return;
@@ -262,13 +263,10 @@ void eraselibrary(LIBRARY *lib)
 		{
 			nni = ni->nextnodeinst;
 
-			/* remove nodeinst link from technology if it is primitive */
-			if (ni->proto->primindex != 0)
-			{
-				if (ni->nextinst != NONODEINST) ni->nextinst->lastinst = ni->lastinst;
-				if (ni->lastinst != NONODEINST) ni->lastinst->nextinst = ni->nextinst; else
-					ni->proto->firstinst = ni->nextinst;
-			}
+			/* remove nodeinst link */
+			if (ni->nextinst != NONODEINST) ni->nextinst->lastinst = ni->lastinst;
+			if (ni->lastinst != NONODEINST) ni->lastinst->nextinst = ni->nextinst; else
+				ni->proto->firstinst = ni->nextinst;
 
 			/* erase the portarcs on this nodeinst */
 			for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = lpo)
@@ -296,8 +294,6 @@ void eraselibrary(LIBRARY *lib)
 		}
 		for(net = np->firstnetwork; net != NONETWORK; net = nnet)
 		{
-			void net_freenetwork(NETWORK*, NODEPROTO*);
-
 			nnet = net->nextnetwork;
 			net_freenetwork(net, np);
 		}
@@ -347,6 +343,42 @@ void eraselibrary(LIBRARY *lib)
 	db_changetimestamp++;
 }
 
+/*
+ * routine to determine the appropriate library associated with the
+ * variable whose address is "addr" and type is "type".
+ */
+LIBRARY *whichlibrary(INTBIG addr, INTBIG type)
+{
+	REGISTER GEOM *geom;
+	REGISTER NODEPROTO *np;
+
+	switch (type&VTYPE)
+	{
+		case VNODEINST: return(((NODEINST *)addr)->parent->cell->lib);
+		case VNODEPROTO:
+			np = (NODEPROTO *)addr;
+			if (np->primindex == 0) return(np->cell->lib);
+			return(NOLIBRARY);
+		case VPORTARCINST:
+			return(((PORTARCINST *)addr)->conarcinst->parent->cell->lib);
+		case VPORTEXPINST:
+			return(((PORTEXPINST *)addr)->exportproto->parent->cell->lib);
+		case VPORTPROTO:
+			np = ((PORTPROTO *)addr)->parent;
+			if (np->primindex == 0) return(np->cell->lib);
+			return(NOLIBRARY);
+		case VARCINST: return(((ARCINST *)addr)->parent->cell->lib);
+		case VGEOM: geom = (GEOM *)addr;
+			if (geom->entryisnode)
+				return(geom->entryaddr.ni->parent->cell->lib);
+			return(geom->entryaddr.ai->parent->cell->lib);
+		case VLIBRARY: return((LIBRARY *)addr);
+		case VNETWORK: return(((NETWORK *)addr)->parent->cell->lib);
+		case VCELL: return(((CELL *)addr)->lib);
+	}
+	return(NOLIBRARY);
+}
+
 /****************************** LAMBDA ******************************/
 
 /*
@@ -363,6 +395,7 @@ void changelambda(INTBIG count, TECHNOLOGY **techarray, INTBIG *newlam,
 	REGISTER INTBIG *oldlam, i;
 	REGISTER NODEPROTO *np;
 	REGISTER LIBRARY *lib;
+	REGISTER TECHNOLOGY *tech;
 
 	if (how == 0)
 	{
@@ -372,11 +405,6 @@ void changelambda(INTBIG count, TECHNOLOGY **techarray, INTBIG *newlam,
 		return;
 	}
 
-	oldlam = (INTBIG *)emalloc(count * SIZEOFINTBIG, el_tempcluster);
-	if (oldlam == 0) return;
-	for(i=0; i<count; i++)
-		oldlam[i] = whichlib->lambda[techarray[i]->techindex];
-
 	/* make the technology agree with the current library */
 	for(i=0; i<count; i++)
 		changetechnologylambda(techarray[i], newlam[i]);
@@ -384,9 +412,20 @@ void changelambda(INTBIG count, TECHNOLOGY **techarray, INTBIG *newlam,
 	/* update lambda values in the libraries */
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 	{
+		lib->temp2 = 0;
 		if (how == 1 && whichlib != lib) continue;
+
+		/* preserve lambda for this library */
+		oldlam = (INTBIG *)emalloc(count * SIZEOFINTBIG, el_tempcluster);
+		if (oldlam == 0) return;
 		for(i=0; i<count; i++)
-			lib->lambda[techarray[i]->techindex] = newlam[i];
+		{
+			tech = techarray[i];
+			oldlam[i] = lib->lambda[tech->techindex];
+			lib->lambda[tech->techindex] = newlam[i];
+		}
+
+		lib->temp2 = (INTBIG)oldlam;
 	}
 
 	/* mark all facets in the library for scaling */
@@ -399,22 +438,28 @@ void changelambda(INTBIG count, TECHNOLOGY **techarray, INTBIG *newlam,
 	{
 		if (how == 1 && whichlib != lib) continue;
 		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-			db_scalefacet(np, count, techarray, newlam, oldlam);
+			db_scalefacet(np, count, techarray, newlam);
 		if (lib->firstnodeproto != NONODEPROTO)
 			lib->userbits |= LIBCHANGEDMAJOR;
 	}
-	efree((char *)oldlam);
+
+	/* free old lambda values */
+	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
+	{
+		if (how == 1 && whichlib != lib) continue;
+		efree((char *)lib->temp2);
+	}
 }
 
 /*
  * routine to recursively scale the contents of facet "np" by "newlam/oldlam"
  */
-void db_scalefacet(NODEPROTO *np, INTBIG count, TECHNOLOGY **techarray,
-	INTBIG *newlam, INTBIG *oldlam)
+void db_scalefacet(NODEPROTO *np, INTBIG count, TECHNOLOGY **techarray, INTBIG *newlamarray)
 {
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
-	REGISTER INTBIG i, *freq, bestfreq, besttechindex;
+	REGISTER VARIABLE *var;
+	REGISTER INTBIG i, *oldlamarray, *position, oldlam, newlam;
 
 	/* quit if the facet is already done */
 	if (np->temp1 != 0) return;
@@ -422,59 +467,38 @@ void db_scalefacet(NODEPROTO *np, INTBIG count, TECHNOLOGY **techarray,
 	/* first look for sub-facets that are not yet scaled */
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		if (ni->proto->primindex == 0)
-			db_scalefacet(ni->proto, count, techarray, newlam, oldlam);
+			db_scalefacet(ni->proto, count, techarray, newlamarray);
 
 	/* mark this facet "scaled" */
 	np->temp1++;
 
-	/* see if there is anything from this technology in the facet */
-	freq = (INTBIG *)emalloc(count * SIZEOFINTBIG, el_tempcluster);
-	if (freq == 0) return;
-	for(i=0; i<count; i++) freq[i] = 0;
-	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
-	{
-		for(i=0; i<count; i++)
-		{
-			if (ni->proto->tech == techarray[i])
-			{
-				freq[i]++;
-				break;
-			}
-		}
-	}
-	for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
-	{
-		for(i=0; i<count; i++)
-		{
-			if (ai->proto->tech == techarray[i])
-			{
-				freq[i]++;
-				break;
-			}
-		}
-	}
-
-	/* find the most prevalent technology in this facet */
-	bestfreq = -1;
+	/* see if this facet gets scaled */
 	for(i=0; i<count; i++)
+		if (np->tech == techarray[i]) break;
+	if (i < count)
 	{
-		if (freq[i] > bestfreq)
+		/* get the old lambda value */
+		oldlamarray = (INTBIG *)np->cell->lib->temp2;
+		if (oldlamarray == 0) return;
+		oldlam = oldlamarray[i];
+		newlam = newlamarray[i];
+
+		/* scale nodes and arcs in the facet */
+		for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+			db_scalenodeinst(ni, newlam, oldlam);
+		for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+			db_scalearcinst(ai, newlam, oldlam);
+
+		/* scale the facet and facet-center */
+		db_boundfacet(np, &np->lowx, &np->highx, &np->lowy, &np->highy);
+		var = getvalkey((INTBIG)np, VNODEPROTO, VINTEGER|VISARRAY, el_prototype_center_key);
+		if (var != NOVARIABLE)
 		{
-			bestfreq = freq[i];
-			besttechindex = i;
+			position = (INTBIG *)var->addr;
+			position[0] = muldiv(position[0], newlam, oldlam);
+			position[1] = muldiv(position[1], newlam, oldlam);
 		}
 	}
-
-	/* if the technology is present, scale the entire facet */
-	if (bestfreq > 0)
-	{
-		for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
-			db_scalenodeinst(ni, newlam[besttechindex], oldlam[besttechindex]);
-		for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
-			db_scalearcinst(ai, newlam[besttechindex], oldlam[besttechindex]);
-		db_boundfacet(np, &np->lowx, &np->highx, &np->lowy, &np->highy);
-	}
-	efree((char *)freq);
 }
 
 void db_scalenodeinst(NODEINST *ni, INTBIG newlam, INTBIG oldlam)
@@ -512,7 +536,7 @@ void db_scalenodeinst(NODEINST *ni, INTBIG newlam, INTBIG oldlam)
 		/* look for trace data on primitives */
 		ni->lowx = newlx;   ni->highx = newhx;
 		ni->lowy = newly;   ni->highy = newhy;
-		var = getvalkey((INTBIG)ni, VNODEINST, VINTEGER|VISARRAY, el_trace);
+		var = getvalkey((INTBIG)ni, VNODEINST, VINTEGER|VISARRAY, el_trace_key);
 		if (var != NOVARIABLE)
 		{
 			len = getlength(var);
@@ -538,7 +562,7 @@ void db_scalearcinst(ARCINST *ai, INTBIG newlam, INTBIG oldlam)
 	updategeom(ai->geom, ai->parent);
 
 	/* look for curvature data on primitives */
-	var = getvalkey((INTBIG)ai, VARCINST, VINTEGER, el_arc_radius);
+	var = getvalkey((INTBIG)ai, VARCINST, VINTEGER, el_arc_radius_key);
 	if (var != NOVARIABLE) var->addr = muldiv(var->addr, newlam, oldlam);
 }
 
@@ -547,32 +571,30 @@ void db_scalearcinst(ARCINST *ai, INTBIG newlam, INTBIG oldlam)
  */
 void db_validatearcinst(ARCINST *ai)
 {
-	REGISTER INTBIG wid;
-	REGISTER INTSML inside0, inside1;
-	INTBIG lx0,lx1,hx0,hx1, ly0,ly1,hy0,hy1, fx, fy, tx, ty;
+	REGISTER BOOLEAN inside0, inside1;
+	INTBIG lx0, lx1, hx0, hx1, ly0, ly1, hy0, hy1, fx, fy, tx, ty;
 	static POLYGON *poly0 = NOPOLYGON, *poly1 = NOPOLYGON;
 
-	/* if nothing is outside port, quit */
-	inside0 = db_stillinport(ai, 0, ai->end[0].xpos, ai->end[0].ypos);
-	inside1 = db_stillinport(ai, 1, ai->end[1].xpos, ai->end[1].ypos);
-	if (inside0 != 0 && inside1 != 0) return;
-
 	/* make sure there is a polygon */
 	if (poly0 == NOPOLYGON) poly0 = allocstaticpolygon(4, db_cluster);
 	if (poly1 == NOPOLYGON) poly1 = allocstaticpolygon(4, db_cluster);
 
-	/* get area of the ports */
-	wid = ai->width - arcwidthoffset(ai);
-	shapeportpoly(ai->end[0].nodeinst, ai->end[0].portarcinst->proto, poly0, 0);
-	reduceportpoly(poly0, ai->end[0].nodeinst, ai->end[0].portarcinst->proto, wid);
-	shapeportpoly(ai->end[1].nodeinst, ai->end[1].portarcinst->proto, poly1, 0);
-	reduceportpoly(poly1, ai->end[1].nodeinst, ai->end[1].portarcinst->proto, wid);
+	/* if nothing is outside port, quit */
+	fx = ai->end[0].xpos;
+	fy = ai->end[0].ypos;
+	tx = ai->end[1].xpos;
+	ty = ai->end[1].ypos;
+	shapeportpoly(ai->end[0].nodeinst, ai->end[0].portarcinst->proto, poly0, FALSE);
+	inside0 = isinside(fx, fy, poly0);
+	shapeportpoly(ai->end[1].nodeinst, ai->end[1].portarcinst->proto, poly1, FALSE);
+	inside1 = isinside(tx, ty, poly1);
+	if (inside0 && inside1) return;
 
 	/* if arcinst is not fixed-angle, run it directly to the port centers */
 	if ((ai->userbits&FIXANG) == 0)
 	{
-		getcenter(poly0, &fx, &fy);
-		getcenter(poly1, &tx, &ty);
+		if (!inside0) closestpoint(poly0, &fx, &fy);
+		if (!inside1) closestpoint(poly1, &tx, &ty);
 		db_setarcinst(ai, fx, fy, tx, ty);
 		return;
 	}
@@ -582,8 +604,8 @@ void db_validatearcinst(ARCINST *ai)
 	getbbox(poly1, &lx1, &hx1, &ly1, &hy1);
 
 	/* if fixed-angle path runs between the ports, adjust the arcinst */
-	if (arcconnects((INTSML)(((ai->userbits&AANGLE) >> AANGLESH) * 10), lx0,hx0, ly0,hy0, lx1,hx1,
-		ly1,hy1, &fx,&fy, &tx,&ty) != 0)
+	if (arcconnects(((ai->userbits&AANGLE) >> AANGLESH) * 10, lx0,hx0, ly0,hy0, lx1,hx1,
+		ly1,hy1, &fx,&fy, &tx,&ty))
 	{
 		closestpoint(poly0, &fx, &fy);
 		closestpoint(poly1, &tx, &ty);
@@ -592,8 +614,12 @@ void db_validatearcinst(ARCINST *ai)
 	}
 
 	/* give up and remove the constraint */
-	getcenter(poly0, &fx, &fy);
-	getcenter(poly1, &tx, &ty);
+	fx = ai->end[0].xpos;
+	fy = ai->end[0].ypos;
+	tx = ai->end[1].xpos;
+	ty = ai->end[1].ypos;
+	if (!inside0) closestpoint(poly0, &fx, &fy);
+	if (!inside1) closestpoint(poly1, &tx, &ty);
 	ai->userbits &= ~FIXANG;
 	db_setarcinst(ai, fx, fy, tx, ty);
 	ttyputmsg(_("Facet %s, arc %s no longer fixed-angle"),
@@ -658,7 +684,7 @@ void changeinternalunits(LIBRARY *whichlib, INTBIG oldunits, INTBIG newunits)
 {
 	REGISTER INTBIG hardscaleerror, softscaleerror, len;
 	INTBIG num, den;
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 	REGISTER char *errortype, *errorlocation;
 	REGISTER TECHNOLOGY *tech;
 	REGISTER LIBRARY *lib;
@@ -668,7 +694,6 @@ void changeinternalunits(LIBRARY *whichlib, INTBIG oldunits, INTBIG newunits)
 	REGISTER ARCINST *ai;
 	REGISTER VARIABLE *var;
 	REGISTER WINDOWPART *w;
-	extern INTBIG us_alignment, us_edgealignment;
 
 	hardscaleerror = softscaleerror = 0;
 	db_getinternalunitscale(&num, &den, oldunits, newunits);
@@ -714,13 +739,9 @@ void changeinternalunits(LIBRARY *whichlib, INTBIG oldunits, INTBIG newunits)
 			softscaleerror += db_scaleunits(&w->screenly, num, den);
 			softscaleerror += db_scaleunits(&w->screenhx, num, den);
 			softscaleerror += db_scaleunits(&w->screenhy, num, den);
-			softscaleerror += db_scaleunits(&w->gridx, num, den);
-			softscaleerror += db_scaleunits(&w->gridy, num, den);
+//			softscaleerror += db_scaleunits(&w->gridx, num, den);
+//			softscaleerror += db_scaleunits(&w->gridy, num, den);
 		}
-
-		/* scale miscellaneous factors */
-		if (us_alignment != 0) softscaleerror += db_scaleunits(&us_alignment, num, den);
-		if (us_edgealignment != 0) softscaleerror += db_scaleunits(&us_edgealignment, num, den);
 	}
 
 	/* scale all appropriate libraries */
@@ -742,7 +763,7 @@ void changeinternalunits(LIBRARY *whichlib, INTBIG oldunits, INTBIG newunits)
 				if (ni->proto->primindex != 0)
 				{
 					/* look for trace data on primitives */
-					var = getvalkey((INTBIG)ni, VNODEINST, VINTEGER|VISARRAY, el_trace);
+					var = getvalkey((INTBIG)ni, VNODEINST, VINTEGER|VISARRAY, el_trace_key);
 					if (var != NOVARIABLE)
 					{
 						len = getlength(var);
@@ -766,7 +787,7 @@ void changeinternalunits(LIBRARY *whichlib, INTBIG oldunits, INTBIG newunits)
 				updategeom(ai->geom, np);
 
 				/* look for curvature data */
-				var = getvalkey((INTBIG)ai, VARCINST, VINTEGER, el_arc_radius);
+				var = getvalkey((INTBIG)ai, VARCINST, VINTEGER, el_arc_radius_key);
 				if (var != NOVARIABLE) hardscaleerror += db_scaleunits(&var->addr, num, den);
 			}
 
