@@ -47,6 +47,10 @@
 #  define USECLUSTERS  1
 #endif
 
+#if defined(ONUNIX)                             /* WINDOW and MAC already do filling */ 
+#define FILLBYTE       0x41                     /* byte to fill emalloc memory */
+#endif
+
 /* the information bits in the header word */
 #define FREE		0			/* block is free */
 #define USED		1			/* block is in use */
@@ -73,7 +77,7 @@ CLUSTER     *db_clusterfree;	/* list of free memory clusters */
 char    *db_getmorememory(CLUSTER*, INTBIG, INTBIG);
 char    *db_getpages(INTBIG);
 void     db_coalescecluster(CLUSTER*);
-void     db_printoneclusterarena(CLUSTER*, INTSML, INTBIG*, INTBIG*, INTBIG*);
+void     db_printoneclusterarena(CLUSTER*, INTBIG, INTBIG*, INTBIG*, INTBIG*);
 #endif
 
 /* prototypes for local routines */
@@ -318,175 +322,159 @@ INTBIG *_emalloc(INTBIG amount, CLUSTER *cluster, char *file, INTBIG line)
 INTBIG *emalloc(INTBIG amount, CLUSTER *cluster)
 #endif
 {
+	REGISTER char *addr;
+#ifdef	DEBUGMEMORY
+	REGISTER INTBIG *pt, filelen, endf;
+#endif
 #ifdef	USECLUSTERS
 	REGISTER INTBIG *ptr, want, head, size, end, *nextptr, *start, atend;
-	REGISTER char *addr;
-#  ifdef DEBUGMEMORY
-	REGISTER INTBIG filelen;
-#  endif
+#endif
+
+	if (cluster == NOCLUSTER) ttyputerr(_("Warning: allocated %ld bytes from null cluster!"), amount);
 
 	/* block must be nonzero length */
 	if (amount == 0) amount = 1;
 
-	if (cluster == NOCLUSTER)
-	{
-		ttyputerr(_("Warning: allocated %ld bytes from null cluster!"), amount);
-		return((INTBIG *)LOWLEVELALLOC(amount));
-	}
-
-	/* make sure the cluster has memory */
-	if (cluster->clustersize == 0)
-	{
-		if (db_getmorememory(cluster, 1, 0) == 0) return(0);
-	}
-
 	/* block must be a word amount */
 	amount = (amount + SIZEOFINTBIG - 1) & ~(SIZEOFINTBIG - 1);
-#  ifdef DEBUGMEMORY
+#ifdef	DEBUGMEMORY
 	filelen = strlen(file);
-	for(end = filelen-1; end > 0; end--)
-		if (file[end] == DIRSEP) break;
-	if (file[end] == DIRSEP) file += end + 1;
+	for(endf = filelen-1; endf > 0; endf--)
+		if (file[endf] == DIRSEP) break;
+	if (file[endf] == DIRSEP) file += endf + 1;
 	filelen = (strlen(file)+SIZEOFINTBIG) & ~(SIZEOFINTBIG - 1);
 	amount += 4 * SIZEOFINTBIG + filelen;
-#  endif
+#endif
 
-	/* search for a block that is large enough */
-	start = ptr = (INTBIG *)cluster->address;
-	atend = 0;
-	for(;;)
+#ifdef	USECLUSTERS
+	if (cluster != NOCLUSTER)
 	{
-		/* get the head of a block in this cluster */
-		head = *ptr;
-
-		/* if the list has been completely examined with no luck, expand it */
-		if (atend != 0)
+		/* make sure the cluster has memory */
+		if (cluster->clustersize == 0)
 		{
-			/* look for a SKIP block */
-			while ((head&FLAGBITS) != SKIP)
-			{
-				ptr = (INTBIG *)(head & ~FLAGBITS);
-				head = *ptr;
-			}
-
-			/* determine the number of pages to allocate */
-			want = (amount + db_pagesize + 7) >> db_pagebits;
-
-			/* get the memory */
-			ptr = (INTBIG *)db_getmorememory(cluster, want, (INTBIG)ptr);
-			if (ptr == 0) break;
-			head = *ptr;
-
-			/* mark this cluster as "growing" */
-			cluster->flags |= CLUSTERFILLING;
+			if (db_getmorememory(cluster, 1, 0) == 0) return(0);
 		}
 
-		/* if block is not free, skip it */
-		if ((head&FLAGBITS) != FREE)
-		{
-#  ifdef DEBUGMEMORY
-			if ((head&FLAGBITS) == USED)
-				db_checkmemoryblock((char *)(&ptr[1]));
-#  endif
-			ptr = (INTBIG *)(head & ~FLAGBITS);
-			if (ptr == start) atend++;
-			continue;
-		}
-
-		/* coalesce this and any subsequent free blocks */
+		/* search for a block that is large enough */
+		start = ptr = (INTBIG *)cluster->address;
+		atend = 0;
 		for(;;)
 		{
-			nextptr = (INTBIG *)head;
+			/* get the head of a block in this cluster */
+			head = *ptr;
 
-			/* stop coalescing if the next block is not free */
-			if ((*nextptr & FLAGBITS) != FREE) break;
-
-			/* stop coalescing if there is enough memory in this area */
-			if (head - (INTBIG)ptr - (INTBIG)SIZEOFINTBIG >= amount) break;
-
-			/* if the coalesced block is the start, update start pointer */
-			if (nextptr == start)
+			/* if the list has been completely examined with no luck, expand it */
+			if (atend != 0)
 			{
-				cluster->address = *nextptr;
-				start = (INTBIG *)*nextptr;
+				/* look for a SKIP block */
+				while ((head&FLAGBITS) != SKIP)
+				{
+					ptr = (INTBIG *)(head & ~FLAGBITS);
+					head = *ptr;
+				}
+
+				/* determine the number of pages to allocate */
+				want = (amount + db_pagesize + 7) >> db_pagebits;
+
+				/* get the memory */
+				ptr = (INTBIG *)db_getmorememory(cluster, want, (INTBIG)ptr);
+				if (ptr == 0) return(0);
+				head = *ptr;
+
+				/* mark this cluster as "growing" */
+				cluster->flags |= CLUSTERFILLING;
 			}
-			head = *nextptr;
-		}
-		*ptr = head;
 
-		/* compute the size of this block */
-		size = head - (INTBIG)ptr - SIZEOFINTBIG;
+			/* if block is not free, skip it */
+			if ((head&FLAGBITS) != FREE)
+			{
+#  ifdef DEBUGMEMORY
+				if ((head&FLAGBITS) == USED)
+					db_checkmemoryblock((char *)(&ptr[1]));
+#  endif
+				ptr = (INTBIG *)(head & ~FLAGBITS);
+				if (ptr == start) atend++;
+				continue;
+			}
 
-		/* if the block is not large enough, go on to the next one */
-		if (size < amount)
-		{
-			ptr = (INTBIG *)head;
-			if (ptr == start) atend++;
+			/* coalesce this and any subsequent free blocks */
+			for(;;)
+			{
+				nextptr = (INTBIG *)head;
+
+				/* stop coalescing if the next block is not free */
+				if ((*nextptr & FLAGBITS) != FREE) break;
+
+				/* stop coalescing if there is enough memory in this area */
+				if (head - (INTBIG)ptr - (INTBIG)SIZEOFINTBIG >= amount) break;
+
+				/* if the coalesced block is the start, update start pointer */
+				if (nextptr == start)
+				{
+					cluster->address = *nextptr;
+					start = (INTBIG *)*nextptr;
+				}
+				head = *nextptr;
+			}
+			*ptr = head;
+
+			/* compute the size of this block */
+			size = head - (INTBIG)ptr - SIZEOFINTBIG;
+
+			/* if the block is not large enough, go on to the next one */
+			if (size < amount)
+			{
+				ptr = (INTBIG *)head;
+				if (ptr == start) atend++;
 
 #  if 0
-			/*
-			 * if this block is not large enough and the cluster is growing,
-			 * don't search it all, just grow the cluster more
-			 */
-			if ((cluster->flags&CLUSTERFILLING) != 0) atend++;
+				/*
+				 * if this block is not large enough and the cluster is growing,
+				 * don't search it all, just grow the cluster more
+				 */
+				if ((cluster->flags&CLUSTERFILLING) != 0) atend++;
 #  endif
-			continue;
-		}
+				continue;
+			}
 
-		/* compute the address of the returned memory */
-		addr = (char *)((INTBIG)ptr + SIZEOFINTBIG);
+			/* compute the address of the returned memory */
+			addr = (char *)((INTBIG)ptr + SIZEOFINTBIG);
 
-		/* give the entire block if the request matches close enough */
-		if (amount + (INTBIG)ROUNDUP >= size)
-		{
-			*ptr = head | USED;
-			cluster->address = (INTBIG)ptr;
-		} else
-		{
-			/* allocate a part of this block for the requested memory */
-			end = (INTBIG)addr + amount;
-			*(INTBIG *)end = *ptr;
-			*ptr = end | USED;
-			cluster->address = (INTBIG)ptr;
+			/* give the entire block if the request matches close enough */
+			if (amount + (INTBIG)ROUNDUP >= size)
+			{
+				*ptr = head | USED;
+				cluster->address = (INTBIG)ptr;
+			} else
+			{
+				/* allocate a part of this block for the requested memory */
+				end = (INTBIG)addr + amount;
+				*(INTBIG *)end = *ptr;
+				*ptr = end | USED;
+				cluster->address = (INTBIG)ptr;
+			}
+			break;
 		}
-#  ifdef DEBUGMEMORY
-		ptr = &((INTBIG *)addr)[(amount-filelen-4)/SIZEOFINTBIG-1];
-		((INTBIG *)addr)[0] = (INTBIG)ptr;
-		((INTBIG *)addr)[1] = 0xC0CEC0CE;
-		*ptr++ = 0xC0CEC0CE;
-		*ptr++ = line;
-		strcpy((char *)ptr, file);
-		addr += SIZEOFINTBIG * 2;
-#  endif
-		return((INTBIG *)addr);
+	} else 
+#endif /* USECLUSTERS */
+	{
+		addr = (char *)LOWLEVELALLOC((unsigned)amount);
+		if (addr == 0) return(0);
 	}
-	return(0);
-#else
-#  ifdef DEBUGMEMORY
-	REGISTER INTBIG *ptr, filelen, *addr;
 
-	if (amount == 0) amount = 1;
-	amount = (amount + SIZEOFINTBIG - 1) & ~(SIZEOFINTBIG - 1);
-	filelen = (strlen(file)+SIZEOFINTBIG) & ~(SIZEOFINTBIG - 1);
-	amount += 4 * SIZEOFINTBIG + filelen;
-	addr = (INTBIG *)malloc((unsigned)amount);
-	if (addr == 0) return(0);
-	ptr = &((INTBIG *)addr)[(amount-filelen-4)/SIZEOFINTBIG-1];
-	((INTBIG *)addr)[0] = (INTBIG)ptr;
-	((INTBIG *)addr)[1] = 0xC0CEC0CE;
-	*ptr++ = 0xC0CEC0CE;
-	*ptr++ = line;
-	strcpy((char *)ptr, file);
-	addr += SIZEOFINTBIG * 2;
-	return(addr);
-#  else
-	REGISTER INTBIG *addr;
-
-	if (amount == 0) amount = 1;
-	addr = (INTBIG *)LOWLEVELALLOC((unsigned)amount);
-	return(addr);
-#  endif
+#ifdef FILLBYTE
+	memset(addr, FILLBYTE, amount);
 #endif
+#ifdef DEBUGMEMORY
+	pt = &((INTBIG *)addr)[(amount-filelen-4)/SIZEOFINTBIG-1];
+	((INTBIG *)addr)[0] = (INTBIG)pt;
+	((INTBIG *)addr)[1] = 0xC0CEC0CE;
+	*pt++ = 0xC0CEC0CE;
+	*pt++ = line;
+	strcpy((char *)pt, file);
+	addr += SIZEOFINTBIG * 2;
+#endif
+	return((INTBIG *)addr);
 }
 
 /*
@@ -497,15 +485,17 @@ void efree(char *addr)
 {
 #ifdef	USECLUSTERS
 	REGISTER INTBIG *ptr;
+#endif
 
 	/* don't free null pointers */
 	if (addr == NOSTRING) return;
 
-#  ifdef DEBUGMEMORY
+#ifdef DEBUGMEMORY
 	addr -= SIZEOFINTBIG * 2;
 	db_checkmemoryblock(addr);
-#  endif
+#endif
 
+#ifdef USECLUSTERS
 	/* get header word before this block */
 	ptr = (INTBIG *)addr;
 	if ((ptr[-1]&FLAGBITS) != USED)
@@ -522,10 +512,6 @@ void efree(char *addr)
 	cluster->flags &= ~CLUSTERFILLING;
 #  endif
 #else
-#  ifdef DEBUGMEMORY
-	addr -= SIZEOFINTBIG * 2;
-	db_checkmemoryblock(addr);
-#  endif
 	free(addr);
 #endif
 }
@@ -675,7 +661,7 @@ char *db_getpages(INTBIG size)
 {
 	REGISTER char *addr;
 	REGISTER INTBIG i, j, newcount, smallest, amount;
-	REGISTER INTSML pass;
+	REGISTER INTBIG pass;
 	static INTBIG old_status = 1, old_size = 0;
 
 	/* look for spare pages in the table */
@@ -788,7 +774,7 @@ void db_printclusterarena(char *which)
 	{
 		freesize = usedsize = blocksused = 0;
 		for(clus=db_firstcluster; clus!=NOCLUSTER; clus=clus->nextcluster)
-			db_printoneclusterarena(clus, 0, &freesize, &usedsize, &blocksused);
+			db_printoneclusterarena(clus, FALSE, &freesize, &usedsize, &blocksused);
 		ttyputmsg(_("%4d blocks%8d used%8d free    TOTAL"), blocksused, usedsize, freesize);
 
 		/* print spare pages summary */
@@ -801,7 +787,7 @@ void db_printclusterarena(char *which)
 			if (namesame(which, clus->clustername) == 0)
 		{
 			db_coalescecluster(clus);
-			db_printoneclusterarena(clus, 1, &freesize, &usedsize, &blocksused);
+			db_printoneclusterarena(clus, TRUE, &freesize, &usedsize, &blocksused);
 			return;
 		}
 		ttyputmsg(_("No cluster called %s"), which);
@@ -819,7 +805,7 @@ void db_printclusterarena(char *which)
  * in the cluster; if "verbose" is negative print nothing; if "verbose" is
  * zero, print a summary only
  */
-void db_printoneclusterarena(CLUSTER *cluster, INTSML verbose, INTBIG *freesize,
+void db_printoneclusterarena(CLUSTER *cluster, INTBIG verbose, INTBIG *freesize,
 	INTBIG *usedsize, INTBIG *blocksused)
 {
 	REGISTER INTBIG addr, *ptr, value, *start, freethis, usedthis;
