@@ -32,6 +32,7 @@
 #include "database.h"
 #include "egraphics.h"
 #include "tech.h"
+#include "tecgen.h"
 #include "tecmocmos.h"
 #include "efunction.h"
 #include "usr.h"
@@ -55,7 +56,7 @@ static INTBIG tech_moscutlx, tech_moscuthx, tech_moscutly, tech_moscuthy,
 static INTBIG tech_ndisplayindex, tech_ndisplaysubindex;
 
 /* for circular arcs */
-static INTSML tech_arcpieces, tech_anglebase, tech_anglerange;
+static INTBIG tech_arcpieces, tech_anglebase, tech_anglerange;
 static INTBIG tech_centerx, tech_centery, tech_radius;
 
 static GRAPHICS tech_arrow = {LAYERO, FACETOUT, SOLIDC, SOLIDC,
@@ -63,7 +64,7 @@ static GRAPHICS tech_arrow = {LAYERO, FACETOUT, SOLIDC, SOLIDC,
 static GRAPHICS tech_vartxt = {LAYERO, FACETTXT, SOLIDC, SOLIDC,
 	{0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF}, NOVARIABLE, 0};
 
-static INTSML    tech_numvar;
+static INTBIG    tech_numvar;
 static VARIABLE *tech_firstvar;
 
 /* prototypes for local routines */
@@ -76,13 +77,12 @@ static VARIABLE *tech_filldisplayableanyvar(POLYGON *poly, INTBIG lx, INTBIG hx,
 
 /******************** GENERAL ********************/
 
-INTSML tech_doinitprocess(TECHNOLOGY *tech)
+BOOLEAN tech_doinitprocess(TECHNOLOGY *tech)
 {
 	REGISTER TECH_NODES *nty;
 	REGISTER TECH_ARCS *at;
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 	REGISTER INTBIG lam;
-	REGISTER ARCPROTO *ap;
 
 	/* calculate the true number of layers, arcprotos, and nodeprotos */
 	for(tech->layercount=0; tech->layers[tech->layercount] != NOGRAPHICS;
@@ -102,7 +102,7 @@ INTSML tech_doinitprocess(TECHNOLOGY *tech)
 		if (nty->creation == NONODEPROTO)
 		{
 			ttyputerr(_("Cannot create nodeprotos"));
-			return(1);
+			return(TRUE);
 		}
 		nty->creation->userbits = nty->initialbits;
 	}
@@ -111,23 +111,23 @@ INTSML tech_doinitprocess(TECHNOLOGY *tech)
 	for(i=0; i<tech->arcprotocount; i++)
 	{
 		at = tech->arcprotos[i];
-		ap = db_newarcproto(tech, at->arcname, at->arcwidth*lam/WHOLE, at->arcindex);
-		if (ap == NOARCPROTO)
+		at->creation = db_newarcproto(tech, at->arcname, at->arcwidth*lam/WHOLE, at->arcindex);
+		if (at->creation == NOARCPROTO)
 		{
 			ttyputerr(_("Cannot create arcproto %s in technology %s"),
 				at->arcname, tech->techname);
-			return(1);
+			return(TRUE);
 		}
-		ap->userbits = at->initialbits;
+		at->creation->userbits = at->initialbits;
 	}
-	return(0);
+	return(FALSE);
 }
 
-INTSML tech_doaddportsandvars(TECHNOLOGY *tech)
+BOOLEAN tech_doaddportsandvars(TECHNOLOGY *tech)
 {
 	REGISTER TECH_NODES *nty;
 	REGISTER NODEPROTO *np;
-	REGISTER INTSML i, j, k;
+	REGISTER INTBIG i, j, k;
 	REGISTER INTBIG pindex, *centerlist;
 	REGISTER TECH_PORTS *portinst;
 	REGISTER ARCPROTO *ap;
@@ -184,7 +184,7 @@ INTSML tech_doaddportsandvars(TECHNOLOGY *tech)
 			if (portinst[j].addr == NOPORTPROTO)
 			{
 				ttyputerr(_("Error creating ports"));
-				return(1);
+				return(TRUE);
 			}
 			portinst[j].addr->userbits = portinst[j].initialbits;
 		}
@@ -200,7 +200,7 @@ INTSML tech_doaddportsandvars(TECHNOLOGY *tech)
 			for(j=0; j<tech->variables[i].type; j++)
 			{
 				np = tech->nodeprotos[centerlist[j*3]-1]->creation;
-				(void)setvalkey((INTBIG)np, VNODEPROTO, el_prototype_center,
+				(void)setvalkey((INTBIG)np, VNODEPROTO, el_prototype_center_key,
 					(INTBIG)&centerlist[j*3+1], VINTEGER|VISARRAY|(2<<VLENGTHSH));
 			}
 			continue;
@@ -212,17 +212,17 @@ INTSML tech_doaddportsandvars(TECHNOLOGY *tech)
 			nextchangequiet();
 			if (setvalkey((INTBIG)tech, VTECHNOLOGY, makekey(tech->variables[i].name),
 				castint(tech->variables[i].fvalue), tech->variables[i].type) == NOVARIABLE)
-					return(1);
+					return(TRUE);
 			continue;
 		}
 
 		/* normal variable setting */
 		nextchangequiet();
 		if (setvalkey((INTBIG)tech, VTECHNOLOGY, makekey(tech->variables[i].name),
-			(INTBIG)tech->variables[i].value, tech->variables[i].type) == NOVARIABLE) return(1);
+			(INTBIG)tech->variables[i].value, tech->variables[i].type) == NOVARIABLE) return(TRUE);
 	}
 
-	return(0);
+	return(FALSE);
 }
 
 /*
@@ -231,7 +231,7 @@ INTSML tech_doaddportsandvars(TECHNOLOGY *tech)
  */
 void tech_convertmocmoslib(LIBRARY *lib)
 {
-	REGISTER INTSML prims;
+	REGISTER INTBIG prims;
 	REGISTER INTBIG lambda;
 	REGISTER NODEPROTO *np;
 	REGISTER ARCINST *ai;
@@ -303,7 +303,7 @@ void tech_convertmocmoslib(LIBRARY *lib)
 	for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 		if (np->firstinst == NONODEINST) db_adjusttree(np);
 
-	ttyputmsg(M_("%d S-active arcs, S-Active pins, Metal-1-S-Active"), prims);
+	ttyputmsg(M_("%ld S-active arcs, S-Active pins, Metal-1-S-Active"), prims);
 	ttyputmsg(M_("  contacts, S-Transistors, and Metal-1-Substrate"));
 	ttyputmsg(M_("  contacts from the MOSIS CMOS technology in this"));
 	ttyputmsg(M_("  library have been adjusted."));
@@ -510,7 +510,7 @@ void tech_shortenmostrans(NODEINST *ni, POLYGON *poly, TECH_POLYGON *lay, INTBIG
  */
 INTBIG tech_getextendfactor(INTBIG wid, INTBIG extend)
 {
-	static INTSML extendfactor[] = {0,
+	static INTBIG extendfactor[] = {0,
 		11459, 5729, 3819, 2864, 2290, 1908, 1635, 1430, 1271, 1143,
 		 1039,  951,  878,  814,  760,  712,  669,  631,  598,  567,
 		  540,  514,  492,  470,  451,  433,  417,  401,  387,  373,
@@ -535,21 +535,47 @@ INTBIG tech_getextendfactor(INTBIG wid, INTBIG extend)
  * routine to determine whether pin display should be supressed by counting
  * the number of arcs and seeing if there are one or two and also by seeing if
  * the node has exports (then draw it if there are three or more).
- * Returns nonzero if the pin should be supressed.  If "ap" is NOARCPROTO, then
- * any arc can be connected.  Otherwise, only count the number of arcs with
- * that type.
+ * Returns true if the pin should be supressed.  If "win" is NOWINDOWPART, then
+ * see if this node is visible in that window and include arcs connected at
+ * higher levels of hierarchy.
  */
-INTSML tech_pinusecount(NODEINST *ni, ARCPROTO *ap)
+BOOLEAN tech_pinusecount(NODEINST *ni, WINDOWPART *win)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
+	INTBIG depth;
+	REGISTER NODEINST *upni;
+	NODEINST **nilist;
 	REGISTER PORTARCINST *pi;
+	REGISTER PORTEXPINST *pe;
 
-	for (i=0, pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
-		if (ap == NOARCPROTO || pi->conarcinst->proto == ap) i++;
-	if (i > 2) return(0);
-	if (ni->firstportexpinst != NOPORTEXPINST) return(1);
-	if (i == 0) return(0);
-	return(1);
+	/* count the number of arcs on this node */
+	i = 0;
+	for (pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
+		i++;
+
+	/* if the next level up the hierarchy is visible, consider arcs connected there */
+	if (win != NOWINDOWPART && ni->firstportexpinst != NOPORTEXPINST)
+	{
+		db_gettraversalpath(&nilist, &depth);
+		if (depth == 1)
+		{
+			upni = nilist[0];
+			if (upni->proto == ni->parent && upni->parent == win->curnodeproto)
+			{
+				for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
+				{
+					for (pi = upni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
+						if (pi->proto == pe->exportproto) i++;
+				}
+			}
+		}
+	}
+
+	/* now decide whether or not to supress the pin */
+	if (i > 2) return(FALSE);
+	if (ni->firstportexpinst != NOPORTEXPINST) return(TRUE);
+	if (i == 0) return(FALSE);
+	return(TRUE);
 }
 
 /*
@@ -680,9 +706,9 @@ void tech_moscutpoly(NODEINST *ni, INTBIG cut, INTBIG descrip[])
  * style of the polygon (if trace information is used) is "sty"
  */
 void tech_fillpoly(POLYGON *poly, TECH_POLYGON *lay, NODEINST *ni, INTBIG lambda,
-	INTSML sty)
+	INTBIG sty)
 {
-	REGISTER INTSML i, lastpoint, count;
+	REGISTER INTBIG i, lastpoint, count;
 	REGISTER INTBIG x, y, *pt, xm, xs, ym, ys;
 	INTBIG minlx, minhx, minly, minhy;
 	REGISTER VARIABLE *var;
@@ -846,7 +872,7 @@ INTBIG tech_inittrans(INTBIG count, NODEINST *ni)
 void tech_filltrans(POLYGON *poly, TECH_POLYGON **lay, TECH_SERPENT *laylist,
 	NODEINST *ni, INTBIG lambda, INTBIG box, TECH_PORTS *portstruct)
 {
-	REGISTER INTSML angle, ang;
+	REGISTER INTBIG angle, ang;
 	REGISTER INTBIG thissg, next, total, segment, element, otherang;
 	REGISTER INTBIG sin, cos, xoff, yoff, thisxl, thisyl, thisxr, thisyr, lwid,
 		rwid, extend, scale, thisx, thisy, nextx, nexty, *list, nextxl, nextyl,
@@ -872,7 +898,7 @@ void tech_filltrans(POLYGON *poly, TECH_POLYGON **lay, TECH_SERPENT *laylist,
 	lwid = lambda * laylist[element].lwidth / WHOLE;
 	rwid = lambda * laylist[element].rwidth / WHOLE;
 	extend = lambda * laylist[element].extend / WHOLE;
-	varw = getvalkey((INTBIG)ni, VNODEINST, VFRACT, el_transistor_width);
+	varw = getvalkey((INTBIG)ni, VNODEINST, VFRACT, el_transistor_width_key);
 	if (varw != NOVARIABLE)
 	{
 		nodesizeoffset(ni, &x, &ly, &x, &hy);
@@ -1053,19 +1079,19 @@ void tech_filltransport(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans
 	TECH_NODES *nodedata, INTBIG diffinset, INTBIG diffextend, INTBIG defwid,
 	INTBIG polyinset, INTBIG polyextend)
 {
-	REGISTER INTSML thissg, next, angle, pangle, ang;
+	REGISTER INTBIG thissg, next, angle, pangle, ang;
 	REGISTER INTBIG sin, cos, thisx, thisy, nextx, nexty, pthisx, pthisy;
 	INTBIG *list, xoff, yoff, lambda, x, y;
-	INTSML total, which;
+	INTBIG total, which;
 	REGISTER VARIABLE *var, *varw;
 	REGISTER PORTPROTO *lpp;
 
 	/* see if the transistor has serpentine information */
-	var = getvalkey((INTBIG)ni, VNODEINST, VINTEGER|VISARRAY, el_trace);
+	var = getvalkey((INTBIG)ni, VNODEINST, VINTEGER|VISARRAY, el_trace_key);
 	if (var != NOVARIABLE)
 	{
 		/* trace data is there: make sure there are enough points */
-		total = (INTSML)getlength(var);
+		total = getlength(var);
 		if (total <= 2) var = NOVARIABLE;
 	}
 
@@ -1088,7 +1114,7 @@ void tech_filltransport(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans
 	defwid = lambda * defwid / WHOLE;
 	diffinset = lambda * diffinset / WHOLE;   diffextend = lambda * diffextend / WHOLE;
 	polyinset = lambda * polyinset / WHOLE;   polyextend = lambda * polyextend / WHOLE;
-	varw = getvalkey((INTBIG)ni, VNODEINST, VFRACT, el_transistor_width);
+	varw = getvalkey((INTBIG)ni, VNODEINST, VFRACT, el_transistor_width_key);
 	if (varw != NOVARIABLE) defwid = lambda * varw->addr / WHOLE;
 
 	/* determine which port is being described */
@@ -1203,6 +1229,13 @@ INTBIG tech_displayablenvars(NODEINST *ni, WINDOWPART *win)
 {
 	tech_numvar = ni->numvar;
 	tech_firstvar = ni->firstvar;
+	if (ni->proto == gen_invispinprim)
+	{
+		if ((us_useroptions&HIDETXTNONLAY) != 0) return(0);
+	} else
+	{
+		if ((us_useroptions&HIDETXTNODE) != 0) return(0);
+	}
 	return(tech_displayableanyvars(win, ni->parent));
 }
 
@@ -1214,14 +1247,23 @@ VARIABLE *tech_filldisplayablenvar(NODEINST *ni, POLYGON *poly, WINDOWPART *win,
 	VARIABLE **varnoeval)
 {
 	REGISTER NODEPROTO *facet;
+	REGISTER INTBIG lx, hx, ly, hy;
+	INTBIG olx, ohx, oly, ohy;
 
 	facet = ni->parent;
 	tech_numvar = ni->numvar;
 	tech_firstvar = ni->firstvar;
 	if (facet->tech == NOTECHNOLOGY)
 		facet->tech = whattech(facet);
-	return(tech_filldisplayableanyvar(poly, ni->lowx, ni->highx,
-		ni->lowy, ni->highy, (INTBIG)ni, VNODEINST, facet->tech, win, facet, varnoeval));
+	lx = ni->lowx;   hx = ni->highx;
+	ly = ni->lowy;   hy = ni->highy;
+#if 1
+	nodesizeoffset(ni, &olx, &oly, &ohx, &ohy);
+	lx += olx;   hx -= ohx;
+	ly += oly;   hy -= ohy;
+#endif
+	return(tech_filldisplayableanyvar(poly, lx, hx, ly, hy, (INTBIG)ni, VNODEINST,
+		facet->tech, win, facet, varnoeval));
 }
 
 /*
@@ -1231,6 +1273,7 @@ INTBIG tech_displayablefacetvars(NODEPROTO *np, WINDOWPART *win)
 {
 	tech_numvar = np->numvar;
 	tech_firstvar = np->firstvar;
+	if ((us_useroptions&HIDETXTFACET) != 0) return(0);
 	return(tech_displayableanyvars(win, np));
 }
 
@@ -1244,8 +1287,10 @@ VARIABLE *tech_filldisplayablefacetvar(NODEPROTO *np, POLYGON *poly, WINDOWPART
 	tech_numvar = np->numvar;
 	tech_firstvar = np->firstvar;
 	if (np->tech == NOTECHNOLOGY) np->tech = whattech(np);
-	return(tech_filldisplayableanyvar(poly, np->lowx, np->highx,
-		np->lowy, np->highy, (INTBIG)np, VNODEPROTO, np->tech, win, np, varnoeval));
+
+	/* facet variables are offset from (0,0) */
+	return(tech_filldisplayableanyvar(poly, 0, 0, 0, 0, (INTBIG)np,
+		VNODEPROTO, np->tech, win, np, varnoeval));
 }
 
 /******************** PORTINST DESCRIPTION ********************/
@@ -1257,9 +1302,9 @@ VARIABLE *tech_filldisplayablefacetvar(NODEPROTO *np, POLYGON *poly, WINDOWPART
  * If "sty" is not -1, the outline is described in trace data on the node.
  */
 void tech_fillportpoly(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans,
-	TECH_NODES *nodedata, INTSML sty)
+	TECH_NODES *nodedata, INTBIG sty)
 {
-	REGISTER INTSML i, count;
+	REGISTER INTBIG i, count;
 	REGISTER INTBIG lambda, x, y;
 	INTBIG lx, ly, hx, hy;
 	REGISTER TECH_PORTS *portdata;
@@ -1299,6 +1344,10 @@ void tech_fillportpoly(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans,
 	subrange(ni->lowy, ni->highy, portdata->lowymul, portdata->lowysum,
 		portdata->highymul, portdata->highysum, &ly, &hy, lambda);
 
+	/* clip to the size of the node */
+	if (hx < lx) lx = hx = (lx + hx) / 2;
+	if (hy < ly) ly = hy = (ly + hy) / 2;
+
 	/* transform this into the port polygon description */
 	if (poly->limit < 4) (void)extendpolygon(poly, 4);
 	xform(lx, ly, &poly->xv[0], &poly->yv[0], trans);
@@ -1311,9 +1360,10 @@ void tech_fillportpoly(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans,
 
 /*
  * routine to tell whether end "e" of arcinst "ai" would be properly connected
- * to its nodeinst if it were located at (x, y)
+ * to its nodeinst if it were located at (x, y), but considering the width of
+ * the arc as a limiting factor.
  */
-INTSML db_stillinport(ARCINST *ai, INTSML e, INTBIG x, INTBIG y)
+BOOLEAN db_stillinport(ARCINST *ai, INTBIG e, INTBIG x, INTBIG y)
 {
 	REGISTER INTBIG wid;
 	static POLYGON *poly = NOPOLYGON;
@@ -1322,13 +1372,14 @@ INTSML db_stillinport(ARCINST *ai, INTSML e, INTBIG x, INTBIG y)
 	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, db_cluster);
 
 	/* determine the area of the nodeinst */
-	shapeportpoly(ai->end[e].nodeinst, ai->end[e].portarcinst->proto, poly, 0);
+	shapeportpoly(ai->end[e].nodeinst, ai->end[e].portarcinst->proto, poly, FALSE);
 	wid = ai->width - arcwidthoffset(ai);
-	reduceportpoly(poly, ai->end[e].nodeinst, ai->end[e].portarcinst->proto, wid);
-	if (isinside(x, y, poly) != 0) return(1);
+	reduceportpoly(poly, ai->end[e].nodeinst, ai->end[e].portarcinst->proto, wid,
+		(ai->userbits&AANGLE)>>AANGLESH);
+	if (isinside(x, y, poly)) return(TRUE);
 
 	/* no good */
-	return(0);
+	return(FALSE);
 }
 
 /*
@@ -1338,6 +1389,7 @@ INTBIG tech_displayableportvars(PORTPROTO *pp, WINDOWPART *win)
 {
 	tech_numvar = pp->numvar;
 	tech_firstvar = pp->firstvar;
+	if ((us_useroptions&HIDETXTEXPORT) != 0) return(0);
 	return(tech_displayableanyvars(win, pp->parent));
 }
 
@@ -1376,9 +1428,9 @@ VARIABLE *tech_filldisplayableportvar(PORTPROTO *pp, POLYGON *poly, WINDOWPART *
  * cases, there are "total" polygons and for curved cases, the true value is
  * computed.
  */
-INTSML tech_initcurvedarc(ARCINST *ai, INTSML total)
+INTBIG tech_initcurvedarc(ARCINST *ai, INTBIG total)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 	INTBIG x1, y1, x2, y2;
 	REGISTER VARIABLE *var;
 
@@ -1386,7 +1438,7 @@ INTSML tech_initcurvedarc(ARCINST *ai, INTSML total)
 	tech_arcpieces = 0;
 
 	/* see if there is radius information on the arc */
-	var = getvalkey((INTBIG)ai, VARCINST, VINTEGER, el_arc_radius);
+	var = getvalkey((INTBIG)ai, VARCINST, VINTEGER, el_arc_radius_key);
 	if (var == NOVARIABLE) return(total);
 
 	/* get the radius of the circle, check for validity */
@@ -1395,7 +1447,7 @@ INTSML tech_initcurvedarc(ARCINST *ai, INTSML total)
 
 	/* determine the center of the circle */
 	if (findcenters(abs(tech_radius), ai->end[0].xpos, ai->end[0].ypos,
-		ai->end[1].xpos, ai->end[1].ypos, ai->length, &x1,&y1, &x2,&y2) != 0)
+		ai->end[1].xpos, ai->end[1].ypos, ai->length, &x1,&y1, &x2,&y2))
 			return(total);
 
 	if (tech_radius < 0)
@@ -1434,16 +1486,16 @@ INTSML tech_initcurvedarc(ARCINST *ai, INTSML total)
 
 /*
  * routine to generate piece "box" of curved arc "ai" and put it in "poly".
- * The arc prototype structure is in "arcprotos".  The routine returns zero
- * if successful, nonzero if the arc is not curved.
+ * The arc prototype structure is in "arcprotos".  The routine returns false
+ * if successful, true if the arc is not curved.
  */
-INTSML tech_curvedarcpiece(ARCINST *ai, INTBIG box, POLYGON *poly, TECH_ARCS **arcprotos)
+BOOLEAN tech_curvedarcpiece(ARCINST *ai, INTBIG box, POLYGON *poly, TECH_ARCS **arcprotos)
 {
-	REGISTER INTSML a;
+	REGISTER INTBIG a;
 	REGISTER INTBIG aindex, sin, cos, innerradius, outerradius, wid;
 	REGISTER TECH_ARCLAY *thista;
 
-	if (tech_arcpieces == 0) return(1);
+	if (tech_arcpieces == 0) return(TRUE);
 
 	aindex = ai->proto->arcindex;
 
@@ -1471,7 +1523,7 @@ INTSML tech_curvedarcpiece(ARCINST *ai, INTBIG box, POLYGON *poly, TECH_ARCS **a
 			poly->xv[2] = ai->end[1].xpos;
 			poly->yv[2] = ai->end[1].ypos;
 		}
-		return(0);
+		return(FALSE);
 	}
 
 	/* nonzero width arcs are described in segments */
@@ -1502,7 +1554,7 @@ INTSML tech_curvedarcpiece(ARCINST *ai, INTBIG box, POLYGON *poly, TECH_ARCS **a
 	poly->yv[2] = mult(sin, outerradius) + tech_centery;
 	poly->xv[3] = mult(cos, innerradius) + tech_centerx;
 	poly->yv[3] = mult(sin, innerradius) + tech_centery;
-	return(0);
+	return(FALSE);
 }
 
 /*
@@ -1511,11 +1563,11 @@ INTSML tech_curvedarcpiece(ARCINST *ai, INTBIG box, POLYGON *poly, TECH_ARCS **a
 void tech_makearrow(ARCINST *ai, POLYGON *poly)
 {
 	REGISTER INTBIG x1, y1, x2, y2, swap;
-	REGISTER INTSML angle;
+	REGISTER INTBIG angle;
 
 	x1 = ai->end[0].xpos;   y1 = ai->end[0].ypos;
 	x2 = ai->end[1].xpos;   y2 = ai->end[1].ypos;
-	angle = (INTSML)(((ai->userbits&AANGLE) >> AANGLESH)) * 10;
+	angle = ((ai->userbits&AANGLE) >> AANGLESH) * 10;
 	if ((ai->userbits&REVERSEEND) != 0)
 	{
 		swap = x1;   x1 = x2;   x2 = swap;
@@ -1538,20 +1590,20 @@ void tech_makearrow(ARCINST *ai, POLYGON *poly)
  * helper routine to add an arrow head to the arc in "poly", given that
  * the arc runs from (x,y) and is at an angle of "angle" tenth-degrees
  */
-void tech_addheadarrow(POLYGON *poly, INTSML angle, INTBIG x, INTBIG y, INTBIG lambda)
+void tech_addheadarrow(POLYGON *poly, INTBIG angle, INTBIG x, INTBIG y, INTBIG lambda)
 {
-	REGISTER INTSML c;
+	REGISTER INTBIG c;
 	REGISTER INTBIG dist;
 
 	c = poly->count;
-	if (poly->limit < c+4) (void)extendpolygon(poly, (INTSML)(c+4));
+	if (poly->limit < c+4) (void)extendpolygon(poly, c+4);
 	dist = K1 * lambda / WHOLE;
 	poly->xv[c] = x;    poly->yv[c] = y;   c++;
-	poly->xv[c] = x + mult(cosine((INTSML)((angle+1500) % 3600)), dist);
-	poly->yv[c] = y + mult(sine((INTSML)((angle+1500) % 3600)), dist);   c++;
+	poly->xv[c] = x + mult(cosine((angle+1500) % 3600), dist);
+	poly->yv[c] = y + mult(sine((angle+1500) % 3600), dist);   c++;
 	poly->xv[c] = x;    poly->yv[c] = y;   c++;
-	poly->xv[c] = x + mult(cosine((INTSML)((angle+2100) % 3600)), dist);
-	poly->yv[c] = y + mult(sine((INTSML)((angle+2100) % 3600)), dist);   c++;
+	poly->xv[c] = x + mult(cosine((angle+2100) % 3600), dist);
+	poly->yv[c] = y + mult(sine((angle+2100) % 3600), dist);   c++;
 	poly->count = c;
 }
 
@@ -1561,12 +1613,12 @@ void tech_addheadarrow(POLYGON *poly, INTSML angle, INTBIG x, INTBIG y, INTBIG l
  * tenth-degrees.  The body of the arc is a double-line so the end must be shortened
  * too.
  */
-void tech_adddoubleheadarrow(POLYGON *poly, INTSML angle, INTBIG *x,INTBIG *y, INTBIG width)
+void tech_adddoubleheadarrow(POLYGON *poly, INTBIG angle, INTBIG *x,INTBIG *y, INTBIG width)
 {
-	REGISTER INTSML c, a;
+	REGISTER INTBIG c, a;
 
 	c = poly->count;
-	if (poly->limit < c+4) (void)extendpolygon(poly, (INTSML)(c+4));
+	if (poly->limit < c+4) (void)extendpolygon(poly, c+4);
 	poly->xv[c] = *x;   poly->yv[c] = *y;   c++;
 	a = (angle + 1350) % 3600;
 	poly->xv[c] = *x + mult(cosine(a), width*2);
@@ -1588,22 +1640,22 @@ void tech_adddoubleheadarrow(POLYGON *poly, INTSML angle, INTBIG *x,INTBIG *y, I
  * the arc runs from (x1,y1) to (x2,y2), is "width" wide, and is at an angle
  * of "angle" tenth-degrees.
  */
-void tech_add2linebody(POLYGON *poly, INTSML angle, INTBIG x1, INTBIG y1, INTBIG x2,
+void tech_add2linebody(POLYGON *poly, INTBIG angle, INTBIG x1, INTBIG y1, INTBIG x2,
 	INTBIG y2, INTBIG width)
 {
-	REGISTER INTSML c;
+	REGISTER INTBIG c;
 	REGISTER INTBIG sin, cos;
 
 	c = poly->count;
-	if (poly->limit < c+4) (void)extendpolygon(poly, (INTSML)(c+4));
-	cos = cosine((INTSML)((angle+900) % 3600));
-	sin = sine((INTSML)((angle+900) % 3600));
+	if (poly->limit < c+4) (void)extendpolygon(poly, c+4);
+	cos = cosine((angle+900) % 3600);
+	sin = sine((angle+900) % 3600);
 	poly->xv[c] = x1 + mult(cos, width);
 	poly->yv[c] = y1 + mult(sin, width);   c++;
 	poly->xv[c] = x2 + mult(cos, width);
 	poly->yv[c] = y2 + mult(sin, width);   c++;
-	cos = cosine((INTSML)((angle+2700) % 3600));
-	sin = sine((INTSML)((angle+2700) % 3600));
+	cos = cosine((angle+2700) % 3600);
+	sin = sine((angle+2700) % 3600);
 	poly->xv[c] = x1 + mult(cos, width);
 	poly->yv[c] = y1 + mult(sin, width);   c++;
 	poly->xv[c] = x2 + mult(cos, width);
@@ -1659,8 +1711,8 @@ void tech_makeendpointpoly(INTBIG len, INTBIG wid, INTBIG angle, INTBIG x1, INTB
 	if (len == 0) len = computedistance(x1,y1, x2,y2);
 	if (len == 0)
 	{
-		sa = sine((INTSML)angle);
-		ca = cosine((INTSML)angle);
+		sa = sine(angle);
+		ca = cosine(angle);
 		xe1 = x1 - mult(ca, e1);
 		ye1 = y1 - mult(sa, e1);
 		xe2 = x2 + mult(ca, e2);
@@ -1703,6 +1755,7 @@ INTBIG tech_displayableavars(ARCINST *ai, WINDOWPART *win)
 {
 	tech_numvar = ai->numvar;
 	tech_firstvar = ai->firstvar;
+	if ((us_useroptions&HIDETXTARC) != 0) return(0);
 	return(tech_displayableanyvars(win, ai->parent));
 }
 
@@ -1735,7 +1788,6 @@ INTBIG tech_displayableanyvars(WINDOWPART *win, NODEPROTO *facet)
 {
 	REGISTER INTBIG i, total;
 	REGISTER VARIABLE *var;
-	REGISTER char *name;
 
 	tech_ndisplayindex = tech_ndisplaysubindex = total = 0;
 	if (win == NOWINDOWPART) win = el_curwindowpart;
@@ -1747,13 +1799,6 @@ INTBIG tech_displayableanyvars(WINDOWPART *win, NODEPROTO *facet)
 		{
 			if (win != NOWINDOWPART && facet != win->curnodeproto) continue;
 		}
-		if ((us_useroptions&HIDEATTRIBUTES) != 0)
-		{
-			/* see if this is an attribute variable */
-			name = makename(var->key);
-			if (namesamen(name, "attr_", 5) == 0) continue;
-			if (namesamen(name, "attrP_", 6) == 0) continue;
-		}
 		if ((var->type&VISARRAY) == 0) total++; else
 			total += getlength(var);
 	}
@@ -1768,10 +1813,9 @@ VARIABLE *tech_filldisplayableanyvar(POLYGON *poly, INTBIG lx, INTBIG hx,
 	INTBIG ly, INTBIG hy, INTBIG addr, INTBIG type, TECHNOLOGY *tech,
 		WINDOWPART *win, NODEPROTO *facet, VARIABLE **varnoeval)
 {
-	REGISTER INTBIG len, language, hidden;
+	REGISTER INTBIG len, language, whichindex;
 	UINTBIG descript[TEXTDESCRIPTSIZE];
-	REGISTER INTSML whichindex;
-	REGISTER char *query, *name;
+	REGISTER char *query;
 	REGISTER VARIABLE *var;
 	REGISTER NODEINST *ni;
 	static VARIABLE retvar;
@@ -1800,65 +1844,51 @@ VARIABLE *tech_filldisplayableanyvar(POLYGON *poly, INTBIG lx, INTBIG hx,
 			(TDGETINTERIOR(var->textdescript) == 0 || win == NOWINDOWPART ||
 				facet == win->curnodeproto))
 		{
-			hidden = 0;
-			if ((us_useroptions&HIDEATTRIBUTES) != 0)
+			TDCOPY(descript, var->textdescript);
+			language = var->type & (VCODE1|VCODE2);
+			if (language != 0)
 			{
-				/* see if this is an attribute variable */
-				name = makename(var->key);
-				if (namesamen(name, "attr_", 5) == 0) hidden = 1;
-				if (namesamen(name, "attrP_", 6) == 0) hidden = 1;
+				if ((var->type&VISARRAY) == 0) query = (char *)var->addr; else
+					query = ((char **)var->addr)[0];
+				retvar.key = var->key;
+				retvar.type = var->type & ~(VCODE1|VCODE2|VISARRAY|VLENGTH);
+				TDCOPY(retvar.textdescript, descript);
+				if (!doquerry(query, language, &retvar.type, &retvar.addr))
+					var = &retvar;
 			}
-			if (hidden == 0)
+			if ((var->type&VISARRAY) == 0)
 			{
-				TDCOPY(descript, var->textdescript);
-				if (TDGETDISPPART(descript) != VTDISPLAYNAME)
+				tech_ndisplayindex++;
+				tech_ndisplaysubindex = 0;
+				if (TDGETPOS(descript) == VTPOSBOXED)
 				{
-					language = var->type & (VCODE1|VCODE2);
-					if (language != 0)
+					makerectpoly(lx, hx, ly, hy, poly);
+					poly->style = CLOSED;
+				}
+				poly->string = describedisplayedvariable(var, -1, -1);
+				break;
+			}
+			len = getlength(var);
+			if (tech_ndisplaysubindex < len)
+			{
+				whichindex = tech_ndisplaysubindex++;
+				poly->string = describedisplayedvariable(var, whichindex, -1);
+				if (TDGETPOS(descript) == VTPOSBOXED)
+				{
+					makerectpoly(lx, hx, ly, hy, poly);
+					poly->style = CLOSED;
+				} else
+				{
+					if (type == VNODEINST)
 					{
-						if ((var->type&VISARRAY) == 0) query = (char *)var->addr; else
-							query = ((char **)var->addr)[0];
-						retvar.key = var->key;
-						retvar.type = var->type & ~(VCODE1|VCODE2|VISARRAY|VLENGTH);
-						TDCOPY(retvar.textdescript, descript);
-						if (doquerry(query, language, retvar.type, &retvar.addr) == 0)
-							var = &retvar;
+						/* multiline variables only work on nodes! */
+						ni = (NODEINST *)addr;
+						if (win == NOWINDOWPART) win = el_curwindowpart;
+						getdisparrayvarlinepos((INTBIG)ni, VNODEINST, tech, win, var,
+							whichindex, &poly->xv[0], &poly->yv[0], FALSE);
 					}
 				}
-				if ((var->type&VISARRAY) == 0)
-				{
-					tech_ndisplayindex++;
-					tech_ndisplaysubindex = 0;
-					if (TDGETPOS(descript) == VTPOSBOXED)
-					{
-						makerectpoly(lx, hx, ly, hy, poly);
-						poly->style = CLOSED;
-					}
-					poly->string = describedisplayedvariable(var, -1, -1);
-					break;
-				}
-				len = getlength(var);
-				if (tech_ndisplaysubindex < len)
-				{
-					whichindex = (INTSML)tech_ndisplaysubindex++;
-					poly->string = describedisplayedvariable(var, whichindex, -1);
-					if (TDGETPOS(descript) == VTPOSBOXED)
-					{
-						makerectpoly(lx, hx, ly, hy, poly);
-						poly->style = CLOSED;
-					} else
-					{
-						if (type == VNODEINST)
-						{
-							/* multiline variables only work on nodes! */
-							ni = (NODEINST *)addr;
-							if (win == NOWINDOWPART) win = el_curwindowpart;
-							getdisparrayvarlinepos((INTBIG)ni, VNODEINST, tech, win, var,
-								whichindex, &poly->xv[0], &poly->yv[0], 0);
-						}
-					}
-					break;
-				}
+				break;
 			}
 		}
 		tech_ndisplayindex++;
