@@ -44,7 +44,7 @@
 
 static NODEPROTO  *dr_flatignored[MAX_DRC_FLATIGNORE];
 static INTBIG      dr_index;
-static INTSML      dr_nflat_ignored = 0;
+static INTBIG      dr_nflat_ignored = 0;
 static INTBIG      dr_flat_boxcount;
 static FILE       *dr_file;
 static TECHNOLOGY *dr_maintech;
@@ -53,79 +53,77 @@ static char        dr_yminfile[132];
 static char        dr_ymaxfile[132];
 
 /* prototypes for local routines */
-static INTSML dr_readshorterrors(INTBIG);
-static void   dr_flatprint(NODEPROTO*, XARRAY);
-static void   dr_transistor_hack(POLYGON*, NODEINST*);
-static void   dr_flatdesc_poly(POLYGON*, INTBIG, XARRAY, TECHNOLOGY*, NODEPROTO*);
-static void   dr_flatprop(ARCINST*, INTBIG);
+static BOOLEAN dr_readshorterrors(INTBIG);
+static void    dr_flatprint(NODEPROTO*, XARRAY);
+static void    dr_transistor_hack(POLYGON*, NODEINST*);
+static void    dr_flatdesc_poly(POLYGON*, INTBIG, XARRAY, TECHNOLOGY*, NODEPROTO*);
+static void    dr_flatprop(ARCINST*, INTBIG);
 
 /*
  * routine to flag facet "facet" as ignorable for flat DRC
  */
-INTSML dr_flatignore(char *facet)
+void dr_flatignore(char *facet)
 {
-	INTSML i;
+	INTBIG i;
 	REGISTER NODEPROTO *np;
 
 	np = getnodeproto(facet);
 	if (np == NONODEPROTO)
 	{
 		ttyputerr(_("No facet called %s"), facet);
-		return(1);
+		return;
 	}
 	if (np->primindex != 0)
 	{
 		ttyputerr(_("Can only ignore facets, not primitives"));
-		return(1);
+		return;
 	}
 	for(i=0; i<dr_nflat_ignored; i++) if (dr_flatignored[i] == np)
-		return(0);
+		return;
 	if (dr_nflat_ignored == MAX_DRC_FLATIGNORE)
 	{
 		ttyputerr(_("Too many facets"));
-		return(1);
+		return;
 	}
 	dr_flatignored[dr_nflat_ignored++] = np;
 	ttyputmsg(_("Facet %s will be ignored from flat DRC"), describenodeproto(np));
-	return(0);
 }
 
 /*
  * routine to flag facet "facet" as not ignorable for flat DRC
  */
-INTSML dr_flatunignore(char *facet)
+void dr_flatunignore(char *facet)
 {
-	INTSML i;
+	INTBIG i;
 	REGISTER NODEPROTO *np;
 
 	np = getnodeproto(facet);
 	if (np == NONODEPROTO)
 	{
 		ttyputerr(_("No facet called %s"), facet);
-		return(1);
+		return;
 	}
 	if (np->primindex != 0)
 	{
 		ttyputerr(_("Can only unignore facets, not primitives"));
-		return(1);
+		return;
 	}
 	for(i=0; i<dr_nflat_ignored && dr_flatignored[i] != np; i++) ;
 	if (i == dr_nflat_ignored)
 	{
 		ttyputerr(_("Not being ignored"));
-		return(1);
+		return;
 	}
 	for(; i<dr_nflat_ignored; i++)
 		dr_flatignored[i-1] = dr_flatignored[i];
 	dr_nflat_ignored--;
 	ttyputmsg(_("Facet %s will be included in flat DRC"), describenodeproto(np));
-	return(0);
 }
 
-INTSML dr_flatwrite(NODEPROTO *simnp)
+void dr_flatwrite(NODEPROTO *simnp)
 {
 	REGISTER INTBIG dr_process, save1, save2;
-	REGISTER INTSML ret=1;
+	REGISTER BOOLEAN ret = TRUE;
 	REGISTER PORTPROTO *pp, *spp;
 	REGISTER TECHNOLOGY *tech;
 	REGISTER VARIABLE *var;
@@ -136,7 +134,7 @@ INTSML dr_flatwrite(NODEPROTO *simnp)
 	if (simnp == NONODEPROTO)
 	{
 		ttyputerr(_("No facet to flatten for DRC"));
-		return(1);
+		return;
 	}
 	dr_maintech = simnp->tech;
 
@@ -155,7 +153,7 @@ INTSML dr_flatwrite(NODEPROTO *simnp)
 	if (dr_file == NULL)
 	{
 		ttyputerr(_("Cannot write %s"), dr_flatdrcfile);
-		return(1);
+		return;
 	}
 	ttyputmsg(_("Writing flattened %s circuit into '%s'..."),
 		dr_maintech->techname, dr_flatdrcfile);
@@ -192,13 +190,13 @@ INTSML dr_flatwrite(NODEPROTO *simnp)
 	/* clean up the file */
 	xclose(dr_file);
 
-	if (stopping(STOPREASONDRC)) return(0);
+	if (stopping(STOPREASONDRC)) return;
 
 	/* no point continuing if nothing to do */
 	if (dr_flat_boxcount == 0)
 	{
 		ttyputmsg(_("No boxes written, DRC short detection complete"));
-		return(0);
+		return;
 	}
 
 	/* setup communication with fast short finding program */
@@ -208,7 +206,7 @@ INTSML dr_flatwrite(NODEPROTO *simnp)
 	if (dr_process == 1)
 	{
 		ttyputerr(_("Shortcheck cannot run on this machine"));
-		return(0);
+		return;
 	}
 	if (dr_process == 0)
 	{
@@ -227,7 +225,7 @@ INTSML dr_flatwrite(NODEPROTO *simnp)
 		channelrestore(1, save1);
 		channelrestore(2, save2);
 		ttyputerr(_("Cannot run fast short detection"));
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 
 	/* close the file descriptor so the pipe will terminate when done */
@@ -240,10 +238,10 @@ INTSML dr_flatwrite(NODEPROTO *simnp)
 	ewait(dr_process);
 
 	/* if this program ran correctly, stop now */
-	if (ret == 0)
+	if (!ret)
 	{
 		ttyputmsg(_("DRC short detection complete"));
-		return(0);
+		return;
 	}
 
 	/* setup for slow short detection */
@@ -310,10 +308,9 @@ INTSML dr_flatwrite(NODEPROTO *simnp)
 	ekill(dr_process);
 	ewait(dr_process);
 	ttyputmsg(_("DRC short detection complete"));
-	return(0);
 }
 
-INTSML dr_readshorterrors(INTBIG where)
+BOOLEAN dr_readshorterrors(INTBIG where)
 {
 	REGISTER char *ptr, *layname;
 	REGISTER INTBIG i, errors, lx, hx, ly, hy;
@@ -333,7 +330,7 @@ INTSML dr_readshorterrors(INTBIG where)
 			*ptr = 0;
 
 			/* special case to detect failure of fast short program */
-			if (strcmp(line, _("Out of space")) == 0) return(1);
+			if (strcmp(line, _("Out of space")) == 0) return(TRUE);
 
 			if (line[0] == 'L')
 			{
@@ -365,7 +362,7 @@ INTSML dr_readshorterrors(INTBIG where)
 		}
 		ptr++;
 	}
-	return(0);
+	return(FALSE);
 }
 
 /*
@@ -484,7 +481,7 @@ void dr_flatprint(NODEPROTO *facet, XARRAY mytrans)
 			transmult(temptrans1, mytrans, temptrans2);
 			maketrans(ni, temptrans1);
 			transmult(temptrans1, temptrans2, subtrans);
-			downhierarchy(ni);
+			downhierarchy(ni, 0);
 			dr_flatprint(ni->proto, subtrans);
 			uphierarchy();
 		}
@@ -517,11 +514,11 @@ void dr_transistor_hack(POLYGON *poly, NODEINST *ni)
 {
 	REGISTER PORTPROTO *pp, *spp;
 	REGISTER PORTARCINST *pi, *spi;
-	REGISTER INTSML drain, portnum, type;
+	REGISTER INTBIG drain, portnum, type;
 	INTBIG edge;
 	REGISTER TECH_NODES *thistn;
 
-	type = (INTSML)((ni->proto->userbits&NFUNCTION) >> NFUNCTIONSH);
+	type = (ni->proto->userbits&NFUNCTION) >> NFUNCTIONSH;
 	if (!(type == NPTRANMOS || type == NPTRADMOS || type == NPTRAPMOS ||
 		type == NPTRANS)) return;
 
@@ -550,11 +547,11 @@ void dr_transistor_hack(POLYGON *poly, NODEINST *ni)
 		else spi = pi->conarcinst->end[0].portarcinst;
 
 	/* spi contains other port arc inst.  See if it is a transistor. */
-	type = (INTSML)((spi->proto->parent->userbits&NFUNCTION) >> NFUNCTIONSH);
+	type = (spi->proto->parent->userbits&NFUNCTION) >> NFUNCTIONSH;
 	if (type == NPTRANMOS || type == NPTRADMOS || type == NPTRAPMOS || type == NPTRANS)
 	{
 		/* Spacing needs adjusting when active width is greater than gate distance. */
-		REGISTER INTSML i, gate_min_distance, active_overlap;
+		REGISTER INTBIG i, gate_min_distance, active_overlap;
 		REGISTER INTBIG lambda, correction;
 		REGISTER TECH_SERPENT *st;
 		REGISTER TECH_POLYGON *lay;
@@ -566,8 +563,8 @@ void dr_transistor_hack(POLYGON *poly, NODEINST *ni)
 		st = &thistn->ele[i];
 		active_overlap = st->lwidth + st->rwidth;
 		i=0; do lay = &thistn->ele[i++].basics; while (lay->portnum != 0);
-		gate_min_distance = (INTSML)drcmindistance(ni->proto->tech, ni->parent->cell->lib,
-			lay->layernum, 0, lay->layernum, 0, 0, 0, &edge, 0);
+		gate_min_distance = drcmindistance(ni->proto->tech, ni->parent->cell->lib,
+			lay->layernum, 0, lay->layernum, 0, FALSE, FALSE, &edge, 0);
 		if (active_overlap > gate_min_distance)
 		{
 			correction = ((active_overlap - gate_min_distance) / WHOLE) * lambda;
@@ -619,7 +616,7 @@ void dr_flatdesc_poly(POLYGON *poly, INTBIG net, XARRAY trans, TECHNOLOGY *tech,
 {
 	INTBIG lx, hx, ly, hy, lxb, hxb, lyb, hyb;
 	REGISTER INTBIG xv, yv;
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 
 	/* ignore layers that have no valid CIF */
 	if (poly->layer < 0 || tech->temp1 == 0) return;
@@ -630,7 +627,7 @@ void dr_flatdesc_poly(POLYGON *poly, INTBIG net, XARRAY trans, TECHNOLOGY *tech,
 
 	xformpoly(poly, trans);
 	getbbox(poly, &lxb, &hxb, &lyb, &hyb);
-	if (isbox(poly, &lx, &hx, &ly, &hy) == 0)
+	if (!isbox(poly, &lx, &hx, &ly, &hy))
 	{
 		/* not a rectangle, but are all coordinates either high or low? */
 		xv = yv = 0;
@@ -648,7 +645,7 @@ void dr_flatdesc_poly(POLYGON *poly, INTBIG net, XARRAY trans, TECHNOLOGY *tech,
 	/* ignore zero or negative sizes */
 	if ((hy - ly) > 0 && (hx - lx) > 0)
 	{
-		xprintf(dr_file, "%ld %ld %ld %ld %d %ld\n", ly, hy, lx, hx, poly->layer, net);
+		xprintf(dr_file, "%ld %ld %ld %ld %ld %ld\n", ly, hy, lx, hx, poly->layer, net);
 		dr_flat_boxcount++;
 	}
 }
@@ -662,7 +659,7 @@ void dr_flatprop(ARCINST *ai, INTBIG nindex)
 	REGISTER ARCINST *oai;
 	REGISTER NODEINST *ni;
 	REGISTER PORTARCINST *pi;
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 
 	/* set this arcinst to the current node number */
 	ai->temp2 = nindex;
