@@ -64,63 +64,60 @@ BEGIN_MESSAGE_MAP(CElectricApp, CWinApp)
 END_MESSAGE_MAP()
 
 /////////////////////////////////////////////////////////////////////////////
-// CElectricApp construction
+/* CElectricApp construction */
 
 CElectricApp::CElectricApp()
 {
-	// Place all significant initialization in InitInstance
+	/* Place all significant initialization in InitInstance */
 }
 
 /////////////////////////////////////////////////////////////////////////////
-// The one and only CElectricApp object
+/* The one and only CElectricApp object */
 
 CElectricApp theApp;
 
 /////////////////////////////////////////////////////////////////////////////
-// CElectricApp initialization
+/* CElectricApp initialization */
 
 BOOL CElectricApp::InitInstance()
 {
-	// Standard initialization
-	// If you are not using these features and wish to reduce the size
-	//  of your final executable, you should remove from the following
-	//  the specific initialization routines you do not need.
-
+	/* turn off memory debugging */
 #ifdef _DEBUG
-	// turn off memory debugging
 	AfxEnableMemoryTracking(false);
 #endif
 
+	/* call this when using MFC in a shared DLL */
 #ifdef _AFXDLL
-	Enable3dControls();			// Call this when using MFC in a shared DLL
+	Enable3dControls();
 #else
-	// I don't know why, but when linking statically to MFC, Electric
-	// still calls the dynamic destructor on exit.  Therefore, if the
-	// static version of the enabler is called, the dynamic destructor
-	// crashes.  Therefore, Electric calls the dynamic version always.
 
+	/*
+	 * I don't know why, but when linking statically to MFC, Electric
+	 * still calls the dynamic destructor on exit.  Therefore, if the
+	 * static version of the enabler is called, the dynamic destructor
+	 * crashes.  Therefore, Electric calls the dynamic version always.
+	 */
 //	Enable3dControlsStatic();	// Call this when linking to MFC statically
 	Enable3dControls();			// Call this when using MFC in a shared DLL
 #endif
 
-	// Change the registry key under which our settings are stored.
-	// You should modify this string to be something appropriate
-	// such as the name of your company or organization.
+	/* change the registry key under which our settings are stored */
 	SetRegistryKey(_T("Static-Free-Software"));
 
-	LoadStdProfileSettings();  // Load standard INI file options (including MRU)
+	/* load standard INI file options (including MRU) */
+	LoadStdProfileSettings();
 
-	// Register the application's document templates.  Document templates
-	//  serve as the connection between documents, frame windows and views.
+	/* register the application's document templates.  Document templates */
+	/*  serve as the connection between documents, frame windows and views. */
 	CMultiDocTemplate* pDocTemplate;
 	pDocTemplate = new CMultiDocTemplate(
 		IDR_ELECTRTYPE,
 		RUNTIME_CLASS(CElectricDoc),
-		RUNTIME_CLASS(CChildFrame), // custom MDI child frame
+		RUNTIME_CLASS(CChildFrame), /* custom MDI child frame */
 		RUNTIME_CLASS(CElectricView));
 	AddDocTemplate(pDocTemplate);
 
-	// create main MDI Frame window
+	/* create main MDI Frame window */
 	CMainFrame* pMainFrame = new CMainFrame;
 	if (!pMainFrame->LoadFrame(IDR_MAINFRAME))
 		return FALSE;
@@ -130,29 +127,78 @@ BOOL CElectricApp::InitInstance()
 //	CMainFrame *wnd = (CMainFrame *)AfxGetMainWnd();
 //	wnd->SetWindowText("Daughter of Electric");
 
-	// Enable drag/drop open
+	/* enable drag/drop open */
 	m_pMainWnd->DragAcceptFiles();
 
-	// Enable DDE Execute open
+	/* enable DDE Execute open */
 	EnableShellOpen();
 	RegisterShellFileTypes(TRUE);
 
-	// Parse command line for standard shell commands, DDE, file open
+	/* parse command line for standard shell commands, DDE, file open */
 	CCommandLineInfo cmdInfo;
 	ParseCommandLine(cmdInfo);
 
-	// Dispatch commands specified on the command line
+	/* dispatch commands specified on the command line */
 	if (!ProcessShellCommand(cmdInfo))
 		return FALSE;
 
-	// The main window has been initialized, so show and update it.
+	/* get former location of Electric window (presume maximized if nothing saved) */
+	char *pt, tmp[256], subkey[256], value[256];
+	WINDOWPLACEMENT wndpl;
+	int top, left, bottom, right, fullscreen;
+	INTBIG gra_getregistry(HKEY key, char *subkey, char *value, char *result);
+	pMainFrame->GetWindowPlacement(&wndpl);
+	strcpy(subkey, "Software\\Static Free Software\\Electric");
+	strcpy(value, "Window_Location");
+	if (gra_getregistry(HKEY_LOCAL_MACHINE, subkey, value, tmp) == 0)
+	{
+		/* key has the format: T,L,B,R,MAX */
+		pt = tmp;
+		top = atoi(pt);
+		while(*pt != ',' && *pt != 0) pt++;
+		if (*pt == ',')
+		{
+			pt++;
+			left = atoi(pt);
+			while(*pt != ',' && *pt != 0) pt++;
+			if (*pt == ',')
+			{
+				pt++;
+				bottom = atoi(pt);
+				while(*pt != ',' && *pt != 0) pt++;
+				if (*pt == ',')
+				{
+					pt++;
+					right = atoi(pt);
+					while(*pt != ',' && *pt != 0) pt++;
+					if (*pt == ',')
+					{
+						pt++;
+						fullscreen = atoi(pt);
+					}
+				}
+			}
+		}
+	} else
+	{
+		/* nothing in the key: just maximize the window */
+		fullscreen = SW_SHOWMAXIMIZED;
+	}
+
+	/* the main window has been initialized, so show and update it */
 	pMainFrame->ShowWindow(m_nCmdShow);
 	pMainFrame->UpdateWindow();
 
-	// make the main window be maximized
-	WINDOWPLACEMENT wndpl;
+	/* place the main window location as remembered */
 	pMainFrame->GetWindowPlacement(&wndpl);
-	wndpl.showCmd = SW_SHOWMAXIMIZED;
+	wndpl.showCmd = fullscreen;
+	if (wndpl.showCmd != SW_SHOWMAXIMIZED)
+	{
+		wndpl.rcNormalPosition.top = top;
+		wndpl.rcNormalPosition.left = left;
+		wndpl.rcNormalPosition.bottom = bottom;
+		wndpl.rcNormalPosition.right = right;
+	}
 	pMainFrame->SetWindowPlacement(&wndpl);
 
 	/* primary initialization of Electric */
@@ -165,7 +211,7 @@ BOOL CElectricApp::InitInstance()
 #endif
 
 	/* secondary initialization of Electric */
-	INTSML argc;
+	INTBIG argc;
 	char *argv[4];
 	argc = 1;
 	argv[0] = "electric";
@@ -219,7 +265,7 @@ BEGIN_MESSAGE_MAP(CAboutDlg, CDialog)
 	//}}AFX_MSG_MAP
 END_MESSAGE_MAP()
 
-// App command to run the dialog
+/* App command to run the dialog */
 void CElectricApp::OnAppAbout()
 {
 	CAboutDlg aboutDlg;
@@ -227,21 +273,21 @@ void CElectricApp::OnAppAbout()
 }
 
 /////////////////////////////////////////////////////////////////////////////
-// CElectricApp commands
+/* CElectricApp commands */
 
 void CElectricApp::OnFileNew()
 {
 }
 
-INTBIG el_inslice = 0;
+BOOLEAN el_inslice = FALSE;
 
 BOOL CElectricApp::OnIdle(LONG lCount)
 {
-	if (el_inslice == 0)
+	if (!el_inslice)
 	{
-		el_inslice = 1;
+		el_inslice = TRUE;
 		tooltimeslice();
-		el_inslice = 0;
+		el_inslice = FALSE;
 	}
 
 	return CWinApp::OnIdle(lCount);
