@@ -41,7 +41,7 @@ static char THIS_FILE[] = __FILE__;
 #endif
 
 /////////////////////////////////////////////////////////////////////////////
-// CChildFrame
+/* CChildFrame */
 
 IMPLEMENT_DYNCREATE(CChildFrame, CMDIChildWnd)
 
@@ -70,7 +70,7 @@ BEGIN_MESSAGE_MAP(CChildFrame, CMDIChildWnd)
 END_MESSAGE_MAP()
 
 /////////////////////////////////////////////////////////////////////////////
-// CChildFrame construction/destruction
+/* CChildFrame construction/destruction */
 
 CChildFrame::CChildFrame()
 {
@@ -91,7 +91,7 @@ BOOL CChildFrame::PreCreateWindow(CREATESTRUCT& cs)
 }
 
 /////////////////////////////////////////////////////////////////////////////
-// CChildFrame diagnostics
+/* CChildFrame diagnostics */
 
 #ifdef _DEBUG
 void CChildFrame::AssertValid() const
@@ -104,15 +104,15 @@ void CChildFrame::Dump(CDumpContext& dc) const
 	CMDIChildWnd::Dump(dc);
 }
 
-#endif //_DEBUG
+#endif
 
 /////////////////////////////////////////////////////////////////////////////
-// CChildFrame message handlers
+/* CChildFrame message handlers */
 
 void gra_buttonaction(int state, UINT nFlags, CPoint point, CWnd *frm);
 void gra_mouseaction(UINT nFlags, CPoint point, CWnd *frm);
 void gra_mousewheelaction(UINT nFlags, short zDelta, CPoint point, CWnd *frm);
-void gra_keyaction(UINT nChar, UINT nFlags, UINT nRepCnt);
+void gra_keyaction(UINT nChar, INTBIG special, UINT nRepCnt);
 void gra_repaint(CChildFrame *frame, CPaintDC *dc);
 void gra_resize(CChildFrame *frame, int cx, int cy);
 int  gra_closeframe(CChildFrame *frame);
@@ -185,11 +185,11 @@ BOOL CChildFrame::OnMouseWheel(UINT nFlags, short zDelta, CPoint point)
 
 void CChildFrame::OnPaint()
 {
-	CPaintDC dc(this); // device context for painting
+	CPaintDC dc(this); /* device context for painting */
 
 	gra_repaint(this, &dc);
 
-	// Do not call CMDIChildWnd::OnPaint() for painting messages
+	/* Do not call CMDIChildWnd::OnPaint() for painting messages */
 }
 
 void CChildFrame::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags)
@@ -205,7 +205,7 @@ void CChildFrame::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags)
 			return;
 		}
 	}
-	gra_keyaction(nChar, nFlags, nRepCnt);
+	gra_keyaction(nChar, 0, nRepCnt);
 }
 
 void CChildFrame::OnSize(UINT nType, int cx, int cy)
@@ -238,96 +238,71 @@ void CChildFrame::OnMDIActivate(BOOL bActivate, CWnd* pActivateWnd, CWnd* pDeact
 
 void CChildFrame::OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags)
 {
-	int controlkeydown, shiftkeydown;
+	INTBIG special;
 
 	/* handle numeric keypad with control key pressed */
-	if ((GetKeyState(VK_CONTROL) & 0x8000) != 0) controlkeydown = 1; else
-		controlkeydown = 0;
-	if ((GetKeyState(VK_SHIFT) & 0x8000) != 0) shiftkeydown = 2; else
-		shiftkeydown = 0;
+	special = 0;
+	if ((GetKeyState(VK_CONTROL) & 0x8000) != 0) special |= ACCELERATORDOWN;
+	if ((GetKeyState(VK_SHIFT) & 0x8000) != 0) special |= SHIFTDOWN;
 
 	/* handle function keys */
-	if (nChar == VK_F1) { gra_keyaction(FUNCTIONF1, nFlags, nRepCnt); return; }
-	if (nChar == VK_F2) { gra_keyaction(FUNCTIONF2, nFlags, nRepCnt); return; }
-	if (nChar == VK_F3) { gra_keyaction(FUNCTIONF3, nFlags, nRepCnt); return; }
-	if (nChar == VK_F4) { gra_keyaction(FUNCTIONF4, nFlags, nRepCnt); return; }
-	if (nChar == VK_F5) { gra_keyaction(FUNCTIONF5, nFlags, nRepCnt); return; }
-	if (nChar == VK_F6) { gra_keyaction(FUNCTIONF6, nFlags, nRepCnt); return; }
-	if (nChar == VK_F7) { gra_keyaction(FUNCTIONF7, nFlags, nRepCnt); return; }
-	if (nChar == VK_F8) { gra_keyaction(FUNCTIONF8, nFlags, nRepCnt); return; }
-	if (nChar == VK_F9) { gra_keyaction(FUNCTIONF9, nFlags, nRepCnt); return; }
-	if (nChar == VK_F10) { gra_keyaction(FUNCTIONF10, nFlags, nRepCnt); return; }
-	if (nChar == VK_F11) { gra_keyaction(FUNCTIONF11, nFlags, nRepCnt); return; }
-	if (nChar == VK_F12) { gra_keyaction(FUNCTIONF12, nFlags, nRepCnt); return; }
+	if (nChar == VK_F1)  { gra_keyaction(0, SPECIALKEYDOWN|(SPECIALKEYF1 <<SPECIALKEYSH), nRepCnt); return; }
+	if (nChar == VK_F2)  { gra_keyaction(0, SPECIALKEYDOWN|(SPECIALKEYF2 <<SPECIALKEYSH), nRepCnt); return; }
+	if (nChar == VK_F3)  { gra_keyaction(0, SPECIALKEYDOWN|(SPECIALKEYF3 <<SPECIALKEYSH), nRepCnt); return; }
+	if (nChar == VK_F4)  { gra_keyaction(0, SPECIALKEYDOWN|(SPECIALKEYF4 <<SPECIALKEYSH), nRepCnt); return; }
+	if (nChar == VK_F5)  { gra_keyaction(0, SPECIALKEYDOWN|(SPECIALKEYF5 <<SPECIALKEYSH), nRepCnt); return; }
+	if (nChar == VK_F6)  { gra_keyaction(0, SPECIALKEYDOWN|(SPECIALKEYF6 <<SPECIALKEYSH), nRepCnt); return; }
+	if (nChar == VK_F7)  { gra_keyaction(0, SPECIALKEYDOWN|(SPECIALKEYF7 <<SPECIALKEYSH), nRepCnt); return; }
+	if (nChar == VK_F8)  { gra_keyaction(0, SPECIALKEYDOWN|(SPECIALKEYF8 <<SPECIALKEYSH), nRepCnt); return; }
+	if (nChar == VK_F9)  { gra_keyaction(0, SPECIALKEYDOWN|(SPECIALKEYF9 <<SPECIALKEYSH), nRepCnt); return; }
+	if (nChar == VK_F10) { gra_keyaction(0, SPECIALKEYDOWN|(SPECIALKEYF10<<SPECIALKEYSH), nRepCnt); return; }
+	if (nChar == VK_F11) { gra_keyaction(0, SPECIALKEYDOWN|(SPECIALKEYF11<<SPECIALKEYSH), nRepCnt); return; }
+	if (nChar == VK_F12) { gra_keyaction(0, SPECIALKEYDOWN|(SPECIALKEYF12<<SPECIALKEYSH), nRepCnt); return; }
 
 	/* handle control keys */
-	if (controlkeydown != 0)
+	if ((special&ACCELERATORDOWN) != 0)
 	{
 		if (nChar == VK_NUMPAD0)
-			{ gra_keyaction('0'+0200, nFlags, nRepCnt); return; }
+			{ gra_keyaction('0', special, nRepCnt); return; }
 		if (nChar == VK_NUMPAD1)
-			{ gra_keyaction('1'+0200, nFlags, nRepCnt); return; }
+			{ gra_keyaction('1', special, nRepCnt); return; }
 		if (nChar == VK_NUMPAD2)
-			{ gra_keyaction('2'+0200, nFlags, nRepCnt); return; }
+			{ gra_keyaction('2', special, nRepCnt); return; }
 		if (nChar == VK_NUMPAD3)
-			{ gra_keyaction('3'+0200, nFlags, nRepCnt); return; }
+			{ gra_keyaction('3', special, nRepCnt); return; }
 		if (nChar == VK_NUMPAD4)
-			{ gra_keyaction('4'+0200, nFlags, nRepCnt); return; }
+			{ gra_keyaction('4', special, nRepCnt); return; }
 		if (nChar == VK_NUMPAD5)
-			{ gra_keyaction('5'+0200, nFlags, nRepCnt); return; }
+			{ gra_keyaction('5', special, nRepCnt); return; }
 		if (nChar == VK_NUMPAD6)
-			{ gra_keyaction('6'+0200, nFlags, nRepCnt); return; }
+			{ gra_keyaction('6', special, nRepCnt); return; }
 		if (nChar == VK_NUMPAD7)
-			{ gra_keyaction('7'+0200, nFlags, nRepCnt); return; }
+			{ gra_keyaction('7', special, nRepCnt); return; }
 		if (nChar == VK_NUMPAD8)
-			{ gra_keyaction('8'+0200, nFlags, nRepCnt); return; }
+			{ gra_keyaction('8', special, nRepCnt); return; }
 		if (nChar == VK_NUMPAD9)
-			{ gra_keyaction('9'+0200, nFlags, nRepCnt); return; }
+			{ gra_keyaction('9', special, nRepCnt); return; }
 	}
 
 	if ((nFlags&0x100) != 0)
 	{
 		if (nChar == VK_DELETE)
-			gra_keyaction(DELETEKEY, nFlags, nRepCnt);
+			gra_keyaction(DELETEKEY, 0, nRepCnt);
 		if (nChar == VK_UP)
 		{
-			switch (controlkeydown+shiftkeydown)
-			{
-				case 0: gra_keyaction( 036, nFlags, nRepCnt);   break;
-				case 1: gra_keyaction(0236, nFlags, nRepCnt);   break;
-				case 2: gra_keyaction(  06, nFlags, nRepCnt);   break;
-				case 3: gra_keyaction(0206, nFlags, nRepCnt);   break;
-			}
+			gra_keyaction(0, SPECIALKEYDOWN|(SPECIALKEYARROWU<<SPECIALKEYSH)|special, nRepCnt);
 		}
 		if (nChar == VK_DOWN)
 		{
-			switch (controlkeydown+shiftkeydown)
-			{
-				case 0: gra_keyaction( 037, nFlags, nRepCnt);   break;
-				case 1: gra_keyaction(0237, nFlags, nRepCnt);   break;
-				case 2: gra_keyaction(  07, nFlags, nRepCnt);   break;
-				case 3: gra_keyaction(0207, nFlags, nRepCnt);   break;
-			}
+			gra_keyaction(0, SPECIALKEYDOWN|(SPECIALKEYARROWD<<SPECIALKEYSH)|special, nRepCnt);
 		}
 		if (nChar == VK_RIGHT)
 		{
-			switch (controlkeydown+shiftkeydown)
-			{
-				case 0: gra_keyaction( 035, nFlags, nRepCnt);   break;
-				case 1: gra_keyaction(0235, nFlags, nRepCnt);   break;
-				case 2: gra_keyaction(  05, nFlags, nRepCnt);   break;
-				case 3: gra_keyaction(0205, nFlags, nRepCnt);   break;
-			}
+			gra_keyaction(0, SPECIALKEYDOWN|(SPECIALKEYARROWR<<SPECIALKEYSH)|special, nRepCnt);
 		}
 		if (nChar == VK_LEFT)
 		{
-			switch (controlkeydown+shiftkeydown)
-			{
-				case 0: gra_keyaction( 034, nFlags, nRepCnt);   break;
-				case 1: gra_keyaction(0234, nFlags, nRepCnt);   break;
-				case 2: gra_keyaction(  02, nFlags, nRepCnt);   break;
-				case 3: gra_keyaction(0202, nFlags, nRepCnt);   break;
-			}
+			gra_keyaction(0, SPECIALKEYDOWN|(SPECIALKEYARROWL<<SPECIALKEYSH)|special, nRepCnt);
 		}
 	}
 	CMDIChildWnd::OnKeyDown(nChar, nRepCnt, nFlags);
