@@ -39,7 +39,7 @@ static char THIS_FILE[] = __FILE__;
 #endif
 
 /////////////////////////////////////////////////////////////////////////////
-// CElectricDialog dialog
+/* CElectricDialog dialog */
 
 
 CElectricDialog::CElectricDialog(CWnd* pParent /*=NULL*/)
@@ -189,14 +189,15 @@ BEGIN_MESSAGE_MAP(CElectricDialog, CDialog)
 	ON_WM_LBUTTONDOWN()
 	ON_WM_LBUTTONUP()
 	ON_WM_VKEYTOITEM()
+	ON_WM_LBUTTONDBLCLK()
 	//}}AFX_MSG_MAP
 END_MESSAGE_MAP()
 
 /////////////////////////////////////////////////////////////////////////////
-// CElectricDialog message handlers
+/* CElectricDialog message handlers */
 void gra_itemclicked(int nID);
 void gra_itemdoubleclicked(int nID);
-void gra_diaredrawitem(void);
+void gra_diaredrawitem(CElectricDialog*);
 void gra_dodialogtextchange(int nID);
 void gra_buttonaction(int state, UINT nFlags, CPoint point, CWnd *frm);
 void gra_mouseaction(UINT nFlags, CPoint point, CWnd *frm);
@@ -371,9 +372,9 @@ void CElectricDialog::OnDialogTextChanged60() { gra_dodialogtextchange(60); }
 
 void CElectricDialog::OnPaint()
 {
-	CPaintDC dc(this); // device context for painting
+	CPaintDC dc(this); /* device context for painting */
 
-	gra_diaredrawitem();
+	gra_diaredrawitem(this);
 }
 
 void CElectricDialog::OnMouseMove(UINT nFlags, CPoint point)
@@ -399,3 +400,9 @@ int CElectricDialog::OnVKeyToItem(UINT nKey, CListBox* pListBox, UINT nIndex)
 	if (gra_dodialoglistkey(nKey, pListBox, nIndex) == 0) return(-2);
 	return(-1);
 }
+
+void CElectricDialog::OnLButtonDblClk(UINT nFlags, CPoint point) 
+{
+	gra_buttonaction(2, nFlags|MK_LBUTTON, point, this);
+	CDialog::OnLButtonDblClk(nFlags, point);
+}
