@@ -36,22 +36,22 @@
 #endif // _MSC_VER >= 1000
 
 /////////////////////////////////////////////////////////////////////////////
-// CElectricDialog dialog
+/* CElectricDialog dialog */
 
 class CElectricDialog : public CDialog
 {
-// Construction
+/* Construction */
 public:
-	CElectricDialog(CWnd* pParent = NULL);   // standard constructor
+	CElectricDialog(CWnd* pParent = NULL);   /* standard constructor */
 
-// Dialog Data
+/* Dialog Data */
 	//{{AFX_DATA(CElectricDialog)
 	enum { IDD = IDD_ELECTRIC_DIALOG };
 		// NOTE: the ClassWizard will add data members here
 	//}}AFX_DATA
 
 
-// Overrides
+/* Overrides */
 	// ClassWizard generated virtual function overrides
 	//{{AFX_VIRTUAL(CElectricDialog)
 	public:
@@ -60,7 +60,7 @@ public:
 	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
 	//}}AFX_VIRTUAL
 
-// Implementation
+/* Implementation */
 protected:
 
 	// Generated message map functions
@@ -196,6 +196,7 @@ protected:
 	afx_msg void OnLButtonDown(UINT nFlags, CPoint point);
 	afx_msg void OnLButtonUp(UINT nFlags, CPoint point);
 	afx_msg int OnVKeyToItem(UINT nKey, CListBox* pListBox, UINT nIndex);
+	afx_msg void OnLButtonDblClk(UINT nFlags, CPoint point);
 	//}}AFX_MSG
 	DECLARE_MESSAGE_MAP()
 };
