@@ -1,7 +1,8 @@
-// graphpcstdafx.h : include file for standard system include files,
-//  or project specific include files that are used frequently, but
-//      are changed infrequently
-//
+/*
+ * graphpcstdafx.h : include file for standard system include files,
+ * or project specific include files that are used frequently, but
+ * are changed infrequently
+ */
 
 #if !defined(AFX_STDAFX_H__07673644_BC3A_11D1_A088_0080C8775F8C__INCLUDED_)
 #define AFX_STDAFX_H__07673644_BC3A_11D1_A088_0080C8775F8C__INCLUDED_
@@ -10,12 +11,12 @@
 #pragma once
 #endif // _MSC_VER >= 1000
 
-#define VC_EXTRALEAN		// Exclude rarely-used stuff from Windows headers
+#define VC_EXTRALEAN		/* Exclude rarely-used stuff from Windows headers */
 
-#include <afxwin.h>         // MFC core and standard components
-#include <afxext.h>         // MFC extensions
+#include <afxwin.h>         /* MFC core and standard components */
+#include <afxext.h>         /* MFC extensions */
 #ifndef _AFX_NO_AFXCMN_SUPPORT
-#include <afxcmn.h>			// MFC support for Windows Common Controls
+#include <afxcmn.h>			/* MFC support for Windows Common Controls */
 #endif // _AFX_NO_AFXCMN_SUPPORT
 
 
