@@ -39,7 +39,7 @@
 
 class CElectricView : public CView
 {
-protected: // create from serialization only
+protected: /* create from serialization only */
 	CElectricView();
 	DECLARE_DYNCREATE(CElectricView)
 
@@ -48,7 +48,7 @@ public:
 	CElectricDoc* GetDocument();
 	void PrintHook(void);
 
-// Operations */
+/* Operations */
 public:
 
 /* Overrides */
