@@ -35,9 +35,9 @@ extern "C"
 
 void compen_init(INTBIG*, char*[], TOOL*);
 void compen_done(void);
-INTSML compen_set(INTSML, char*[]);
+void compen_set(INTBIG, char*[]);
 void compen_slice(void);
-void compen_modifynodeinst(NODEINST*,INTBIG,INTBIG,INTBIG,INTBIG,INTSML,INTSML);
+void compen_modifynodeinst(NODEINST*,INTBIG,INTBIG,INTBIG,INTBIG,INTBIG,INTBIG);
 void compen_killobject(INTBIG, INTBIG);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
