@@ -53,8 +53,15 @@
 #ifdef	MACOS						/***** Macintosh *****/
 #  include <QDOffscreen.h>
 #  define STDC_HEADERS     1
+#  define HAVE_STRCHR      1
+#  define HAVE_QSORT       1
+#  define HAVE_STRING_H    1
+#  define HAVE_STDLIB_H    1
 #  define HAVE_INTTYPES_H  1
+#  define BYTES_SWAPPED    1						/* bytes are MSB first */
 #  define DIRSEP           ':'						/* directory separator */
+#  define DIRSEPSTR        ":"						/* directory separator */
+#  define MACFSTAG(x)      x
 #  define NONFILECH        '|'						/* character that cannot be in file name */
 #  define CADRCFILENAME    "cadrc"					/* CAD startup file */
 #  define LIBDIR           ":lib:"					/* location of library files */
@@ -73,7 +80,13 @@
 #ifdef WIN32						/***** Windows *****/
 #  include "windows.h"
 #  define STDC_HEADERS     1
+#  define HAVE_GETCWD      1
+#  define HAVE_QSORT       1
+#  define HAVE_STRCHR      1
+#  define HAVE_STRING_H    1
 #  define DIRSEP           '\\'						/* directory separator */
+#  define DIRSEPSTR        "\\"						/* directory separator */
+#  define MACFSTAG(x)      0
 #  define NONFILECH        '|'						/* character that cannot be in file name */
 #  define CADRCFILENAME    "cadrc"					/* CAD startup file */
 #  define LIBDIR           "lib\\"					/* location of library files */
@@ -93,8 +106,17 @@
 
 #ifdef ONUNIX						/***** UNIX *****/
 #  include "defines.h"
-#  include <X11/Intrinsic.h>
+#  ifdef USEQT
+#    include <qglobal.h>
+#  else
+#    include <X11/Intrinsic.h>
+#  endif
+#  ifdef sparc
+#    define BYTES_SWAPPED  1						/* bytes are MSB first */
+#  endif
 #  define DIRSEP           '/'						/* directory separator */
+#  define DIRSEPSTR        "/"						/* directory separator */
+#  define MACFSTAG(x)      0
 #  define NONFILECH        '?'						/* character that cannot be in file name */
 #  define CADRCFILENAME    ".cadrc"					/* CAD startup file */
 #  define LIBDIR           "/usr/local/lib/electric/"		/* location of library files */
@@ -109,7 +131,7 @@
 #  define FLATDRCLOC       "/usr/local/bin/ffindshort"
 #  define SFLATDRCLOC      "/usr/local/bin/findshort"
 #  ifdef sun
-     typedef uint64_t u_int64_t;
+#    define u_int64_t uint64_t
 #  endif
 #endif
 
