@@ -47,13 +47,14 @@ extern CONSTRAINT *cla_constraint;		/* the constraint object for this solver */
 
 void cla_layconinit(CONSTRAINT*);
 void cla_layconterm(void);
-void cla_layconsetmode(INTSML, char*[]);
+void cla_layconsetmode(INTBIG, char*[]);
 INTBIG cla_layconrequest(char*, INTBIG);
 void cla_layconsolve(NODEPROTO*);
 void cla_layconnewobject(INTBIG, INTBIG);
 void cla_layconkillobject(INTBIG, INTBIG);
-INTSML cla_layconsetobject(INTBIG, INTBIG, INTBIG, INTBIG);
-void cla_layconmodifynodeinst(NODEINST*, INTBIG, INTBIG, INTBIG, INTBIG, INTSML, INTSML);
+BOOLEAN cla_layconsetobject(INTBIG, INTBIG, INTBIG, INTBIG);
+void cla_layconmodifynodeinst(NODEINST*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+void cla_layconmodifynodeinsts(INTBIG, NODEINST**, INTBIG*, INTBIG*, INTBIG*, INTBIG*, INTBIG*, INTBIG*);
 void cla_layconmodifyarcinst(ARCINST*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 void cla_layconmodifyportproto(PORTPROTO*, NODEINST*, PORTPROTO*);
 void cla_layconmodifynodeproto(NODEPROTO*);
