@@ -41,6 +41,7 @@ extern "C"
 #define TOUCHN           0100				/* NODEINST->userbits: nodeinst is touched */
 
 #define FIXEDMOD   0100000000				/* ARCINST->userbits: fixed arc was changed */
+
 #define FACETMOD      0400000				/* NODEPROTO->userbits: facet is changed */
 #define FACETNOMOD   01000000				/* NODEPROTO->userbits: facet is not changed */
 
@@ -48,7 +49,7 @@ extern "C"
 
 #define NOCHANGE	((CHANGE *)-1)
 
-/* meaning of "changetype" */
+/* meaning of "changetype" (when changing this, also change "broadcasttype[]" in "db_change()") */
 #define NODEINSTNEW      0					/* new nodeinst */
 #define NODEINSTKILL     1					/* killed nodeinst */
 #define NODEINSTMOD      2					/* modified nodeinst */
@@ -82,7 +83,7 @@ extern "C"
 
 typedef struct Ichange
 {
-	INTSML          changetype;				/* type of change */
+	INTBIG          changetype;				/* type of change */
 	INTBIG          entryaddr;				/* address of object that was changed */
 	struct Ichange *nextchange;				/* address of next change module in list */
 	struct Ichange *prevchange;				/* address of previous change module */
@@ -96,7 +97,7 @@ typedef struct Ichange
 typedef struct Ichangefacet
 {
 	NODEPROTO           *changefacet;		/* the facet that changed */
-	INTSML               forcedlook;		/* nonzero if library must be re-examined */
+	BOOLEAN              forcedlook;		/* true if library must be re-examined */
 	struct Ichangefacet *nextchangefacet;	/* next in list */
 } CHANGEFACET;
 
@@ -113,7 +114,7 @@ typedef struct Ichangebatch
 	TOOL                *tool;				/* tool that made this batch */
 	char                *activity;			/* description of activity */
 	INTBIG               batchnumber;		/* identifying index of this batch */
-	INTSML               done;				/* nonzero if this batch was done */
+	BOOLEAN              done;				/* true if this batch was done */
 } CHANGEBATCH;
 
 /*************************** BOX MERGING ****************************/
@@ -133,7 +134,7 @@ typedef struct Iboxpoly
 /* box list head */
 typedef struct Iboxlisthead
 {
-	INTSML               layer;
+	INTBIG               layer;
 	TECHNOLOGY          *tech;
 	struct Iboxpoly     *box;
 	struct Iboxlisthead *nextlayer;
@@ -150,7 +151,7 @@ typedef struct Ipolycoord
 typedef struct Ipolylisthead
 {
 	struct Ipolycoord *firstpoly;
-	INTSML             numedge, modified;
+	INTBIG             numedge, modified;
 } POLYLISTHEAD;
 
 /*************************** ERROR CODES ****************************/
@@ -246,30 +247,32 @@ typedef struct Ipolylisthead
 #define DBXFORM					(50<<16)
 
 extern INTBIG       db_lasterror;			/* last error message */
-extern INTSML       db_printerrors;			/* flag for printing internal errors */
+extern BOOLEAN      db_printerrors;			/* flag for printing internal errors */
 
 /*************************** VARIABLE KEYS ****************************/
 
-extern INTBIG  db_tech_node_width_offset;		/* variable "TECH_node_width_offset" */
-extern INTBIG  db_tech_layer_function;			/* variable "TECH_layer_function" */
-extern INTBIG  db_tech_layer_names;				/* variable "TECH_layer_names" */
-extern INTBIG  db_tech_arc_width_offset;		/* variable "TECH_arc_width_offset" */
+extern INTBIG  db_tech_node_width_offset_key;	/* variable "TECH_node_width_offset" */
+extern INTBIG  db_tech_layer_function_key;		/* variable "TECH_layer_function" */
+extern INTBIG  db_tech_layer_names_key;			/* variable "TECH_layer_names" */
+extern INTBIG  db_tech_arc_width_offset_key;	/* variable "TECH_arc_width_offset" */
 
 /*************************** CHANGE CONTROL ****************************/
 
-extern INTSML  db_donextchangequietly;			/* nonzero to do next change quietly */
-extern INTSML  db_dochangesquietly;				/* nonzero to do changes quietly */
+extern BOOLEAN db_donextchangequietly;			/* true to do next change quietly */
+extern BOOLEAN db_dochangesquietly;				/* true to do changes quietly */
 extern UINTBIG db_changetimestamp;				/* timestamp for changes to database */
+extern UINTBIG db_traversaltimestamp;			/* timestamp for hierarchy traversal */
+extern INTBIG  db_broadcasting;					/* nonzero if broadcasting */
 
 /*************************** PROTOTYPES ****************************/
 
 /* database prototypes */
 void         db_addportarcinst(NODEINST*, PORTARCINST*);
 void         db_addportexpinst(NODEINST*, PORTEXPINST*);
-INTSML       db_addtortnode(UINTBIG, RTNODE*, NODEPROTO*);
+BOOLEAN      db_addtortnode(UINTBIG, RTNODE*, NODEPROTO*);
 void         db_boundfacet(NODEPROTO*, INTBIG*, INTBIG*, INTBIG*, INTBIG*);
 void         db_buildcellhashtable(LIBRARY*);
-CHANGE      *db_change(INTBIG, INTSML, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+CHANGE      *db_change(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 void         db_changeport(PORTPROTO*, NODEINST*, PORTPROTO*);
 void         db_checkallmemoryfree(void);
 void         db_clearportcache(NODEPROTO *facet);
@@ -277,7 +280,7 @@ void         db_endbatch(void);
 void         db_enterarcinst(ARCINST*);
 void         db_enternodeinst(NODEINST*);
 void         db_enterportproto(PORTPROTO*);
-INTSML       db_enterwindowpart(WINDOWPART *w);
+BOOLEAN      db_enterwindowpart(WINDOWPART *w);
 INTBIG       db_error(INTBIG);
 CELL        *db_findcellname(char*, LIBRARY*);
 void         db_forcehierarchicalanalysis(NODEPROTO*);
@@ -298,7 +301,8 @@ void         db_freevars(VARIABLE**, INTSML*);
 CHANGEBATCH *db_getcurrentbatch(void);
 float        db_getcurrentscale(INTBIG, INTBIG);
 void         db_getinternalunitscale(INTBIG*, INTBIG*, INTBIG, INTBIG);
-INTSML       db_getvarptr(INTBIG, INTBIG, VARIABLE***, INTSML**);
+void         db_gettraversalpath(NODEINST ***nilist, INTBIG *depth);
+BOOLEAN      db_getvarptr(INTBIG, INTBIG, VARIABLE***, INTSML**);
 void         db_initclusters(void);
 void         db_initdatabase(void);
 void         db_initializechanges(void);
@@ -310,13 +314,13 @@ void         db_killnodeinst(NODEINST*);
 void         db_mrgdatainit(void);
 ARCINST     *db_newarcinst(ARCPROTO*, INTBIG, INTBIG, NODEINST*, PORTPROTO*, INTBIG, INTBIG,
 	NODEINST*, PORTPROTO*, INTBIG, INTBIG, NODEPROTO*);
-ARCPROTO    *db_newarcproto(TECHNOLOGY*, char*, INTBIG, INTSML);
-NODEINST    *db_newnodeinst(NODEPROTO*, INTBIG, INTBIG, INTBIG, INTBIG, INTSML, INTSML, NODEPROTO*);
+ARCPROTO    *db_newarcproto(TECHNOLOGY*, char*, INTBIG, INTBIG);
+NODEINST    *db_newnodeinst(NODEPROTO*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*);
 PORTPROTO   *db_newportproto(NODEPROTO*, NODEINST*, PORTPROTO*, char*);
-NODEPROTO   *db_newprimnodeproto(char*, INTBIG, INTBIG, INTSML, TECHNOLOGY*);
+NODEPROTO   *db_newprimnodeproto(char*, INTBIG, INTBIG, INTBIG, TECHNOLOGY*);
 PORTPROTO   *db_newprimportproto(NODEPROTO*, ARCPROTO**, char*);
 void         db_printclusterarena(char*);
-void         db_printrtree(RTNODE*, RTNODE*, INTSML);
+void         db_printrtree(RTNODE*, RTNODE*, INTBIG);
 void         db_removechangefacet(NODEPROTO*);
 void         db_removeportexpinst(PORTPROTO*);
 void         db_retractarcinst(ARCINST*);
@@ -324,13 +328,12 @@ void         db_retractnodeinst(NODEINST*);
 void         db_retractnodeproto(NODEPROTO*);
 void         db_retractportproto(PORTPROTO*);
 void         db_retractwindowpart(WINDOWPART *w);
-void         db_rtnbbox(RTNODE*, INTSML, INTBIG*, INTBIG*, INTBIG*, INTBIG*);
+void         db_rtnbbox(RTNODE*, INTBIG, INTBIG*, INTBIG*, INTBIG*, INTBIG*);
 void         db_setchangefacet(NODEPROTO*);
 void         db_setcurrenttool(TOOL*);
-INTSML       db_stillinport(ARCINST*, INTSML, INTBIG, INTBIG);
+BOOLEAN      db_stillinport(ARCINST*, INTBIG, INTBIG, INTBIG);
 void         db_termlanguage(void);
 void         db_undodlog(void);
-LIBRARY     *db_whichlibrary(INTBIG, INTBIG);
 NODEPROTO   *db_whichnodeproto(INTBIG, INTBIG);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
