@@ -76,7 +76,7 @@ void killcontour(CONTOUR *con);
 void getcontoursegmentparameters(INTBIG *arcres, INTBIG *arcsag);
 void setcontoursegmentparameters(INTBIG arcres, INTBIG arcsag);
 void initcontoursegmentgeneration(CONTOURELEMENT *conel);
-INTSML nextcontoursegmentgeneration(INTBIG *x1, INTBIG *y1, INTBIG *x2, INTBIG *y2);
+BOOLEAN nextcontoursegmentgeneration(INTBIG *x1, INTBIG *y1, INTBIG *x2, INTBIG *y2);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
 }
