@@ -37,19 +37,19 @@ extern "C"
 
 #if LANGLISP
 # include "elkkernel.h"
-  void lsp_init(void);
+  void      lsp_init(void);
   ELKObject lsp_makeobject(char*);
-  INTSML lsp_describeobject(ELKObject, INTBIG, INTBIG*);
+  BOOLEAN   lsp_describeobject(ELKObject, INTBIG, INTBIG*);
 #endif
 
 /***************************** TCL DECLARATIONS *****************************/
 
 #if LANGTCL
 # include "tclInt.h"
-  void el_tclinterpreter(Tcl_Interp *interp);
-  INTBIG tcl_converttoelectric(char *tclstr, INTBIG type);
-  void tcl_nativemenuinitialize(void);
-  INTSML tcl_nativemenuload(INTSML count, char *par[]);
+  void    el_tclinterpreter(Tcl_Interp *interp);
+  INTBIG  tcl_converttoelectric(char *tclstr, INTBIG type);
+  void    tcl_nativemenuinitialize(void);
+  BOOLEAN tcl_nativemenuload(INTBIG count, char *par[]);
   extern Tcl_Interp *tcl_interp;
   extern char *tcl_outputbuffer, *tcl_outputloc;
 #endif
@@ -69,10 +69,10 @@ extern "C"
 # define METHODRETURNSLONG    7
 # define METHODRETURNSFLOAT   8
 # define METHODRETURNSDOUBLE  9
-  char  *java_init(void);
-  INTSML java_evaluate(char *str);
-  char  *java_query(char *str, INTBIG *methodreturntype);
-  void   java_freememory(void);
+  char   *java_init(void);
+  BOOLEAN java_evaluate(char *str);
+  char   *java_query(char *str, INTBIG *methodreturntype);
+  void    java_freememory(void);
 #endif
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
