@@ -30,17 +30,15 @@
 
 /*
  * when changing this table, also change:
- * dbtech.c:nodefunctionname() (both table and end-of-list test)
+ * dbtech.c:db_nodefunname[]
  * dbtech.c:nodefunction(), transistorsize(), isfet()
  * erc:erc_analyzefacet()
  * ioedifo.c
- * netdiff.c:net_diffwirelist()
  * netflat.c:net_getfunction()
  * simsilos.c:sim_silostype()
  * simspice.c:sim_spice_nodetype()
  * simtexsim.c:sim_writetexcell(), sim_texproto()
  * usrctech.c:us_tran_logmakenodes(), us_tranismos()
- * usredtecc.c:us_tecnode_functions[]
  * usrmenu.c:us_groupfunction()
  * vhdl.c:vhdl_primname()
  */
@@ -90,27 +88,19 @@
 #define NPMUX              41	/* node is multiplexor */
 #define NPCONPOWER         42	/* node is connected to power */
 #define NPCONGROUND        43	/* node is connected to ground */
-#define NPSOURCE           44	/* node is source of unknown type */
-#define NPSOURCEV          45	/* node is voltage source */
-#define NPSOURCEC          46	/* node is current source */
-#define NPSOURCECM         47	/* node is current meter */
-#define NPSOURCET          48	/* node is transient analysis specification */
-#define NPSOURCEDC         49	/* node is DC analysis specification */
-#define NPSOURCEAC         50	/* node is AC analysis specification */
-#define NPSOURCEN          51	/* node is NodeSet source */
-#define NPSOURCEX          52	/* node is Extension source */
-#define NPSOURCEB          53	/* node is Bulk source */
-#define NPSOURCES          54	/* node is Special source */
-#define NPSUBSTRATE        55	/* node is connected to substrate */
-#define NPWELL             56	/* node is connected to well */
-#define NPART              57	/* node is pure artwork */
-#define NPARRAY            58	/* node is an array */
-#define NPALIGN            59	/* node is an alignment object */
-#define NPCCVS             60	/* node is a current-controlled voltage source */
-#define NPCCCS             61	/* node is a current-controlled current source */
-#define NPVCVS             62	/* node is a voltage-controlled voltage source */
-#define NPVCCS             63	/* node is a voltage-controlled current source */
-#define NPTLINE            64	/* node is a transmission line */
+#define NPSOURCE           44	/* node is source */
+#define NPSUBSTRATE        45	/* node is connected to substrate */
+#define NPWELL             46	/* node is connected to well */
+#define NPART              47	/* node is pure artwork */
+#define NPARRAY            48	/* node is an array */
+#define NPALIGN            49	/* node is an alignment object */
+#define NPCCVS             50	/* node is a current-controlled voltage source */
+#define NPCCCS             51	/* node is a current-controlled current source */
+#define NPVCVS             52	/* node is a voltage-controlled voltage source */
+#define NPVCCS             53	/* node is a voltage-controlled current source */
+#define NPTLINE            54	/* node is a transmission line */
+
+#define MAXNODEFUNCTION    55	/* the number of functions above */
 
 /*
  * when changing this table, also change:
@@ -211,3 +201,4 @@
 #define LFTRANS3     02000000	/* layer is transparent number 3 */
 #define LFTRANS4     04000000	/* layer is transparent number 4 */
 #define LFTRANS5    010000000	/* layer is transparent number 5 */
+#define LFINTRANS   020000000	/* layer inside transistor */
