@@ -100,16 +100,16 @@ extern "C"
 #define OUTLINEPAT  8			/* if NATURE is PATTERNED, outline it    */
 
 /* variables with the acutal colors to use for special graphics */
-extern INTSML el_maplength;		/* number of entries in color map */
-extern INTSML el_colfacettxt;	/* color to use for facet text and port names */
-extern INTSML el_colfacet;		/* color to use for facet outline */
-extern INTSML el_colwinbor;		/* color to use for window border */
-extern INTSML el_colhwinbor;	/* color to use for highlighted window border */
-extern INTSML el_colmenbor;		/* color to use for menu border */
-extern INTSML el_colhmenbor;	/* color to use for highlighted menu border */
-extern INTSML el_colmentxt;		/* color to use for menu text */
-extern INTSML el_colmengly;		/* color to use for menu glyphs */
-extern INTSML el_colcursor;		/* color to use for cursor */
+extern INTBIG el_maplength;		/* number of entries in color map */
+extern INTBIG el_colfacettxt;	/* color to use for facet text and port names */
+extern INTBIG el_colfacet;		/* color to use for facet outline */
+extern INTBIG el_colwinbor;		/* color to use for window border */
+extern INTBIG el_colhwinbor;	/* color to use for highlighted window border */
+extern INTBIG el_colmenbor;		/* color to use for menu border */
+extern INTBIG el_colhmenbor;	/* color to use for highlighted menu border */
+extern INTBIG el_colmentxt;		/* color to use for menu text */
+extern INTBIG el_colmengly;		/* color to use for menu glyphs */
+extern INTBIG el_colcursor;		/* color to use for cursor */
 
 /******************************* POLYGONS ********************************/
 
@@ -130,23 +130,25 @@ extern INTSML el_colcursor;		/* color to use for cursor */
 #define VECTORS        10			/* vector endpoint pairs, solid              */
 		/* curves */
 #define CIRCLE         11			/* circle at [0] radius to [1]               */
-#define DISC           12			/* filled circle                             */
-#define CIRCLEARC      13			/* arc of circle at [0] ends [1] and [2]     */
+#define THICKCIRCLE    12			/* thick circle at [0] radius to [1]         */
+#define DISC           13			/* filled circle                             */
+#define CIRCLEARC      14			/* arc of circle at [0] ends [1] and [2]     */
+#define THICKCIRCLEARC 15			/* thick arc of circle at [0] ends [1] and [2] */
 		/* text */
-#define TEXTCENT       14			/* text at center                            */
-#define TEXTTOP        15			/* text below top edge                       */
-#define TEXTBOT        16			/* text above bottom edge                    */
-#define TEXTLEFT       17			/* text to right of left edge                */
-#define TEXTRIGHT      18			/* text to left of right edge                */
-#define TEXTTOPLEFT    19			/* text to lower-right of top-left corner    */
-#define TEXTBOTLEFT    20			/* text to upper-right of bottom-left corner */
-#define TEXTTOPRIGHT   21			/* text to lower-left of top-right corner    */
-#define TEXTBOTRIGHT   22			/* text to upper-left of bottom-right corner */
-#define TEXTBOX        23			/* text that fits in box (may shrink)        */
+#define TEXTCENT       16			/* text at center                            */
+#define TEXTTOP        17			/* text below top edge                       */
+#define TEXTBOT        18			/* text above bottom edge                    */
+#define TEXTLEFT       19			/* text to right of left edge                */
+#define TEXTRIGHT      20			/* text to left of right edge                */
+#define TEXTTOPLEFT    21			/* text to lower-right of top-left corner    */
+#define TEXTBOTLEFT    22			/* text to upper-right of bottom-left corner */
+#define TEXTTOPRIGHT   23			/* text to lower-left of top-right corner    */
+#define TEXTBOTRIGHT   24			/* text to upper-left of bottom-right corner */
+#define TEXTBOX        25			/* text that fits in box (may shrink)        */
 		/* miscellaneous */
-#define GRIDDOTS       24			/* grid dots in the window                   */
-#define CROSS          25			/* cross                                     */
-#define BIGCROSS       26			/* big cross                                 */
+#define GRIDDOTS       26			/* grid dots in the window                   */
+#define CROSS          27			/* cross                                     */
+#define BIGCROSS       28			/* big cross                                 */
 
 /* text font sizes (in VARIABLE, NODEINST, PORTPROTO, and POLYGON->textdescription) */
 #define TXTPOINTS        077		/* points from 1 to TXTMAXPOINTS */
@@ -164,6 +166,34 @@ extern INTSML el_colcursor;		/* color to use for cursor */
 #define TXTEDITOR     020000		/* fixed-width text for text editing */
 #define TXTMENU       040000		/* text for menu selection */
 
+/******************** PROTOTYPES ********************/
+
+#ifndef USEQT
+void    gra_drawline(WINDOWPART *win, INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2,
+			GRAPHICS *desc, INTBIG texture); 
+void    gra_invertline(WINDOWPART *win, INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2);
+void    gra_drawpolygon(WINDOWPART *win, INTBIG *x, INTBIG *y, INTBIG count, GRAPHICS *desc);
+void    gra_drawbox(WINDOWPART *win, INTBIG lowx, INTBIG highx, INTBIG lowy, INTBIG highy,
+			GRAPHICS *desc);
+void    gra_invertbox(WINDOWPART *win, INTBIG lowx, INTBIG highx, INTBIG lowy, INTBIG highy);
+void    gra_movebox(WINDOWPART *win, INTBIG sx, INTBIG sy, INTBIG wid, INTBIG hei,
+			INTBIG dx, INTBIG dy);
+INTBIG  gra_savebox(WINDOWPART *win, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy);
+void    gra_movesavedbox(INTBIG code, INTBIG dx, INTBIG dy);
+BOOLEAN gra_restorebox(INTBIG code, INTBIG destroy);
+void    gra_drawtext(WINDOWPART *win, INTBIG atx, INTBIG aty, INTBIG rotation,
+			char *s, GRAPHICS *desc);
+void    gra_drawcircle(WINDOWPART *win, INTBIG atx, INTBIG aty, INTBIG radius, GRAPHICS *desc);
+void    gra_drawthickcircle(WINDOWPART *win, INTBIG atx, INTBIG aty, INTBIG radius,
+			GRAPHICS *desc);
+void    gra_drawdisc(WINDOWPART *win, INTBIG atx, INTBIG aty, INTBIG radius, GRAPHICS *desc);
+void    gra_drawcirclearc(WINDOWPART *win, INTBIG centerx, INTBIG centery, INTBIG p1_x, INTBIG p1_y,
+			INTBIG p2_x, INTBIG p2_y, BOOLEAN thick, GRAPHICS *desc);
+void    gra_drawgrid(WINDOWPART *win, POLYGON *obj);
+void    gra_setrect(WINDOWFRAME *wf, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy);
+void    gra_termgraph(void);
+#endif
+
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
 }
 #endif
