@@ -33,11 +33,19 @@ extern "C"
 {
 #endif
 
+#define DISPLAYCAPACITANCE    01
+#define HIGHLIGHTCOMPONENTS   02
+
+#define DEFAULTSTATE        DISPLAYCAPACITANCE
+
+#define DEFWIRERATIO   10				/* default wire ratio */
+
 extern TOOL    *le_tool;				/* the Logical Effort tool object */
+extern INTBIG   le_wire_ratio_key;		/* variable key for "LE_wire_ratio" */
 
 void le_init(INTBIG*, char*[], TOOL*);
 void le_done(void);
-INTSML le_set(INTSML, char*[]);
+void le_set(INTBIG, char*[]);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
 }
