@@ -32,8 +32,6 @@
 #define PLAC_X_SEP         10	 /* Lambda seperation between grid lines in array */
 #define PLAC_Y_MIR_SEP     10	 /* Lambda seperation between grid line */
 #define PLAC_Y_SEP         10	 /* Lambda seperation between grid lines in array */
-#define TRUE               1
-#define FALSE              0
 
 
 #define NOUCITEM ((UCITEM *)-1)
