@@ -40,8 +40,6 @@ extern "C"
 #define VERSION			"1.00"
 #define DATE			"Feb 24, 1987"
 #define PARS			10
-#define TRUE			1
-#define FALSE			0
 #define MAXLINE         80
 #define GND				0
 #define PWR				1
@@ -743,7 +741,7 @@ extern INTBIG      sc_filetypesctab;	/* Silicon compiler table file descriptor *
 /* prototypes for tool interface */
 void sc_init(INTBIG*, char*[], TOOL*);
 void sc_done(void);
-INTSML sc_set(INTSML, char*[]);
+void sc_set(INTBIG, char*[]);
 INTBIG sc_request(char*, va_list);
 void sc_slice(void);
 
