@@ -46,6 +46,7 @@ extern NODEPROTO  *art_boxprim;						/* Box */
 extern NODEPROTO  *art_crossedboxprim;				/* Crossed-Box */
 extern NODEPROTO  *art_filledboxprim;				/* Filled-Box */
 extern NODEPROTO  *art_circleprim;					/* Circle */
+extern NODEPROTO  *art_thickcircleprim;				/* Thick-Circle */
 extern NODEPROTO  *art_filledcircleprim;			/* Filled-Circle */
 extern NODEPROTO  *art_splineprim;					/* Spline */
 extern NODEPROTO  *art_triangleprim;				/* Triangle */
@@ -69,14 +70,14 @@ extern INTBIG      art_degreeskey;					/* key for "ART_degrees" */
 extern INTBIG      art_patternkey;					/* key for "ART_pattern" */
 
 /* prototypes for technology routines */
-INTSML art_initprocess(TECHNOLOGY*, INTSML);
-void art_setmode(INTSML, char*[]);
+BOOLEAN art_initprocess(TECHNOLOGY*, INTBIG);
+void art_setmode(INTBIG, char*[]);
 INTBIG art_request(char*, va_list);
 INTBIG art_nodepolys(NODEINST*, INTBIG*, WINDOWPART*);
 INTBIG art_nodeEpolys(NODEINST*, INTBIG*, WINDOWPART*);
 void art_shapenodepoly(NODEINST*, INTBIG, POLYGON*);
 void art_shapeEnodepoly(NODEINST*, INTBIG, POLYGON*);
-void art_shapeportpoly(NODEINST*, PORTPROTO*, POLYGON*, XARRAY, INTSML);
+void art_shapeportpoly(NODEINST*, PORTPROTO*, POLYGON*, XARRAY, BOOLEAN);
 INTBIG art_arcpolys(ARCINST*, WINDOWPART*);
 void art_shapearcpoly(ARCINST*, INTBIG, POLYGON*);
 
