@@ -33,7 +33,7 @@ extern "C"
 #endif
 
 /* prototypes for technology routines */
-INTSML dodcmosn_initprocess(TECHNOLOGY *tech, INTSML pass);
+BOOLEAN dodcmosn_initprocess(TECHNOLOGY *tech, INTBIG pass);
 void dodcmosn_shapenodepoly(NODEINST*, INTBIG, POLYGON*);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
