@@ -36,13 +36,13 @@ extern "C"
 /* prototypes for technology routines */
 void fpga_shapearcpoly(ARCINST*, INTBIG, POLYGON*);
 INTBIG fpga_arcpolys(ARCINST*, WINDOWPART*);
-void fpga_shapeportpoly(NODEINST*, PORTPROTO*, POLYGON*, XARRAY, INTSML);
+void fpga_shapeportpoly(NODEINST*, PORTPROTO*, POLYGON*, XARRAY, BOOLEAN);
 INTBIG fpga_nodeEpolys(NODEINST*, INTBIG*, WINDOWPART*);
 void fpga_shapeEnodepoly(NODEINST*, INTBIG, POLYGON*);
 void fpga_shapenodepoly(NODEINST*, INTBIG, POLYGON*);
 INTBIG fpga_nodepolys(NODEINST*, INTBIG*, WINDOWPART*);
-void fpga_setmode(INTSML, char*[]);
-INTSML fpga_initprocess(TECHNOLOGY*, INTSML);
+void fpga_setmode(INTBIG, char*[]);
+BOOLEAN fpga_initprocess(TECHNOLOGY*, INTBIG);
 void fpga_termprocess(void);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
