@@ -34,7 +34,7 @@ extern "C"
 #endif
 
 /* prototypes for technology routines */
-INTSML gem_initprocess(TECHNOLOGY *tech, INTSML pass);
+BOOLEAN gem_initprocess(TECHNOLOGY *tech, INTBIG pass);
 void gem_shapenodepoly(NODEINST*, INTBIG, POLYGON*);
 void gem_shapearcpoly(ARCINST*, INTBIG, POLYGON*);
 
