@@ -442,16 +442,16 @@ extern INTBIG      tech_realpolys;			/* polygon count without displayable variab
 extern WINDOWPART *tech_curwindowpart;		/* window used in getting polygons from node/arc */
 
 /* technology prototypes */
-INTSML    tech_doinitprocess(TECHNOLOGY*);
-INTSML    tech_doaddportsandvars(TECHNOLOGY*);
-INTSML    tech_initcurvedarc(ARCINST*, INTSML);
-INTSML    tech_curvedarcpiece(ARCINST*, INTBIG, POLYGON*, TECH_ARCS**);
-void      tech_addheadarrow(POLYGON*, INTSML, INTBIG, INTBIG, INTBIG);
-void      tech_adddoubleheadarrow(POLYGON*, INTSML, INTBIG*, INTBIG*, INTBIG);
-void      tech_add2linebody(POLYGON*, INTSML, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+BOOLEAN   tech_doinitprocess(TECHNOLOGY*);
+BOOLEAN   tech_doaddportsandvars(TECHNOLOGY*);
+INTBIG    tech_initcurvedarc(ARCINST*, INTBIG);
+BOOLEAN   tech_curvedarcpiece(ARCINST*, INTBIG, POLYGON*, TECH_ARCS**);
+void      tech_addheadarrow(POLYGON*, INTBIG, INTBIG, INTBIG, INTBIG);
+void      tech_adddoubleheadarrow(POLYGON*, INTBIG, INTBIG*, INTBIG*, INTBIG);
+void      tech_add2linebody(POLYGON*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 INTBIG    tech_moscutcount(NODEINST*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG*);
 INTBIG    tech_inittrans(INTBIG, NODEINST*);
-INTSML    tech_pinusecount(NODEINST*, ARCPROTO*);
+BOOLEAN   tech_pinusecount(NODEINST*, WINDOWPART*);
 INTBIG    tech_displayablenvars(NODEINST*, WINDOWPART*);
 VARIABLE *tech_filldisplayablenvar(NODEINST*, POLYGON*, WINDOWPART*, VARIABLE**);
 INTBIG    tech_displayablefacetvars(NODEPROTO *np, WINDOWPART *win);
@@ -463,10 +463,10 @@ VARIABLE *tech_filldisplayableportvar(PORTPROTO *pp, POLYGON *poly, WINDOWPART *
 void      tech_filltrans(POLYGON*, TECH_POLYGON**, TECH_SERPENT*, NODEINST*, INTBIG,
 			INTBIG, TECH_PORTS*);
 void      tech_moscutpoly(NODEINST*, INTBIG, INTBIG[]);
-void      tech_fillpoly(POLYGON*, TECH_POLYGON*, NODEINST*, INTBIG, INTSML);
+void      tech_fillpoly(POLYGON*, TECH_POLYGON*, NODEINST*, INTBIG, INTBIG);
 void      tech_filltransport(NODEINST*, PORTPROTO*, POLYGON*, XARRAY, TECH_NODES*, INTBIG,
 			INTBIG, INTBIG, INTBIG, INTBIG);
-void      tech_fillportpoly(NODEINST*, PORTPROTO*, POLYGON*, XARRAY, TECH_NODES*, INTSML);
+void      tech_fillportpoly(NODEINST*, PORTPROTO*, POLYGON*, XARRAY, TECH_NODES*, INTBIG);
 void      tech_resetnegated(ARCINST*);
 INTBIG    tech_displayableavars(ARCINST*, WINDOWPART*);
 VARIABLE *tech_filldisplayableavar(ARCINST*, POLYGON*, WINDOWPART*, VARIABLE**);
