@@ -46,6 +46,7 @@ extern "C"
 #define MOCMOSDEEPRULES       040		/*   set if deep rules in use */
 #define MOCMOSSCMOSRULES     0100		/*   set if standard SCMOS rules in use */
 #define MOCMOSALTAPRULES     0200		/* set to use alternate active/poly rules */
+#define MOCMOSTWOPOLY        0400		/* set to use second polysilicon layer */
 
 extern TECHNOLOGY *mocmos_tech;			/* the technology */
 extern NODEPROTO  *mocmos_metal1poly2prim;
@@ -59,8 +60,8 @@ extern NODEPROTO  *mocmos_metal1pwellprim;
 extern NODEPROTO  *mocmos_metal1nwellprim;
 
 /* prototypes for local routines */
-INTSML mocmos_initprocess(TECHNOLOGY*, INTSML);
-void mocmos_setmode(INTSML, char*[]);
+BOOLEAN mocmos_initprocess(TECHNOLOGY*, INTBIG);
+void mocmos_setmode(INTBIG, char*[]);
 INTBIG mocmos_request(char*, va_list);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
