@@ -34,9 +34,9 @@ extern "C"
 #endif
 
 /* prototypes for local routines */
-INTSML mocmosold_initprocess(TECHNOLOGY*, INTSML);
+BOOLEAN mocmosold_initprocess(TECHNOLOGY*, INTBIG);
 INTBIG mocmosold_arcpolys(ARCINST*, WINDOWPART*);
-void mocmosold_setmode(INTSML, char*[]);
+void mocmosold_setmode(INTBIG, char*[]);
 void mocmosold_shapearcpoly(ARCINST*, INTBIG, POLYGON*);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
