@@ -44,8 +44,8 @@ extern "C"
 extern TECHNOLOGY *mocmossub_tech;			/* the technology */
 
 /* prototypes for local routines */
-INTSML mocmossub_initprocess(TECHNOLOGY*, INTSML);
-void mocmossub_setmode(INTSML, char*[]);
+BOOLEAN mocmossub_initprocess(TECHNOLOGY*, INTBIG);
+void mocmossub_setmode(INTBIG, char*[]);
 INTBIG mocmossub_request(char*, va_list);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
