@@ -34,7 +34,7 @@ extern "C"
 #endif
 
 /* prototypes for technology routines */
-INTSML rcmos_initprocess(TECHNOLOGY*, INTSML);
+BOOLEAN rcmos_initprocess(TECHNOLOGY*, INTBIG);
 INTBIG rcmos_arcpolys(ARCINST*, WINDOWPART*);
 void rcmos_shapearcpoly(ARCINST*, INTBIG, POLYGON*);
 
