@@ -44,17 +44,6 @@ extern "C"
 #define FFCLOCKP            02000000		/*    FlipFlop is Positive clock */
 #define FFCLOCKN            04000000		/*    FlipFlop is Negative clock */
 
-#define SOURCEVS                   0		/* Source is Voltage */
-#define SOURCEAC             0400000		/* Source is AC analysis */
-#define SOURCEBULK          01000000		/* Source is Bulk */
-#define SOURCECURSRC        01400000		/* Source is Current source */
-#define SOURCECURMTR        02000000		/* Source is Current meter */
-#define SOURCENODE          02400000		/* Source is Nodeset */
-#define SOURCESPEC          03000000		/* Source is Special */
-#define SOURCETRAN          03400000		/* Source is Transient Analysis */
-#define SOURCEDCAN          04000000		/* Source is DC Analysis */
-#define SOURCEEXT           04400000		/* Source is Extension */
-
 #define TRANNMOS                   0		/* Transistor is N channel MOS */
 #define TRANDMOS             0400000		/* Transistor is Depletion MOS */
 #define TRANPMOS            01000000		/* Transistor is P channel MOS */
@@ -105,32 +94,34 @@ extern NODEPROTO  *sch_wellprim;		/* well connection */
 extern NODEPROTO  *sch_substrateprim;	/* substrate connection */
 extern NODEPROTO  *sch_twoportprim;		/* generic two-port block */
 extern NODEPROTO  *sch_transistor4prim;	/* 4-port transistor */
+extern NODEPROTO  *sch_globalprim;		/* global signal */
 
 extern ARCPROTO   *sch_wirearc;			/* wire arc */
 extern ARCPROTO   *sch_busarc;			/* bus arc */
 
+extern INTBIG      sch_wirepinsizex;	/* X size if wire-pin primitives */
+extern INTBIG      sch_wirepinsizey;	/* Y size if wire-pin primitives */
+
 extern INTBIG      sch_meterkey;		/* key for "SCHEM_meter_type" */
 extern INTBIG      sch_diodekey;		/* key for "SCHEM_diode" */
 extern INTBIG      sch_capacitancekey;	/* key for "SCHEM_capacitance" */
 extern INTBIG      sch_resistancekey;	/* key for "SCHEM_resistance" */
 extern INTBIG      sch_inductancekey;	/* key for "SCHEM_inductance" */
-extern INTBIG      sch_twoportkey;		/* key for "SCHEM_twoport_type" */
 extern INTBIG      sch_functionkey;		/* key for "SCHEM_function" */
 extern INTBIG      sch_spicemodelkey;	/* key for "SIM_spice_model" */
-extern INTBIG      sch_wirepinsizex;	/* X size if wire-pin primitives */
-extern INTBIG      sch_wirepinsizey;	/* Y size if wire-pin primitives */
+extern INTBIG      sch_globalnamekey;	/* key for "SCHEM_global_name" */
 
 /* prototypes for technology routines */
 void sch_shapearcpoly(ARCINST*, INTBIG, POLYGON*);
 INTBIG sch_arcpolys(ARCINST*, WINDOWPART*);
-void sch_shapeportpoly(NODEINST*, PORTPROTO*, POLYGON*, XARRAY, INTSML);
+void sch_shapeportpoly(NODEINST*, PORTPROTO*, POLYGON*, XARRAY, BOOLEAN);
 INTBIG sch_nodeEpolys(NODEINST*, INTBIG*, WINDOWPART*);
 void sch_shapeEnodepoly(NODEINST*, INTBIG, POLYGON*);
 void sch_shapenodepoly(NODEINST*, INTBIG, POLYGON*);
 INTBIG sch_nodepolys(NODEINST*, INTBIG*, WINDOWPART*);
-void sch_setmode(INTSML, char*[]);
+void sch_setmode(INTBIG, char*[]);
 INTBIG sch_request(char*, va_list);
-INTSML sch_initprocess(TECHNOLOGY*, INTSML);
+BOOLEAN sch_initprocess(TECHNOLOGY*, INTBIG);
 void sch_termprocess(void);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
