@@ -28,7 +28,7 @@
  * info@staticfreesoft.com
  */
 
-WINDOWPART *us_editpacmakeeditor(WINDOWPART*, char*, INTSML*, INTSML*);
+WINDOWPART *us_editpacmakeeditor(WINDOWPART*, char*, INTBIG*, INTBIG*);
 void us_editpacterminate(EDITOR*);
 INTBIG us_editpactotallines(WINDOWPART*);
 char *us_editpacgetline(WINDOWPART*, INTBIG);
@@ -42,7 +42,7 @@ void us_editpacwritetextfile(WINDOWPART*, char*);
 void us_editpacreadtextfile(WINDOWPART*, char*);
 void us_editpaceditorterm(WINDOWPART*);
 void us_editpacshipchanges(WINDOWPART*);
-INTSML us_editpacgotchar(WINDOWPART*, INTSML);
+BOOLEAN us_editpacgotchar(WINDOWPART*, INTSML, INTBIG);
 void us_editpaccut(WINDOWPART*);
 void us_editpaccopy(WINDOWPART*);
 void us_editpacpaste(WINDOWPART*);
