@@ -121,8 +121,8 @@ typedef struct Ipcon
 {
 	INTBIG       *connects;
 	INTBIG       *assoc;
-	INTSML        total;
-	INTSML        pcindex;
+	INTBIG        total;
+	INTBIG        pcindex;
 	struct Ipcon *nextpcon;
 } PCON;
 
@@ -133,13 +133,13 @@ typedef struct Ipcon
 typedef struct Irule
 {
 	INTBIG       *value;					/* data points for rule */
-	INTSML        count;					/* number of points in rule */
-	INTSML        istext;					/* nonzero if text at end of rule */
-	INTSML        rindex;					/* identifier for this rule */
-	INTSML        used;						/* nonzero if actually used */
-	INTSML        multicut;					/* nonzero if this is multiple cut */
-	INTSML        multixs, multiys;			/* size of multicut */
-	INTSML        multiindent, multisep;	/* indent and separation of multicuts */
+	INTBIG        count;					/* number of points in rule */
+	INTBIG        istext;					/* nonzero if text at end of rule */
+	INTBIG        rindex;					/* identifier for this rule */
+	BOOLEAN       used;						/* nonzero if actually used */
+	BOOLEAN       multicut;					/* nonzero if this is multiple cut */
+	INTBIG        multixs, multiys;			/* size of multicut */
+	INTBIG        multiindent, multisep;	/* indent and separation of multicuts */
 	struct Irule *nextrule;
 } RULE;
 
@@ -179,7 +179,7 @@ typedef struct Itechvar
 {
 	char            *varname;
 	struct Itechvar *nexttechvar;
-	INTSML           changed;
+	BOOLEAN          changed;
 	INTBIG           ival;
 	float            fval;
 	char            *sval;
@@ -190,45 +190,43 @@ typedef struct Itechvar
 extern TECHVAR us_knownvars[];
 
 /* the globals that define a technology */
-extern INTSML           us_teceddrclayers;
+extern INTBIG           us_teceddrclayers;
 extern char           **us_teceddrclayernames;
 
 extern LIST us_teclayer_functions[];
 extern LIST us_tecarc_functions[];
-extern LIST us_tecnode_functions[];
 
 /* prototypes for intramodule routines */
 void     us_tecedgetbbox(NODEINST *ni, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy);
-INTSML   us_tecedgetdrc(char *str, INTSML *connected, INTSML *wide, INTSML *multi,
-			INTSML *widrule, INTSML *edge, INTBIG *amt, INTSML *layer1, INTSML *layer2,
-			char **rule, INTSML maxlayers, char **layernames);
-EXAMPLE *us_tecedgetexamples(NODEPROTO *np, INTSML isnode);
-INTSML   us_teceditfindsequence(LIBRARY **dependentlibs, INTSML dependentlibcount,
+BOOLEAN  us_tecedgetdrc(char *str, BOOLEAN *connected, BOOLEAN *wide, BOOLEAN *multi,
+			INTBIG *widrule, BOOLEAN *edge, INTBIG *amt, INTBIG *layer1, INTBIG *layer2,
+			char **rule, INTBIG maxlayers, char **layernames);
+EXAMPLE *us_tecedgetexamples(NODEPROTO *np, BOOLEAN isnode);
+INTBIG   us_teceditfindsequence(LIBRARY **dependentlibs, INTBIG dependentlibcount,
 			char *match, char *seqname, NODEPROTO ***sequence);
-INTSML   us_teceditgetdependents(LIBRARY *lib, LIBRARY ***liblist);
-INTSML   us_teceditgetlayerinfo(NODEPROTO *np, GRAPHICS *desc, char **cif, INTBIG *func,
+INTBIG   us_teceditgetdependents(LIBRARY *lib, LIBRARY ***liblist);
+BOOLEAN  us_teceditgetlayerinfo(NODEPROTO *np, GRAPHICS *desc, char **cif, INTBIG *func,
 			char **layerletters, char **dxf, INTBIG *gds, float *spires, float *spicap,
 			float *spiecap, INTBIG *drcminwid, INTBIG *height3d, INTBIG *thick3d);
 void     us_teceditsetpatch(NODEINST *ni, GRAPHICS *desc);
 void     us_tecedmakearc(NODEPROTO *np, INTBIG func, INTBIG fixang, INTBIG wipes,
 			INTBIG noextend, INTBIG anginc);
 void     us_tecedmakeinfo(NODEPROTO *np, INTBIG lambda, char *description);
-void     us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML style,
+void     us_tecedmakelayer(NODEPROTO *np, INTBIG colorindex, UINTSML stip[8], INTBIG style,
 			char *ciflayer, INTBIG functionindex, char *layerletters, char *dxf,
 			INTBIG gds, float spires, float spicap, float spiecap,
 			INTBIG height3d, INTBIG thick3d);
 LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech);
-void     us_tecedmakenode(NODEPROTO *np, INTBIG func, INTSML serp, INTSML square, INTSML wipes,
-			INTSML lockable);
+void     us_tecedmakenode(NODEPROTO *np, INTBIG func, BOOLEAN serp, BOOLEAN square, BOOLEAN wipes,
+			BOOLEAN lockable);
 void     us_tecedpointout(NODEINST *ni, NODEPROTO *np);
 char    *us_tecedsamplename(NODEPROTO *layernp);
-void     us_tecedswapports(INTSML *p1, INTSML *p2, TECH_NODES *tlist);
-void     us_tecfromlibinit(LIBRARY *lib, char *techname, INTSML dumpc);
+void     us_tecedswapports(INTBIG *p1, INTBIG *p2, TECH_NODES *tlist);
+void     us_tecfromlibinit(LIBRARY *lib, char *techname, BOOLEAN dumpc);
 void     us_tecedfreeexamples(EXAMPLE *ne);
-char    *us_tecedstripdash(char *str);
 void     us_tecedgetlayernamelist(void);
 void     us_tecedloaddrcmessage(DRCRULES *rules, LIBRARY *lib);
-INTSML   us_teceditgetdrcarrays(VARIABLE *var, DRCRULES *rules);
+BOOLEAN  us_teceditgetdrcarrays(VARIABLE *var, DRCRULES *rules);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
 }
