@@ -33,84 +33,86 @@ extern "C"
 {
 #endif
 
+void us_arccurveinit(ARCINST *ai);
+BOOLEAN us_arccurvedown(INTBIG x, INTBIG y);
+BOOLEAN us_arccenterdown(INTBIG x, INTBIG y);
+void us_oncommand(INTSML cmd, INTBIG special);
+void us_ontablet(INTBIG x, INTBIG y, INTBIG but);
 void us_distanceinit(void);
-void us_distancebegin(void);
-INTSML us_distancedown(INTBIG, INTBIG);
-INTSML us_distancechar(INTBIG x, INTBIG y, INTSML chr);
+BOOLEAN us_distancedown(INTBIG, INTBIG);
 void us_distanceup(void);
-INTSML us_distanceaborted(void);
 void us_textgrabinit(UINTBIG*, INTBIG, INTBIG, INTBIG, INTBIG, GEOM*);
 void us_textgrabbegin(void);
-INTSML us_textgrabdown(INTBIG, INTBIG);
+BOOLEAN us_textgrabdown(INTBIG, INTBIG);
 void us_sizeainit(ARCINST*);
 void us_sizeabegin(void);
-INTSML us_sizeadown(INTBIG, INTBIG);
+BOOLEAN us_sizeadown(INTBIG, INTBIG);
 void us_sizeinit(NODEINST*);
 INTBIG us_sizeterm(void);
-void us_sizebegin(void);
-INTSML us_sizecdown(INTBIG, INTBIG);
-INTSML us_sizedown(INTBIG, INTBIG);
+BOOLEAN us_sizecdown(INTBIG, INTBIG);
+BOOLEAN us_sizedown(INTBIG, INTBIG);
 void us_rotateinit(NODEINST*);
 void us_rotatebegin(void);
-INTSML us_rotatedown(INTBIG, INTBIG);
+BOOLEAN us_rotatedown(INTBIG, INTBIG);
 void us_tracebegin(void);
-INTSML us_tracedown(INTBIG, INTBIG);
+BOOLEAN us_tracedown(INTBIG, INTBIG);
 void us_traceup(void);
 void us_pointbegin(void);
-INTSML us_addpdown(INTBIG, INTBIG);
-void us_createinit(INTBIG, INTBIG, NODEPROTO*, INTSML, INTSML, GEOM*, PORTPROTO*);
-INTSML us_ignoreup(INTBIG, INTBIG);
+BOOLEAN us_addpdown(INTBIG, INTBIG);
+void us_createinit(INTBIG, INTBIG, NODEPROTO*, INTBIG, BOOLEAN, GEOM*, PORTPROTO*);
+BOOLEAN us_ignoreup(INTBIG, INTBIG);
 void us_createbegin(void);
-INTSML us_dragdown(INTBIG, INTBIG);
-INTSML us_stoponchar(INTBIG, INTBIG, INTSML);
-INTSML us_stopandpoponchar(INTBIG, INTBIG, INTSML);
+BOOLEAN us_dragdown(INTBIG, INTBIG);
+BOOLEAN us_stoponchar(INTBIG, INTBIG, INTSML);
+BOOLEAN us_stopandpoponchar(INTBIG, INTBIG, INTSML);
 void us_dragup(void);
 void us_invertdragup(void);
 void us_createabegin(void);
-INTSML us_createadown(INTBIG, INTBIG);
+BOOLEAN us_createadown(INTBIG, INTBIG);
 void us_createaup(void);
 void us_createajoinedobject(GEOM**, PORTPROTO**);
 void us_createinsinit(ARCINST*, NODEPROTO*);
-INTSML us_createinsdown(INTBIG, INTBIG);
-void us_multidraginit(INTBIG, INTBIG, GEOM**, NODEINST**, INTBIG, INTSML);
+void us_createinsbegin(void);
+BOOLEAN us_createinsdown(INTBIG, INTBIG);
+void us_multidraginit(INTBIG, INTBIG, GEOM**, NODEINST**, INTBIG, INTBIG);
 void us_multidragbegin(void);
-INTSML us_multidragdown(INTBIG, INTBIG);
+BOOLEAN us_multidragdown(INTBIG, INTBIG);
 void us_multidragup(void);
-void us_pointinit(NODEINST*, INTSML);
+void us_pointinit(NODEINST*, INTBIG);
 void us_findpointbegin(void);
-INTSML us_movepdown(INTBIG, INTBIG);
+BOOLEAN us_movepdown(INTBIG, INTBIG);
 void us_findiinit(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 void us_findibegin(void);
-INTSML us_findidown(INTBIG, INTBIG);
+BOOLEAN us_findidown(INTBIG, INTBIG);
 void us_findiup(void);
 void us_findcibegin(void);
 void us_findinit(INTBIG, INTBIG);
 void us_findmbegin(void);
 void us_findsbegin(void);
-INTSML us_stretchdown(INTBIG, INTBIG);
+BOOLEAN us_stretchdown(INTBIG, INTBIG);
 void us_finddbegin(void);
 void us_finddterm(INTBIG*, INTBIG*);
 void us_hthumbbegin(INTBIG x, WINDOWPART *w, INTBIG ly, INTBIG lx, INTBIG hx, void (*callback)(INTBIG));
 void us_hthumbtrackingcallback(INTBIG delta);
-INTSML us_hthumbdown(INTBIG x, INTBIG y);
+BOOLEAN us_hthumbdown(INTBIG x, INTBIG y);
 void us_hthumbdone(void);
 void us_vthumbbegin(INTBIG y, WINDOWPART *w, INTBIG hx, INTBIG ly, INTBIG hy,
-		INTSML onleft, void (*callback)(INTBIG));
+		BOOLEAN onleft, void (*callback)(INTBIG));
 void us_vthumbtrackingcallback(INTBIG delta);
-INTSML us_vthumbdown(INTBIG x, INTBIG y);
+BOOLEAN us_vthumbdown(INTBIG x, INTBIG y);
 void us_vthumbdone(void);
 void us_hpartdividerbegin(INTBIG y, INTBIG lx, INTBIG hx, WINDOWFRAME *wf);
-INTSML us_hpartdividerdown(INTBIG x, INTBIG y);
+BOOLEAN us_hpartdividerdown(INTBIG x, INTBIG y);
 void us_hpartdividerdone(void);
 void us_vpartdividerbegin(INTBIG y, INTBIG lx, INTBIG hx, WINDOWFRAME *wf);
-INTSML us_vpartdividerdown(INTBIG x, INTBIG y);
+BOOLEAN us_vpartdividerdown(INTBIG x, INTBIG y);
 void us_vpartdividerdone(void);
 void us_arrowclickbegin(WINDOWPART *w, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy, INTBIG amount);
-INTSML us_varrowdown(INTBIG x, INTBIG y);
-INTSML us_harrowdown(INTBIG x, INTBIG y);
-INTSML us_nullup(INTBIG, INTBIG);
+BOOLEAN us_varrowdown(INTBIG x, INTBIG y);
+BOOLEAN us_harrowdown(INTBIG x, INTBIG y);
+BOOLEAN us_nullup(INTBIG, INTBIG);
 void us_nullvoid(void);
-INTSML us_nullchar(INTBIG x, INTBIG y, INTSML ch);
+BOOLEAN us_nullchar(INTBIG x, INTBIG y, INTSML ch);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
 }
