@@ -33,21 +33,21 @@
 #include "usr.h"
 #include "edialogs.h"
 
-static INTSML  io_outputstage;		/* progress of database (aborting) */
+static BOOLEAN io_outputstage;		/* progress of database (aborting) */
 static char   *io_namesave;			/* for saving the global namespace */
 static char   *io_outfilename = 0;	/* the name of the file being written */
 
 /* prototypes for local routines */
 static void io_cleanup(void);
-static void io_writenodeproto(NODEPROTO*, INTSML);
+static void io_writenodeproto(NODEPROTO*, BOOLEAN);
 static void io_writenodeinst(NODEINST*);
 static void io_writearcinst(ARCINST*);
 static void io_writenamespace(void);
 static void io_restorenamespace(void);
-static void io_writevariables(VARIABLE*, INTSML);
+static void io_writevariables(VARIABLE*, INTSML, INTBIG);
 static void io_findxlibvariables(VARIABLE*, INTSML);
 static void io_putoutvar(INTBIG*, INTBIG);
-static void io_putout(void*, INTSML);
+static void io_putout(void*, INTBIG);
 static void io_putoutbig(void*);
 static void io_putstring(char*);
 
@@ -59,14 +59,16 @@ void io_freebinoutmemory(void)
 	if (io_outfilename != 0) efree(io_outfilename);
 }
 
-INTSML io_writebinlibrary(LIBRARY *lib, INTSML nobackup)
+BOOLEAN io_writebinlibrary(LIBRARY *lib, BOOLEAN nobackup)
 {
 	INTBIG i, a, n, p, magic, aacount, techcount, nodepprotoindex,
-		portpprotoindex, arcprotoindex, nodeprotoindex, nodeindex,
-		portprotoindex, arcindex, geomindex, curnodeproto, cellindex,
+		portprotoindex, portpprotoindex, arcprotoindex, nodeprotoindex, nodeindex,
+		arcindex, geomindex, curnodeproto, cellindex,
 		*curstate, facetshere;
+	BOOLEAN err;
 	UINTBIG olddate;
-	INTSML save, year, month, mday, hour, minute, second;
+	INTBIG year, month, mday, hour, minute, second;
+	INTSML save;
 	REGISTER NODEPROTO *np;
 	REGISTER ARCPROTO *ap;
 	REGISTER PORTPROTO *pp;
@@ -82,26 +84,35 @@ INTSML io_writebinlibrary(LIBRARY *lib, INTSML nobackup)
 	REGISTER CELL *c;
 	REGISTER VIEW *v;
 
-	io_outputstage = 0;
+	io_outputstage = FALSE;
+	dotaddr = 0;
 	ext = &lib->libfile[strlen(lib->libfile)-5];
 	if (strcmp(ext, ".elib") == 0)
 	{
 		dotaddr = ext;
 		*ext = 0;
-	} else dotaddr = 0;
-	istrue = truepath(lib->libfile);
-	i = initinfstr();
-	i += addstringtoinfstr(istrue);
-	i += addstringtoinfstr(".elib");
-	if (io_outfilename == 0) 
-	{
-		i += allocstring(&io_outfilename, returninfstr(), io_tool->cluster);
 	} else
 	{
-		i += reallocstring(&io_outfilename, returninfstr(), io_tool->cluster);
+		ext = &lib->libfile[strlen(lib->libfile)-4];
+		if (strcmp(ext, ".txt") == 0)
+		{
+			dotaddr = ext;
+			*ext = 0;
+		}
+	}
+	istrue = truepath(lib->libfile);
+	err = initinfstr();
+	err |= addstringtoinfstr(istrue);
+	err |= addstringtoinfstr(".elib");
+	if (io_outfilename == 0) 
+	{
+		err |= allocstring(&io_outfilename, returninfstr(), io_tool->cluster);
+	} else
+	{
+		err |= reallocstring(&io_outfilename, returninfstr(), io_tool->cluster);
 	}
 	if (dotaddr != 0) *dotaddr = '.';
-	if (i != 0)
+	if (err)
 	{
 		DiaMessageInDialog(_("No memory! saving to 'PANIC'"));
 		name = _("PANIC");
@@ -114,9 +125,9 @@ INTSML io_writebinlibrary(LIBRARY *lib, INTSML nobackup)
 	if ((curstate[0]&CHECKATWRITE) != 0)
 	{
 		ttyputmsg(_("Checking all libraries..."));
-		us_checkdatabase(0);
+		us_checkdatabase(FALSE);
 	}
-	if (nobackup != 0) curstate[0] &= ~(BINOUTBACKUP|CHECKATWRITE);
+	if (nobackup) curstate[0] &= ~(BINOUTBACKUP|CHECKATWRITE);
 
 	rename = 0;
 	if ((lib->userbits&READFROMDISK) == 0) msg = _("Library File"); else
@@ -153,8 +164,8 @@ INTSML io_writebinlibrary(LIBRARY *lib, INTSML nobackup)
 					parsetime(olddate, &year, &month, &mday, &hour, &minute, &second);
 					for(i=0; i<1000; i++)
 					{
-						if (i == 0) sprintf(datesuffix, "-%d-%d-%d", year, month+1, mday); else
-							sprintf(datesuffix, "-%d-%d-%d--%ld", year, month+1, mday, i);
+						if (i == 0) sprintf(datesuffix, "-%ld-%ld-%ld", year, month+1, mday); else
+							sprintf(datesuffix, "-%ld-%ld-%ld--%ld", year, month+1, mday, i);
 						(void)strcpy(rename, name);
 						rename[strlen(rename)-5] = 0;
 						(void)strcat(rename, datesuffix);
@@ -175,7 +186,7 @@ INTSML io_writebinlibrary(LIBRARY *lib, INTSML nobackup)
 	{
 		if (truename != 0) DiaMessageInDialog(_("Cannot write %s"), truename);
 		if (rename != 0) efree(rename);
-		return(1);
+		return(TRUE);
 	}
 
 	/* if the user got a dialog, replace the library and file name */
@@ -205,7 +216,7 @@ INTSML io_writebinlibrary(LIBRARY *lib, INTSML nobackup)
 			ttyputmsg(_("Old binary file saved in %s"), rename);
 			efree(rename);
 		}
-		return(1);
+		return(TRUE);
 	}
 
 	/* first flush all changes so that database is clean */
@@ -447,34 +458,34 @@ INTSML io_writebinlibrary(LIBRARY *lib, INTSML nobackup)
 
 	/* write the global namespace */
 	io_writenamespace();
-	io_outputstage = 1;
+	io_outputstage = TRUE;
 
 	/* write the library variables */
-	io_writevariables(lib->firstvar, lib->numvar);
+	io_writevariables(lib->firstvar, lib->numvar, VLIBRARY);
 
 	/* write the tool variables */
 	for(i=0; i<el_maxtools; i++)
-		io_writevariables(el_tools[i].firstvar, el_tools[i].numvar);
+		io_writevariables(el_tools[i].firstvar, el_tools[i].numvar, VTOOL);
 
 	/* write the variables on technologies */
 	for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
-		io_writevariables(tech->firstvar, tech->numvar);
+		io_writevariables(tech->firstvar, tech->numvar, VTECHNOLOGY);
 
 	/* write the arcproto variables */
 	for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
 		for(ap = tech->firstarcproto; ap != NOARCPROTO; ap = ap->nextarcproto)
-			io_writevariables(ap->firstvar, ap->numvar);
+			io_writevariables(ap->firstvar, ap->numvar, VARCPROTO);
 
 	/* write the variables on primitive node prototypes */
 	for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
 		for(np = tech->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-			io_writevariables(np->firstvar, np->numvar);
+			io_writevariables(np->firstvar, np->numvar, VNODEPROTO);
 
 	/* write the variables on primitive port prototypes */
 	for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
 		for(np = tech->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 			for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
-				io_writevariables(pp->firstvar, pp->numvar);
+				io_writevariables(pp->firstvar, pp->numvar, VPORTPROTO);
 
 	/* write the view variables */
 	i = 0;
@@ -483,7 +494,7 @@ INTSML io_writebinlibrary(LIBRARY *lib, INTSML nobackup)
 	for(v = el_views; v != NOVIEW; v = v->nextview)
 	{
 		io_putoutbig(&v->temp1);
-		io_writevariables(v->firstvar, v->numvar);
+		io_writevariables(v->firstvar, v->numvar, VVIEW);
 	}
 
 	/* write all of the cell names in this library */
@@ -495,7 +506,7 @@ INTSML io_writebinlibrary(LIBRARY *lib, INTSML nobackup)
 		io_putstring(c->cellname);
 
 		/* write variable information */
-		io_writevariables(c->firstvar, c->numvar);
+		io_writevariables(c->firstvar, c->numvar, VCELL);
 
 		if (io_verbose > 0) ttyputmsg(M_("Wrote cell %s"), c->cellname);
 	}
@@ -513,7 +524,7 @@ INTSML io_writebinlibrary(LIBRARY *lib, INTSML nobackup)
 
 			/* write dummy variable information */
 			save = c->numvar;   c->numvar = 0;
-			io_writevariables(c->firstvar, c->numvar);
+			io_writevariables(c->firstvar, c->numvar, VCELL);
 			c->numvar = save;
 		}
 	}
@@ -522,7 +533,7 @@ INTSML io_writebinlibrary(LIBRARY *lib, INTSML nobackup)
 	for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 	{
 		if (stopping(STOPREASONBINARY)) longjmp(io_filerror, 1);
-		io_writenodeproto(np, 1);
+		io_writenodeproto(np, TRUE);
 	}
 
 	/* write all of the facets in external libraries */
@@ -532,7 +543,7 @@ INTSML io_writebinlibrary(LIBRARY *lib, INTSML nobackup)
 		for(np = olib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 		{
 			if (np->temp2 == 0) continue;
-			io_writenodeproto(np, 0);
+			io_writenodeproto(np, FALSE);
 		}
 	}
 
@@ -580,7 +591,7 @@ INTSML io_writebinlibrary(LIBRARY *lib, INTSML nobackup)
 #endif
 	}
 	lib->userbits = (lib->userbits & ~(LIBCHANGEDMAJOR | LIBCHANGEDMINOR)) | READFROMDISK;
-	return(0);
+	return(FALSE);
 }
 
 /*
@@ -590,7 +601,7 @@ INTSML io_writebinlibrary(LIBRARY *lib, INTSML nobackup)
 void io_cleanup(void)
 {
 	/* if binary output didn't get far, no cleanup needed */
-	if (io_outputstage == 0) return;
+	if (!io_outputstage) return;
 
 	/* restore damage to the global namespace */
 	io_restorenamespace();
@@ -598,7 +609,7 @@ void io_cleanup(void)
 
 /******************** COMPONENT OUTPUT ********************/
 
-void io_writenodeproto(NODEPROTO *np, INTSML thislib)
+void io_writenodeproto(NODEPROTO *np, BOOLEAN thislib)
 {
 	INTBIG i;
 	REGISTER PORTPROTO *pp;
@@ -617,7 +628,7 @@ void io_writenodeproto(NODEPROTO *np, INTSML thislib)
 	io_putoutbig(&np->lowy);
 	io_putoutbig(&np->highy);
 
-	if (thislib == 0)
+	if (!thislib)
 	{
 		instlib = np->cell->lib;
 		io_putstring(instlib->libfile);
@@ -631,23 +642,35 @@ void io_writenodeproto(NODEPROTO *np, INTSML thislib)
 	/* write the portprotos on this nodeproto */
 	for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 	{
-		if (thislib != 0)
+		if (thislib)
 		{
 			/* write the connecting subnodeinst for this portproto */
-			if (pp->subnodeinst == NONODEINST) i = -1; else
-				i = pp->subnodeinst->temp1;
+			if (pp->subnodeinst != NONODEINST) i = pp->subnodeinst->temp1; else
+			{
+				ttyputmsg(_("ERROR: Library %s, facet %s, export %s has no node"),
+					np->cell->lib->libname, describenodeproto(np), pp->protoname);
+				i = -1;
+			}	
 			io_putoutbig(&i);
 
 			/* write the portproto index in the subnodeinst */
-			if (pp->subnodeinst == NONODEINST || pp->subportproto == NOPORTPROTO) i = -1; else
+			if (pp->subnodeinst != NONODEINST && pp->subportproto != NOPORTPROTO)
+			{
 				i = pp->subportproto->temp1;
+			} else
+			{
+				if (pp->subportproto != NOPORTPROTO)
+					ttyputmsg(_("ERROR: Library %s, facet %s, export %s has no subport"),
+						np->cell->lib->libname, describenodeproto(np), pp->protoname);
+				i = -1;
+			}
 			io_putoutbig(&i);
 		}
 
 		/* write the portproto name */
 		io_putstring(pp->protoname);
 
-		if (thislib != 0)
+		if (thislib)
 		{
 			/* write the text descriptor */
 			io_putoutbig(&pp->textdescript[0]);
@@ -657,18 +680,18 @@ void io_writenodeproto(NODEPROTO *np, INTSML thislib)
 			io_putoutbig(&pp->userbits);
 
 			/* write variable information */
-			io_writevariables(pp->firstvar, pp->numvar);
+			io_writevariables(pp->firstvar, pp->numvar, VPORTPROTO);
 		}
 	}
 
-	if (thislib != 0)
+	if (thislib)
 	{
 		/* write tool information */
 		io_putoutbig(&np->adirty);
 		io_putoutbig(&np->userbits);
 
 		/* write variable information */
-		io_writevariables(np->firstvar, np->numvar);
+		io_writevariables(np->firstvar, np->numvar, VNODEPROTO);
 	}
 
 	if (io_verbose > 0) ttyputmsg(M_("Wrote facet %s"), describenodeproto(np));
@@ -713,7 +736,7 @@ void io_writenodeinst(NODEINST *ni)
 		io_putoutbig(&pi->proto->temp1);
 
 		/* write the variable information */
-		io_writevariables(pi->firstvar, pi->numvar);
+		io_writevariables(pi->firstvar, pi->numvar, VPORTARCINST);
 	}
 
 	/* count the exports */
@@ -730,14 +753,14 @@ void io_writenodeinst(NODEINST *ni)
 		io_putoutbig(&pe->proto->temp1);
 
 		/* write the variable information */
-		io_writevariables(pe->firstvar, pe->numvar);
+		io_writevariables(pe->firstvar, pe->numvar, VPORTEXPINST);
 	}
 
 	/* write the tool information */
 	io_putoutbig(&ni->userbits);
 
 	/* write variable information */
-	io_writevariables(ni->firstvar, ni->numvar);
+	io_writevariables(ni->firstvar, ni->numvar, VNODEINST);
 }
 
 void io_writearcinst(ARCINST *arcinst)
@@ -764,7 +787,7 @@ void io_writearcinst(ARCINST *arcinst)
 	io_putoutbig(&arcinst->userbits);
 
 	/* write variable information */
-	io_writevariables(arcinst->firstvar, arcinst->numvar);
+	io_writevariables(arcinst->firstvar, arcinst->numvar, VARCINST);
 }
 
 /******************** VARIABLE ROUTINES ********************/
@@ -815,7 +838,7 @@ void io_restorenamespace(void)
  */
 void io_findxlibvariables(VARIABLE *firstvar, INTSML numvar)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 	REGISTER INTBIG len, type, j;
 	REGISTER VARIABLE *var;
 	REGISTER NODEPROTO *np, **nparray;
@@ -852,7 +875,7 @@ void io_findxlibvariables(VARIABLE *firstvar, INTSML numvar)
 	}
 }
 
-void io_writevariables(VARIABLE *firstvar, INTSML numvar)
+void io_writevariables(VARIABLE *firstvar, INTSML numvar, INTBIG type)
 {
 	REGISTER INTBIG i, j, datasize;
 	INTBIG num, ty, len, addr;
@@ -863,14 +886,24 @@ void io_writevariables(VARIABLE *firstvar, INTSML numvar)
 	for(i=0; i<numvar; i++)
 	{
 		if ((firstvar[i].type&VDONTSAVE) != 0) continue;
+		if (io_verbose > 0)
+		{
+			if (type == VTOOL)
+			{
+				(void)initinfstr();
+				j = *((INTSML *)firstvar[i].key);
+				(void)addtoinfstr(io_namesave[j*2]);
+				(void)addtoinfstr(io_namesave[j*2+1]);
+				if (io_namesave[j*2+1] != 0)
+					(void)addstringtoinfstr(&makename(firstvar[i].key)[2]);
+				ttyputmsg("Writing tool variable: %s", returninfstr());
+			}
+		}
 		io_putout((void *)firstvar[i].key, SIZEOFINTSML);
 		ty = firstvar[i].type;
 		io_putoutbig(&ty);
-		if ((ty&VDISPLAY) != 0)
-		{
-			io_putoutbig(&firstvar[i].textdescript[0]);
-			io_putoutbig(&firstvar[i].textdescript[1]);
-		}
+		io_putoutbig(&firstvar[i].textdescript[0]);
+		io_putoutbig(&firstvar[i].textdescript[1]);
 		addr = firstvar[i].addr;
 		if ((ty&VISARRAY) != 0)
 		{
@@ -979,13 +1012,13 @@ void io_putoutvar(INTBIG *addr, INTBIG ty)
 			break;
 		case VGEOM:
 			geom = (GEOM *)*addr;
-			io_putoutbig(&geom->entrytype);
+			if (geom->entryisnode) j = 1; else j = 0;
+			io_putoutbig(&j);
 			if ((INTBIG)geom->entryaddr.blind == -1) io_putoutbig(&nullptr); else
 			{
-				if (geom->entrytype == OBJNODEINST)
+				if (geom->entryisnode)
 					io_putoutbig(&geom->entryaddr.ni->temp1); else
-						if (geom->entrytype == OBJARCINST)
-							io_putoutbig(&geom->entryaddr.ai->temp1);
+						io_putoutbig(&geom->entryaddr.ai->temp1);
 			}
 			break;
 		case VPORTARCINST:
@@ -1025,7 +1058,7 @@ void io_putoutbig(void *data)
 	io_putout(data, SIZEOFINTBIG);
 }
 
-void io_putout(void *data, INTSML size)
+void io_putout(void *data, INTBIG size)
 {
 	REGISTER INTBIG ret;
 
@@ -1044,5 +1077,5 @@ void io_putstring(char *name)
 
 	len = strlen(name);
 	io_putoutbig(&len);
-	if (len != 0) io_putout(name, (INTSML)len);
+	if (len != 0) io_putout(name, len);
 }
