@@ -34,6 +34,7 @@
 #include "global.h"
 #include "database.h"
 #include "eio.h"
+#include "usr.h"
 #include "iocifpars.h"
 #include "edialogs.h"
 #include <math.h>
@@ -56,7 +57,7 @@ static CIFCELL **io_cifcells = (CIFCELL **)NOSTRING; /* hash table of 'cifcells'
 static INTBIG    io_cifcells_size = 0; 	/* allocated size of io_cifcells */
 static INTBIG    io_cifcells_num = 0;	/* number of used entries in io_cifcells */
 static CIFCELL  *io_curcell;			/* the current cell */
-static INTSML    io_cifroundwires;		/* nonzero if wires should be rounded */
+static BOOLEAN   io_cifroundwires;		/* nonzero if wires should be rounded */
 
 /**************************** CIF LISTS ****************************/
 
@@ -76,7 +77,7 @@ static INTSML    io_cifroundwires;		/* nonzero if wires should be rounded */
 
 typedef struct Iciflist
 {
-	INTSML           identity;		/* specifies the nature of the entry */
+	INTBIG           identity;		/* specifies the nature of the entry */
 	char            *member;		/* will point to member's structure */
 	struct Iciflist *next;			/* next entry in list */
 } CIFLIST;
@@ -95,22 +96,22 @@ typedef struct Icfstart
 
 typedef struct Icbox
 {
-	INTSML lay;						/* the corresponding layer number */
+	INTBIG lay;						/* the corresponding layer number */
 	INTBIG length, width;			/* dimensions of box */
 	INTBIG cenx, ceny;				/* center point of box */
-	INTSML xrot, yrot;				/* box direction */
+	INTBIG xrot, yrot;				/* box direction */
 } CBOX;
 
 typedef struct Icpolygon
 {
-	INTSML  lay;					/* the corresponding layer number */
+	INTBIG  lay;					/* the corresponding layer number */
 	INTBIG *x, *y;					/* list of points */
-	INTSML  lim;					/* number of points in list */
+	INTBIG  lim;					/* number of points in list */
 } CPOLY;
 
 typedef struct Icgeoname
 {
-	INTSML lay;						/* the corresponding layer number */
+	INTBIG lay;						/* the corresponding layer number */
 	INTBIG x, y;					/* location of name */
 	char  *geoname;					/* the geo name */
 } CGNAME;
@@ -138,7 +139,7 @@ typedef struct Iccall
 
 typedef struct Ictrans
 {
-	INTSML          type;			/* type of transformation */
+	INTBIG          type;			/* type of transformation */
 	INTBIG          x, y;			/* not required for the mirror types */
 	struct Ictrans *next;			/* next element in list */
 } CTRANS;
@@ -150,27 +151,27 @@ static CTRANS *io_curctrans;				/* current transformation description */
 static char       *io_curnodeprotoname;		/* name of the current cell */
 static NODEPROTO  *io_incell;				/* address of facet being defined */
 static NODEPROTO **io_cifnodes = 0;			/* nodeprotos associated with CIF names */
-static INTSML      io_varlength;			/* the length of all attribute arrays */
+static INTBIG      io_varlength;			/* the length of all attribute arrays */
 static VARIABLE   *io_cifnames;				/* cif names for the current technology */
 static INTBIG      io_cifnotfoundcount;		/* number of unknown layer names */
 static char      **io_cifnotfoundlist;		/* unknown layer name list */
 static INTBIG      io_cifnotfoundlimit = 0;	/* size of unknown layer name list */
 
 /* prototypes for local routines */
-static INTSML     io_interpret(FILE*);
-static INTSML     io_listtonodes(LIBRARY*);
+static BOOLEAN    io_interpret(FILE*);
+static BOOLEAN    io_listtonodes(LIBRARY*);
 static NODEPROTO *io_nodes_start(LIBRARY*);
-static INTSML     io_nodes_box(void);
-static INTSML     io_nodes_poly(void);
-static INTSML     io_nodes_call(void);
-static void       io_rotatelayer(INTBIG*, INTBIG*, INTSML);
-static INTSML     io_initfind(void);
-static NODEPROTO *io_findprotonode(INTSML);
+static BOOLEAN    io_nodes_box(void);
+static BOOLEAN    io_nodes_poly(void);
+static BOOLEAN    io_nodes_call(void);
+static void       io_rotatelayer(INTBIG*, INTBIG*, INTBIG);
+static BOOLEAN    io_initfind(void);
+static NODEPROTO *io_findprotonode(INTBIG);
 static CIFCELL   *io_findcifcell(INTBIG);
 static void       io_insertcifcell(CIFCELL *cifcell);
 static CIFCELL   *io_newcifcell(INTBIG);
-static CIFLIST   *io_newciflist(INTSML);
-static void       io_placeciflist(INTSML);
+static CIFLIST   *io_newciflist(INTBIG);
+static void       io_placeciflist(INTBIG);
 static CTRANS    *io_newctrans(void);
 static void       io_ciffreeciflist(void);
 static void       io_ciffreecifcells(void);
@@ -185,90 +186,90 @@ void io_freecifinmemory(void)
 	if (io_cifnodes != 0) efree((char *)io_cifnodes);
 }
 
-INTSML io_readciflibrary(LIBRARY *lib)
+BOOLEAN io_readciflibrary(LIBRARY *lib)
 {
 	REGISTER FILE *f;
 	char *filename;
 	REGISTER INTBIG i, *curstate;
 
 	curstate = io_getstatebits();
-	if ((curstate[0]&CIFINSQUARE) != 0) io_cifroundwires = 0;
-		else io_cifroundwires = 1;
+	if ((curstate[0]&CIFINSQUARE) != 0) io_cifroundwires = FALSE;
+		else io_cifroundwires = TRUE;
 
 	/* initialize all lists and the searching routines */
 	io_ciffreecifcells();
 	io_ciffreeciflist();
 
-	if (io_initfind()) return(1);
+	if (io_initfind()) return(TRUE);
 
 	/* get the cif file */
 	f = xopen(lib->libfile, io_filetypecif, "", &filename);
 	if (f == NULL)
 	{
 		ttyputerr(_("File %s not found"), lib->libfile);
-		return(1);
+		return(TRUE);
 	}
 
 	if (setjmp(io_filerror))
 	{
 		ttyputerr(_("Error reading CIF"));
-		return(1);
+		return(TRUE);
 	}
 
 	/* initialize list of not-found layers */
 	io_cifnotfoundcount = 0;
 
 	/* parse the cif and create a listing */
-	if (io_interpret(f)) return(1);
+	if (io_interpret(f)) return(TRUE);
 
 	/* instantiate the cif as nodes */
-	if (io_listtonodes(lib)) return(1);
+	if (io_listtonodes(lib)) return(TRUE);
 
 	/* clean up */
 	(void)io_doneinterpreter();
 	for(i=0; i<io_cifnotfoundcount; i++) efree((char *)io_cifnotfoundlist[i]);
 
-	return(0);
+	return(FALSE);
 }
 
-INTSML io_interpret(FILE *file)
+BOOLEAN io_interpret(FILE *file)
 {
 	INTBIG comcount, left, right, bottom, top;
 
 	if (io_initparser())
 	{
 		ttyputerr(_("Error initializing parser"));
-		return(1);
+		return(TRUE);
 	}
 	if (io_initinterpreter())
 	{
 		ttyputerr(_("Error initializing interpreter"));
-		return(1);
+		return(TRUE);
 	}
-	if (io_infromfile(file)) return(1);
+	if (io_infromfile(file)) return(TRUE);
 	comcount = io_parsefile();		/* read in the cif */
 	(void)io_doneparser();
-	if (stopping(STOPREASONCIF)) return(1);
+	if (stopping(STOPREASONCIF)) return(TRUE);
 	ttyputverbose(M_("Total CIF commands: %ld"), comcount);
 
-	if (io_fatalerrors() > 0) return(1);
+	if (io_fatalerrors() > 0) return(TRUE);
 
 	io_iboundbox(&left, &right, &bottom, &top);
 
 	/* construct a list: first step in the conversion */
 	(void)io_createlist();
-	return(0);
+	return(FALSE);
 }
 
 /**************************** NODE CONVERSION ****************************/
 
-INTSML io_listtonodes(LIBRARY *lib)
+BOOLEAN io_listtonodes(LIBRARY *lib)
 {
 	extern DIALOG us_progressdialog;
 
 	if (io_verbose < 0)
 	{
-		if (DiaInitDialog(&us_progressdialog) != 0) return(1);
+		if (DiaInitDialog(&us_progressdialog)) return(TRUE);
 		DiaPercent(1, 100);
 	}
 	io_incell = NONODEPROTO;
@@ -277,7 +278,7 @@ INTSML io_listtonodes(LIBRARY *lib)
 		if (stopping(STOPREASONCIF))
 		{
 			if (io_verbose < 0) DiaDoneDialog();
-			return(1);
+			return(TRUE);
 		}
 		if (io_incell != NONODEPROTO || io_curlist->identity == C_START)
 			switch (io_curlist->identity)
@@ -287,7 +288,7 @@ INTSML io_listtonodes(LIBRARY *lib)
 				if (io_incell == NONODEPROTO)
 				{
 					if (io_verbose < 0) DiaDoneDialog();
-					return(1);
+					return(TRUE);
 				}
 				break;
 			case C_END:
@@ -301,27 +302,27 @@ INTSML io_listtonodes(LIBRARY *lib)
 				if (io_nodes_box())
 				{
 					if (io_verbose < 0) DiaDoneDialog();
-					return(1);
+					return(TRUE);
 				}
 				break;
 			case C_POLY:
 				if (io_nodes_poly())
 				{
 					if (io_verbose < 0) DiaDoneDialog();
-					return(1);
+					return(TRUE);
 				}
 				break;
 			case C_CALL:
 				if (io_nodes_call())
 				{
 					if (io_verbose < 0) DiaDoneDialog();
-					return(1);
+					return(TRUE);
 				}
 				break;
 		}
 	}
 	if (io_verbose < 0) DiaDoneDialog();
-	return(0);
+	return(FALSE);
 }
 
 NODEPROTO *io_nodes_start(LIBRARY *lib)
@@ -340,7 +341,7 @@ NODEPROTO *io_nodes_start(LIBRARY *lib)
 	for(opt = io_curnodeprotoname; *opt != 0; opt++)
 		if (*opt <= ' ' || *opt == ':' || *opt == ';' || *opt >= 0177)
 			*opt = 'X';
-	cifcell->addr = newnodeproto(io_curnodeprotoname, lib);
+	cifcell->addr = us_newnodeproto(io_curnodeprotoname, lib);
 	if (cifcell->addr == NONODEPROTO)
 	{
 		ttyputerr(_("Cannot create the cell %s"), io_curnodeprotoname);
@@ -356,7 +357,7 @@ NODEPROTO *io_nodes_start(LIBRARY *lib)
 	return(cifcell->addr);
 }
 
-INTSML io_nodes_box(void)
+BOOLEAN io_nodes_box(void)
 {
 	NODEPROTO *node;
 	CBOX *cb;
@@ -368,9 +369,9 @@ INTSML io_nodes_box(void)
 	if (node == NONODEPROTO)
 	{
 		layname = layername(el_curtech, cb->lay);
-		ttyputerr(_("Cannot find primitive to use for layer '%s' (number %d)"),
+		ttyputerr(_("Cannot find primitive to use for layer '%s' (number %ld)"),
 			layname, cb->lay);
-		return(1);
+		return(TRUE);
 	}
 	l = cb->length;        w = cb->width;
 	lx = cb->cenx - l/2;   ly = cb->ceny - w/2;
@@ -378,17 +379,17 @@ INTSML io_nodes_box(void)
 	r = figureangle(0, 0, (INTBIG)cb->xrot, (INTBIG)cb->yrot);
 	if (newnodeinst(node, scalefromdispunit((float)lx, DISPUNITCMIC),
 		scalefromdispunit((float)hx, DISPUNITCMIC), scalefromdispunit((float)ly, DISPUNITCMIC),
-		scalefromdispunit((float)hy, DISPUNITCMIC), 0, (INTSML)r, io_curcell->addr) == NONODEINST)
+		scalefromdispunit((float)hy, DISPUNITCMIC), 0, r, io_curcell->addr) == NONODEINST)
 	{
 		layname = layername(el_curtech, cb->lay);
 		ttyputerr(_("Problems creating a box on layer %s in facet %s"), layname,
 			describenodeproto(io_curcell->addr));
-		return(1);
+		return(TRUE);
 	}
-	return(0);
+	return(FALSE);
 }
 
-INTSML io_nodes_poly(void)
+BOOLEAN io_nodes_poly(void)
 {
 	REGISTER INTBIG lx, ly, hx, hy, i, *trace, cx, cy, *pt;
 	REGISTER NODEPROTO *np;
@@ -396,7 +397,7 @@ INTSML io_nodes_poly(void)
 	REGISTER CPOLY *cp;
 
 	cp = (CPOLY *)io_curlist->member;
-	if (cp->lim == 0) return(0);
+	if (cp->lim == 0) return(FALSE);
 	np = io_findprotonode(cp->lay);
 	lx = hx = cp->x[0];   ly = hy = cp->y[0];
 	for(i=1; i<cp->lim; i++)
@@ -411,14 +412,14 @@ INTSML io_nodes_poly(void)
 			scalefromdispunit((float)hy, DISPUNITCMIC), 0, 0, io_curcell->addr);
 	if (newni == NONODEINST)
 	{
-		ttyputerr(_("Problems creating a polygon on layer %d in facet %s"), cp->lay,
+		ttyputerr(_("Problems creating a polygon on layer %ld in facet %s"), cp->lay,
 			describenodeproto(io_curcell->addr));
-		return(1);
+		return(TRUE);
 	}
 
 	/* store the trace information */
 	pt = trace = emalloc((cp->lim*2*SIZEOFINTBIG), io_tool->cluster);
-	if (trace == 0) return(1);
+	if (trace == 0) return(TRUE);
 	cx = (hx + lx) / 2;   cy = (hy + ly) / 2;
 	for(i=0; i<cp->lim; i++)
 	{
@@ -427,29 +428,29 @@ INTSML io_nodes_poly(void)
 	}
 
 	/* store the trace information */
-	(void)setvalkey((INTBIG)newni, VNODEINST, el_trace, (INTBIG)trace,
+	(void)setvalkey((INTBIG)newni, VNODEINST, el_trace_key, (INTBIG)trace,
 		VINTEGER|VISARRAY|((cp->lim*2)<<VLENGTHSH));
 
 	/* free the polygon memory */
 	efree((char *)trace);
 	efree((char *)cp->x);   efree((char *)cp->y);
 	cp->lim = 0;
-	return(0);
+	return(FALSE);
 }
 
-INTSML io_nodes_call(void)
+BOOLEAN io_nodes_call(void)
 {
 	CIFCELL *cell;
 	CCALL *cc;
 	CTRANS *ctrans;
 	INTBIG l, r, t, b, rot, trans, hlen, hwid, cenx, ceny, temp;
-	INTSML deg;
+	INTBIG deg;
 
 	cc = (CCALL *)io_curlist->member;
 	if ((cell = io_findcifcell(cc->cindex)) == NOCIFCELL)
 	{
 		ttyputerr(_("Referencing an undefined cell"));
-		return(1);
+		return(TRUE);
 	}
 	rot = trans = 0;
 	l = cell->l;    r = cell->r;    b = cell->b;    t = cell->t;
@@ -476,7 +477,7 @@ INTSML io_nodes_call(void)
 			{
 				hlen = abs(((l-r)/2));   hwid = abs(((b-t)/2));
 				cenx = (l+r)/2;   ceny = (b+t)/2;
-				io_rotatelayer(&cenx,&ceny, deg);
+				io_rotatelayer(&cenx, &ceny, deg);
 				l = cenx - hlen;   r = cenx + hlen;
 				b = ceny - hwid;   t = ceny + hwid;
 				rot += ((trans) ? -deg : deg);
@@ -486,17 +487,17 @@ INTSML io_nodes_call(void)
 	while(rot < 0) rot += 3600;
 	if (newnodeinst((NODEPROTO *)(cell->addr), scalefromdispunit((float)l, DISPUNITCMIC),
 		scalefromdispunit((float)r, DISPUNITCMIC), scalefromdispunit((float)b, DISPUNITCMIC),
-			scalefromdispunit((float)t, DISPUNITCMIC), (INTSML)trans, (INTSML)rot, io_curcell->addr) ==
+			scalefromdispunit((float)t, DISPUNITCMIC), trans, rot, io_curcell->addr) ==
 				NONODEINST)
 	{
 		ttyputerr(_("Problems creating an instance of cell %s in facet %s"),
 			describenodeproto(cell->addr), describenodeproto(io_curcell->addr));
-		return(1);
+		return(TRUE);
 	}
-	return(0);
+	return(FALSE);
 }
 
-void io_rotatelayer(INTBIG *cenx, INTBIG *ceny, INTSML deg)
+void io_rotatelayer(INTBIG *cenx, INTBIG *ceny, INTBIG deg)
 {
 	double vlen, vang, fx, fy, factx, facty, fact;
 	INTBIG temp;
@@ -532,7 +533,7 @@ void io_rotatelayer(INTBIG *cenx, INTBIG *ceny, INTSML deg)
 
 /**************************** SEARCHING ROUTINES ****************************/
 
-INTSML io_initfind(void)
+BOOLEAN io_initfind(void)
 {
 	REGISTER char *ch, *ch2;
 	REGISTER NODEPROTO *np;
@@ -546,21 +547,21 @@ INTSML io_initfind(void)
 	{
 		ttyputerr(_("There are no CIF layer names assigned in the %s technology"),
 			el_curtech->techname);
-		return(-1);
+		return(TRUE);
 	}
-	io_varlength = (INTSML)getlength(io_cifnames);
+	io_varlength = getlength(io_cifnames);
 	if (io_varlength < el_curtech->layercount)
 	{
 		ttyputerr(_("Warning: CIF layer information is bad for technology %s.  Use 'CIF Options' to fix it"),
 			el_curtech->techname);
-		return(-1);
+		return(TRUE);
 	}
 
 	/* create the array of nodes associated with the array of CIF names */
 	total = el_curtech->layercount;
 	if (io_cifnodes != 0) efree((char *)io_cifnodes);
 	io_cifnodes = (NODEPROTO **)emalloc((total * (sizeof (NODEPROTO *))), io_tool->cluster);
-	if (io_cifnodes == 0) return(-1);
+	if (io_cifnodes == 0) return(TRUE);
 	for(i=0; i<total; i++) io_cifnodes[i] = NONODEPROTO;
 
 	/* create the polygon */
@@ -631,7 +632,7 @@ INTSML io_initfind(void)
 		}
 	}
 
-	return(0);
+	return(FALSE);
 }
 
 INTBIG io_findlayernum(char *name)
@@ -666,7 +667,7 @@ INTBIG io_findlayernum(char *name)
 	return(-1);
 }
 
-NODEPROTO *io_findprotonode(INTSML num)
+NODEPROTO *io_findprotonode(INTBIG num)
 {
 	return(io_cifnodes[num]);
 }
@@ -765,7 +766,7 @@ void io_ciffreecifcells(void)
 	io_cifcells = (CIFCELL **)NOSTRING;
 }
 
-CIFLIST *io_newciflist(INTSML id)
+CIFLIST *io_newciflist(INTBIG id)
 {
 	CIFLIST *newcl;
 	CCALL *cc;
@@ -853,7 +854,7 @@ void io_ciffreeciflist(void)
 	}
 }
 
-void io_placeciflist(INTSML id)
+void io_placeciflist(INTBIG id)
 {
 	CIFLIST *cl;
 
@@ -886,10 +887,10 @@ CTRANS *io_newctrans(void)
 	return(newct);
 }
 
-void io_outputwire(INTSML lay, INTBIG width, char *wpath)
+void io_outputwire(INTBIG lay, INTBIG width, char *wpath)
 {
 	/* convert wires to boxes and flashes  */
-	INTSML i;
+	INTBIG i;
 	INTBIG llt, lrt, lbm, ltp, lim;
 	point prev, curr;
 
@@ -897,7 +898,7 @@ void io_outputwire(INTSML lay, INTBIG width, char *wpath)
 	prev = io_removepoint((path)wpath);
 
 	/* do not use roundflashes with zero-width wires */
-	if (width != 0 && io_cifroundwires != 0)
+	if (width != 0 && io_cifroundwires)
 	{
 		io_bbflash(lay, width, prev, &llt, &lrt, &lbm, &ltp);
 		io_outputflash(lay, width, prev);
@@ -911,22 +912,22 @@ void io_outputwire(INTSML lay, INTBIG width, char *wpath)
 		curr = io_removepoint((path)wpath);
 
 		/* do not use roundflashes with zero-width wires */
-		if (width != 0 && io_cifroundwires != 0)
+		if (width != 0 && io_cifroundwires)
 		{
 			io_bbflash(lay, width, curr, &llt, &lrt, &lbm, &ltp);
 			io_outputflash(lay, width, curr);
 		}
 		xr = curr.x-prev.x;   yr = curr.y-prev.y;
 		len = computedistance(0, 0, xr, yr);
-		if (io_cifroundwires == 0) len += width;
+		if (!io_cifroundwires) len += width;
 		center.x = (curr.x+prev.x)/2;   center.y = (curr.y+prev.y)/2;
 		io_bbbox(lay, len, width, center, xr, yr, &llt, &lrt, &lbm, &ltp);
-		io_outputbox(lay, len, width, center, (INTSML)xr, (INTSML)yr);
+		io_outputbox(lay, len, width, center, xr, yr);
 		prev = curr;
 	}
 }
 
-void io_outputflash(INTSML lay, INTBIG diameter, point center)
+void io_outputflash(INTBIG lay, INTBIG diameter, point center)
 {
 	/* flash approximated by an octagon */
 	INTBIG radius = diameter/2;
@@ -938,31 +939,31 @@ void io_outputflash(INTSML lay, INTBIG diameter, point center)
 
 	temp.x = center.x-radius;
 	temp.y = roundfloat(fcy+offset);
-	if (io_appendpoint((path)fpath, temp) != 0) return;
+	if (io_appendpoint((path)fpath, temp)) return;
 	temp.y = roundfloat(fcy-offset);
-	if (io_appendpoint((path)fpath, temp) != 0) return;
+	if (io_appendpoint((path)fpath, temp)) return;
 	temp.x = roundfloat(fcx-offset);
 	temp.y = center.y-radius;
-	if (io_appendpoint((path)fpath, temp) != 0) return;
+	if (io_appendpoint((path)fpath, temp)) return;
 	temp.x = roundfloat(fcx+offset);
-	if (io_appendpoint((path)fpath, temp) != 0) return;
+	if (io_appendpoint((path)fpath, temp)) return;
 	temp.x = center.x+radius;
 	temp.y = roundfloat(fcy-offset);
-	if (io_appendpoint((path)fpath, temp) != 0) return;
+	if (io_appendpoint((path)fpath, temp)) return;
 	temp.y = roundfloat(fcy+offset);
-	if (io_appendpoint((path)fpath, temp) != 0) return;
+	if (io_appendpoint((path)fpath, temp)) return;
 	temp.x = roundfloat(fcx+offset);
 	temp.y = center.y+radius;
-	if (io_appendpoint((path)fpath, temp) != 0) return;
+	if (io_appendpoint((path)fpath, temp)) return;
 	temp.x = roundfloat(fcx-offset);
-	if (io_appendpoint((path)fpath, temp) != 0) return;
+	if (io_appendpoint((path)fpath, temp)) return;
 
 	io_outputpolygon(lay, fpath);
 	io_freepath((path)fpath);
 }
 
-void io_outputbox(INTSML lay, INTBIG length, INTBIG width, point center,
-	INTSML xrotation, INTSML yrotation)
+void io_outputbox(INTBIG lay, INTBIG length, INTBIG width, point center,
+	INTBIG xrotation, INTBIG yrotation)
 {
 	CBOX *cb;
 
@@ -975,9 +976,9 @@ void io_outputbox(INTSML lay, INTBIG length, INTBIG width, point center,
 	cb->xrot = xrotation;	cb->yrot = yrotation;
 }
 
-void io_outputpolygon(INTSML lay, char *ppath)
+void io_outputpolygon(INTBIG lay, char *ppath)
 {
-	INTSML i;
+	INTBIG i;
 	INTBIG lim;
 	CPOLY *cp;
 	point temp;
@@ -1003,7 +1004,7 @@ void io_outputpolygon(INTSML lay, char *ppath)
 		return;
 	}
 
-	cp->lim = (INTSML)lim;
+	cp->lim = lim;
 	for (i = 0; i < lim; i++)
 	{
 		temp = io_removepoint((path)ppath);
@@ -1012,11 +1013,11 @@ void io_outputpolygon(INTSML lay, char *ppath)
 	}
 }
 
-void io_outputusercommand(INTSML command, char *text)
+void io_outputusercommand(INTBIG command, char *text)
 {
 }
 
-void io_outputgeoname(char *name, point pt, INTSML lay)
+void io_outputgeoname(char *name, point pt, INTBIG lay)
 {
 	CGNAME *cg;
 
