@@ -45,15 +45,15 @@
 static INTBIG     io_prev_chr_sep, io_nchar;	/* for CRC checksum */
 static UINTBIG    io_check_sum;					/* for CRC checksum */
 static UINTBIG    io_cifcrctab[256];			/* for CRC checksum */
-static INTSML     io_cif_resolution;			/* for resolution tests */
+static INTBIG     io_cif_resolution;			/* for resolution tests */
 static INTBIG     io_cif_polypoints;			/* for points on a polygon tests */
 static INTBIG    *io_cifoutputstate;			/* current output state */
 static INTBIG     io_cifoutoffx;				/* offset for current facet - for highlight */
 static INTBIG     io_cifoutoffy;				/* offset for current facet - for highlight */
 static NODEPROTO *io_cifoutcurnp;				/* node proto of facet being written */
-static INTSML     io_zero_offset;				/* Set if there is no centering */
-static INTSML     io_cif_highlightreserr;		/* Set to highlight resolution errors */
-static INTSML     io_reserr_count;				/* count the resolution errors */
+static BOOLEAN    io_zero_offset;				/* Set if there is no centering */
+static BOOLEAN    io_cif_highlightreserr;		/* Set to highlight resolution errors */
+static INTBIG     io_reserr_count;				/* count the resolution errors */
 static char       io_cifoutcurlayer[200];		/* current layer name written out */
 static INTBIG     io_cifoutfacetnumber;			/* count of facets being written out */
 static INTBIG     io_cifoutjobsize;				/* number of facets to write out */
@@ -75,11 +75,11 @@ static LAYERREQ **io_ciflayerreqlist;
 static INTBIG     io_ciflayerreqlisttotal = 0;
 
 /* prototypes for local routines */
-static void io_cifwritefacet(NODEPROTO*, INTSML);
+static void io_cifwritefacet(NODEPROTO*, BOOLEAN);
 static void io_outputcifpoly(TECHNOLOGY*, POLYGON*, INTBIG, INTBIG, INTBIG, INTBIG, XARRAY, GEOM*);
 static void io_cifprintf(char *msg, ...);
-static void io_cifreserror(GEOM*, INTBIG, INTBIG, INTBIG, INTBIG);
-static void io_cif_write_polygon(INTSML, TECHNOLOGY*, INTBIG*, INTBIG*, INTSML);
+static void io_cifreserror(GEOM*, INTBIG, INTBIG, INTBIG, INTBIG, XARRAY);
+static void io_cif_write_polygon(INTBIG, TECHNOLOGY*, INTBIG*, INTBIG*, INTBIG);
 static void io_cif_show_reserror(INTBIG, INTBIG, INTBIG, INTBIG);
 static INTBIG io_cif_outscale(INTBIG value);
 static LAYERREQ *io_alloclayerreq(void);
@@ -122,7 +122,7 @@ void io_initcif(void)
 	DiaDeclareHook("cifopt", &io_cifp, io_cifoptionsdlog);
 }
 
-INTSML io_writeciflibrary(LIBRARY *lib)
+BOOLEAN io_writeciflibrary(LIBRARY *lib)
 {
 	char file[100], *truename;
 	REGISTER char *name;
@@ -139,7 +139,7 @@ INTSML io_writeciflibrary(LIBRARY *lib)
 	if (lib->curnodeproto == NONODEPROTO)
 	{
 		ttyputerr(_("Must be editing a facet to generate CIF output"));
-		return(1);
+		return(TRUE);
 	}
 	(void)strcpy(file, lib->curnodeproto->cell->cellname);
 	if (strcmp(&file[strlen(file)-4],".cif") != 0) (void)strcat(file, ".cif");
@@ -148,25 +148,25 @@ INTSML io_writeciflibrary(LIBRARY *lib)
 	if (io_fileout == NULL)
 	{
 		if (truename != 0) ttyputerr(_("Cannot write %s"), truename);
-		return(1);
+		return(TRUE);
 	}
 
 	/* get current output state */
 	io_cifoutputstate = io_getstatebits();
 
 	/* get form of output */
-	if ((io_cifoutputstate[0]&CIFOUTNOTCEN) != 0) io_zero_offset = 1; else
-		io_zero_offset = 0;
-	if ((io_cifoutputstate[1]&CIFRESHIGH) != 0) io_cif_highlightreserr = 1; else
-		io_cif_highlightreserr = 0;
+	if ((io_cifoutputstate[0]&CIFOUTNORMALIZE) != 0) io_zero_offset = FALSE; else
+		io_zero_offset = TRUE;
+	if ((io_cifoutputstate[1]&CIFRESHIGH) != 0) io_cif_highlightreserr = TRUE; else
+		io_cif_highlightreserr = FALSE;
 
 	/* get cif resolution */
 	var = getval((INTBIG)el_curtech, VTECHNOLOGY, VINTEGER, "IO_cif_resolution");
 	if (var == NOVARIABLE) io_cif_resolution = 0; else
 	{
-		io_cif_resolution = (INTSML)var->addr;
-		if (io_cif_resolution != 0 && io_cif_highlightreserr != 0)
-			(void)asktool(us_tool, "clear");
+		io_cif_resolution = var->addr;
+		if (io_cif_resolution != 0 && io_cif_highlightreserr)
+			initerrorlogging("CIF Resolution");
 	}
 
 	/* get the number of allowable points on a polygon */
@@ -219,9 +219,9 @@ INTSML io_writeciflibrary(LIBRARY *lib)
 	for(olib = el_curlib; olib != NOLIBRARY; olib = olib->nextlibrary)
 		for(np = olib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 			np->temp1 = 0;
-	io_cifwritefacet(lib->curnodeproto, 1);
+	io_cifwritefacet(lib->curnodeproto, TRUE);
 	io_cifoutjobsize = io_cifoutfacetnumber;
-	if (DiaInitDialog(&us_progressdialog) != 0) return(1);
+	if (DiaInitDialog(&us_progressdialog)) return(TRUE);
 	DiaPercent(1, 0);
 	DiaSetText(2, _("Writing CIF..."));
 
@@ -232,11 +232,11 @@ INTSML io_writeciflibrary(LIBRARY *lib)
 	for(olib = el_curlib; olib != NOLIBRARY; olib = olib->nextlibrary)
 		for(np = olib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 			np->temp1 = 0;
-	io_cifwritefacet(lib->curnodeproto, 0);
+	io_cifwritefacet(lib->curnodeproto, FALSE);
 
 	/* clean up */
 	if ((io_cifoutputstate[0]&CIFOUTNOTOPCALL) == 0)
-		io_cifprintf("C %d;\n", io_cifbase);
+		io_cifprintf("C %ld;\n", io_cifbase);
 	io_cifprintf("E\n");
 	xclose(io_fileout);
 	DiaDoneDialog();
@@ -249,19 +249,6 @@ INTSML io_writeciflibrary(LIBRARY *lib)
 	/* tell the user that the file is written */
 	ttyputmsg(_("%s written"), truename);
 
-	if (io_cif_resolution != 0 && io_reserr_count != 0)
-	{
-		if (io_cif_highlightreserr != 0)
-		{
-			ttyputerr(_("WARNING: Highlighted %d resolution %s"), io_reserr_count,
-				makeplural(_("error"), io_reserr_count));
-		} else
-		{
-			ttyputerr(_("WARNING: Found %d resolution %s"), io_reserr_count,
-				makeplural(_("error"), io_reserr_count));
-		}
-	}
-
 	/* complete the checksum accumulation */
 	if (!io_prev_chr_sep)
 	{
@@ -279,28 +266,41 @@ INTSML io_writeciflibrary(LIBRARY *lib)
 	io_check_sum = ~io_check_sum & 0xFFFFFFFF;
 	ttyputmsg(_("(MOSIS CRC: %lu %ld)"), io_check_sum, io_nchar);
 
-	return(0);
+	/* complete error accumulation */
+	if (io_cif_resolution != 0)
+	{
+		if (io_cif_highlightreserr)
+		{
+			io_reserr_count = numerrors();
+			termerrorlogging(TRUE);
+		}
+		if (io_reserr_count != 0)
+			ttyputerr(_("WARNING: Found %ld resolution %s"), io_reserr_count,
+				makeplural(_("error"), io_reserr_count));
+	}
+
+	return(FALSE);
 }
 
-void io_cifwritefacet(NODEPROTO *np, INTSML fake)
+void io_cifwritefacet(NODEPROTO *np, BOOLEAN fake)
 {
 	REGISTER NODEINST *subni;
 	REGISTER ARCINST *ai;
-	REGISTER NODEPROTO *subnt, *bodysubnt, *onp;
+	REGISTER NODEPROTO *subnt, *onp;
 	REGISTER PORTPROTO *pp, *subpp;
 	REGISTER PORTARCINST *pi;
 	REGISTER INTBIG i, j, total, validport, toplayer, toplayerfound;
 	REGISTER INTBIG offx, offy, fun;
 	REGISTER LAYERREQ *req;
-	XARRAY trans, localtran, temp2, subrot;
-	INTBIG rx, ry, xpos, ypos, bx, by, cx, cy;
+	XARRAY trans, localtran, temp2, subrot, subt, subr, submat;
+	INTBIG rx, ry, xpos, ypos, bx, by, subcornerx, subcornery;
 	static POLYGON *poly = NOPOLYGON;
 
 	/* get polygon */
 	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_tool->cluster);
 
 	io_cifoutfacetnumber++;
-	if (fake == 0)
+	if (!fake)
 	{
 		/* stop if requested */
 		if (stopping(STOPREASONCIF)) return;
@@ -335,22 +335,23 @@ void io_cifwritefacet(NODEPROTO *np, INTSML fake)
 	}
 
 	np->temp1 = ++io_cifbase;
-	if (fake != 0) return;
+	if (fake) return;
 
 	io_cifoutcurnp = np;			/* set global for highlighting */
 
 	/* prepare to write the facet */
-	if (io_zero_offset != 0)
+	if (io_zero_offset)
 	{
-		offx = io_cifoutoffx = np->lowx;
-		offy = io_cifoutoffy = np->lowy;
+		grabpoint(np, &io_cifoutoffx, &io_cifoutoffy);
+		offx = io_cifoutoffx;
+		offy = io_cifoutoffy;
 	} else
 	{
 		offx = io_cifoutoffx = (np->lowx + np->highx) / 2;
 		offy = io_cifoutoffy = (np->lowy + np->highy) / 2;
 	}
-	io_cifprintf("DS %d 1 1;\n", io_cifbase);
-	io_cifprintf("9 %s;\n", np->cell->cellname);
+	io_cifprintf("DS %ld 1 1;\n", io_cifbase);
+	io_cifprintf("9 %s; (from library %s);\n", np->cell->cellname, np->cell->lib->libname);
 
 	io_cifoutcurlayer[0] = 0;
 	if ((io_cifoutputstate[0]&CIFOUTMERGE) == 0)
@@ -428,8 +429,8 @@ void io_cifwritefacet(NODEPROTO *np, INTSML fake)
 				if (subnt->tech != req->tech) continue;
 				i = subni->rotation;
 				if (subni->transpose != 0) i = (i + 900) % 3600;
-				rx = ((cosine((INTSML)i)>>14) * 100) >> 16;
-				ry = ((sine((INTSML)i)>>14) * 100) >> 16;
+				rx = ((cosine(i)>>14) * 100) >> 16;
+				ry = ((sine(i)>>14) * 100) >> 16;
 				makerot(subni, trans);
 
 				/* write a primitive nodeinst */
@@ -473,8 +474,8 @@ void io_cifwritefacet(NODEPROTO *np, INTSML fake)
 			if (subnt->primindex == 0) continue;
 			i = subni->rotation;
 			if (subni->transpose != 0) i = (i + 900) % 3600;
-			rx = ((cosine((INTSML)i)>>14) * 100) >> 16;
-			ry = ((sine((INTSML)i)>>14) * 100) >> 16;
+			rx = ((cosine(i)>>14) * 100) >> 16;
+			ry = ((sine(i)>>14) * 100) >> 16;
 			makerot(subni, trans);
 
 			/* write a primitive nodeinst */
@@ -517,80 +518,39 @@ void io_cifwritefacet(NODEPROTO *np, INTSML fake)
 
 		i = subni->rotation;
 		if (subni->transpose != 0) i = (i + 900) % 3600;
-		rx = ((cosine((INTSML)i)>>14) * 100) >> 16;
-		ry = ((sine((INTSML)i)>>14) * 100) >> 16;
+		rx = ((cosine(i)>>14) * 100) >> 16;
+		ry = ((sine(i)>>14) * 100) >> 16;
 		makerot(subni, trans);
+
+		/* determine offset of facet */
+		if (io_zero_offset)
+		{
+			grabpoint(subni->proto, &bx, &by);
+			maketrans(subni, subt);
+			makerot(subni, subr);
+			transmult(subt, subr, submat);
+			xform(bx, by, &subcornerx, &subcornery, submat);
+			xpos = (subcornerx - offx);
+			ypos = (subcornery - offy);
+		} else
+		{
+			xpos = (subni->lowx + subni->highx)/2 - offx;
+			ypos = (subni->lowy + subni->highy)/2 - offy;
+		}
 		if ((subni->userbits&NEXPAND) != 0 || (io_cifoutputstate[0]&CIFOUTEXACT) == 0)
 		{
-			/* write a call to a facet */
-			if (io_zero_offset != 0)
-			{
-				/*
-				 * find where the lower corner has been moved to,
-				 * by moving the origin back to the center, transforming the lower
-				 * corner, then converting back to lower left origin
-				 */
-				trans[2][0] = (subni->highx - subni->lowx); /* avoid roundoff */
-				trans[2][1] = (subni->highy - subni->lowy);
-				xform(-trans[2][0], -trans[2][1], &xpos, &ypos, trans);
-				xpos /= 2; ypos /= 2;   /* now contains the correction */
-				xpos += (subni->lowx - offx);
-				ypos += (subni->lowy - offy);
-			} else
-			{
-				xpos = (subni->lowx + subni->highx)/2 - offx;
-				ypos = (subni->lowy + subni->highy)/2 - offy;
-			}
-
-			/* convert body facets to contents facets */
-			onp = contentsview(subnt);
-			if (onp != NONODEPROTO)
-			{
-				/* look for grab points in contents and body facets */
-				bodysubnt = subnt;
-				subnt = onp;
-
-				corneroffset(subni, bodysubnt, subni->rotation, subni->transpose, &bx, &by, 0);
-				corneroffset(NONODEINST, subnt, subni->rotation, subni->transpose, &cx, &cy, 0);
-
-				if (io_zero_offset != 0)
-				{
-					/* This code may be incorrect */
-					trans[2][0] = (subni->highx - subni->lowx); /* avoid roundoff */
-					trans[2][1] = (subni->highy - subni->lowy);
-					xform(-trans[2][0], -trans[2][1], &xpos, &ypos, trans);
-					xpos /= 2; ypos /= 2;   /* now contains the correction */
-					xpos += subni->lowx + bx - cx - offx;
-					ypos += subni->lowy + by - cy - offy;
-				} else
-				{
-					xpos = subni->lowx + bx - cx + (subnt->highx-subnt->lowx)/2 - offx;
-					ypos = subni->lowy + by - cy + (subnt->highy-subnt->lowy)/2 - offy;
-				}
-			}
-
-			/* resolution problem with call */
+			/* check resolution of call */
 			if (io_cif_resolution != 0)
 			{
-				if (io_zero_offset != 0) /* Why not use xpos and ypos here? */
+				if ((xpos%io_cif_resolution) != 0 || (ypos%io_cif_resolution) != 0)
 				{
-					if ((xpos%io_cif_resolution) != 0 || (ypos%io_cif_resolution) != 0)
-					{
-						io_cifprintf(_("(Call to symbol %ld does not resolve to grid);\n"),
-							subnt->temp1);
-						io_reserr_count++;
-					}
-				} else
-				{
-					if ((((subni->lowx+subni->highx)/2-offx)%io_cif_resolution) != 0 ||
-						(((subni->lowy+subni->highy)/2-offy)%io_cif_resolution) != 0)
-					{
-						io_cifprintf(_("(Call to symbol %ld does not resolve to grid);\n"),
-							subnt->temp1);
-						io_reserr_count++;
-					}
+					io_cifprintf(_("(Call to symbol %ld does not resolve to grid);\n"),
+						subnt->temp1);
+					io_reserr_count++;
 				}
 			}
+
+			/* write a call to a facet */
 			io_cifprintf("C %ld R %ld %ld", subnt->temp1, rx, ry);
 			if (subni->transpose != 0) io_cifprintf(" M Y");
 			io_cifprintf(" T %ld %ld;\n", io_cif_outscale(xpos), io_cif_outscale(ypos));
@@ -603,13 +563,8 @@ void io_cifwritefacet(NODEPROTO *np, INTSML fake)
 						io_cif_outscale(subni->highx-offx), io_cif_outscale(subni->highy-offy),
 							io_cif_outscale(subni->highx-offx), io_cif_outscale(subni->lowy-offy),
 								io_cif_outscale(subni->lowx-offx), io_cif_outscale(subni->lowy-offy));
-			io_cifprintf("2C \"%s", describenodeproto(subnt));
-			if (io_zero_offset != 0)
-				io_cifprintf("\" T %ld %ld;\n", io_cif_outscale(subni->lowx - offx),
-					io_cif_outscale(subni->lowy - offy)); else
-						io_cifprintf("\" T %ld %ld;\n",
-							io_cif_outscale((subni->lowx+subni->highx)/2-offx),
-								io_cif_outscale((subni->lowy+subni->highy)/2-offy));
+			io_cifprintf("2C \"%s\" T %ld %ld;\n", describenodeproto(subnt),
+				io_cif_outscale(xpos), io_cif_outscale(ypos));
 		}
 	}
 
@@ -646,10 +601,10 @@ void io_cifwritefacet(NODEPROTO *np, INTSML fake)
 			fun = layerfunction(poly->tech, poly->layer);
 			if ((fun&LFPSEUDO) != 0) continue;
 			xformpoly(poly, subrot);
-			if (isinside(xpos-1, ypos, poly) == 0) continue;
-			if (isinside(xpos+1, ypos, poly) == 0) continue;
-			if (isinside(xpos, ypos-1, poly) == 0) continue;
-			if (isinside(xpos, ypos+1, poly) == 0) continue;
+			if (!isinside(xpos-1, ypos, poly)) continue;
+			if (!isinside(xpos+1, ypos, poly)) continue;
+			if (!isinside(xpos, ypos-1, poly)) continue;
+			if (!isinside(xpos, ypos+1, poly)) continue;
 			if (poly->layer == toplayer) toplayerfound = 1;
 			validport = 1;
 			break;
@@ -673,10 +628,10 @@ void io_cifwritefacet(NODEPROTO *np, INTSML fake)
 						fun = layerfunction(poly->tech, poly->layer);
 						if ((fun&LFPSEUDO) != 0) continue;
 						xformpoly(poly, subrot);
-						if (isinside(xpos-1, ypos, poly) == 0) continue;
-						if (isinside(xpos+1, ypos, poly) == 0) continue;
-						if (isinside(xpos, ypos-1, poly) == 0) continue;
-						if (isinside(xpos, ypos+1, poly) == 0) continue;
+						if (!isinside(xpos-1, ypos, poly)) continue;
+						if (!isinside(xpos+1, ypos, poly)) continue;
+						if (!isinside(xpos, ypos-1, poly)) continue;
+						if (!isinside(xpos, ypos+1, poly)) continue;
 						if (poly->layer == toplayer) toplayerfound = 1;
 						validport = 1;
 						break;
@@ -737,7 +692,7 @@ INTBIG io_ciffindhighestlayer(NODEPROTO *np, INTBIG x, INTBIG y)
 	{
 		geom = nextobject(sea);
 		if (geom == NOGEOM) break;
-		if (geom->entrytype == OBJNODEINST)
+		if (geom->entryisnode)
 		{
 			ni = geom->entryaddr.ni;
 			if (ni->proto->primindex == 0) continue;
@@ -745,8 +700,8 @@ INTBIG io_ciffindhighestlayer(NODEPROTO *np, INTBIG x, INTBIG y)
 			for(i=0; i<tot; i++)
 			{
 				shapenodepoly(ni, i, poly);
-				if (isinside(x, y, poly) == 0) continue;
-				if (get3dfactors(poly->tech, poly->layer, &height, &thickness) != 0)
+				if (!isinside(x, y, poly)) continue;
+				if (get3dfactors(poly->tech, poly->layer, &height, &thickness))
 					continue;
 
 				/* LINTED "bestheight" used in proper order */
@@ -764,8 +719,8 @@ INTBIG io_ciffindhighestlayer(NODEPROTO *np, INTBIG x, INTBIG y)
 			for(i=0; i<tot; i++)
 			{
 				shapearcpoly(ai, i, poly);
-				if (isinside(x, y, poly) == 0) continue;
-				if (get3dfactors(poly->tech, poly->layer, &height, &thickness) != 0)
+				if (!isinside(x, y, poly)) continue;
+				if (get3dfactors(poly->tech, poly->layer, &height, &thickness))
 					continue;
 				if (first != 0 || height > bestheight)
 				{
@@ -844,7 +799,7 @@ void io_outputcifpoly(TECHNOLOGY *tech, POLYGON *poly, INTBIG rx, INTBIG ry,
 			}
 #endif
 
-			if (isbox(poly, &xl,&xh, &yl,&yh) != 0)
+			if (isbox(poly, &xl,&xh, &yl,&yh))
 			{
 				/* ignore zero-size polygons */
 				if (xh == xl || yh == yl) return;
@@ -876,10 +831,10 @@ void io_outputcifpoly(TECHNOLOGY *tech, POLYGON *poly, INTBIG rx, INTBIG ry,
 				io_writeciflayer(layername);
 
 				/* non-merged box: highlight resolution errors */
-				xform((xl+xh)/2, (yl+yh)/2, &xpos, &ypos, trans);
-				io_cifreserror(geom, xh-xl+bloat, yh-yl+bloat, xpos-offx, ypos-offy);
+				io_cifreserror(geom, xh-xl+bloat, yh-yl+bloat, (xl+xh)/2, (yl+yh)/2, trans);
 
 				/* want individual box output */
+				xform((xl+xh)/2, (yl+yh)/2, &xpos, &ypos, trans);
 				io_cifprintf(" B %ld %ld %ld %ld", io_cif_outscale(xh-xl+bloat),
 					io_cif_outscale(yh-yl+bloat), io_cif_outscale(xpos-offx),
 						io_cif_outscale(ypos-offy));
@@ -1000,35 +955,43 @@ void io_cifprintf(char *msg, ...)
 	xprintf(io_fileout, "%s", temp);
 }
 
-/* routine which highlights box which doesnt resolve */
-void io_cifreserror(GEOM *pos, INTBIG length, INTBIG width, INTBIG xc, INTBIG yc)
+/* routine which highlights box which doesn't resolve */
+void io_cifreserror(GEOM *pos, INTBIG length, INTBIG width, INTBIG xc, INTBIG yc, XARRAY trans)
 {
-	INTBIG left, right, top, bot;
+	INTBIG ptx[4], pty[4], x, y;
+	REGISTER INTBIG i;
+	void *err;
 
-	left = xc - (length/2);
-	right = xc + (length/2);
-	top = yc + (width/2);
-	bot = yc - (width/2);
+	/* stop if no resolution check or no geometry module */
+	if (io_cif_resolution == 0 || pos == NOGEOM) return;
 
-	/* if there is a geometry module */
-	if (io_cif_resolution != 0 && pos != NOGEOM)
+	ptx[0] = ptx[1] = xc - (length/2);
+	ptx[2] = ptx[3] = xc + (length/2);
+	pty[0] = pty[3] = yc + (width/2);
+	pty[1] = pty[2] = yc - (width/2);
+	for(i=0; i<4; i++)
 	{
+		xform(ptx[i], pty[i], &x, &y, trans);
+
 		/* see if it resolves to grid */
-		if ((left % io_cif_resolution) != 0 || (right % io_cif_resolution) != 0 ||
-			(top % io_cif_resolution) != 0 || (bot % io_cif_resolution) != 0)
+		if ((x % io_cif_resolution) != 0 || (y % io_cif_resolution) != 0)
 		{
 			/* highlight the object */
-			if (io_cif_highlightreserr != 0)
-				(void)asktool(us_tool, "show-object", (INTBIG)pos);
+			if (io_cif_highlightreserr)
+			{
+				err = logerror("Resolution error", geomparent(pos), 0);
+				addgeomtoerror(err, pos, TRUE, 0, 0);
+			}
 			io_reserr_count++;
+			return;
 		}
 	}
 }
 
-void io_cif_write_polygon(INTSML layer, TECHNOLOGY *tech, INTBIG *xbuf, INTBIG *ybuf,
-	INTSML count)
+void io_cif_write_polygon(INTBIG layer, TECHNOLOGY *tech, INTBIG *xbuf, INTBIG *ybuf,
+	INTBIG count)
 {
-	INTSML buflen, prlen, i, err;
+	INTBIG buflen, prlen, i;
 	INTBIG tmpx, tmpy;
 	char outbuf[NMCHR+2], prbuf[40], *layername; /* declare buffers */
 
@@ -1044,13 +1007,12 @@ void io_cif_write_polygon(INTSML layer, TECHNOLOGY *tech, INTBIG *xbuf, INTBIG *
 
 	/* check the number of points on the polygon */
 	if (count > io_cif_polypoints)
-		ttyputerr(_("WARNING: Polygon has too many points (%d)"), count);
+		ttyputerr(_("WARNING: Polygon has too many points (%ld)"), count);
 
 	/* search for any resolution errors on this polygon */
 	/* highlight any edges that don't resolve */
 	if (io_cif_resolution != 0)
 	{
-		err = 0;
 		tmpx = xbuf[count-1];
 		tmpy = ybuf[count-1];
 		for (i = 0; i < count; i++)
@@ -1059,17 +1021,14 @@ void io_cif_write_polygon(INTSML layer, TECHNOLOGY *tech, INTBIG *xbuf, INTBIG *
 			{
 				io_cif_show_reserror(tmpx+io_cifoutoffx, tmpy+io_cifoutoffy,
 					xbuf[i]+io_cifoutoffx, ybuf[i]+io_cifoutoffy);
-				err++;
 			} else if ((tmpy%io_cif_resolution) != 0 && tmpy == ybuf[i])
 			{
 				io_cif_show_reserror(tmpx+io_cifoutoffx, tmpy+io_cifoutoffy,
 					xbuf[i]+io_cifoutoffx, ybuf[i]+io_cifoutoffy);
-				err++;
 			}
 			tmpx = xbuf[i];
 			tmpy = ybuf[i];
 		}
-		if (err != 0) io_reserr_count++;
 	}
 
 	for(i=0; i<count; i++)
@@ -1112,16 +1071,14 @@ void io_cif_write_polygon(INTSML layer, TECHNOLOGY *tech, INTBIG *xbuf, INTBIG *
 
 void io_cif_show_reserror(INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2)
 {
-	REGISTER NODEPROTO *np;
+	REGISTER void *err;
 
-	if (io_cif_highlightreserr == 0) return;
+	if (!io_cif_highlightreserr) return;
 
 	/* show resolution error if it is in the current window */
-	np = getcurfacet();
-	if (np == io_cifoutcurnp)
-		(void)asktool(us_tool, "show-line", x1, y1, x2, y2, np); else
-			ttyputmsg(_("Resolution error in subfacet %s"),
-				describenodeproto(io_cifoutcurnp));
+	err = logerror("Resolution error", io_cifoutcurnp, 0);
+	addlinetoerror(err, x1, y1, x2, y2);
+	io_reserr_count++;
 }
 
 INTBIG io_cif_outscale(INTBIG value)
@@ -1176,20 +1133,22 @@ void io_freelayerreq(LAYERREQ *req)
 /* CIF Options */
 static DIALOGITEM io_cifoptionsdialogitems[] =
 {
- /*  1 */ {0, {180,380,204,452}, BUTTON, N_("OK")},
- /*  2 */ {0, {180,240,204,312}, BUTTON, N_("Cancel")},
- /*  3 */ {0, {8,8,204,223}, SCROLL, ""},
+ /*  1 */ {0, {224,380,248,452}, BUTTON, N_("OK")},
+ /*  2 */ {0, {224,240,248,312}, BUTTON, N_("Cancel")},
+ /*  3 */ {0, {8,8,248,223}, SCROLL, ""},
  /*  4 */ {0, {8,232,24,312}, MESSAGE, N_("CIF Layer:")},
  /*  5 */ {0, {8,316,24,454}, EDITTEXT, ""},
  /*  6 */ {0, {32,232,48,454}, CHECK, N_("Output Mimics Display")},
  /*  7 */ {0, {56,232,72,454}, CHECK, N_("Output Merges Boxes")},
- /*  8 */ {0, {104,232,120,454}, CHECK, N_("Input Squares Wires")},
- /*  9 */ {0, {80,232,96,454}, CHECK, N_("Output Instantiates Top Level")},
- /* 10 */ {0, {148,240,164,384}, MESSAGE, N_("Output resolution:")},
- /* 11 */ {0, {148,388,164,454}, EDITTEXT, ""},
- /* 12 */ {0, {128,232,144,436}, POPUP, ""}
+ /*  8 */ {0, {148,232,164,454}, CHECK, N_("Input Squares Wires")},
+ /*  9 */ {0, {100,232,116,454}, CHECK, N_("Output Instantiates Top Level")},
+ /* 10 */ {0, {196,240,212,384}, MESSAGE, N_("Output resolution:")},
+ /* 11 */ {0, {196,388,212,454}, EDITTEXT, ""},
+ /* 12 */ {0, {172,232,188,436}, POPUP, ""},
+ /* 13 */ {0, {124,232,140,454}, CHECK, N_("Normalize Coordinates")},
+ /* 14 */ {0, {76,248,92,454}, MESSAGE, N_("(time consuming)")}
 };
-static DIALOG io_cifoptionsdialog = {{50,75,263,538}, N_("CIF Options"), 0, 12, io_cifoptionsdialogitems};
+static DIALOG io_cifoptionsdialog = {{50,75,307,538}, N_("CIF Options"), 0, 14, io_cifoptionsdialogitems};
 
 /* special items for the "CIF Options" dialog: */
 #define DCFO_LAYERLIST         3		/* Layer list (scroll list) */
@@ -1201,6 +1160,7 @@ static DIALOG io_cifoptionsdialog = {{50,75,263,538}, N_("CIF Options"), 0, 12,
 #define DCFO_ORESOLUTION_L    10		/* Output Resolution label (stat text) */
 #define DCFO_ORESOLUTION      11		/* Output resolution (edit text) */
 #define DCFO_ORESOLUTIONMODE  12		/* Output resolution mode (popup) */
+#define DCFO_ONORMALIZECOORD  13		/* Output normalizes coordinates (check) */
 
 void io_cifoptionsdlog(void)
 {
@@ -1212,7 +1172,7 @@ void io_cifoptionsdlog(void)
 	static char *whattodisplay[] = {N_("No Resolution Check"),
 		N_("Report Resolution Errors"), N_("Show Resolution Errors")};
 
-	if (DiaInitDialog(&io_cifoptionsdialog) != 0) return;
+	if (DiaInitDialog(&io_cifoptionsdialog)) return;
 	for(i=0; i<3; i++) newlang[i] = _(whattodisplay[i]);
 	DiaSetPopup(DCFO_ORESOLUTIONMODE, 3, newlang);
 	DiaInitTextDialog(DCFO_LAYERLIST, DiaNullDlogList, DiaNullDlogItem,
@@ -1241,6 +1201,7 @@ void io_cifoptionsdlog(void)
 	if ((curstate[0]&CIFOUTMERGE) != 0) DiaSetControl(DCFO_OMERGEBOXES, 1);
 	if ((curstate[0]&CIFINSQUARE) != 0) DiaSetControl(DCFO_ISQUAREWIRES, 1);
 	if ((curstate[0]&CIFOUTNOTOPCALL) == 0) DiaSetControl(DCFO_OINSTANTIATETOP, 1);
+	if ((curstate[0]&CIFOUTNORMALIZE) != 0) DiaSetControl(DCFO_ONORMALIZECOORD, 1);
 	var = getval((INTBIG)el_curtech, VTECHNOLOGY, VINTEGER, "IO_cif_resolution");
 	if (var == NOVARIABLE) oldresolution = 0; else oldresolution = var->addr;
 	if (oldresolution == 0)
@@ -1276,7 +1237,8 @@ void io_cifoptionsdlog(void)
 			break;
 		}
 		if (itemHit == DCFO_OMIMICDISPLAY || itemHit == DCFO_OMERGEBOXES ||
-			itemHit == DCFO_ISQUAREWIRES || itemHit == DCFO_OINSTANTIATETOP)
+			itemHit == DCFO_ISQUAREWIRES || itemHit == DCFO_OINSTANTIATETOP ||
+			itemHit == DCFO_ONORMALIZECOORD)
 		{
 			DiaSetControl(itemHit, 1 - DiaGetControl(itemHit));
 			continue;
@@ -1302,7 +1264,6 @@ void io_cifoptionsdlog(void)
 				if (atola(DiaGetText(DCFO_ORESOLUTION)) == 0)
 					DiaSetText(DCFO_ORESOLUTION, "1");
 			}
-			DiaSetText(DCFO_NEWLAYER, layernames[i]);
 			continue;
 		}
 		if (itemHit == DCFO_NEWLAYER)
@@ -1332,6 +1293,8 @@ void io_cifoptionsdlog(void)
 			newstate[0] &= ~CIFINSQUARE;
 		if (DiaGetControl(DCFO_OINSTANTIATETOP) == 0) newstate[0] |= CIFOUTNOTOPCALL; else
 			newstate[0] &= ~CIFOUTNOTOPCALL;
+		if (DiaGetControl(DCFO_ONORMALIZECOORD) != 0) newstate[0] |= CIFOUTNORMALIZE; else
+			newstate[0] &= ~CIFOUTNORMALIZE;
 		if (DiaGetPopupEntry(DCFO_ORESOLUTIONMODE) == 2) newstate[1] |= CIFRESHIGH; else
 			newstate[1] &= ~CIFRESHIGH;
 		for(i=0; i<NUMIOSTATEBITWORDS; i++) if (curstate[i] != newstate[i]) break;
