@@ -120,9 +120,9 @@ static char io_initutil(void);
 static void io_freestorage(void);
 static void io_freedef(objectptr);
 static void io_clear(transform);
-static INTSML io_swapcontext(INTBIG);
-static INTSML io_increfcount(INTBIG);
-static INTSML io_decrefcount(INTBIG);
+static BOOLEAN io_swapcontext(INTBIG);
+static BOOLEAN io_increfcount(INTBIG);
+static BOOLEAN io_decrefcount(INTBIG);
 static void io_pushtrans(void);
 static void io_poptrans(void);
 static void io_matmult(transform, transform, transform);
@@ -137,7 +137,7 @@ static void io_printmat(transform);
 static void io_bbpolygon(INTBIG, path, INTBIG*, INTBIG*, INTBIG*, INTBIG*);
 static void io_bbwire(INTBIG, INTBIG, path, INTBIG*, INTBIG*, INTBIG*, INTBIG*);
 static char io_inititems(void);
-static INTSML io_doneitems(void);
+static BOOLEAN io_doneitems(void);
 static itementry *io_newnode(void);
 static void io_freenode(itementry*);
 static void io_sendlist(itementry*);
@@ -292,7 +292,7 @@ void io_iusercommand(INTBIG command, char *text)
 {
 	io_cifstatesince++;
 	if (io_cifignore) return;
-	io_outputusercommand((INTSML)command, text);
+	io_outputusercommand(command, text);
 }
 
 void io_iend(void)
@@ -515,7 +515,7 @@ static void io_scalepath(char *src, char *dest)
 
 		temp.x = (INTBIG) (io_cifscalefactor*(float)temp.x);
 		temp.y = (INTBIG) (io_cifscalefactor*(float)temp.y);
-		if (io_appendpoint((path)dest, temp) != 0) break;
+		if (io_appendpoint((path)dest, temp)) break;
 	}
 }
 
@@ -1209,40 +1209,40 @@ static void io_clear(transform mat)
 	mat->type = TIDENT;   mat->multiplied = 0;
 }
 
-INTSML io_swapcontext(INTBIG id)
+BOOLEAN io_swapcontext(INTBIG id)
 {
 	if (id >= io_cifclength || io_cifcarray[id].refcount == 0)
 	{
 		io_report(_("illegal swap context"), FATALINTERNAL);
-		return(-1);
+		return(TRUE);
 	}
-	if (io_cifcurcontext == id) return(0);
+	if (io_cifcurcontext == id) return(FALSE);
 	io_cifcarray[io_cifcurcontext].ctop = io_cifstacktop;		/* save current context */
 	io_cifcurcontext = id;
 	io_cifstacktop = io_cifcarray[io_cifcurcontext].ctop;
-	return(0);
+	return(FALSE);
 }
 
-INTSML io_increfcount(INTBIG id)
+BOOLEAN io_increfcount(INTBIG id)
 {
 	if (id >= io_cifclength)
 	{
 		io_report(_("illegal context: io_increfcount"), FATALINTERNAL);
-		return(-1);
+		return(TRUE);
 	}
 	io_cifcarray[id].refcount++;
-	return(0);
+	return(FALSE);
 }
 
-INTSML io_decrefcount(INTBIG id)
+BOOLEAN io_decrefcount(INTBIG id)
 {
 	if (id >= io_cifclength || io_cifcarray[id].refcount == 0)
 	{
 		io_report(_("illegal context: io_decrefcount"), FATALINTERNAL);
-		return(-1);
+		return(TRUE);
 	}
 	io_cifcarray[id].refcount--;
-	return(0);
+	return(FALSE);
 }
 
 void io_pushtrans(void)
@@ -1461,10 +1461,10 @@ void io_dumpstack(void)
 
 static void io_printmat(transform t)
 {
-	ttyputmsg("type: %ld, mult: %d",t->type,t->multiplied);
-	ttyputmsg("%f %f",t->a11,t->a12);
-	ttyputmsg("%f %f",t->a21,t->a22);
-	ttyputmsg("%f %f %f",t->a31,t->a32,t->a33);
+	ttyputmsg("type: %ld, mult: %d", t->type, t->multiplied);
+	ttyputmsg("%f %f", t->a11, t->a12);
+	ttyputmsg("%f %f", t->a21, t->a22);
+	ttyputmsg("%f %f %f", t->a31, t->a32, t->a33);
 }
 
 /************ bbs.c: bounding box finder for primitive geometry ************/
@@ -1554,7 +1554,7 @@ char io_inititems(void)
 	return(0);
 }
 
-INTSML io_doneitems(void)
+BOOLEAN io_doneitems(void)
 {
 	itementry *cur, *next;
 
@@ -1570,7 +1570,7 @@ INTSML io_doneitems(void)
 		io_freeonedef((struct kludge *)cur->it_what);
 		efree((char *)cur);
 	}
-	return(0);
+	return(FALSE);
 }
 
 /*
@@ -1657,32 +1657,32 @@ static void io_shipcontents(stentry *sym)
 				length = ((polygon *)ro)->po_numpts;
 				ppath = io_makepath();
 				for (i = 0; i < length; i++)
-					if (io_appendpoint((path)ppath, ((polygon *)ro)->po_p[i]) != 0) return;
-				io_outputpolygon((INTSML)(((polygon *)ro)->po_layer), ppath);
+					if (io_appendpoint((path)ppath, ((polygon *)ro)->po_p[i])) return;
+				io_outputpolygon(((polygon *)ro)->po_layer, ppath);
 				io_freepath((path)ppath);
 				break;
 			case WIRE:
 				length = ((wire *)ro)->wi_numpts;
 				ppath = io_makepath();
 				for (i = 0; i < length; i++)
-					if (io_appendpoint((path)ppath, ((wire *)ro)->wi_p[i]) != 0) return;
-				io_outputwire((INTSML)(((wire *)ro)->wi_layer), ((wire *)ro)->wi_width,
+					if (io_appendpoint((path)ppath, ((wire *)ro)->wi_p[i])) return;
+				io_outputwire(((wire *)ro)->wi_layer, ((wire *)ro)->wi_width,
 					ppath);
 				io_freepath((path)ppath);
 				break;
 			case FLASH:
-				io_outputflash((INTSML)(((flash *)ro)->fl_layer), ((flash *)ro)->fl_diameter,
+				io_outputflash(((flash *)ro)->fl_layer, ((flash *)ro)->fl_diameter,
 					((flash *)ro)->fl_center);
 				break;
 			case RECTANGLE:
-				io_outputbox((INTSML)(((box *)ro)->bo_layer), ((box *)ro)->bo_length,
+				io_outputbox(((box *)ro)->bo_layer, ((box *)ro)->bo_length,
 					((box *)ro)->bo_width, ((box *)ro)->bo_center,
-						(INTSML)(((box *)ro)->bo_xrot), (INTSML)(((box *)ro)->bo_yrot));
+						((box *)ro)->bo_xrot, ((box *)ro)->bo_yrot);
 				break;
 			case MBOX:
 				temp.x = (((mbox *)ro)->mb_bb.r + ((mbox *) ro)->mb_bb.l)/2;
 				temp.y = (((mbox *)ro)->mb_bb.t + ((mbox *) ro)->mb_bb.b)/2;
-				io_outputbox((INTSML)(((mbox *)ro)->mb_layer),
+				io_outputbox(((mbox *)ro)->mb_layer,
 					((mbox *)ro)->mb_bb.r-((mbox *)ro)->mb_bb.l,
 						((mbox *)ro)->mb_bb.t-((mbox *)ro)->mb_bb.b, temp, 1, 0);
 				break;
@@ -1695,7 +1695,7 @@ static void io_shipcontents(stentry *sym)
 				break;
 			case NAME:
 				io_outputgeoname(((gname *)ro)->gn_name,
-					((gname *)ro)->gn_pos, (INTSML)(((gname *)ro)->gn_layer));
+					((gname *)ro)->gn_pos, ((gname *)ro)->gn_layer);
 				break;
 			case LABEL:
 				io_outputlabel(((label *)ro)->la_name, ((label *)ro)->la_pos);
@@ -1762,14 +1762,14 @@ void io_iboundbox(INTBIG *l, INTBIG *r, INTBIG *b, INTBIG *t)
 	(void)io_swapcontext(0);		/* always leave in context 0 */
 }
 
-INTSML io_createlist(void)
+BOOLEAN io_createlist(void)
 {
 	if (!io_endseen()) ttyputmsg(_("missing End command, assumed"));
-	if (io_fatalerrors() > 0) return(-1);
+	if (io_fatalerrors() > 0) return(TRUE);
 	io_sendlist(io_cifilist);		/* sendlist deletes nodes */
 	io_cifilist = NIL;
 	(void)io_swapcontext(0);
-	return(0);
+	return(FALSE);
 }
 
 static void io_outitem(itementry *thing)		/* spit out an item */
@@ -1785,8 +1785,8 @@ static void io_outitem(itementry *thing)		/* spit out an item */
 			length = ((polygon *) (thing->it_what))->po_numpts;
 			ppath = io_makepath();
 			for (i = 0; i < length; i++)
-				if (io_appendpoint((path)ppath, ((polygon *)(thing->it_what))->po_p[i]) != 0) return;
-			io_outputpolygon((INTSML)(((polygon *) (thing->it_what))->po_layer), ppath);
+				if (io_appendpoint((path)ppath, ((polygon *)(thing->it_what))->po_p[i])) return;
+			io_outputpolygon(((polygon *) (thing->it_what))->po_layer, ppath);
 			(void)io_decrefcount(thing->it_context);
 			io_freepath((path)ppath);
 			break;
@@ -1796,8 +1796,8 @@ static void io_outitem(itementry *thing)		/* spit out an item */
 			length = ((wire *) (thing->it_what))->wi_numpts;
 			ppath = io_makepath();
 			for (i = 0; i < length; i++)
-				if (io_appendpoint((path)ppath, ((wire *) (thing->it_what))->wi_p[i]) != 0) return;
-			io_outputwire((INTSML)(((wire *) (thing->it_what))->wi_layer),
+				if (io_appendpoint((path)ppath, ((wire *) (thing->it_what))->wi_p[i])) return;
+			io_outputwire(((wire *) (thing->it_what))->wi_layer,
 				((wire *) (thing->it_what))->wi_width, ppath);
 			(void)io_decrefcount(thing->it_context);
 			io_freepath((path)ppath);
@@ -1805,17 +1805,17 @@ static void io_outitem(itementry *thing)		/* spit out an item */
 
 		case FLASH:
 			(void)io_swapcontext(thing->it_context);
-			io_outputflash((INTSML)(((flash *) (thing->it_what))->fl_layer),
+			io_outputflash(((flash *) (thing->it_what))->fl_layer,
 				((flash *) (thing->it_what))->fl_diameter, ((flash *) (thing->it_what))->fl_center);
 			(void)io_decrefcount(thing->it_context);
 			break;
 
 		case RECTANGLE:
 			(void)io_swapcontext(thing->it_context); /* get right frame of ref */
-			io_outputbox((INTSML)(((box *) (thing->it_what))->bo_layer),
+			io_outputbox(((box *) (thing->it_what))->bo_layer,
 				((box *) (thing->it_what))->bo_length, ((box *) (thing->it_what))->bo_width,
-					((box *) (thing->it_what))->bo_center, (INTSML)(((box *) (thing->it_what))->bo_xrot),
-						(INTSML)(((box *) (thing->it_what))->bo_yrot));
+					((box *) (thing->it_what))->bo_center, ((box *) (thing->it_what))->bo_xrot,
+						((box *) (thing->it_what))->bo_yrot);
 			(void)io_decrefcount(thing->it_context);
 			break;
 
@@ -1826,7 +1826,7 @@ static void io_outitem(itementry *thing)		/* spit out an item */
 			temp.y = (((mbox *) (thing->it_what))->mb_bb.t+
 				((mbox *) (thing->it_what))->mb_bb.b)/2;
 			io_outputbox(
-				(INTSML)(((mbox *) (thing->it_what))->mb_layer),
+				((mbox *) (thing->it_what))->mb_layer,
 				((mbox *) (thing->it_what))->mb_bb.r-
 				((mbox *) (thing->it_what))->mb_bb.l,
 				((mbox *) (thing->it_what))->mb_bb.t-
@@ -1853,7 +1853,7 @@ static void io_outitem(itementry *thing)		/* spit out an item */
 		case NAME:
 			(void)io_swapcontext(thing->it_context);
 			io_outputgeoname(((gname *) (thing->it_what))->gn_name,
-				((gname *) (thing->it_what))->gn_pos, (INTSML)(((gname *) (thing->it_what))->gn_layer));
+				((gname *) (thing->it_what))->gn_pos, ((gname *) (thing->it_what))->gn_layer);
 			(void)io_decrefcount(thing->it_context);
 			break;
 
@@ -1983,7 +1983,7 @@ static char io_doneinput(void)
 	return(0);
 }
 
-INTSML io_infromfile(FILE *file)
+BOOLEAN io_infromfile(FILE *file)
 {
 	extern DIALOG us_progressdialog;
 
@@ -1993,13 +1993,13 @@ INTSML io_infromfile(FILE *file)
 		io_ciffilelength = filesize(io_cifinfile);
 		if (io_ciffilelength > 0)
 		{
-			if (DiaInitDialog(&us_progressdialog) != 0) return(1);
+			if (DiaInitDialog(&us_progressdialog)) return(TRUE);
 			DiaPercent(1, 0);
 		}
 	} else io_ciffilelength = 0;
 	io_cifnextchar = xgetc(io_cifinfile);
 	io_cifcharsread = 1;
-	return(0);
+	return(FALSE);
 }
 
 static char io_getch(void)
@@ -2153,19 +2153,19 @@ static void io_freepnode(linkedpoint *a)
 }
 
 /* returns nonzero on memory error */
-INTSML io_appendpoint(path a, point p)
+BOOLEAN io_appendpoint(path a, point p)
 {
 	linkedpoint *temp;
 
 	temp = a->plast;
 	a->plast = io_getpnode();
-	if (a->plast == 0) return(1);
+	if (a->plast == 0) return(TRUE);
 	if (temp != NIL) temp->pnext = a->plast;
 	a->plast->pvalue = p;
 	a->plast->pnext = NIL;
 	if (a->pfirst == NIL) a->pfirst = a->plast;
 	a->plength += 1;
-	return(0);
+	return(FALSE);
 }
 
 void io_copypath(path src, path dest)
@@ -2176,7 +2176,7 @@ void io_copypath(path src, path dest)
 	if (src == dest) return;
 	while (temp != NIL)
 	{
-		if (io_appendpoint(dest, temp->pvalue) != 0) break;
+		if (io_appendpoint(dest, temp->pvalue)) break;
 		temp = temp->pnext;
 	}
 }
@@ -2331,10 +2331,10 @@ static char io_doneerror(void)
 	return(0);
 }
 
-INTSML io_fatalerrors(void)
+INTBIG io_fatalerrors(void)
 {
-	return((INTSML)(io_cifecounts[FATALINTERNAL]+io_cifecounts[FATALSYNTAX]+
-		io_cifecounts[FATALSEMANTIC]+io_cifecounts[FATALOUTPUT]));
+	return(io_cifecounts[FATALINTERNAL]+io_cifecounts[FATALSYNTAX]+
+		io_cifecounts[FATALSEMANTIC]+io_cifecounts[FATALOUTPUT]);
 }
 
 void io_report(char *mess, INTBIG kind)
@@ -2616,7 +2616,7 @@ static void io_getpath(path a)
 	while (((c = io_peek()) >= '0' && c <= '9') || c == '-')
 	{
 		temp = io_getpoint();	/* hack because of compiler error */
-		if (io_appendpoint(a, temp) != 0) break;
+		if (io_appendpoint(a, temp)) break;
 		io_sep();
 	}
 	if (io_pathlength(a) == 0) io_logit(NOPATH);
@@ -3026,7 +3026,7 @@ recover:		/* errors come here */
 	goto alldone;
 }
 
-INTSML io_parsefile(void)
+INTBIG io_parsefile(void)
 {
 	INTBIG com;
 	INTBIG comcount = 1;
@@ -3038,7 +3038,7 @@ INTSML io_parsefile(void)
 		if (com == END || com == ENDFILE) break;
 		comcount++;
 	}
-	return((INTSML)comcount);
+	return(comcount);
 }
 
 #endif  /* IOCIF - at top */
