@@ -63,10 +63,10 @@ typedef struct Inexteaglenet
 static EAGLENET *io_eaglefirstnet;
 
 /* prototypes for local routines */
-static void io_eagledumpfacet(NODEPROTO *curfacet, char *prefix);
+static INTBIG io_eagledumpfacet(NODEPROTO *curfacet, char *prefix);
 static void io_eaglemarkfacets(NODEPROTO *curfacet);
 
-INTSML io_writeeaglelibrary(LIBRARY *lib)
+BOOLEAN io_writeeaglelibrary(LIBRARY *lib)
 {
 	char file[100], *truename;
 	REGISTER INTBIG i, sorted, maxnetname, maxpackagename;
@@ -80,7 +80,7 @@ INTSML io_writeeaglelibrary(LIBRARY *lib)
 	if (curfacet == NONODEPROTO)
 	{
 		ttyputerr(_("Must be editing a facet to generate EAGLE output"));
-		return(1);
+		return(TRUE);
 	}
 	(void)strcpy(file, curfacet->cell->cellname);
 	(void)strcat(file, ".txt");
@@ -89,14 +89,15 @@ INTSML io_writeeaglelibrary(LIBRARY *lib)
 	if (io_fileout == NULL)
 	{
 		if (truename != 0) ttyputerr(_("Cannot write %s"), truename);
-		return(1);
+		return(TRUE);
 	}
 
 	/* recurse through the circuit, gathering network connections */
 	io_eaglefirstnet = NOEAGLENET;
 	for(pp = curfacet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		pp->temp1 = 0;
-	io_eagledumpfacet(curfacet, "");
+	if (io_eagledumpfacet(curfacet, "") != 0)
+		ttyputmsg(_("Back-annotation information has been added (library must be saved)"));
 	xprintf(io_fileout, ";\n");
 
 	/* sort the signals */
@@ -176,13 +177,14 @@ INTSML io_writeeaglelibrary(LIBRARY *lib)
 
 	/* tell the user that the file is written */
 	ttyputmsg(_("%s written"), truename);
-	return(0);
+	return(FALSE);
 }
 
 /*
  * Routine to write out all facets in the current library that are marked (temp1 != 0).
+ * Returns nonzero if backannotation has been added.
  */
-void io_eagledumpfacet(NODEPROTO *curfacet, char *prefix)
+INTBIG io_eagledumpfacet(NODEPROTO *curfacet, char *prefix)
 {
 	char *name;
 	char line[50], *newprefix, *tempname;
@@ -193,6 +195,11 @@ void io_eagledumpfacet(NODEPROTO *curfacet, char *prefix)
 	REGISTER PORTARCINST *pi;
 	REGISTER PORTPROTO *pp;
 	REGISTER EAGLENET *en;
+	REGISTER INTBIG backannotate;
+
+	/* make sure that all arcs have network names on them */
+	backannotate = 0;
+	if (asktool(net_tool, "name-nets", (INTBIG)curfacet) != 0) backannotate++;
 
 	/* mark those facets that will be included in this dump */
 	io_eaglemarkfacets(curfacet);
@@ -233,7 +240,7 @@ void io_eagledumpfacet(NODEPROTO *curfacet, char *prefix)
 				/* compute new prefix for nets in the subfacet */
 				(void)initinfstr();
 				(void)addstringtoinfstr(prefix);
-				var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name);
+				var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
 				if (var == NOVARIABLE)
 				{
 					sprintf(line, "NODE%ld.", (INTBIG)ni);
@@ -243,7 +250,7 @@ void io_eagledumpfacet(NODEPROTO *curfacet, char *prefix)
 					(void)addstringtoinfstr((char *)var->addr);
 					(void)addtoinfstr('.');
 				}
-				allocstring(&newprefix, returninfstr(), el_tempcluster);
+				(void)allocstring(&newprefix, returninfstr(), el_tempcluster);
 
 				/* store net names on ports for use inside the subfacet */
 				for(pp = subnp->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
@@ -256,12 +263,12 @@ void io_eagledumpfacet(NODEPROTO *curfacet, char *prefix)
 					(void)initinfstr();
 					(void)addstringtoinfstr(prefix);
 					(void)addstringtoinfstr(net->netname);
-					allocstring(&tempname, returninfstr(), io_tool->cluster);
+					(void)allocstring(&tempname, returninfstr(), io_tool->cluster);
 					pp->temp1 = (INTBIG)tempname;
 				}
 
 				/* recurse */
-				io_eagledumpfacet(subnp, newprefix);
+				if (io_eagledumpfacet(subnp, newprefix) != 0) backannotate++;
 
 				/* remark the facets at the current level and clean up memory */
 				io_eaglemarkfacets(curfacet);
@@ -302,7 +309,7 @@ void io_eagledumpfacet(NODEPROTO *curfacet, char *prefix)
 
 					/* create a new net connection */
 					en = (EAGLENET *)emalloc(sizeof (EAGLENET), io_tool->cluster);
-					if (en == 0) return;
+					if (en == 0) return(backannotate);
 					net = pi->conarcinst->network;
 					if (net->temp1 != 0)
 					{
@@ -331,6 +338,7 @@ void io_eagledumpfacet(NODEPROTO *curfacet, char *prefix)
 			}
 		}
 	}
+	return(backannotate);
 }
 
 /*
