@@ -78,10 +78,10 @@ typedef struct Inextecadnet
 static ECADNET *io_ecadfirstnet;
 
 /* prototypes for local routines */
-static void io_ecaddumpfacet(NODEPROTO *curfacet, char *prefix);
+static INTBIG io_ecaddumpfacet(NODEPROTO *curfacet, char *prefix);
 static void io_ecadmarkfacets(NODEPROTO *curfacet);
 
-INTSML io_writeecadlibrary(LIBRARY *lib)
+BOOLEAN io_writeecadlibrary(LIBRARY *lib)
 {
 	char file[100], *truename;
 	REGISTER INTBIG i, sorted, maxnetname, maxpackagename;
@@ -95,7 +95,7 @@ INTSML io_writeecadlibrary(LIBRARY *lib)
 	if (curfacet == NONODEPROTO)
 	{
 		ttyputerr(_("Must be editing a facet to generate ECAD output"));
-		return(1);
+		return(TRUE);
 	}
 	(void)strcpy(file, curfacet->cell->cellname);
 	(void)strcat(file, ".enl");
@@ -104,15 +104,16 @@ INTSML io_writeecadlibrary(LIBRARY *lib)
 	if (io_fileout == NULL)
 	{
 		if (truename != 0) ttyputerr(_("Cannot write %s"), truename);
-		return(1);
+		return(TRUE);
 	}
 
 	/* recurse through the circuit, gathering network connections */
 	io_ecadfirstnet = NOECADNET;
 	for(pp = curfacet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		pp->temp1 = 0;
-	io_ecaddumpfacet(curfacet, "");
-	xprintf(io_fileout, "| end of part list\n");  // cm - removed before netlist
+	if (io_ecaddumpfacet(curfacet, "") != 0)
+		ttyputmsg(_("Back-annotation information has been added (library must be saved)"));
+	xprintf(io_fileout, "| end of part list\n");  /* cm - removed before netlist */
 
 	/* sort the signals */
 	sorted = 0;
@@ -157,34 +158,36 @@ INTSML io_writeecadlibrary(LIBRARY *lib)
 		   {
 			if (lasten != NOECADNET)
             xprintf(io_fileout, ";\n");
-			xprintf(io_fileout, _("%s : "), en->netname);            // cm - write netname on first line of net
+			xprintf(io_fileout, "%s : ", en->netname);            /* cm - write netname on first line of net */
 		   }
       else
 		   {
-			xprintf(io_fileout, "      ");                           // cm - was net name on each line
+			xprintf(io_fileout, "      ");                           /* cm - was net name on each line */
 		   }
 		for(i=strlen(en->netname); i<maxnetname; i++)
 			xprintf(io_fileout, " ");
 
 		/* write "Part" column */
-		xprintf(io_fileout, "%s", en->packagename);                 // cm - removed single quotes
+		xprintf(io_fileout, "%s", en->packagename);                 /* cm - removed single quotes */
 		for(i=strlen(en->packagename); i<maxpackagename; i++)
 			xprintf(io_fileout, " ");
 
 		/* write "Pad" column (an attribute with a number) */
-		xprintf(io_fileout, "%s \\\n", en->pinname);                   // cm - removed single quotes
-//		if (lasten == NOECADNET || namesame(lasten->netname, en->netname) != 0)
-//		   {
-//			if (lasten != NOECADNET)
- //           xprintf(io_fileout, ";\n");
-//         else
-//            xprintf(io_fileout, "\\\n");
-//         }
+		xprintf(io_fileout, "%s \\\n", en->pinname);                   /* cm - removed single quotes */
+#if 0
+		if (lasten == NOECADNET || namesame(lasten->netname, en->netname) != 0)
+		{
+			if (lasten != NOECADNET)
+				xprintf(io_fileout, ";\n");
+			else
+				xprintf(io_fileout, "\\\n");
+		}
+#endif
 
       lasten = en;
 	}
 
-	if (lasten != NOECADNET) xprintf(io_fileout, ";    |end of net section.\n"); // cm - end of net section
+	if (lasten != NOECADNET) xprintf(io_fileout, ";    |end of net section.\n"); /* cm - end of net section */
 
 	/* free memory */
 	while (io_ecadfirstnet != NOECADNET)
@@ -202,13 +205,14 @@ INTSML io_writeecadlibrary(LIBRARY *lib)
 
 	/* tell the user that the file is written */
 	ttyputmsg(_("%s written"), truename);
-	return(0);
+	return(FALSE);
 }
 
 /*
  * Routine to write out all facets in the current library that are marked (temp1 != 0).
+ * Returns nonzero if backannotation has been added.
  */
-void io_ecaddumpfacet(NODEPROTO *curfacet, char *prefix)
+INTBIG io_ecaddumpfacet(NODEPROTO *curfacet, char *prefix)
 {
 	char *name;
 	char line[50], *newprefix, *tempname;
@@ -219,6 +223,11 @@ void io_ecaddumpfacet(NODEPROTO *curfacet, char *prefix)
 	REGISTER PORTARCINST *pi;
 	REGISTER PORTPROTO *pp;
 	REGISTER ECADNET *en;
+	REGISTER INTBIG backannotate;
+
+	/* make sure that all arcs have network names on them */
+	backannotate = 0;
+	if (asktool(net_tool, "name-nets", (INTBIG)curfacet) != 0) backannotate++;
 
 	/* mark those facets that will be included in this dump */
 	io_ecadmarkfacets(curfacet);
@@ -250,7 +259,7 @@ void io_ecaddumpfacet(NODEPROTO *curfacet, char *prefix)
 			/* ignore recursive references (showing icon in contents) */
 			if (subnp->cell == np->cell) continue;
 
-			varpart = getval((INTBIG)ni, VNODEINST, -1, "ATTR_ref_des");   // cm - changed for ecad
+			varpart = getval((INTBIG)ni, VNODEINST, -1, "ATTR_ref_des");   /* cm - changed for ecad */
 			if (varpart == NOVARIABLE)
 			{
 				subcnp = contentsview(subnp);
@@ -259,7 +268,7 @@ void io_ecaddumpfacet(NODEPROTO *curfacet, char *prefix)
 				/* compute new prefix for nets in the subfacet */
 				(void)initinfstr();
 				(void)addstringtoinfstr(prefix);
-				var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name);
+				var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
 				if (var == NOVARIABLE)
 				{
 					sprintf(line, "NODE%ld.", (INTBIG)ni);
@@ -269,7 +278,7 @@ void io_ecaddumpfacet(NODEPROTO *curfacet, char *prefix)
 					(void)addstringtoinfstr((char *)var->addr);
 					(void)addtoinfstr('.');
 				}
-				allocstring(&newprefix, returninfstr(), el_tempcluster);
+				(void)allocstring(&newprefix, returninfstr(), el_tempcluster);
 
 				/* store net names on ports for use inside the subfacet */
 				for(pp = subnp->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
@@ -282,12 +291,12 @@ void io_ecaddumpfacet(NODEPROTO *curfacet, char *prefix)
 					(void)initinfstr();
 					(void)addstringtoinfstr(prefix);
 					(void)addstringtoinfstr(net->netname);
-					allocstring(&tempname, returninfstr(), io_tool->cluster);
+					(void)allocstring(&tempname, returninfstr(), io_tool->cluster);
 					pp->temp1 = (INTBIG)tempname;
 				}
 
 				/* recurse */
-				io_ecaddumpfacet(subnp, newprefix);
+				if (io_ecaddumpfacet(subnp, newprefix) != 0) backannotate++;
 
 				/* remark the facets at the current level and clean up memory */
 				io_ecadmarkfacets(curfacet);
@@ -301,8 +310,10 @@ void io_ecaddumpfacet(NODEPROTO *curfacet, char *prefix)
 				varpackagetype = getval((INTBIG)ni, VNODEINST, -1, "ATTR_pkg_type");
 				if (varpackagetype == NOVARIABLE)
 				{
-//					xprintf(io_fileout, ".cmp_t %s '%s%s'", ni->proto->cell->cellname,            // cm - changed
-//						prefix, name);
+#if 0
+					xprintf(io_fileout, ".cmp_t %s '%s%s'", ni->proto->cell->cellname,
+						prefix, name);
+#endif
 					xprintf(io_fileout, "Error no pkg_type attribute for %s%s", prefix, name);
 				} else
 				{
@@ -328,7 +339,7 @@ void io_ecaddumpfacet(NODEPROTO *curfacet, char *prefix)
                   }
 					/* create a new net connection */
 					en = (ECADNET *)emalloc(sizeof (ECADNET), io_tool->cluster);
-					if (en == 0) return;
+					if (en == 0) return(backannotate);
 					net = pi->conarcinst->network;
 					if (net->temp1 != 0)
 					{
@@ -357,6 +368,7 @@ void io_ecaddumpfacet(NODEPROTO *curfacet, char *prefix)
 			}
 		}
 	}
+	return(backannotate);
 }
 
 /*
