@@ -40,6 +40,7 @@
 #include "tecgen.h"
 #include "tecschem.h"
 #include "network.h"
+#include "usr.h"
 #include "edialogs.h"
 #include <math.h>
 
@@ -66,8 +67,8 @@ typedef struct _eo_stream
 } EO_STREAM, *EO_STREAM_PTR;
 
 static char  *io_edifoextlibname[WORD+1];
-static INTSML io_edifoextlibcount;
-static INTSML io_edifo_gateindex;
+static INTBIG io_edifoextlibcount;
+static INTBIG io_edifo_gateindex;
 static char   io_edifo_blanks[] = "                                                  ";
 
 /* globals for SCHEMATIC View */
@@ -91,21 +92,21 @@ static INTBIG io_edif_scale(INTBIG val);
 static INTBIG io_edifsearch(NODEPROTO *np);
 static void io_edifextsearch(NODEPROTO *np);
 static char *io_ediffind_path(NODEPROTO *np);
-static void io_edifwriteprim(NODEPROTO *np, INTSML i, INTSML fun);
+static void io_edifwriteprim(NODEPROTO *np, INTBIG i, INTBIG fun);
 static char *io_edif_orientation(NODEINST *ni);
-static char *io_edifwritecompname(NODEINST *ni, INTBIG fun, INTSML serindex);
+static char *io_edifwritecompname(NODEINST *ni, INTBIG fun, INTBIG serindex);
 static void io_edif_pt(INTBIG x, INTBIG y);
-static INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external);
+static BOOLEAN io_edifwritefacet(NODEPROTO *np, INTBIG external);
 static char *io_edifdescribepriminst(NODEINST *ni, INTBIG fun);
-static INTSML io_edifisglobal(PORTPROTO *pp);
-static INTSML io_edifmarknetports(NODEPROTO *np);
-static INTSML io_edifwritelibext(NODEPROTO *np);
+static BOOLEAN io_edifisglobal(PORTPROTO *pp);
+static INTBIG io_edifmarknetports(NODEPROTO *np);
+static BOOLEAN io_edifwritelibext(NODEPROTO *np);
 static char *io_ediftoken(char *str);
 static char io_edifnotwhitespace(char ch);
-static INTSML io_edifvalid(char ch);
+static BOOLEAN io_edifvalid(char ch);
 static char *io_edifvalidname(VARIABLE *var);
-static INTSML io_edifwritefootprint(NODEPROTO *np, char *name, INTBIG routegrid);
-static INTSML io_edifwriteportpositions(PORTPROTO *pp, INTBIG cellx, INTBIG celly,
+static BOOLEAN io_edifwritefootprint(NODEPROTO *np, char *name, INTBIG routegrid);
+static BOOLEAN io_edifwriteportpositions(PORTPROTO *pp, INTBIG cellx, INTBIG celly,
 	char *accessrules, INTBIG routegrid);
 static char *io_ediflowerstring(char *str);
 static char *io_edifupperstring(char *str);
@@ -149,12 +150,12 @@ void io_initedif(void)
  * routine to write a ".edif" file (or a ".foot" file for layouts)
  * describing the current facet from the library "lib"
  */
-INTSML io_writeediflibrary(LIBRARY *lib)
+BOOLEAN io_writeediflibrary(LIBRARY *lib)
 {
 	char name[100], fname[100];
 	REGISTER NODEPROTO *lnp, *np;
-	REGISTER INTSML i, backannotate;
-	REGISTER INTBIG lambda, *curstate;
+	REGISTER BOOLEAN backannotate;
+	REGISTER INTBIG i, lambda, *curstate;
 	REGISTER LIBRARY *olib;
 	REGISTER TECHNOLOGY *tech;
 	INTBIG fun, rgrid;
@@ -165,9 +166,9 @@ INTSML io_writeediflibrary(LIBRARY *lib)
 	if ((net_tool->toolstate & TOOLON) == 0)
 	{
 		ttyputerr(_("Network tool must be running...turning it on"));
-		toolturnon(net_tool, 0);
+		toolturnon(net_tool, FALSE);
 		ttyputerr(_("...now reissue the EDIF I/O command"));
-		return(1);
+		return(TRUE);
 	}
 
 	/* initialize counters for automatic name generation */
@@ -178,7 +179,7 @@ INTSML io_writeediflibrary(LIBRARY *lib)
 	if (np == NONODEPROTO)
 	{
 		ttyputerr(_("Must be editing a facet to generate EDIF output"));
-		return(1);
+		return(TRUE);
 	}
 
 	/* See if schematic view is requested */
@@ -208,15 +209,21 @@ INTSML io_writeediflibrary(LIBRARY *lib)
 	(void)sprintf(fname, "%s.edif", name);
 	if ((edif_stream = EO_open_stream(fname, 0)) == NOEO_STREAM)
 	{
-		return(1);
+		return(TRUE);
 	}
 
 	/* write the header */
-	(void)sprintf(name, _("Electric Design System v%s"), el_version);
+	if ((us_useroptions&NODATEORVERSION) == 0)
+	{
+		(void)sprintf(name, _("Electric Design System, version %s"), el_version);
+	} else
+	{
+		(void)sprintf(name, _("Electric Design System"));
+	}
 	(void)EO_put_header(edif_stream, name, _("EDIF Writer"), lib->libname);
 
 	/* write the external primitive reference library, if any */
-	if (io_edifwritelibext(np) != 0)
+	if (io_edifwritelibext(np))
 	{
 		/* determine the primitives being used */
 		for (tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
@@ -257,7 +264,7 @@ INTSML io_writeediflibrary(LIBRARY *lib)
 					if (fun == NPUNKNOWN || fun == NPPIN || fun == NPCONTACT ||
 						fun == NPNODE || fun == NPCONNECT || fun == NPART) continue;
 					for (i = 0; i < lnp->temp1; i++)
-						io_edifwriteprim(lnp, i, (INTSML)fun);
+						io_edifwriteprim(lnp, i, fun);
 				}
 			}
 			EO_close_block(edif_stream, "library");
@@ -265,7 +272,7 @@ INTSML io_writeediflibrary(LIBRARY *lib)
 	}
 
 	/* search recursively for all external libraries required */
-	backannotate = 0;
+	backannotate = FALSE;
 	for(olib = el_curlib; olib != NOLIBRARY; olib = olib->nextlibrary)
 		for (lnp = olib->firstnodeproto; lnp != NONODEPROTO; lnp = lnp->nextnodeproto)
 	{
@@ -285,7 +292,7 @@ INTSML io_writeediflibrary(LIBRARY *lib)
 		for (i = 1; i <= io_edifoextlibcount; i++)
 	{
 		EO_open_block(edif_stream, "external");
-		(void)sprintf(name, "schem_lib_%d", i);
+		(void)sprintf(name, "schem_lib_%ld", i);
 		EO_put_identifier(edif_stream, name);
 		EO_put_block(edif_stream, "edifLevel", "0");
 		EO_open_block(edif_stream, "technology");
@@ -299,7 +306,7 @@ INTSML io_writeediflibrary(LIBRARY *lib)
 			EO_close_block(edif_stream, "scale");
 		}
 		EO_close_block(edif_stream, "technology");
-		if (io_edifwritefacet(np, i) != 0) backannotate = 1;
+		if (io_edifwritefacet(np, i)) backannotate = TRUE;
 		EO_close_block(edif_stream, "external");
 	}
 
@@ -319,7 +326,7 @@ INTSML io_writeediflibrary(LIBRARY *lib)
 	}
 	EO_close_block(edif_stream, "technology");
 
-	if (io_edifwritefacet(np, 0) != 0) backannotate = 1;
+	if (io_edifwritefacet(np, 0)) backannotate = TRUE;
 	EO_close_block(edif_stream, "library");
 
 	/* post-identify the design and library */
@@ -332,9 +339,9 @@ INTSML io_writeediflibrary(LIBRARY *lib)
 	/* clean up */
 	ttyputmsg(_("%s written"), edif_stream->filename);
 	EO_close_stream(edif_stream);
-	if (backannotate != 0)
+	if (backannotate)
 		ttyputmsg(_("Back-annotation information has been added (library must be saved)"));
-	return(0);
+	return(FALSE);
 }
 
 /*
@@ -399,7 +406,7 @@ void io_edifextsearch(NODEPROTO *np)
 {
 	REGISTER NODEINST *ni;
 	REGISTER NODEPROTO *onp, *subnp;
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 	char *libname;
 
 	/* return if primitive (handled separately) */
@@ -424,7 +431,7 @@ void io_edifextsearch(NODEPROTO *np)
 			(void)initinfstr();
 			(void)addstringtoinfstr(libname);
 			(void)allocstring(&io_edifoextlibname[i], returninfstr(), io_tool->cluster);
-			ttyputmsg(_("External library %s, lib number %d"), io_edifoextlibname[i], i);
+			ttyputmsg(_("External library %s, lib number %ld"), io_edifoextlibname[i], i);
 		}
 		np->temp2 = i;
 		np->temp1++;
@@ -450,9 +457,9 @@ void io_edifextsearch(NODEPROTO *np)
  */
 char *io_ediffind_path(NODEPROTO *np)
 {
-	char *path, libpath[255], sep[2], ch, *filename;
+	char *path, libpath[255], ch, *filename;
 	FILE *f, *etry;
-	INTSML i;
+	INTBIG i;
 
 	/* initialize the local path name variable */
 	f = xopen("edifpath", io_filetypeedif, el_libdir, &filename);
@@ -466,10 +473,9 @@ char *io_ediffind_path(NODEPROTO *np)
 				libpath[i] = DIRSEP;
 				libpath[i + 1] = 0;
 				strcat(libpath, np->cell->cellname);
-				sep[0] = DIRSEP;   sep[1] = 0;
-				strcat(libpath, sep);
+				strcat(libpath, DIRSEPSTR);
 				strcat(libpath, "edif");
-				strcat(libpath, sep);
+				strcat(libpath, DIRSEPSTR);
 				strcat(libpath, "source");
 				etry = xopen(libpath, io_filetypeedif, el_libdir, &filename);
 				if (etry != NULL)
@@ -497,9 +503,9 @@ char *io_ediffind_path(NODEPROTO *np)
  * routine to dump the description of primitive "np" to the EDIF file
  * If the primitive is a schematic gate, use "i" as the number of inputs
  */
-void io_edifwriteprim(NODEPROTO *np, INTSML i, INTSML fun)
+void io_edifwriteprim(NODEPROTO *np, INTBIG i, INTBIG fun)
 {
-	REGISTER INTSML j;
+	REGISTER INTBIG j;
 	REGISTER PORTPROTO *firstport, *pp;
 	REGISTER char *direction;
 	char name[100];
@@ -508,7 +514,7 @@ void io_edifwriteprim(NODEPROTO *np, INTSML i, INTSML fun)
 	if (fun == NPGATEAND || fun == NPGATEOR || fun == NPGATEXOR)
 	{
 		EO_open_block(edif_stream, "cell");
-		(void)sprintf(name, "%s%d", io_ediftoken(np->primname), i);
+		(void)sprintf(name, "%s%ld", io_ediftoken(np->primname), i);
 		EO_put_identifier(edif_stream, name);
 	} else
 	{
@@ -520,7 +526,7 @@ void io_edifwriteprim(NODEPROTO *np, INTSML i, INTSML fun)
 	EO_put_block(edif_stream, "cellType", "GENERIC");
 	EO_open_block(edif_stream, "view");
 	EO_put_identifier(edif_stream, "cell");
-	EO_put_block(edif_stream, "viewType", schematic_view ? "SCHEMATIC" : "NETLIST");
+	EO_put_block(edif_stream, "viewType", (char *)(schematic_view ? "SCHEMATIC" : "NETLIST"));
 	EO_open_block(edif_stream, "interface");
 
 	firstport = np->firstportproto;
@@ -529,7 +535,7 @@ void io_edifwriteprim(NODEPROTO *np, INTSML i, INTSML fun)
 		for (j = 0; j < i; j++)
 		{
 			EO_open_block(edif_stream, "port");
-			(void)sprintf(name, "IN%d", j + 1);
+			(void)sprintf(name, "IN%ld", j + 1);
 			EO_put_identifier(edif_stream, name);
 			EO_put_block(edif_stream, "direction", "INPUT");
 			EO_close_block(edif_stream, "port");
@@ -603,7 +609,7 @@ char *io_edif_orientation(NODEINST *ni)
 /*
  * Helper name builder
  */
-char *io_edifwritecompname(NODEINST *ni, INTBIG fun, INTSML serindex)
+char *io_edifwritecompname(NODEINST *ni, INTBIG fun, INTBIG serindex)
 {
 	REGISTER VARIABLE *var;
 	REGISTER char *okname;
@@ -618,12 +624,12 @@ char *io_edifwritecompname(NODEINST *ni, INTBIG fun, INTSML serindex)
 	if (okname == 0)
 	{
 		/* check for node name */
-		var = getvalkey((INTBIG) ni, VNODEINST, VSTRING, el_node_name);
+		var = getvalkey((INTBIG) ni, VNODEINST, VSTRING, el_node_name_key);
 		okname = io_edifvalidname(var);
 		if (okname == 0)
 		{
 			/* create a new EDIF_name */
-			(void)sprintf(name, "INSTANCE%d", io_edifo_gateindex++);
+			(void)sprintf(name, "INSTANCE%ld", io_edifo_gateindex++);
 			(void)setvalkey((INTBIG) ni, VNODEINST, EDIF_name_key, (INTBIG)name, VSTRING);
 		} else
 		{
@@ -654,12 +660,13 @@ void io_edif_pt(INTBIG x, INTBIG y)
  * Recurses for contents if 'external' is zero, creates only
  * interface models for external elements for library number
  * 'external' if 'external' is non-zero.
- * Returns nonzero if back-annotation was added.
+ * Returns true if back-annotation was added.
  */
-INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external)
+BOOLEAN io_edifwritefacet(NODEPROTO *np, INTBIG external)
 {
 	INTBIG i, netcount, displaytotal;
-	INTBIG fun, backannotate;
+	INTBIG fun;
+	BOOLEAN backannotate;
 	NETWORK *net, *cnet, *onet;
 	VARIABLE *var;
 	NODEINST *ni;
@@ -669,10 +676,10 @@ INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external)
 	NODEPROTO *onp, *cnp;
 	ARCINST *ai;
 	char *pt, *iname, *oname, line[WORD+1], *direction;
-	INTSML globalport;
-	INTSML contents, schematic;
+	BOOLEAN globalport;
+	BOOLEAN contents, schematic;
 	INTBIG netindex, pageindex, is_array, sx, mx, rx, sy, my, ry;
-	INTSML diffcount;
+	INTBIG diffcount;
 	XARRAY trans;
 	INTBIG bx, by, xpos, ypos;
 	char name[WORD+1], page[10];
@@ -687,14 +694,14 @@ INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external)
 	if (el_pleasestop != 0)
 	{
 		stopping(STOPREASONEDIF);
-		return(0);
+		return(FALSE);
 	}
 
 	/* get polygon */
 	if (schematic_view && poly == NOPOLYGON) poly = allocstaticpolygon(4, io_tool->cluster);
 
 	/* recurse on sub-facets first */
-	backannotate = 0;
+	backannotate = FALSE;
 	if (np->cellview != el_iconview)
 	{
 		for (ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
@@ -715,7 +722,7 @@ INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external)
 			/* write the subfacet */
 			if (onp->temp1 == 0)
 			{
-				if (io_edifwritefacet(onp, external) != 0) backannotate = 1;
+				if (io_edifwritefacet(onp, external) != 0) backannotate = TRUE;
 			}
 		}
 	}
@@ -747,7 +754,7 @@ INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external)
 	EO_put_block(edif_stream, "cellType", "generic");
 	EO_open_block(edif_stream, "view");
 	EO_put_identifier(edif_stream, "cell");
-	EO_put_block(edif_stream, "viewType", schematic_view ? "SCHEMATIC" : "NETLIST");
+	EO_put_block(edif_stream, "viewType", (char *)(schematic_view ? "SCHEMATIC" : "NETLIST"));
 
 	/* write out the interface description */
 	EO_open_block(edif_stream, "interface");
@@ -759,7 +766,7 @@ INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external)
 	diffcount = 0;
 	for (net = np->firstnetwork; net != NONETWORK; net = net->nextnetwork)
 	{
-		if ((pp = (PORTPROTO *) net->temp2) != NOPORTPROTO && io_edifisglobal(pp) == 0)
+		if ((pp = (PORTPROTO *) net->temp2) != NOPORTPROTO && !io_edifisglobal(pp))
 		{
 			switch (pp->userbits & STATEBITS)
 			{
@@ -805,7 +812,7 @@ INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external)
 	if (np->cellview != el_iconview)
 	{
 		/* write the components, if there are any */
-		contents = 0;
+		contents = FALSE;
 
 		/* determine if this is a schematic view */
 		if (schematic_view && !strncmp(np->cellview->viewname, "schematic-page-", 15))
@@ -822,15 +829,16 @@ INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external)
 				(void)io_edifmarknetports(np);
 				break;
 			}
-			schematic = 1;
-		} else schematic = 0;
+			schematic = TRUE;
+		} else schematic = FALSE;
 
-		contents = 0;
+		contents = FALSE;
 		while (np != NONODEPROTO)
 		{
 			if (np->firstnodeinst != NONODEINST)
 			{
-				if (contents++ == 0) EO_open_block(edif_stream, "contents");
+				contents = TRUE;
+				if (!contents) EO_open_block(edif_stream, "contents");
 				if (schematic_view && schematic)
 				{
 					EO_open_block(edif_stream, "page");
@@ -851,7 +859,7 @@ INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external)
 
 					EO_open_block(edif_stream, "instance");
 					iname = io_edifwritecompname(ni, fun, 0);
-					if ((var = getvalkey((INTBIG) ni, VNODEINST, VSTRING, el_node_name)) != NOVARIABLE)
+					if ((var = getvalkey((INTBIG) ni, VNODEINST, VSTRING, el_node_name_key)) != NOVARIABLE)
 						oname = (char *)var->addr; else
 							oname = iname;
 
@@ -932,7 +940,7 @@ INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external)
 						/* now the origin */
 						EO_open_block(edif_stream, "origin");
 						var = getvalkey((INTBIG) ni->proto, VNODEPROTO, VINTEGER | VISARRAY,
-							el_prototype_center);
+							el_prototype_center_key);
 						if (var != NOVARIABLE)
 						{
 							bx = ((INTBIG *) var->addr)[0] + (ni->lowx + ni->highx) / 2 -
@@ -1017,7 +1025,7 @@ INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external)
 											describenodeproto(ni->parent));
 							else if (onet->signals < pp->network->signals)
 								for (i = onet->signals; i != pp->network->signals; i++)
-									ttyputmsg(_("** WARNING - no connection to %s port %s (signal %d) on %s in %s"),
+									ttyputmsg(_("** WARNING - no connection to %s port %s (signal %ld) on %s in %s"),
 										((pp->userbits & STATEBITS) == INPORT ? _("input") : _("vbias")),
 							 				pp->network->networklist[i]->netname, i,
 												 describenodeinst(ni), describenodeproto(ni->parent));
@@ -1133,14 +1141,14 @@ INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external)
 					}
 
 					/* establish if this is a global net */
-					globalport = 0;
+					globalport = FALSE;
 					if ((pp = (PORTPROTO *) net->temp2) != NOPORTPROTO)
 						globalport = io_edifisglobal(pp);
 
 					EO_open_block(edif_stream, "net");
 					if (net->namecount > 0)
 					{
-						if (globalport != 0)
+						if (globalport)
 						{
 							EO_open_block(edif_stream, "rename");
 							EO_put_identifier(edif_stream, io_ediftoken(net->netname));
@@ -1173,7 +1181,7 @@ INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external)
 					EO_open_block(edif_stream, "joined");
 
 					/* include exported ports (by net name) */
-					if (pp != NOPORTPROTO && globalport == 0)
+					if (pp != NOPORTPROTO && !globalport)
 						EO_put_block(edif_stream, "portRef", io_ediftoken(net->netname));
 
 					/* now include components using existing net-port pointers */
@@ -1296,7 +1304,7 @@ INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external)
 									EO_put_identifier(edif_stream, io_ediftoken(cnet->netname));
 								} else
 								{
-									ttyputerr(_("Proto bus width too narrow at %s {signal %d} in %s"),
+									ttyputerr(_("Proto bus width too narrow at %s {signal %ld} in %s"),
 										cpp->network->netname, i, describenodeproto(cpp->parent));
 									EO_put_identifier(edif_stream,
 										io_ediftoken(cpp->network->netname));
@@ -1331,7 +1339,7 @@ INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external)
 										io_ediftoken(cpp->network->netname));
 								} else
 								{
-									ttyputerr(_("Proto bus width too narrow at %s{signal %d}"),
+									ttyputerr(_("Proto bus width too narrow at %s"),
 										cpp->network->netname);
 									EO_put_identifier(edif_stream,
 										io_ediftoken(cpp->network->netname));
@@ -1358,7 +1366,7 @@ INTBIG io_edifwritefacet(NODEPROTO *np, INTSML external)
 						egraphic_override = EGUNKNOWN;
 					}
 
-					if (globalport != 0)
+					if (globalport)
 						EO_put_block(edif_stream, "userData", "global");
 					EO_close_block(edif_stream, "net");
 				} /* for (net = ... */
@@ -1428,17 +1436,17 @@ char *io_edifdescribepriminst(NODEINST *ni, INTBIG fun)
 /*
  * Establish whether port 'pp' is a global port or not
  */
-INTSML io_edifisglobal(PORTPROTO *pp)
+BOOLEAN io_edifisglobal(PORTPROTO *pp)
 {
 	NODEPROTO *inp;
 
 	/* pp is a global port if it is marked global */
-	if ((pp->userbits & BODYONLY) != 0) return(1);
+	if ((pp->userbits & BODYONLY) != 0) return(TRUE);
 
 	/* or if it does not exist on the icon */
-	if ((inp = iconview(pp->parent)) == NONODEPROTO) return(0);
-	if (equivalentport(pp->parent, pp, inp) == NOPORTPROTO) return(1);
-	return(0);
+	if ((inp = iconview(pp->parent)) == NONODEPROTO) return(FALSE);
+	if (equivalentport(pp->parent, pp, inp) == NOPORTPROTO) return(TRUE);
+	return(FALSE);
 }
 
 /*
@@ -1449,11 +1457,11 @@ INTSML io_edifisglobal(PORTPROTO *pp)
  * marked NOPORTPROTO.  Multiply exported nets have been collapsed at
  * both levels of hierarchy to a single net by the network maintainer.
  */
-INTSML io_edifmarknetports(NODEPROTO *np)
+INTBIG io_edifmarknetports(NODEPROTO *np)
 {
 	NETWORK *net;
 	PORTPROTO *pp;
-	REGISTER INTSML i, count, portnetcount;
+	REGISTER INTBIG i, count, portnetcount;
 
 	for (net = np->firstnetwork; net != NONETWORK; net = net->nextnetwork)
 		net->temp2 = (INTBIG) NOPORTPROTO;
@@ -1466,14 +1474,14 @@ INTSML io_edifmarknetports(NODEPROTO *np)
 		if ((count = pp->network->signals) > 1)
 			for (i = 0; i < count; i++)
 		{
-			if (pp->network->networklist[i]->temp2 == (INTBIG) NOPORTPROTO)
+			if (pp->network->networklist[i]->temp2 == (INTBIG)NOPORTPROTO)
 			{
-				pp->network->networklist[i]->temp2 = (INTBIG) pp;
+				pp->network->networklist[i]->temp2 = (INTBIG)pp;
 				portnetcount++;
 			}
-		} else if (pp->network->temp2 == (INTBIG) NOPORTPROTO)
+		} else if (pp->network->temp2 == (INTBIG)NOPORTPROTO)
 		{
-			pp->network->temp2 = (INTBIG) pp;
+			pp->network->temp2 = (INTBIG)pp;
 			portnetcount++;
 		}
 	}
@@ -1482,9 +1490,9 @@ INTSML io_edifmarknetports(NODEPROTO *np)
 
 /*
  * function to incorporate external library interface data or reference file
- * for current facet into EDIF netlist - returns 0 if successful
+ * for current facet into EDIF netlist - returns false if successful
  */
-INTSML io_edifwritelibext(NODEPROTO *np)
+BOOLEAN io_edifwritelibext(NODEPROTO *np)
 {
 	REGISTER FILE *f;
 	char buf[256], *filename;
@@ -1493,13 +1501,13 @@ INTSML io_edifwritelibext(NODEPROTO *np)
 
 	/* import the external library for this facet, if it exists */
 	var = getval((INTBIG) np, VNODEPROTO, VSTRING, "EDIF_external_lib");
-	if (var == NOVARIABLE) return(1);
+	if (var == NOVARIABLE) return(TRUE);
 	f = xopen((char *)var->addr, io_filetypeedif, "", &filename);
 	if (f == NULL)
 	{
 		ttyputerr(_("Cannot find EDIF external reference file %s on facet %s"),
 			(char *) var->addr, describenodeproto(np));
-		return(1);
+		return(TRUE);
 	}
 	for (;;)
 	{			/* copy the file */
@@ -1509,12 +1517,12 @@ INTSML io_edifwritelibext(NODEPROTO *np)
 		{
 			ttyputerr(_("Error copying EDIF reference file %s"), (char *) var->addr);
 			xclose(f);
-			return(1);
+			return(TRUE);
 		}
 	}
 	xclose(f);
 	ttyputmsg(_("Incorporated external EDIF reference file %s"), (char *) var->addr);
-	return(0);
+	return(FALSE);
 }
 
 /*
@@ -1526,14 +1534,14 @@ char *io_ediftoken(char *str)
 {
 	static char token[100];
 	char *tkptr;
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 
 	i = 0;
 	if (*str >= '0' && *str <= '9') token[i++] = 'X';
 	for (tkptr = token; (token[i++] = io_edifnotwhitespace(*str)); str++)
 	{
 		if (*str == ']') i--;			/* suppress the ']' */
-			else if (io_edifvalid(*str) == 0) token[i - 1] = '_';
+			else if (!io_edifvalid(*str)) token[i - 1] = '_';
 	}
 	token[i - 1] = '\0';
 	return(tkptr);
@@ -1545,11 +1553,11 @@ char io_edifnotwhitespace(char ch)
 	return(ch);
 }
 
-INTSML io_edifvalid(char ch)
+BOOLEAN io_edifvalid(char ch)
 {
 	if ((ch >= 'a' && ch <= 'z') || (ch >= 'A' && ch <= 'Z') ||
-		(ch >= '0' && ch <= '9') || ch == '&' || ch == '_') return(1);
-	return(0);
+		(ch >= '0' && ch <= '9') || ch == '&' || ch == '_') return(TRUE);
+	return(FALSE);
 }
 
 /*
@@ -1583,14 +1591,15 @@ char *io_edifvalidname(VARIABLE *var)
  * stopExpand property, which is a property attached to
  * either the layout view or the schematic view (if there is one).
  */
-INTSML io_edifwritefootprint(NODEPROTO *np, char *name, INTBIG routegrid)
+BOOLEAN io_edifwritefootprint(NODEPROTO *np, char *name, INTBIG routegrid)
 {
 	char iname[100], *cellType, *cellRep, *portAccess, *defaultAccess, *truename;
-	INTSML connections, allports;
+	BOOLEAN connections;
+	BOOLEAN allports;
 	NODEPROTO *vnp;
 	PORTPROTO *pp;
 	VARIABLE *var;
-	INTBIG width, height, access;
+	INTBIG width, height, accesskey;
 	float route;
 
 	(void)strcpy(iname, name);
@@ -1599,11 +1608,11 @@ INTSML io_edifwritefootprint(NODEPROTO *np, char *name, INTBIG routegrid)
 	if (io_fileout == NULL)
 	{
 		if (truename != 0) ttyputerr(_("Cannot write %s"), iname);
-		return(1);
+		return(TRUE);
 	}
 
 	/* make the access variable key */
-	access = makekey("EDIF_access");
+	accesskey = makekey("EDIF_access");
 
 	/* calculate the actual routing grid in microns */
 	route = (float)routegrid;
@@ -1649,28 +1658,28 @@ INTSML io_edifwritefootprint(NODEPROTO *np, char *name, INTBIG routegrid)
 	/* get standard cell dimensions */
 	width = (np->highx - np->lowx) / routegrid;
 	height = (np->highy - np->lowy) / routegrid;
-	xprintf(io_fileout, "  (%s %s (%d %d)\n",
+	xprintf(io_fileout, "  (%s %s (%ld %ld)\n",
 		io_ediftoken(np->cell->cellname), cellRep, height, width);
 
 	/* find out if all port connections are wanted */
 	var = getval((INTBIG) np, VNODEPROTO, VSTRING, "EDIF_placeallports");
 	if (var != NOVARIABLE)
 	{
-		allports = 1;
+		allports = TRUE;
 		defaultAccess = (char *) var->addr;
-	} else allports = 0;
+	} else allports = FALSE;
 
 	/* find all ports */
 	for (pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 	{
 		/* global connections are made in standard cells by abutment */
-		if (allports == 0 && (pp->userbits & BODYONLY) != 0) continue;
+		if (!allports && (pp->userbits & BODYONLY) != 0) continue;
 
-		var = getvalkey((INTBIG) pp, VPORTPROTO, VSTRING, access);
+		var = getvalkey((INTBIG) pp, VPORTPROTO, VSTRING, accesskey);
 		if (var == NOVARIABLE)
 		{
-			var = getvalkey((INTBIG) pp->subnodeinst, VNODEINST, VSTRING, access);
-			if (allports == 0 && var == NOVARIABLE)
+			var = getvalkey((INTBIG) pp->subnodeinst, VNODEINST, VSTRING, accesskey);
+			if (!allports && var == NOVARIABLE)
 			{
 				ttyputmsg(_("Non-global port %s has no access direction"), pp->protoname);
 				continue;
@@ -1684,7 +1693,7 @@ INTSML io_edifwritefootprint(NODEPROTO *np, char *name, INTBIG routegrid)
 		/* find the connecting layers */
 		connections = io_edifwriteportpositions(pp, np->lowx, np->lowy, portAccess, routegrid);
 
-		if (connections == 0)
+		if (!connections)
 			ttyputmsg(_("Non-global port %s has no connection access"), pp->protoname);
 	}
 
@@ -1693,7 +1702,7 @@ INTSML io_edifwritefootprint(NODEPROTO *np, char *name, INTBIG routegrid)
 	xclose(io_fileout);
 	ttyputmsg(_("%s written"), iname);
 
-	return(0);
+	return(FALSE);
 }
 
 /*
@@ -1701,13 +1710,14 @@ INTSML io_edifwritefootprint(NODEPROTO *np, char *name, INTBIG routegrid)
  * which takes the form "material:DIR,material:DIR," for all valid
  * materials.
  */
-INTSML io_edifwriteportpositions(PORTPROTO *pp, INTBIG cellx, INTBIG celly,
+BOOLEAN io_edifwriteportpositions(PORTPROTO *pp, INTBIG cellx, INTBIG celly,
 	char *accessrules, INTBIG routegrid)
 {
 	char accessdirection[20], material[30], *pt, *portdirection;
 	float xpos, ypos, scale;
 	INTBIG xsize, ysize, cx, cy;
-	INTSML i, j, connections;
+	INTBIG i, j;
+	BOOLEAN connections;
 	NODEINST *ni;
 	PORTPROTO *ppt;
 	static POLYGON *poly = NOPOLYGON;
@@ -1742,7 +1752,7 @@ INTSML io_edifwriteportpositions(PORTPROTO *pp, INTBIG cellx, INTBIG celly,
 	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_tool->cluster);
 
 	/* get this port geometry */
-	shapeportpoly(ni, ppt, poly, 0);
+	shapeportpoly(ni, ppt, poly, FALSE);
 	getcenter(poly, &cx, &cy);
 
 	/* offset center based on cell lower left corner */
@@ -1759,7 +1769,8 @@ INTSML io_edifwriteportpositions(PORTPROTO *pp, INTBIG cellx, INTBIG celly,
 	ypos = (float)cy;
 	ypos /= scale;
 
-	i = j = connections = 0;
+	i = j = 0;
+	connections = FALSE;
 	for (pt = accessrules;; pt++)
 	{
 		if (i == 0)
@@ -1787,7 +1798,7 @@ INTSML io_edifwriteportpositions(PORTPROTO *pp, INTBIG cellx, INTBIG celly,
 			(namesame(portdirection, "feed") == 0 ? io_edifupperstring(io_ediftoken(pp->protoname)) :
 				io_ediflowerstring(io_ediftoken(pp->protoname))), portdirection, material,
 					xpos, ypos, xsize, ysize, accessdirection);
-		connections++;
+		connections = TRUE;
 
 		if (*pt == 0) break;
 		i = j = 0;
@@ -1802,7 +1813,7 @@ char *io_ediflowerstring(char *str)
 {
 	char *pt;
 	static char newstr[1000];
-	INTSML i;
+	INTBIG i;
 
 	for (pt = str, i = 0; *pt != 0; i++)
 		newstr[i] = (isupper(*pt) ? tolower(*pt++) : *pt++);
@@ -1817,7 +1828,7 @@ char *io_edifupperstring(char *str)
 {
 	char *pt;
 	static char newstr[1000];
-	INTSML i;
+	INTBIG i;
 
 	for (pt = str, i = 0; *pt != 0; i++)
 		newstr[i] = (islower(*pt) ? toupper(*pt++) : *pt++);
@@ -1848,7 +1859,7 @@ void io_edifsymbol(NODEPROTO *np)
 		EO_open_block(edif_stream, "portImplementation");
 		EO_put_identifier(edif_stream, io_ediftoken(pp->protoname));
 		EO_open_block(edif_stream, "connectLocation");
-		shapeportpoly(pp->subnodeinst, pp->subportproto, poly, 0);
+		shapeportpoly(pp->subnodeinst, pp->subportproto, poly, FALSE);
 		io_edifsymbol_showpoly(poly);
 
 		/* close figure */
@@ -2308,11 +2319,11 @@ INTBIG io_edifsymbol_showpoly(POLYGON *obj)
 						EO_close_block(edif_stream, "rectangle");
 					}
 					obj->count = 5;
-					obj->style = (INTSML)i;
+					obj->style = i;
 					return(0);
 				}
 				obj->count = 5;
-				obj->style = (INTSML)i;
+				obj->style = i;
 			}
 			io_edifsetgraphic(EGART);
 			EO_open_block(edif_stream, "path");
@@ -2375,7 +2386,7 @@ EO_STREAM_PTR EO_open_stream(char *filename, INTBIG compress)
 	}
 
 	/* update filename - allocate name and initialize the structure */
-	if (allocstring(&stream->filename, truename, io_tool->cluster) != 0)
+	if (allocstring(&stream->filename, truename, io_tool->cluster))
 	{
 		ttyputnomemory();
 		return(NOEO_STREAM);
@@ -2426,7 +2437,7 @@ INTBIG EO_open_block(EO_STREAM_PTR stream, char *keyword)
 			xprintf(stream->file, "\n");
 		}
 		if (allocstring(&stream->blkstack[stream->blkstack_ptr++], keyword,
-			io_tool->cluster) != 0)
+			io_tool->cluster))
 		{
 			ttyputnomemory();
 			return(1);
@@ -2743,7 +2754,7 @@ void io_edifoptionsdlog(void)
 	char line[50];
 	float inputscale, newscale;
 
-	if (DiaInitDialog(&io_edifoptionsdialog) != 0) return;
+	if (DiaInitDialog(&io_edifoptionsdialog)) return;
 	curstate = io_getstatebits();
 	for(i=0; i<NUMIOSTATEBITWORDS; i++) newstate[i] = curstate[i];
 	if ((curstate[0]&EDIFSCHEMATIC) != 0) DiaSetControl(DEDO_USESCHEMATIC, 1);
