@@ -66,6 +66,7 @@
 #include "efunction.h"
 #include "database.h"
 #include "eio.h"
+#include "usr.h"
 #include "iogdsi.h"
 #include "tech.h"
 #include "tecgen.h"
@@ -88,9 +89,9 @@ static INTBIG          io_gdslayershape[MAXLAYERS];
 static INTBIG          io_gdslayerrect[MAXLAYERS];
 static INTBIG          io_gdslayerpath[MAXLAYERS];
 static INTBIG          io_gdslayerpoly[MAXLAYERS];
-static INTSML          io_gdslayervisible[MAXLAYERS];
-static INTSML          io_gdslayerused;
-static INTSML          io_gdslayerwhich;
+static BOOLEAN         io_gdslayervisible[MAXLAYERS];
+static BOOLEAN         io_gdslayerused;
+static INTBIG          io_gdslayerwhich;
 static INTBIG          io_gdssrefcount;
 static INTBIG          io_gdsrecomputed;
 static INTBIG         *io_gdscurstate;
@@ -268,7 +269,7 @@ static void            io_gdsIdetermine_shape(void);
 static void            io_gdsIdetermine_sref(void);
 static void            io_gdsIdetermine_text(void);
 static void            io_gdsIdetermine_time(char*);
-static void            io_gdsIelement(INTSML*);
+static void            io_gdsIelement(BOOLEAN*);
 static void            io_gdsIerror(INTBIG);
 static NODEPROTO      *io_gdsIfindproto(char *name);
 static void            io_gdsIfonts(void);
@@ -286,8 +287,8 @@ static void            io_gdsIheader(void);
 static void            io_gdsIinit(void);
 static void            io_gdsIitoa(char*, INTBIG);
 static void            io_gdsIlibrary(void);
-static INTSML          io_gdsIload(FILE*);
-static INTSML          io_gdsImember(gsymbol, gsymbol[]);
+static BOOLEAN         io_gdsIload(FILE*);
+static BOOLEAN         io_gdsImember(gsymbol, gsymbol[]);
 static void            io_gdsIOnceinit(void);
 static void            io_gdsIonlyone(gsymbol[], gsymbol);
 static double          io_gdsIpower(INTBIG, INTBIG);
@@ -298,7 +299,7 @@ static void            io_gdsIstep(INTBIG, INTBIG, INTBIG, INTBIG);
 static void            io_gdsIstructure(void);
 static void            io_gdsItext(char*, INTBIG, INTBIG, INTBIG, INTBIG, double);
 static void            io_gdsItransform(point_type, INTBIG, INTBIG);
-static void            io_gdsItranslate(INTBIG*, INTBIG*, double, INTSML);
+static void            io_gdsItranslate(INTBIG*, INTBIG*, double, BOOLEAN);
 static void            io_gdsIunits(void);
 static void            io_gdsIunsupported(gsymbol[]);
 
@@ -315,13 +316,13 @@ double io_gdsIpower(INTBIG val, INTBIG power)
 	return(result);
 }
 
-INTSML io_gdsImember(gsymbol tok, gsymbol set[])
+BOOLEAN io_gdsImember(gsymbol tok, gsymbol set[])
 {
 	REGISTER gsymbol *ctok;
 
 	for (ctok = set; *ctok != GDS_BADFIELD; ctok++)
-		if (*ctok == tok) return(1);
-	return(0);
+		if (*ctok == tok) return(TRUE);
+	return(FALSE);
 }
 
 void io_gdsIcopyset(gsymbol set1[], gsymbol set2[])
@@ -454,11 +455,11 @@ void io_gdsIgetdouble(double *realvalue)
 	INTBIG	long_integer;
 	static double twoto32;
 	static double twotoneg56;
-	static INTSML init = 1;
+	static BOOLEAN init = TRUE;
 
 	if (init)
 	{
-		init = 0;
+		init = FALSE;
 		twoto32 = io_gdsIpower(2, 32);
 		twotoneg56 = 1.0 / io_gdsIpower (2, 56);
 	}
@@ -655,10 +656,10 @@ void io_gdsIgettoken(void)
 	}
 }
 
-void io_gdsItranslate(INTBIG *ang, INTBIG *trans, double angle, INTSML reflected)
+void io_gdsItranslate(INTBIG *ang, INTBIG *trans, double angle, BOOLEAN reflected)
 {
 	*ang = rounddouble(angle) % 3600;
-	*trans = reflected;
+	*trans = reflected ? 1 : 0;
 	if (*trans)
 		*ang = (2700 - *ang) % 3600;
 
@@ -670,7 +671,7 @@ void io_gdsItransform(point_type delta, INTBIG angle, INTBIG trans)
 {
 	XARRAY matrix;
 
-	makeangle((INTSML)angle, (INTSML)trans, matrix);
+	makeangle(angle, trans, matrix);
 	xform(delta.px, delta.py, &delta.px, &delta.py, matrix);
 }
 
@@ -695,7 +696,7 @@ void io_gdsIstep(INTBIG nc, INTBIG nr, INTBIG angle, INTBIG trans)
 	}
 
 	/* create the node */
-	makeangle((INTSML)angle, (INTSML)trans, transform);
+	makeangle(angle, trans, transform);
 
 	/* now transform the center */
 	cx = (io_gdssref->highx + io_gdssref->lowx) / 2;
@@ -719,7 +720,7 @@ void io_gdsIstep(INTBIG nc, INTBIG nr, INTBIG angle, INTBIG trans)
 			{
 				if ((io_gdsinstance = newnodeinst(io_gdssref, pt.px + io_gdssref->lowx + ox,
 					pt.px + io_gdssref->highx + ox, pt.py + io_gdssref->lowy + oy,
-						pt.py + io_gdssref->highy + oy, (INTSML)trans, (INTSML)angle,
+						pt.py + io_gdssref->highy + oy, trans, angle,
 							io_gdsstructure)) == NONODEINST)
 								longjmp(io_gdsenv, (INTBIG)_("failed to create AREF"));
 				if ((io_gdscurstate[0] & GDSINEXPAND) != 0)
@@ -738,11 +739,11 @@ void io_gdsIstep(INTBIG nc, INTBIG nr, INTBIG angle, INTBIG trans)
 
 void io_gdsIdetermine_boundary(INTBIG npts, shape_type *perimeter, shape_type *oclass)
 {
-	INTSML is90, is45;
+	BOOLEAN is90, is45;
 	REGISTER INTBIG i;
 
-	is90 = 1;
-	is45 = 1;
+	is90 = TRUE;
+	is45 = TRUE;
 	if (io_gdsvertex[0].px == io_gdsvertex[npts-1].px &&
 		io_gdsvertex[0].py == io_gdsvertex[npts-1].py)
 			(*perimeter) = GDS_CLOSED; else
@@ -757,15 +758,15 @@ void io_gdsIdetermine_boundary(INTBIG npts, shape_type *perimeter, shape_type *o
 	{
 		if (io_gdsboundarydelta[i].px != 0 && io_gdsboundarydelta[i].py != 0)
 		{
-			is90 = 0;
+			is90 = FALSE;
 			if (abs(io_gdsboundarydelta[i].px) != abs(io_gdsboundarydelta[i].py))
-				is45 = 0;
+				is45 = FALSE;
 		}
 	}
-	if ((*perimeter) == GDS_CLOSED && (is90 != 0 || is45 != 0))
+	if ((*perimeter) == GDS_CLOSED && (is90 || is45))
 		(*oclass) = GDS_POLY; else
 			(*oclass) = GDS_OBLIQUE;
-	if (npts == 5 && is90 != 0 && (*perimeter) == GDS_CLOSED)
+	if (npts == 5 && is90 && (*perimeter) == GDS_CLOSED)
 		(*oclass) = GDS_RECTANGLE;
 }
 
@@ -847,7 +848,7 @@ void io_gdsIshape(INTBIG npts, shape_type perimeter, shape_type oclass)
 			}
 
 			/* store the trace information */
-			if (setvalkey((INTBIG)ni, VNODEINST, el_trace, (INTBIG)trace,
+			if (setvalkey((INTBIG)ni, VNODEINST, el_trace_key, (INTBIG)trace,
 				VINTEGER|VISARRAY|((npts*2)<<VLENGTHSH)) == NOVARIABLE)
 					longjmp(io_gdsenv, (INTBIG)_("failed to create POLYGON points"));
 
@@ -875,12 +876,12 @@ void io_gdsItext(char *charstring, INTBIG vjust, INTBIG hjust, INTBIG angle,
 
 	/* create a holding node */
 	if ((ni = newnodeinst(io_gdslayernode, io_gdsvertex[0].px, io_gdsvertex[0].px,
-		io_gdsvertex[0].py, io_gdsvertex[0].py, (INTSML)trans, (INTSML)angle,
+		io_gdsvertex[0].py, io_gdsvertex[0].py, trans, angle,
 			io_gdsstructure)) == NONODEINST)
 				longjmp(io_gdsenv, (INTBIG)_("Could not create text marker"));
 
 	/* now add the text */
-	if ((var = setvalkey((INTBIG)ni, VNODEINST, el_node_name, (INTBIG)charstring,
+	if ((var = setvalkey((INTBIG)ni, VNODEINST, el_node_name_key, (INTBIG)charstring,
 		VSTRING|VDISPLAY)) == NOVARIABLE)
 			longjmp(io_gdsenv, (INTBIG)_("Could not create text string"));
 
@@ -949,7 +950,7 @@ void io_gdsIOnceinit(void)
 		io_gdslayerrect[i] = 0;
 		io_gdslayerpath[i] = 0;
 		io_gdslayerpoly[i] = 0;
-		io_gdslayervisible[i] = 1;
+		io_gdslayervisible[i] = TRUE;
 	}
 	if ((var = getval((INTBIG)el_curtech, VTECHNOLOGY, VINTEGER|VISARRAY,
 		"IO_gds_layer_numbers")) != NOVARIABLE)
@@ -976,7 +977,7 @@ void io_gdsIOnceinit(void)
 					{
 						/* ignore if this layer is not to be drawn */
 						if ((poly->desc->colstyle&INVISIBLE) != 0)
-							io_gdslayervisible[which] = 0;
+							io_gdslayervisible[which] = FALSE;
 						break;
 					}
 				}
@@ -1155,11 +1156,11 @@ void io_gdsIunits(void)
 
 void io_gdsIunsupported(gsymbol bad_op_set[])
 {
-	if (io_gdsImember(io_gdstoken, bad_op_set) != 0)
+	if (io_gdsImember(io_gdstoken, bad_op_set))
 	do
 	{
 		io_gdsIgettoken();
-	} while (io_gdsImember(io_gdstoken, io_gdsIgood_op_set) == 0);
+	} while (!io_gdsImember(io_gdstoken, io_gdsIgood_op_set));
 }
 
 void io_gdsIdetermine_points(INTBIG min_points, INTBIG max_points, INTBIG *point_counter)
@@ -1187,15 +1188,15 @@ void io_gdsIdetermine_points(INTBIG min_points, INTBIG max_points, INTBIG *point
 
 void io_gdsIdetermine_orientation(INTBIG *angle, INTBIG *trans, double *scale)
 {
-	INTSML mirror_x;
+	BOOLEAN mirror_x;
 	double anglevalue;
 
 	anglevalue = 0.0;
-	mirror_x = 0;
+	mirror_x = FALSE;
 	io_gdsIgettoken();
 	if (io_gdstoken == GDS_FLAGSYM)
 	{
-		if (io_gdstokenflags.u.f.flag0) mirror_x = 1;
+		if (io_gdstokenflags.u.f.flag0) mirror_x = TRUE;
 		/* if (io_gdstokenflags.u.f.flag13) abs_scale = 1; */
 		/* if (io_gdstokenflags.u.f.flag14) abs_angle = 1; */
 		io_gdsIgettoken();
@@ -1252,15 +1253,15 @@ void io_gdsIdetermine_layer(INTBIG *layer, INTBIG *sublayer)
 			if (io_gdslayernode == gen_drcprim &&
 				(io_gdscurstate[0]&GDSINIGNOREUKN) != 0)
 			{
-				io_gdslayerused = 0;
+				io_gdslayerused = FALSE;
 			} else
 			{
 				io_gdslayerused = io_gdslayervisible[io_gdscurlayer];
 			}
-			io_gdslayerwhich = (INTSML)io_gdscurlayer;
+			io_gdslayerwhich = io_gdscurlayer;
 
 			io_gdsIgettoken();
-			if (io_gdsImember(io_gdstoken, io_gdsImask_set) != 0)
+			if (io_gdsImember(io_gdstoken, io_gdsImask_set))
 			{
 				io_gdsIgettoken();
 				if (io_gdstokenvalue16 != 0)
@@ -1315,7 +1316,7 @@ void io_gdsIbeginstructure(void)
 				if (io_gdsstructure == NONODEPROTO)
 				{
 					/* create the proto */
-					io_gdsstructure = newnodeproto(io_gdstokenstring, io_gdslibrary);
+					io_gdsstructure = us_newnodeproto(io_gdstokenstring, io_gdslibrary);
 					if (io_gdsstructure == NONODEPROTO)
 						longjmp(io_gdsenv, (INTBIG)_("failed to create structure"));
 					if (io_verbose < 0 && io_gdsfilesize > 0)
@@ -1326,11 +1327,17 @@ void io_gdsIbeginstructure(void)
 					} else if (io_verbose != 0) ttyputmsg(_("Reading %s"), io_gdstokenstring);
 
 #ifdef PLACEFACETCENTERS
-					/* add the facet center */
-					if (newnodeinst(gen_facetcenterprim, gen_facetcenterprim->lowx,
-						gen_facetcenterprim->highx, gen_facetcenterprim->lowy,
-						gen_facetcenterprim->highy, 0, 0, io_gdsstructure) == NONODEINST)
+					{
+						REGISTER NODEINST *ni;
+
+						/* add the facet center */
+						ni = newnodeinst(gen_facetcenterprim, gen_facetcenterprim->lowx,
+							gen_facetcenterprim->highx, gen_facetcenterprim->lowy,
+							gen_facetcenterprim->highy, 0, 0, io_gdsstructure);
+						if (ni == NONODEINST)
 							longjmp(io_gdsenv, (INTBIG)_("failed to create facet center"));
+						ni->userbits |= HARDSELECTN|NVISIBLEINSIDE;
+					}
 #endif
 					if (io_gdslibrary->curnodeproto == NONODEPROTO)
 						io_gdslibrary->curnodeproto = io_gdsstructure;
@@ -1621,7 +1628,7 @@ void io_gdsIdetermine_path(void)
 						off[j*2] = poly->xv[j] - cx;
 						off[j*2+1] = poly->yv[j] - cy;
 					}
-					(void)setvalkey((INTBIG)ni, VNODEINST, el_trace, (INTBIG)off,
+					(void)setvalkey((INTBIG)ni, VNODEINST, el_trace_key, (INTBIG)off,
 						VINTEGER|VISARRAY|(8<<VLENGTHSH));
 				}
 			}
@@ -1642,7 +1649,7 @@ void io_gdsIgetproto(char *name)
 	if (np == NONODEPROTO)
 	{
 		/* FILO order, create this nodeproto */
-		if ((np = newnodeproto(io_gdstokenstring, io_gdslibrary)) == NONODEPROTO)
+		if ((np = us_newnodeproto(io_gdstokenstring, io_gdslibrary)) == NONODEPROTO)
 			longjmp(io_gdsenv, (INTBIG)_("failed to create SREF proto"));
 		if (io_verbose < 0 && io_gdsfilesize > 0)
 		{
@@ -1652,11 +1659,17 @@ void io_gdsIgetproto(char *name)
 		} else if (io_verbose != 0) ttyputmsg(_("Reading %s"), io_gdstokenstring);
 
 #ifdef PLACEFACETCENTERS
-		/* add the facet center */
-		if (newnodeinst(gen_facetcenterprim, gen_facetcenterprim->lowx,
-			gen_facetcenterprim->highx, gen_facetcenterprim->lowy,
-				gen_facetcenterprim->highy, 0, 0, np) == NONODEINST)
-					longjmp(io_gdsenv, (INTBIG)_("failed to create facet center"));
+		{
+			NODEINST *ni;
+
+			/* add the facet center */
+			ni = newnodeinst(gen_facetcenterprim, gen_facetcenterprim->lowx,
+				gen_facetcenterprim->highx, gen_facetcenterprim->lowy,
+					gen_facetcenterprim->highy, 0, 0, np);
+			if (ni == NONODEINST)
+				longjmp(io_gdsenv, (INTBIG)_("failed to create facet center"));
+			ni->userbits |= HARDSELECTN|NVISIBLEINSIDE;
+		}
 #endif
 	}
 
@@ -1696,7 +1709,7 @@ void io_gdsIdetermine_sref(void)
 		}
 
 		/* create the node */
-		makeangle((INTSML)angle, (INTSML)trans, transform);
+		makeangle(angle, trans, transform);
 
 		/* now transform the center */
 		cx = (io_gdssref->highx + io_gdssref->lowx) / 2;
@@ -1711,7 +1724,7 @@ void io_gdsIdetermine_sref(void)
 			io_gdsvertex[0].px + io_gdssref->highx + ox,
 			io_gdsvertex[0].py + io_gdssref->lowy + oy,
 			io_gdsvertex[0].py + io_gdssref->highy + oy,
-			(INTSML)trans, (INTSML)angle, io_gdsstructure)) == NONODEINST)
+			trans, angle, io_gdsstructure)) == NONODEINST)
 				longjmp(io_gdsenv, (INTBIG)_("failed to create SREF"));
 		if (io_gdscurstate[0]&GDSINEXPAND)
 			io_gdsinstance->userbits |= NEXPAND;
@@ -1817,33 +1830,46 @@ void io_gdsIdetermine_text(void)
 		io_gdsIgettoken();
 	}
 	angle = trans = 0;
-	if (io_gdstoken == GDS_STRANS)
-	io_gdsIdetermine_orientation(&angle, &trans, &scale);
-	if (io_gdstoken == GDS_XY)
+	for(;;)
 	{
-		io_gdsIgettoken();
-		io_gdsIdetermine_points(1, 1, &n);
-	} else
-	{
-		io_gdsIonlyone(io_gdsIrecovery_set, GDS_ENDEL);
-		io_gdsIerror(26);
-	}
-	if (io_gdstoken == GDS_STRING)
-	{
-		if (io_gdsrecordcount |= 0)
+		if (io_gdstoken == GDS_STRANS)
+		{
+			io_gdsIdetermine_orientation(&angle, &trans, &scale);
+			continue;
+		}
+		if (io_gdstoken == GDS_XY)
 		{
 			io_gdsIgettoken();
-			(void)strcpy(textstring,io_gdstokenstring);
+			io_gdsIdetermine_points(1, 1, &n);
+			continue;
 		}
-		else textstring[0] = '\0';
-		io_gdsIgettoken();
+		if (io_gdstoken == GDS_ANGLE)
+		{
+			io_gdsIgettoken();
+			angle = (INTBIG)(io_gdsrealtokendp * 10.0);
+			io_gdsIgettoken();
+			continue;
+		}
+		if (io_gdstoken == GDS_STRING)
+		{
+			if (io_gdsrecordcount == 0) textstring[0] = '\0'; else
+			{
+				io_gdsIgettoken();
+				(void)strcpy(textstring, io_gdstokenstring);
+			}
+			io_gdsIgettoken();
+			break;
+		}
+		io_gdsIonlyone(io_gdsIrecovery_set, GDS_ENDEL);
+		io_gdsIerror(26);
+		break;
 	}
 	io_gdsItext(textstring, vert_just, horiz_just, angle, trans, scale);
 }
 
-void io_gdsIelement(INTSML *empty_structure)
+void io_gdsIelement(BOOLEAN *empty_structure)
 {
-	while (io_gdsImember(io_gdstoken, io_gdsIshape_set) != 0)
+	while (io_gdsImember(io_gdstoken, io_gdsIshape_set))
 	{
 		switch (io_gdstoken)
 		{
@@ -1858,29 +1884,29 @@ void io_gdsIelement(INTSML *empty_structure)
 		}
 	}
 
-	if (io_gdstoken == GDS_PROPATTR)
+	while (io_gdstoken == GDS_PROPATTR)
 		io_gdsIdetermine_property();
 	if (io_gdstoken != GDS_ENDEL)
 	{
 		io_gdsIonlyone(io_gdsIrecovery_set, GDS_BGNSTR);
 		io_gdsIerror(15);
 	}
-	(*empty_structure) = 0;
+	(*empty_structure) = FALSE;
 }
 
 void io_gdsIstructure(void)
 {
-	INTSML empty_structure;
+	BOOLEAN empty_structure;
 
 	io_gdsIbeginstructure();
-	empty_structure = 1;
+	empty_structure = TRUE;
 	io_gdsIgettoken();
 	while (io_gdstoken != GDS_ENDSTR)
 	{
 		io_gdsIelement(&empty_structure);
 		io_gdsIgettoken();
 	}
-	if (empty_structure != 0)
+	if (empty_structure)
 	{
 		ttyputmsg("%s", _(io_gdsIerror_string[11]));
 		ttyputerr(_("Error at block number %5d and offset %4d"),
@@ -1892,7 +1918,7 @@ void io_gdsIstructure(void)
 		&io_gdsstructure->lowy, &io_gdsstructure->highy);
 }
 
-INTSML io_gdsIload(FILE *input)
+BOOLEAN io_gdsIload(FILE *input)
 {
 	io_gdsIinit();
 	io_gdsIgettoken();
@@ -1900,7 +1926,7 @@ INTSML io_gdsIload(FILE *input)
 	io_gdsIgettoken();
 	io_gdsIlibrary();
 	io_gdsIgettoken();
-	while (io_gdsImember(io_gdstoken, io_gdsIoption_set) != 0)
+	while (io_gdsImember(io_gdstoken, io_gdsIoption_set))
 		switch (io_gdstoken)
 	{
 		case GDS_REFLIBS:
@@ -1922,7 +1948,7 @@ INTSML io_gdsIload(FILE *input)
 		io_gdsIstructure();
 		io_gdsIgettoken();
 	}
-	return(0);
+	return(FALSE);
 }
 
 /* module: io_readgdslibrary
@@ -1933,12 +1959,13 @@ INTSML io_gdsIload(FILE *input)
  *           1 for first of series
  *           2 for midseriese
  *           3 for end of series
- * returns 0 on success, 1 on error
+ * returns false on success, true on error
  */
-INTSML io_readgdslibrary(LIBRARY *lib, INTSML position)
+BOOLEAN io_readgdslibrary(LIBRARY *lib, INTBIG position)
 {
 	FILE *input;
-	INTSML err, i;
+	BOOLEAN err;
+	INTBIG i;
 	INTBIG count;
 	char *msg, *filename;
 	NODEPROTO *np;
@@ -1953,17 +1980,17 @@ INTSML io_readgdslibrary(LIBRARY *lib, INTSML position)
 	if ((input = xopen(io_gdslibrary->libfile, io_filetypegds, "", &filename)) == NULL)
 	{
 		ttyputerr(_("File %s not found"), io_gdslibrary->libfile);
-		return(1);
+		return(TRUE);
 	}
 
 	io_gdsstream.fp = input;
 	io_gdsfilesize = filesize(input);
 	if (io_verbose < 0 && io_gdsfilesize > 0)
 	{
-		if (DiaInitDialog(&us_progressdialog) != 0)
+		if (DiaInitDialog(&us_progressdialog))
 		{
 			xclose(input);
-			return(1);
+			return(TRUE);
 		}
 		DiaPercent(1, 0);
 	}
@@ -1975,7 +2002,7 @@ INTSML io_readgdslibrary(LIBRARY *lib, INTSML position)
 		ttyputerr(_("Error: %s"), msg);
 		xclose(input);
 		if (io_verbose < 0 && io_gdsfilesize > 0) DiaDoneDialog();
-		return(1);
+		return(TRUE);
 	}
 
 	/* set default objects */
@@ -1996,19 +2023,19 @@ INTSML io_readgdslibrary(LIBRARY *lib, INTSML position)
 			if (position == 0)
 				ttyputmsg(_("%s information:"), skippath(io_gdslibrary->libfile)); else
 					ttyputmsg(_("Summary information:"));
-			ttyputmsg("  %d %s", io_gdssrefcount, makeplural("SREF", io_gdssrefcount));
+			ttyputmsg("  %ld %s", io_gdssrefcount, makeplural("SREF", io_gdssrefcount));
 			for (i = 0; i < MAXLAYERS; i++)
 			{
 				if (io_gdslayertext[i] || io_gdslayerpoly[i])
 				{
 					if (i < el_curtech->layercount)
 					{
-						ttyputmsg(_("  %d objects on layer %d (%s)"),
+						ttyputmsg(_("  %ld objects on layer %ld (%s)"),
 							io_gdslayerpoly[i]+io_gdslayertext[i], i,
 								describenodeproto(io_gdslayernodes[i]));
 					} else
 					{
-						ttyputmsg(_("  %d objects on layer %d"),
+						ttyputmsg(_("  %ld objects on layer %ld"),
 							io_gdslayerpoly[i]+io_gdslayertext[i], i);
 					}
 				}
@@ -2055,7 +2082,7 @@ void io_gdsIrecompute(NODEPROTO *np, INTBIG count)
 	   just updating the SREF info */
 	/* first clear the geometry structure */
 	db_freertree(np->rtree);
-	geomstructure(np);
+	(void)geomstructure(np);
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		if (ni->proto->primindex == 0)
