@@ -96,36 +96,36 @@
 #define WORSTTHRESH          0.1			/* 1/10 of a millimeter */
 
 static char   *io_dbuffer= 0, *io_empty;	/* for buffering output data  */
-static INTSML  io_gds_curlayer;				/* Current layer for gds output */
+static INTBIG  io_gds_curlayer;				/* Current layer for gds output */
 static INTBIG  io_gds_pos;					/* Position of next byte in the buffer */
 static INTBIG  io_gds_block;				/* Number data buffers output so far */
 static FILE   *io_gds_outfd;				/* File descriptor for output */
 static INTBIG *io_gds_outputstate;			/* current output state */
-static INTSML  io_gds_polypoints;			/* number of allowable points on a polygon */
+static INTBIG  io_gds_polypoints;			/* number of allowable points on a polygon */
 static double  io_gds_scale;				/* constant */
 static INTBIG  io_gds_layerkey;				/* key for "IO_gds_layer" */
 
 /* prototypes for local routines */
 static void io_gdswritecell(NODEPROTO*);
-static void io_outputgdspoly(TECHNOLOGY*, POLYGON*, INTSML, INTBIG, INTBIG, XARRAY, VARIABLE*);
-static void io_gds_set_layer(INTSML);
+static void io_outputgdspoly(TECHNOLOGY*, POLYGON*, INTBIG, INTBIG, INTBIG, XARRAY, VARIABLE*);
+static void io_gds_set_layer(INTBIG);
 static void io_gds_initialize(void);
 static void io_gds_closefile(void);
 static void io_gds_bgnlib(NODEPROTO*);
 static void io_gds_bgnstr(NODEPROTO*);
 static void io_gds_date(UINTBIG*);
-static void io_gds_header(INTSML, INTSML);
-static void io_gds_name(INTSML, char*, INTSML);
-static void io_gds_angle(INTSML);
+static void io_gds_header(INTBIG, INTBIG);
+static void io_gds_name(INTBIG, char*, INTBIG);
+static void io_gds_angle(INTBIG);
 static void io_gds_boundary(POLYGON*);
 static void io_gds_path(POLYGON*);
 static void io_gds_byte(char);
 static void io_gds_int2(INTSML);
 static void io_gds_int4(INTBIG);
-static void io_gds_int2_arr(INTSML*, INTSML);
-static void io_gds_int4_arr(INTBIG*, INTSML);
-static void io_gds_string(char*, INTSML);
-static void io_gds_write_polygon(INTSML, TECHNOLOGY*, INTBIG*, INTBIG*, INTSML);
+static void io_gds_int2_arr(INTSML*, INTBIG);
+static void io_gds_int4_arr(INTBIG*, INTBIG);
+static void io_gds_string(char*, INTBIG);
+static void io_gds_write_polygon(INTBIG, TECHNOLOGY*, INTBIG*, INTBIG*, INTBIG);
 static char *io_gds_makename(char*);
 static void io_gds_cvfloat8(double*, UINTBIG*, UINTBIG*);
 static void io_gdsoptionsdlog(void);
@@ -149,7 +149,7 @@ void io_initgds(void)
 	DiaDeclareHook("gdsopt", &io_gdsp, io_gdsoptionsdlog);
 }
 
-INTSML io_writegdslibrary(LIBRARY *lib)
+BOOLEAN io_writegdslibrary(LIBRARY *lib)
 {
 	char *name, *truename;
 	REGISTER NODEPROTO *np;
@@ -161,7 +161,7 @@ INTSML io_writegdslibrary(LIBRARY *lib)
 	if (lib->curnodeproto == NONODEPROTO)
 	{
 		ttyputerr(_("Must be editing a facet to generate GDS output"));
-		return(1);
+		return(TRUE);
 	}
 
 	/* construct file name */
@@ -176,7 +176,7 @@ INTSML io_writegdslibrary(LIBRARY *lib)
 	{
 		if (truename != 0) ttyputerr(_("Cannot write %s"), truename);
 		efree(name);
-		return(1);
+		return(TRUE);
 	}
 
 	/* get current output state */
@@ -185,7 +185,7 @@ INTSML io_writegdslibrary(LIBRARY *lib)
 	/* get the number of allowable points on a polygon */
 	var = getval((INTBIG)el_curtech, VTECHNOLOGY, VINTEGER, "IO_gds_polypoints");
 	if (var == NOVARIABLE) io_gds_polypoints = 200; else /* 200 is the MAX allowed in GDS-II */
-		io_gds_polypoints = (INTSML)var->addr;
+		io_gds_polypoints = var->addr;
 
 	/* initialize cache of layer information */
 	for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
@@ -229,7 +229,7 @@ INTSML io_writegdslibrary(LIBRARY *lib)
 	/* tell the user that the file is written */
 	ttyputmsg(_("%s written"), truename);
 	efree(name);
-	return(0);
+	return(FALSE);
 }
 
 void io_gdswritecell(NODEPROTO *np)
@@ -242,7 +242,7 @@ void io_gdswritecell(NODEPROTO *np)
 	REGISTER INTBIG offx, offy, laynum, bestthresh, worstthresh;
 	XARRAY trans;
 	INTBIG xpos, ypos, bx, by, fx, fy, tx, ty;
-	INTSML angle, transvalue, gatherpolygon;
+	INTBIG angle, transvalue, gatherpolygon;
 	static POLYGON *poly = NOPOLYGON;
 	char str[513];
 	REGISTER CONTOUR *con, *nextcon, *contourlist;
@@ -290,7 +290,8 @@ void io_gdswritecell(NODEPROTO *np)
 	gatherpolygon = 0;
 	for(subno = np->firstnodeinst; subno != NONODEINST; subno = subno->nextnodeinst)
 	{
-		if (subno->proto == art_openedpolygonprim || subno->proto == art_circleprim)
+		if (subno->proto == art_openedpolygonprim || subno->proto == art_circleprim ||
+			subno->proto == art_thickcircleprim)
 		{
 			gatherpolygon = 1;
 			break;
@@ -315,7 +316,7 @@ void io_gdswritecell(NODEPROTO *np)
 
 			/* add in first point of contour */
 			if (poly->count+1 >= poly->limit)
-				extendpolygon(poly, (INTSML)(poly->count+1));
+				(void)extendpolygon(poly, poly->count+1);
 			poly->xv[poly->count] = con->firstcontourelement->sx;
 			poly->yv[poly->count] = con->firstcontourelement->sy;
 			poly->count++;
@@ -331,9 +332,9 @@ void io_gdswritecell(NODEPROTO *np)
 						initcontoursegmentgeneration(conel);
 						for(;;)
 						{
-							if (nextcontoursegmentgeneration(&fx, &fy, &tx, &ty) != 0) break;
+							if (nextcontoursegmentgeneration(&fx, &fy, &tx, &ty)) break;
 							if (poly->count+1 >= poly->limit)
-								extendpolygon(poly, (INTSML)(poly->count+1));
+								(void)extendpolygon(poly, poly->count+1);
 							poly->xv[poly->count] = tx;
 							poly->yv[poly->count] = ty;
 							poly->count++;
@@ -341,7 +342,7 @@ void io_gdswritecell(NODEPROTO *np)
 						break;
 					case LINESEGMENTTYPE:
 						if (poly->count+1 >= poly->limit)
-							extendpolygon(poly, (INTSML)(poly->count+1));
+							(void)extendpolygon(poly, poly->count+1);
 						poly->xv[poly->count] = conel->ex;
 						poly->yv[poly->count] = conel->ey;
 						poly->count++;
@@ -394,7 +395,7 @@ void io_gdswritecell(NODEPROTO *np)
 				/* determine the layer name for this polygon */
 				if (poly->layer < 0 || subnt->tech->temp1 == 0) continue;
 				laynum = ((INTBIG *)subnt->tech->temp1)[poly->layer];
-				io_gds_set_layer((INTSML)laynum);
+				io_gds_set_layer(laynum);
 
 				for (i=0; i<displaytotal; i++)
 				{
@@ -402,9 +403,9 @@ void io_gdswritecell(NODEPROTO *np)
 					/* dump this text field */
 					/* note that a presentation of 8 is bottomleft */
 					io_gds_header(HDR_TEXT, 0);
-					io_gds_header(HDR_LAYER, (INTSML)io_gds_curlayer);
-					io_gds_header(HDR_TEXTTYPE, (INTSML)0);
-					io_gds_header(HDR_PRESENTATION, (INTSML)8);
+					io_gds_header(HDR_LAYER, io_gds_curlayer);
+					io_gds_header(HDR_TEXTTYPE, 0);
+					io_gds_header(HDR_PRESENTATION, 8);
 					/* now the orientation */
 					transvalue = 0;
 					if (subno->transpose != 0)
@@ -430,7 +431,7 @@ void io_gdswritecell(NODEPROTO *np)
 					str[j] = '\0';
 					io_gds_int2((INTSML)(4+j));
 					io_gds_int2(HDR_STRING);
-					io_gds_string(str, (INTSML)j);
+					io_gds_string(str, j);
 					io_gds_header(HDR_ENDEL, 0);
 
 					/* write out the node the text is attached to */
@@ -459,7 +460,7 @@ void io_gdswritecell(NODEPROTO *np)
 
 			/* write a call to a cell */
 #ifndef OLDGDS
-			var = getvalkey((INTBIG)subno->proto, VNODEPROTO, VINTEGER|VISARRAY, el_prototype_center);
+			var = getvalkey((INTBIG)subno->proto, VNODEPROTO, VINTEGER|VISARRAY, el_prototype_center_key);
 			if (var != NOVARIABLE)
 			{
 				bx = ((INTBIG *)var->addr)[0] + (subno->lowx+subno->highx)/2 -
@@ -485,8 +486,8 @@ void io_gdswritecell(NODEPROTO *np)
 				/* look for grab points in contents and body cells */
 				bodysubnt = subnt;
 				subnt = onp;
-				corneroffset(subno, bodysubnt, subno->rotation, subno->transpose, &bx, &by, 0);
-				corneroffset(NONODEINST, subnt, subno->rotation, subno->transpose, &cx, &cy, 0);
+				corneroffset(subno, bodysubnt, subno->rotation, subno->transpose, &bx, &by, FALSE);
+				corneroffset(NONODEINST, subnt, subno->rotation, subno->transpose, &cx, &cy, FALSE);
 				xpos = subno->lowx + bx - cx + (subnt->highx-subnt->lowx)/2 - offx;
 				ypos = subno->lowy + by - cy + (subnt->highy-subnt->lowy)/2 - offy;
 			}
@@ -546,11 +547,11 @@ void io_gdswritecell(NODEPROTO *np)
  * by "offx" and "offy" in its parent cell.  If "layervar" is not NOVARIABLE,
  * it is the layer number to use (an override).
  */
-void io_outputgdspoly(TECHNOLOGY *tech, POLYGON *poly, INTSML angle, INTBIG offx,
+void io_outputgdspoly(TECHNOLOGY *tech, POLYGON *poly, INTBIG angle, INTBIG offx,
 	INTBIG offy, XARRAY trans, VARIABLE *layervar)
 {
 	REGISTER INTBIG r, bloat;
-	INTSML i;
+	INTBIG i;
 	INTBIG xl, xh, yl, yh, xpos, ypos, laynum;
 	static POLYGON *poly2 = NOPOLYGON;
 
@@ -563,7 +564,7 @@ void io_outputgdspoly(TECHNOLOGY *tech, POLYGON *poly, INTSML angle, INTBIG offx
 		laynum = ((INTBIG *)tech->temp1)[poly->layer];
 		if (laynum < 0) return;
 	}
-	io_gds_set_layer((INTSML)laynum);
+	io_gds_set_layer(laynum);
 
 	/* determine bloat factor */
 	if (poly->layer < 0 || tech->temp2 == 0) bloat = 0; else
@@ -591,7 +592,7 @@ void io_outputgdspoly(TECHNOLOGY *tech, POLYGON *poly, INTSML angle, INTBIG offx
 			return;
 
 		default:
-			if (isbox(poly, &xl,&xh, &yl,&yh) != 0)
+			if (isbox(poly, &xl,&xh, &yl,&yh))
 			{
 				/* rectangular manhattan shape */
 				if (xh == xl || yh == yl) return;
@@ -603,9 +604,9 @@ void io_outputgdspoly(TECHNOLOGY *tech, POLYGON *poly, INTSML angle, INTBIG offx
 				{
 					/* do polygon format output */
 					if (angle%1800 == 0)
-						mrgstorebox((INTSML)laynum, tech, xh-xl+bloat, yh-yl+bloat, xpos-offx, ypos-offy);
+						mrgstorebox(laynum, tech, xh-xl+bloat, yh-yl+bloat, xpos-offx, ypos-offy);
 					else	/* rotated by 90 degrees */
-						mrgstorebox((INTSML)laynum, tech, yh-yl+bloat, xh-xl+bloat, xpos-offx, ypos-offy);
+						mrgstorebox(laynum, tech, yh-yl+bloat, xh-xl+bloat, xpos-offx, ypos-offy);
 				} else    /* Output as a single box */
 				{
 					makerectpoly(xl-bloat/2, xh+bloat/2, yl-bloat/2, yh+bloat/2, poly2);
@@ -640,7 +641,7 @@ void io_outputgdspoly(TECHNOLOGY *tech, POLYGON *poly, INTSML angle, INTBIG offx
 
 			/* polygonally defined shape or a line */
 			if (poly2->limit < poly->count)	 /* SRP */
-				extendpolygon(poly2, poly->count);
+				(void)extendpolygon(poly2, poly->count);
 
 			for (i = 0; i < poly->count; i++)
 			{
@@ -657,7 +658,7 @@ void io_outputgdspoly(TECHNOLOGY *tech, POLYGON *poly, INTSML angle, INTBIG offx
 /*
  * routine to set the correct layer in "layer" for later output.
  */
-void io_gds_set_layer(INTSML layer)
+void io_gds_set_layer(INTBIG layer)
 {
 	io_gds_curlayer = layer;
 }
@@ -667,7 +668,7 @@ void io_gds_set_layer(INTSML layer)
 /* Initialize various fields, get some standard values */
 void io_gds_initialize(void)
 {
-	INTSML i;
+	INTBIG i;
 
 	io_gds_block = 0;
 	io_gds_pos = 0;
@@ -778,7 +779,7 @@ void io_gds_date(UINTBIG *val)
  * Enter with the header as argument, the routine will output
  * the count, the header, and the argument (if present) in p1.
  */
-void io_gds_header(INTSML header, INTSML p1)
+void io_gds_header(INTBIG header, INTBIG p1)
 {
 	INTBIG type, count;
 
@@ -807,9 +808,9 @@ void io_gds_header(INTSML header, INTSML p1)
 			return;
 	}
 	io_gds_int2((INTSML)count);
-	io_gds_int2(header);
+	io_gds_int2((INTSML)header);
 	if (type == DTYP_NONE) return;
-	if (count == 6) io_gds_int2(p1);
+	if (count == 6) io_gds_int2((INTSML)p1);
 	if (count == 8) io_gds_int4(p1);
 }
 
@@ -819,19 +820,19 @@ void io_gds_header(INTSML header, INTSML p1)
  * if there is an odd number of bytes, then output the 0 at
  * the end of the string as a pad. The maximum length of string is "max"
  */
-void io_gds_name(INTSML header, char *p1, INTSML max)
+void io_gds_name(INTBIG header, char *p1, INTBIG max)
 {
-	INTSML count;
+	INTBIG count;
 
-	count = (INTSML)mini(strlen(p1), max);
+	count = mini(strlen(p1), max);
 	if ((count&1) != 0) count++;
 	io_gds_int2((INTSML)(count+4));
-	io_gds_int2(header);
+	io_gds_int2((INTSML)header);
 	io_gds_string(p1, count);
 }
 
 /* Output an angle as part of a STRANS */
-void io_gds_angle(INTSML ang)
+void io_gds_angle(INTBIG ang)
 {
 	double gdfloat;
 	static INTBIG units[2];
@@ -840,13 +841,13 @@ void io_gds_angle(INTSML ang)
 	io_gds_int2(HDR_N_ANGLE);
 	io_gds_int2(HDR_ANGLE);
 	io_gds_cvfloat8(&gdfloat, (UINTBIG *)&units[0], (UINTBIG *)&units[1]);
-	io_gds_int4_arr(units,2);
+	io_gds_int4_arr(units, 2);
 }
 
 /* Output the pairs of XY points to the file  */
 void io_gds_boundary(POLYGON *poly)
 {
-	INTSML count, i, j, sofar;
+	INTBIG count, i, j, sofar;
 	REGISTER INTBIG *xv, *yv;
 	INTBIG lx, hx, ly, hy;
 	POLYGON *side1, *side2;
@@ -856,10 +857,10 @@ void io_gds_boundary(POLYGON *poly)
 		getbbox(poly, &lx, &hx, &ly, &hy);
 		if (hx-lx > hy-ly)
 		{
-			if (polysplitvert((lx+hx)/2, poly, &side1, &side2) != 0) return;
+			if (polysplitvert((lx+hx)/2, poly, &side1, &side2)) return;
 		} else
 		{
-			if (polysplithoriz((ly+hy)/2, poly, &side1, &side2) != 0) return;
+			if (polysplithoriz((ly+hy)/2, poly, &side1, &side2)) return;
 		}
 		io_gds_boundary(side1);
 		io_gds_boundary(side2);
@@ -898,13 +899,13 @@ void io_gds_boundary(POLYGON *poly)
 
 void io_gds_path(POLYGON *poly)
 {
-	INTSML count, i;
+	INTBIG count, i;
 
 	io_gds_header(HDR_PATH, 0);
 	io_gds_header(HDR_LAYER, io_gds_curlayer);
 	io_gds_header(HDR_DATATYPE, 0);
 	count = 8 * poly->count + 4;
-	io_gds_int2(count);
+	io_gds_int2((INTSML)count);
 	io_gds_int2(HDR_XY);
 	for (i = 0; i < poly->count; i ++)
 	{
@@ -943,17 +944,17 @@ void io_gds_int4(INTBIG val)
 }
 
 /* Array of 2 byte integers in array ptr, count n */
-void io_gds_int2_arr(INTSML *ptr, INTSML n)
+void io_gds_int2_arr(INTSML *ptr, INTBIG n)
 {
-	INTSML i;
+	INTBIG i;
 
 	for (i = 0; i < n; i++) io_gds_int2(ptr[i]);
 }
 
 /* Array of 4-byte integers or floating numbers in array  ptr, count n */
-void io_gds_int4_arr(INTBIG *ptr, INTSML n)
+void io_gds_int4_arr(INTBIG *ptr, INTBIG n)
 {
-	INTSML i;
+	INTBIG i;
 
 	for (i = 0; i < n; i++) io_gds_int4(ptr[i]);
 }
@@ -962,9 +963,9 @@ void io_gds_int4_arr(INTBIG *ptr, INTSML n)
  * String of n bytes, starting at ptr
  * Revised 90-11-23 to convert to upper case (SRP)
  */
-void io_gds_string(char *ptr, INTSML n)
+void io_gds_string(char *ptr, INTBIG n)
 {
-	INTSML i;
+	INTBIG i;
 
 	for (i = 0; i < n; i++)
 		io_gds_byte((char)(islower(ptr[i]) ? toupper(ptr[i]):ptr[i]));
@@ -975,15 +976,15 @@ void io_gds_string(char *ptr, INTSML n)
  * we have to scan it to make sure that it is closed
  * We assume that it does not exceed 200 points.
  */
-void io_gds_write_polygon(INTSML layer, TECHNOLOGY *tech, INTBIG *xbuf, INTBIG *ybuf,
-	INTSML count)
+void io_gds_write_polygon(INTBIG layer, TECHNOLOGY *tech, INTBIG *xbuf, INTBIG *ybuf,
+	INTBIG count)
 {
 	static POLYGON *gds_poly = NOPOLYGON;
-	INTSML i;
+	INTBIG i;
 
 	/* check the number of points on the polygon */
 	if (count > io_gds_polypoints)
-		ttyputerr(_("WARNING: Polygon has too many points (%d)"), count);
+		ttyputerr(_("WARNING: Polygon has too many points (%ld)"), count);
 
 	if (gds_poly == NOPOLYGON) gds_poly = allocstaticpolygon(4, io_tool->cluster);
 	if (count > gds_poly->limit) (void)extendpolygon(gds_poly, count);
@@ -1030,8 +1031,8 @@ char *io_gds_makename(char *str)
 void io_gds_cvfloat8(double *a, UINTBIG *m, UINTBIG *n)
 {
 	double temp, top, frac;
-	INTSML sign, i;
-	INTBIG exponent;
+	BOOLEAN negsign;
+	INTBIG exponent, i;
 	UINTBIG highmantissa;
 
 	/* handle default */
@@ -1046,9 +1047,9 @@ void io_gds_cvfloat8(double *a, UINTBIG *m, UINTBIG *n)
 	temp = *a;
 	if (temp < 0)
 	{
-		sign = -1;
+		negsign = TRUE;
 		temp = -temp;
-	} else sign = 1;
+	} else negsign = FALSE;
 
 	/* establish the excess-64 exponent value */
 	exponent = 64;
@@ -1063,7 +1064,7 @@ void io_gds_cvfloat8(double *a, UINTBIG *m, UINTBIG *n)
 	if (exponent > 127) ttyputerr(_("Exponent overflow"));
 
 	/* set the sign */
-	if (sign == -1) exponent |= 0x80;;
+	if (negsign) exponent |= 0x80;
 
 	/* convert temp to 7-byte binary integer */
 	top = temp;
@@ -1113,7 +1114,7 @@ void io_gdsoptionsdlog(void)
 	char buf[50];
 	REGISTER VARIABLE *gdsvar;
 
-	if (DiaInitDialog(&io_gdsoptionsdialog) != 0) return;
+	if (DiaInitDialog(&io_gdsoptionsdialog)) return;
 	DiaInitTextDialog(DGDO_LAYERLIST, DiaNullDlogList, DiaNullDlogItem, DiaNullDlogDone, 0,
 		SCSELMOUSE|SCREPORT);
 	layernumbers = (INTBIG *)emalloc(el_curtech->layercount * SIZEOFINTBIG, el_tempcluster);
