@@ -38,40 +38,40 @@
 
 static FILE      *io_hpout;
 static WINDOWPART io_hpwindow;
-static INTSML     io_hpcurrent_line_type;
-static INTSML     io_hpcurrent_pen_color;
-static INTSML     io_hpmerging;
-static INTSML     io_hpgl2;
+static INTBIG     io_hpcurrent_line_type;
+static INTBIG     io_hpcurrent_pen_color;
+static INTBIG     io_hpmerging;
+static INTBIG     io_hpgl2;
 
 typedef struct
 {
-	INTSML pnum;		/* pen number */
-	INTSML ltype;		/* line type (0=solid) */
-	INTSML ftype;		/* fill type (0=none, 1=solid, */
+	INTBIG pnum;		/* pen number */
+	INTBIG ltype;		/* line type (0=solid) */
+	INTBIG ftype;		/* fill type (0=none, 1=solid, */
 						/*      3=parallel lines 4=crosshatched lines) */
-	INTSML fdist;		/* fill distance (ftype 3 or 4 only) */
-	INTSML fangle;		/* fill angle (ftype 3 or 4 only) */
+	INTBIG fdist;		/* fill distance (ftype 3 or 4 only) */
+	INTBIG fangle;		/* fill angle (ftype 3 or 4 only) */
 } PENCOLOR;
 
 static PENCOLOR pen_color_table[256];
 
 /* prototypes for local routines */
-static void io_hpwritepolygon(INTSML, TECHNOLOGY*, INTBIG*, INTBIG*, INTSML);
-static INTSML io_hppoly(POLYGON*, WINDOWPART*);
-static void io_hpline(INTBIG, INTBIG, INTBIG, INTBIG, INTSML);
-static void io_hparc(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTSML);
-static void io_hpcircle(INTBIG, INTBIG, INTBIG, INTBIG, INTSML);
+static void io_hpwritepolygon(INTBIG, TECHNOLOGY*, INTBIG*, INTBIG*, INTBIG);
+static void io_hppoly(POLYGON*, WINDOWPART*);
+static void io_hpline(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+static void io_hparc(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+static void io_hpcircle(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 static void io_hpdisc(INTBIG, INTBIG, INTBIG, INTBIG, GRAPHICS*);
-static void io_hpfilledpolygon(INTBIG*, INTBIG*, INTSML, INTSML);
-static void io_hptext(INTSML, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, char*, INTSML);
+static void io_hpfilledpolygon(INTBIG*, INTBIG*, INTBIG, INTBIG);
+static void io_hptext(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, char*, INTBIG);
 static void io_hpparsepenfile(void);
-static INTSML io_hpchoosecolorentry(INTSML);
-static void io_hppenselect(INTSML);
+static INTBIG io_hpchoosecolorentry(INTBIG);
+static void io_hppenselect(INTBIG);
 static void io_hpmove(INTBIG, INTBIG);
 static void io_hpdraw(INTBIG, INTBIG);
 static void io_hpcmd(char[]);
 
-void io_hpwritepolygon(INTSML layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *y, INTSML count)
+void io_hpwritepolygon(INTBIG layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *y, INTBIG count)
 {
 	io_hpfilledpolygon(x, y, count, layer);
 }
@@ -79,7 +79,7 @@ void io_hpwritepolygon(INTSML layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *y, INT
 /*
  * routine to write out a HPGL file
  */
-INTSML io_writehpgllibrary(LIBRARY *lib)
+BOOLEAN io_writehpgllibrary(LIBRARY *lib)
 {
 	char file[100], buff[MAXSTR], *truename;
 	REGISTER NODEPROTO *np;
@@ -92,7 +92,14 @@ INTSML io_writehpgllibrary(LIBRARY *lib)
 	if (np == NONODEPROTO)
 	{
 		ttyputerr(_("No current facet to plot"));
-		return(1);
+		return(TRUE);
+	}
+
+	/* cannot write text-only facets */
+	if ((np->cellview->viewstate&TEXTVIEW) != 0)
+	{
+		ttyputerr(_("Cannot write textual facets"));
+		return(TRUE);
 	}
 
 	/* determine whether this is HPGL or HPGL/2 */
@@ -113,11 +120,11 @@ INTSML io_writehpgllibrary(LIBRARY *lib)
 	if (io_hpout == NULL)
 	{
 		if (truename != 0) ttyputerr(_("Cannot create %s"), truename);
-		return(1);
+		return(TRUE);
 	}
 
 	/* determine area to plot */
-	if (io_getareatoprint(np, &lx, &hx, &ly, &hy, 1) != 0) return(1);
+	if (io_getareatoprint(np, &lx, &hx, &ly, &hy, TRUE)) return(TRUE);
 
 	/* build pseudowindow */
 	io_hpwindow.uselx = 0;       io_hpwindow.screenlx = lx;
@@ -144,7 +151,7 @@ INTSML io_writehpgllibrary(LIBRARY *lib)
 		if (varred == NOVARIABLE || vargreen == NOVARIABLE || varblue == NOVARIABLE)
 		{
 			ttyputmsg(_("Cannot get colors!"));
-			return(1);
+			return(TRUE);
 		}
 		for(i=0; i<256; i++)
 		{
@@ -211,8 +218,8 @@ INTSML io_writehpgllibrary(LIBRARY *lib)
 	el_curwindowpart->screenhy = io_hpwindow.screenhy;
 	computewindowscale(el_curwindowpart);
 	(void)asktool(us_tool, "display-to-routine", io_hppoly);
-	el_curwindowpart->uselx = (INTSML)sulx;      el_curwindowpart->usehx = (INTSML)suhx;
-	el_curwindowpart->usely = (INTSML)suly;      el_curwindowpart->usehy = (INTSML)suhy;
+	el_curwindowpart->uselx = sulx;      el_curwindowpart->usehx = suhx;
+	el_curwindowpart->usely = suly;      el_curwindowpart->usehy = suhy;
 	el_curwindowpart->screenlx = sslx;   el_curwindowpart->screenhx = sshx;
 	el_curwindowpart->screenly = ssly;   el_curwindowpart->screenhy = sshy;
 	computewindowscale(el_curwindowpart);
@@ -235,24 +242,24 @@ INTSML io_writehpgllibrary(LIBRARY *lib)
 	}
 	xclose(io_hpout);
 	ttyputmsg(_("%s written"), truename);
-	return(0);
+	return(FALSE);
 }
 
 /*
  * routine to plot the polygon "poly"
  */
-INTSML io_hppoly(POLYGON *poly, WINDOWPART *win)
+void io_hppoly(POLYGON *poly, WINDOWPART *win)
 {
-	REGISTER INTSML k;
+	REGISTER INTBIG k;
 	INTBIG xl, xh, yl, yh, x, y, size;
-	INTSML color;
+	INTBIG color;
 	REGISTER TECHNOLOGY *tech;
 
 	/* ignore null layers */
-	if (poly->desc->bits == LAYERN || poly->desc->col == ALLOFF) return(1);
+	if (poly->desc->bits == LAYERN || poly->desc->col == ALLOFF) return;
 
 	/* ignore grids */
-	if (poly->style == GRIDDOTS) return(0);
+	if (poly->style == GRIDDOTS) return;
 
 	color = poly->desc->col;
 	switch (poly->style)
@@ -336,11 +343,11 @@ INTSML io_hppoly(POLYGON *poly, WINDOWPART *win)
 			io_hpdisc(poly->xv[0], poly->yv[0], poly->xv[1], poly->yv[1], poly->desc);
 			/* FALLTHROUGH */ 
 
-		case CIRCLE:
+		case CIRCLE: case THICKCIRCLE:
 			io_hpcircle(poly->xv[0], poly->yv[0], poly->xv[1], poly->yv[1], color);
 			break;
 
-		case CIRCLEARC:
+		case CIRCLEARC: case THICKCIRCLEARC:
 			io_hparc(poly->xv[0], poly->yv[0], poly->xv[1], poly->yv[1],
 				poly->xv[2], poly->yv[2], color);
 			break;
@@ -361,10 +368,9 @@ INTSML io_hppoly(POLYGON *poly, WINDOWPART *win)
 			io_hptext(poly->style, xl, xh, yl, yh, size, poly->string, color);
 			break;
 	}
-	return(0);
 }
 
-void io_hpline(INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2, INTSML color)
+void io_hpline(INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2, INTBIG color)
 {
 	io_hppenselect(color);	/* color */
 	io_hpmove(x1, y1);		/* move to the start */
@@ -372,10 +378,10 @@ void io_hpline(INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2, INTSML color)
 }
 
 void io_hparc(INTBIG centerx, INTBIG centery, INTBIG x1, INTBIG y1, INTBIG x2,
-	INTBIG y2, INTSML color)
+	INTBIG y2, INTBIG color)
 {
 	char buff[MAXSTR];
-	INTSML startangle, endangle, amt;
+	INTBIG startangle, endangle, amt;
 
 	startangle = figureangle(centerx, centery, x1, y1);
 	endangle = figureangle(centerx, centery, x2, y2);
@@ -384,12 +390,12 @@ void io_hparc(INTBIG centerx, INTBIG centery, INTBIG x1, INTBIG y1, INTBIG x2,
 	io_hppenselect(color);
 	io_hpmove(x1, y1);
 	io_hpcmd("PD;");
-	(void)sprintf(buff, "AA %ld %ld %d;", centerx, centery, -amt);
+	(void)sprintf(buff, "AA %ld %ld %ld;", centerx, centery, -amt);
 	io_hpcmd(buff);
 	io_hpcmd("PU;");
 }
 
-void io_hpcircle(INTBIG atx, INTBIG aty, INTBIG ex, INTBIG ey, INTSML color)
+void io_hpcircle(INTBIG atx, INTBIG aty, INTBIG ex, INTBIG ey, INTBIG color)
 {
 	char buff[MAXSTR];
 	INTBIG radius;
@@ -407,7 +413,7 @@ void io_hpdisc(INTBIG atx, INTBIG aty, INTBIG ex, INTBIG ey, GRAPHICS *desc)
 {
 	char buff[MAXSTR];
 	INTBIG radius;
-	INTSML cindex, ftype, fangle, fdist, color;
+	INTBIG cindex, ftype, fangle, fdist, color;
 
 	color = desc->col;
 	cindex = io_hpchoosecolorentry(color);
@@ -417,7 +423,7 @@ void io_hpdisc(INTBIG atx, INTBIG aty, INTBIG ex, INTBIG ey, GRAPHICS *desc)
 
 	radius = computedistance(atx, aty, ex, ey);
 	io_hppenselect(color);
-	(void)sprintf(buff, "FT %d,%d,%d;", ftype, fdist, fangle);
+	(void)sprintf(buff, "FT %ld,%ld,%ld;", ftype, fdist, fangle);
 	io_hpcmd(buff);
 
 	io_hpmove(atx, aty);
@@ -431,10 +437,10 @@ void io_hpdisc(INTBIG atx, INTBIG aty, INTBIG ex, INTBIG ey, GRAPHICS *desc)
 	io_hpcmd("PU;");
 }
 
-void io_hpfilledpolygon(INTBIG *xlist, INTBIG *ylist, INTSML count, INTSML color)
+void io_hpfilledpolygon(INTBIG *xlist, INTBIG *ylist, INTBIG count, INTBIG color)
 {
 	char buff[MAXSTR];
-	INTSML cindex, ftype, fangle, fdist, i;
+	INTBIG cindex, ftype, fangle, fdist, i;
 	INTBIG firstx, firsty;
 
 	if (count <= 1) return;
@@ -444,7 +450,7 @@ void io_hpfilledpolygon(INTBIG *xlist, INTBIG *ylist, INTSML count, INTSML color
 	fdist = pen_color_table[cindex].fdist;
 
 	io_hppenselect(color);	/* color */
-	(void)sprintf(buff, "FT %d,%d,%d;", ftype, fdist, fangle);
+	(void)sprintf(buff, "FT %ld,%ld,%ld;", ftype, fdist, fangle);
 	io_hpcmd(buff);
 
 	firstx = xlist[0];		/* save the end point */
@@ -459,8 +465,8 @@ void io_hpfilledpolygon(INTBIG *xlist, INTBIG *ylist, INTSML count, INTSML color
 	if (ftype != 1) io_hpcmd("EP;");
 }
 
-void io_hptext(INTSML type, INTBIG xl, INTBIG xh, INTBIG yl, INTBIG yh, INTBIG size,
-	char *text, INTSML color)
+void io_hptext(INTBIG type, INTBIG xl, INTBIG xh, INTBIG yl, INTBIG yh, INTBIG size,
+	char *text, INTBIG color)
 {
 	char s[MAXSTR];
 
@@ -596,7 +602,7 @@ static char *io_hppendata[] =
 void io_hpparsepenfile(void)
 {
 	char *pt;
-	INTSML in_color, in_pnum, in_ltype, in_ftype, in_fdist, in_fangle, i;
+	INTBIG in_color, in_pnum, in_ltype, in_ftype, in_fdist, in_fangle, i;
 
 	for(i=0; i<256; i++)
 	{
@@ -611,7 +617,7 @@ void io_hpparsepenfile(void)
 	{
 		/* get the color */
 		pt = io_hppendata[i];
-		in_color = (INTSML)myatoi(pt);
+		in_color = myatoi(pt);
 		in_color = io_hpchoosecolorentry(in_color);
 		if (in_color <= 0 || in_color >= 256) continue;
 
@@ -619,31 +625,31 @@ void io_hpparsepenfile(void)
 		while (*pt != 0 && *pt != ' ' && *pt != '\t') pt++;
 		while (*pt == ' ' || *pt == '\t') pt++;
 		if (*pt == 0) continue;
-		in_pnum = (INTSML)myatoi(pt);
+		in_pnum = myatoi(pt);
 
 		/* skip to type field */
 		while (*pt != 0 && *pt != ' ' && *pt != '\t') pt++;
 		while (*pt == ' ' || *pt == '\t') pt++;
 		if (*pt == 0) continue;
-		in_ltype = (INTSML)myatoi(pt);
+		in_ltype = myatoi(pt);
 
 		/* skip to fill field */
 		while (*pt != 0 && *pt != ' ' && *pt != '\t') pt++;
 		while (*pt == ' ' || *pt == '\t') pt++;
 		if (*pt == 0) continue;
-		in_ftype = (INTSML)myatoi(pt);
+		in_ftype = myatoi(pt);
 
 		/* skip to distance field */
 		while (*pt != 0 && *pt != ' ' && *pt != '\t') pt++;
 		while (*pt == ' ' || *pt == '\t') pt++;
 		if (*pt == 0) continue;
-		in_fdist = (INTSML)myatoi(pt);
+		in_fdist = myatoi(pt);
 
 		/* skip to angle field */
 		while (*pt != 0 && *pt != ' ' && *pt != '\t') pt++;
 		while (*pt == ' ' || *pt == '\t') pt++;
 		if (*pt == 0) continue;
-		in_fangle = (INTSML)myatoi(pt);
+		in_fangle = myatoi(pt);
 
 		/* load the table */
 		pen_color_table[in_color].pnum = in_pnum;
@@ -663,7 +669,7 @@ void io_hpparsepenfile(void)
  * identical transparent objects exactly overlap each other.  For our
  * applications, this will be rare.
  */
-INTSML io_hpchoosecolorentry(INTSML c)
+INTBIG io_hpchoosecolorentry(INTBIG c)
 {
 	/* if the desired color is opaque, mask out the unused bit planes */
 	if (c & LAYEROE) return(c & LAYERO);
@@ -682,10 +688,10 @@ INTSML io_hpchoosecolorentry(INTSML c)
  * proper entry from the pen table, and select an appropriate pen from the
  * pen_color_table.  The appropriate pen and line type is then selected.
  */
-void io_hppenselect(INTSML color)
+void io_hppenselect(INTBIG color)
 {
 	char pbuff[10];
-	INTSML desired_pen, line_type, cindex;
+	INTBIG desired_pen, line_type, cindex;
 
 	cindex = io_hpchoosecolorentry(color);
 	desired_pen = pen_color_table[cindex].pnum;
@@ -706,7 +712,7 @@ void io_hppenselect(INTSML color)
 	if (line_type != io_hpcurrent_line_type)
 	{
 		if (line_type == 0) (void)sprintf(pbuff, "LT;"); else
-			(void)sprintf(pbuff, "LT%d;", line_type);
+			(void)sprintf(pbuff, "LT%ld;", line_type);
 		io_hpcurrent_line_type = line_type;
 		io_hpcmd(pbuff);
 	}
