@@ -77,18 +77,18 @@ static void       io_leffreepaths(LEFPATH *firstlp);
 static ARCPROTO  *io_lefgetarc(INTBIG afunc);
 static char      *io_lefgetkeyword(FILE *f);
 static NODEPROTO *io_lefgetnode(INTBIG lfunc);
-static INTSML     io_lefignoretosemicolon(FILE *f, char *command);
+static BOOLEAN    io_lefignoretosemicolon(FILE *f, char *command);
 static void       io_lefkillpath(LEFPATH *lp);
 static LEFPATH   *io_lefnewpath(void);
 static PORTPROTO *io_lefnewport(NODEPROTO *facet, NODEINST *ni, PORTPROTO *pp, char *thename);
 static void       io_lefparselayer(char *layername, INTBIG *arcfunc, INTBIG *layerfunc);
-static INTSML     io_lefreadfile(FILE *f, LIBRARY *lib);
-static INTSML     io_lefreadlayer(FILE *f, LIBRARY *lib);
-static INTSML     io_lefreadmacro(FILE *f, LIBRARY *lib);
-static INTSML     io_lefreadvia(FILE *f, LIBRARY *lib);
-static INTSML     io_lefreadobs(FILE *f, NODEPROTO *facet);
-static INTSML     io_lefreadpin(FILE *f, NODEPROTO *facet);
-static INTSML     io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits);
+static BOOLEAN    io_lefreadfile(FILE *f, LIBRARY *lib);
+static BOOLEAN    io_lefreadlayer(FILE *f, LIBRARY *lib);
+static BOOLEAN    io_lefreadmacro(FILE *f, LIBRARY *lib);
+static BOOLEAN    io_lefreadvia(FILE *f, LIBRARY *lib);
+static BOOLEAN    io_lefreadobs(FILE *f, NODEPROTO *facet);
+static BOOLEAN    io_lefreadpin(FILE *f, NODEPROTO *facet);
+static BOOLEAN    io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits);
 static void       io_leffreevias(void);
 
 /*
@@ -99,10 +99,10 @@ void io_freelefimemory(void)
 	io_leffreevias();
 }
 
-INTSML io_readleflibrary(LIBRARY *lib)
+BOOLEAN io_readleflibrary(LIBRARY *lib)
 {
 	FILE *fp;
-	REGISTER INTSML ret;
+	REGISTER BOOLEAN ret;
 	char *filename;
 	extern DIALOG us_progressdialog;
 
@@ -111,7 +111,7 @@ INTSML io_readleflibrary(LIBRARY *lib)
 	if (fp == NULL)
 	{
 		ttyputerr(_("File %s not found"), lib->libfile);
-		return(1);
+		return(TRUE);
 	}
 
 	/* remove any vias in the globals */
@@ -119,10 +119,10 @@ INTSML io_readleflibrary(LIBRARY *lib)
 
 	/* prepare for input */
 	io_leffilesize = filesize(fp);
-	if (DiaInitDialog(&us_progressdialog) != 0)
+	if (DiaInitDialog(&us_progressdialog))
 	{
 		xclose(fp);
-		return(1);
+		return(TRUE);
 	}
 	DiaPercent(1, 0);
 	DiaSetText(2, _("Reading LEF file..."));
@@ -136,9 +136,9 @@ INTSML io_readleflibrary(LIBRARY *lib)
 	/* clean up */
 	DiaDoneDialog();
 	xclose(fp);
-	if (ret == 0) ttyputmsg(_("LEF file %s is read"), lib->libfile); else
+	if (!ret) ttyputmsg(_("LEF file %s is read"), lib->libfile); else
 		ttyputmsg(_("Error reading LEF file %s"), lib->libfile);
-	return(0);
+	return(FALSE);
 }
 
 void io_leffreevias(void)
@@ -157,7 +157,7 @@ void io_leffreevias(void)
 /*
  * Routine to read the LEF file in "f".
  */
-INTSML io_lefreadfile(FILE *f, LIBRARY *lib)
+BOOLEAN io_lefreadfile(FILE *f, LIBRARY *lib)
 {
 	REGISTER char *key;
 
@@ -168,18 +168,18 @@ INTSML io_lefreadfile(FILE *f, LIBRARY *lib)
 		if (key == 0) break;
 		if (namesame(key, "LAYER") == 0)
 		{
-			if (io_lefreadlayer(f, lib) != 0) return(1);
+			if (io_lefreadlayer(f, lib)) return(TRUE);
 		}
 		if (namesame(key, "MACRO") == 0)
 		{
-			if (io_lefreadmacro(f, lib) != 0) return(1);
+			if (io_lefreadmacro(f, lib)) return(TRUE);
 		}
 		if (namesame(key, "VIA") == 0)
 		{
-			if (io_lefreadvia(f, lib) != 0) return(1);
+			if (io_lefreadvia(f, lib)) return(TRUE);
 		}
 	}
-	return(0);
+	return(FALSE);
 }
 
 void io_lefparselayer(char *layername, INTBIG *arcfunc, INTBIG *layerfunc)
@@ -265,7 +265,7 @@ void io_lefparselayer(char *layername, INTBIG *arcfunc, INTBIG *layerfunc)
 	}
 }
 
-INTSML io_lefreadlayer(FILE *f, LIBRARY *lib)
+BOOLEAN io_lefreadlayer(FILE *f, LIBRARY *lib)
 {
 	REGISTER char *layername, *key;
 	char curkey[200];
@@ -278,7 +278,7 @@ INTSML io_lefreadlayer(FILE *f, LIBRARY *lib)
 	if (layername == 0)
 	{
 		ttyputerr(_("EOF parsing LAYER header"));
-		return(1);
+		return(TRUE);
 	}
 	io_lefparselayer(layername, &afunc, &layerfunc);
 	if (afunc == APUNKNOWN) ap = NOARCPROTO; else
@@ -294,7 +294,7 @@ INTSML io_lefreadlayer(FILE *f, LIBRARY *lib)
 		if (key == 0)
 		{
 			ttyputerr(_("EOF parsing LAYER"));
-			return(1);
+			return(TRUE);
 		}
 
 		if (namesame(key, "END") == 0)
@@ -309,7 +309,7 @@ INTSML io_lefreadlayer(FILE *f, LIBRARY *lib)
 			if (key == 0)
 			{
 				ttyputerr(_("EOF reading WIDTH"));
-				return(1);
+				return(TRUE);
 			}
 			v = (float)atof(key);
 			defwidth = scalefromdispunit(v, DISPUNITMIC);
@@ -317,7 +317,7 @@ INTSML io_lefreadlayer(FILE *f, LIBRARY *lib)
 			{
 				setval((INTBIG)ap, VARCPROTO, "IO_lef_width", defwidth, VINTEGER);
 			}
-			if (io_lefignoretosemicolon(f, "WIDTH") != 0) return(1);
+			if (io_lefignoretosemicolon(f, "WIDTH")) return(TRUE);
 			continue;
 		}
 
@@ -326,14 +326,14 @@ INTSML io_lefreadlayer(FILE *f, LIBRARY *lib)
 			namesame(key, "CAPACITANCE") == 0 || namesame(key, "RESISTANCE") == 0)
 		{
 			strcpy(curkey, key);
-			if (io_lefignoretosemicolon(f, curkey) != 0) return(1);
+			if (io_lefignoretosemicolon(f, curkey)) return(TRUE);
 			continue;
 		}
 	}
-	return(0);
+	return(FALSE);
 }
 
-INTSML io_lefreadmacro(FILE *f, LIBRARY *lib)
+BOOLEAN io_lefreadmacro(FILE *f, LIBRARY *lib)
 {
 	REGISTER char *cellname, *key;
 	REGISTER INTBIG ox, oy, blx, bhx, bly, bhy;
@@ -347,17 +347,17 @@ INTSML io_lefreadmacro(FILE *f, LIBRARY *lib)
 	if (cellname == 0)
 	{
 		ttyputerr(_("EOF parsing MACRO header"));
-		return(1);
+		return(TRUE);
 	}
 	(void)initinfstr();
 	(void)addstringtoinfstr(cellname);
 	(void)addstringtoinfstr("{sk}");
 	cellname = returninfstr();
-	facet = newnodeproto(cellname, lib);
+	facet = us_newnodeproto(cellname, lib);
 	if (facet == NONODEPROTO)
 	{
 		ttyputerr(_("Cannot create facet '%s'"), cellname);
-		return(1);
+		return(TRUE);
 	}
 
 	for(;;)
@@ -367,7 +367,7 @@ INTSML io_lefreadmacro(FILE *f, LIBRARY *lib)
 		if (key == 0)
 		{
 			ttyputerr(_("EOF parsing MACRO"));
-			return(1);
+			return(TRUE);
 		}
 
 		if (namesame(key, "END") == 0)
@@ -381,7 +381,7 @@ INTSML io_lefreadmacro(FILE *f, LIBRARY *lib)
 			namesame(key, "CLASS") == 0 || namesame(key, "LEQ") == 0)
 		{
 			strcpy(curkey, key);
-			if (io_lefignoretosemicolon(f, curkey) != 0) return(1);
+			if (io_lefignoretosemicolon(f, curkey)) return(TRUE);
 			continue;
 		}
 
@@ -391,7 +391,7 @@ INTSML io_lefreadmacro(FILE *f, LIBRARY *lib)
 			if (key == 0)
 			{
 				ttyputerr(_("EOF reading ORIGIN X"));
-				return(1);
+				return(TRUE);
 			}
 			x = (float)atof(key);
 			ox = scalefromdispunit(x, DISPUNITMIC);
@@ -400,11 +400,11 @@ INTSML io_lefreadmacro(FILE *f, LIBRARY *lib)
 			if (key == 0)
 			{
 				ttyputerr(_("EOF reading ORIGIN Y"));
-				return(1);
+				return(TRUE);
 			}
 			y = (float)atof(key);
 			oy = scalefromdispunit(y, DISPUNITMIC);
-			if (io_lefignoretosemicolon(f, "ORIGIN") != 0) return(1);
+			if (io_lefignoretosemicolon(f, "ORIGIN")) return(TRUE);
 
 			/* create the facet-center node */
 			defaultnodesize(gen_facetcenterprim, &sx, &sy);
@@ -413,9 +413,10 @@ INTSML io_lefreadmacro(FILE *f, LIBRARY *lib)
 			ni = newnodeinst(gen_facetcenterprim, blx, bhx, bly, bhy, 0, 0, facet);
 			if (ni == NONODEINST)
 			{
-				ttyputerr(_("Line %d: Cannot create facet center node"), io_leflineno);
-				return(1);
+				ttyputerr(_("Line %ld: Cannot create facet center node"), io_leflineno);
+				return(TRUE);
 			}
+			ni->userbits |= HARDSELECTN|NVISIBLEINSIDE;
 			endobjectchange((INTBIG)ni, VNODEINST);
 			continue;
 		}
@@ -426,7 +427,7 @@ INTSML io_lefreadmacro(FILE *f, LIBRARY *lib)
 			if (key == 0)
 			{
 				ttyputerr(_("EOF reading SIZE X"));
-				return(1);
+				return(TRUE);
 			}
 			x = (float)atof(key);
 			sx = scalefromdispunit(x, DISPUNITMIC);
@@ -435,45 +436,45 @@ INTSML io_lefreadmacro(FILE *f, LIBRARY *lib)
 			if (key == 0)
 			{
 				ttyputerr(_("EOF reading SIZE 'BY'"));
-				return(1);
+				return(TRUE);
 			}
 			if (namesame(key, "BY") != 0)
 			{
-				ttyputerr(_("Line %d: Expected 'by' in SIZE"), io_leflineno);
-				return(1);
+				ttyputerr(_("Line %ld: Expected 'by' in SIZE"), io_leflineno);
+				return(TRUE);
 			}
 
 			key = io_lefgetkeyword(f);
 			if (key == 0)
 			{
 				ttyputerr(_("EOF reading SIZE Y"));
-				return(1);
+				return(TRUE);
 			}
 			y = (float)atof(key);
 			sy = scalefromdispunit(y, DISPUNITMIC);
-			if (io_lefignoretosemicolon(f, "SIZE") != 0) return(1);
+			if (io_lefignoretosemicolon(f, "SIZE")) return(TRUE);
 			continue;
 		}
 
 		if (namesame(key, "PIN") == 0)
 		{
-			if (io_lefreadpin(f, facet) != 0) return(1);
+			if (io_lefreadpin(f, facet)) return(TRUE);
 			continue;
 		}
 
 		if (namesame(key, "OBS") == 0)
 		{
-			if (io_lefreadobs(f, facet) != 0) return(1);
+			if (io_lefreadobs(f, facet)) return(TRUE);
 			continue;
 		}
 
-		ttyputerr(_("Line %d: Unknown MACRO keyword (%s)"), io_leflineno, key);
-		return(1);
+		ttyputerr(_("Line %ld: Unknown MACRO keyword (%s)"), io_leflineno, key);
+		return(TRUE);
 	}
-	return(0);
+	return(FALSE);
 }
 
-INTSML io_lefreadvia(FILE *f, LIBRARY *lib)
+BOOLEAN io_lefreadvia(FILE *f, LIBRARY *lib)
 {
 	REGISTER char *vianame, *key;
 	REGISTER INTBIG lx, hx, ly, hy, i, lay1found, lay2found;
@@ -486,11 +487,11 @@ INTSML io_lefreadvia(FILE *f, LIBRARY *lib)
 
 	/* get the via name */
 	vianame = io_lefgetkeyword(f);
-	if (vianame == 0) return(1);
+	if (vianame == 0) return(TRUE);
 
 	/* create a new via definition */
 	vd = (VIADEF *)emalloc(sizeof (VIADEF), io_tool->cluster);
-	if (vd == 0) return(1);
+	if (vd == 0) return(TRUE);
 	(void)allocstring(&vd->vianame, vianame, io_tool->cluster);
 	vd->sx = vd->sy = 0;
 	vd->via = NONODEPROTO;
@@ -500,18 +501,18 @@ INTSML io_lefreadvia(FILE *f, LIBRARY *lib)
 
 	/* ignore the "DEFAULT" keyword */
 	key = io_lefgetkeyword(f);
-	if (key == 0) return(1);
+	if (key == 0) return(TRUE);
 	if (namesame(key, "DEFAULT") != 0)
 	{
 		ttyputerr(_("Expected 'DEFAULT' after VIA name"));
-		return(1);
+		return(TRUE);
 	}
 
 	for(;;)
 	{
 		/* get the next keyword */
 		key = io_lefgetkeyword(f);
-		if (key == 0) return(1);
+		if (key == 0) return(TRUE);
 		if (namesame(key, "END") == 0)
 		{
 			key = io_lefgetkeyword(f);
@@ -519,13 +520,13 @@ INTSML io_lefreadvia(FILE *f, LIBRARY *lib)
 		}
 		if (namesame(key, "RESISTANCE") == 0)
 		{
-			if (io_lefignoretosemicolon(f, key) != 0) return(1);
+			if (io_lefignoretosemicolon(f, key)) return(TRUE);
 			continue;
 		}
 		if (namesame(key, "LAYER") == 0)
 		{
 			key = io_lefgetkeyword(f);
-			if (key == 0) return(1);
+			if (key == 0) return(TRUE);
 			io_lefparselayer(key, &afunc, &layerfunc);
 			if (afunc == APUNKNOWN) ap = NOARCPROTO; else
 			{
@@ -537,29 +538,29 @@ INTSML io_lefreadvia(FILE *f, LIBRARY *lib)
 				if (vd->lay1 == NOARCPROTO) vd->lay1 = ap; else
 					vd->lay2 = ap;
 			}
-			if (io_lefignoretosemicolon(f, "LAYER") != 0) return(1);
+			if (io_lefignoretosemicolon(f, "LAYER")) return(TRUE);
 			continue;
 		}
 		if (namesame(key, "RECT") == 0)
 		{
 			/* handle definition of a via rectangle */
 			key = io_lefgetkeyword(f);
-			if (key == 0) return(1);
+			if (key == 0) return(TRUE);
 			v = (float)atof(key);
 			lx = scalefromdispunit(v, DISPUNITMIC);
 
 			key = io_lefgetkeyword(f);
-			if (key == 0) return(1);
+			if (key == 0) return(TRUE);
 			v = (float)atof(key);
 			ly = scalefromdispunit(v, DISPUNITMIC);
 
 			key = io_lefgetkeyword(f);
-			if (key == 0) return(1);
+			if (key == 0) return(TRUE);
 			v = (float)atof(key);
 			hx = scalefromdispunit(v, DISPUNITMIC);
 
 			key = io_lefgetkeyword(f);
-			if (key == 0) return(1);
+			if (key == 0) return(TRUE);
 			v = (float)atof(key);
 			hy = scalefromdispunit(v, DISPUNITMIC);
 
@@ -567,7 +568,7 @@ INTSML io_lefreadvia(FILE *f, LIBRARY *lib)
 			if (hx-lx > vd->sx) vd->sx = hx - lx;
 			if (hy-ly > vd->sy) vd->sy = hy - ly;
 
-			if (io_lefignoretosemicolon(f, "RECT") != 0) return(1);
+			if (io_lefignoretosemicolon(f, "RECT")) return(TRUE);
 			continue;
 		}
 	}
@@ -587,10 +588,10 @@ INTSML io_lefreadvia(FILE *f, LIBRARY *lib)
 		}
 		vd->via = np;
 	}
-	return(0);
+	return(FALSE);
 }
 
-INTSML io_lefreadpin(FILE *f, NODEPROTO *facet)
+BOOLEAN io_lefreadpin(FILE *f, NODEPROTO *facet)
 {
 	REGISTER char *key;
 	REGISTER INTBIG portbits, usebits;
@@ -601,7 +602,7 @@ INTSML io_lefreadpin(FILE *f, NODEPROTO *facet)
 	if (key == 0)
 	{
 		ttyputerr(_("EOF parsing PIN name"));
-		return(1);
+		return(TRUE);
 	}
 	strcpy(pinname, key);
 
@@ -612,7 +613,7 @@ INTSML io_lefreadpin(FILE *f, NODEPROTO *facet)
 		if (key == 0)
 		{
 			ttyputerr(_("EOF parsing PIN"));
-			return(1);
+			return(TRUE);
 		}
 
 		if (namesame(key, "END") == 0)
@@ -625,7 +626,7 @@ INTSML io_lefreadpin(FILE *f, NODEPROTO *facet)
 			namesame(key, "ANTENNASIZE") == 0)
 		{
 			strcpy(curkey, key);
-			if (io_lefignoretosemicolon(f, curkey) != 0) return(1);
+			if (io_lefignoretosemicolon(f, curkey)) return(TRUE);
 			continue;
 		}
 
@@ -635,16 +636,16 @@ INTSML io_lefreadpin(FILE *f, NODEPROTO *facet)
 			if (key == 0)
 			{
 				ttyputerr(_("EOF reading USE clause"));
-				return(1);
+				return(TRUE);
 			}
 			if (namesame(key, "POWER") == 0) usebits = PWRPORT; else
 			if (namesame(key, "GROUND") == 0) usebits = GNDPORT; else
 			if (namesame(key, "CLOCK") == 0) usebits = CLKPORT; else
 			{
-				ttyputerr(_("Line %d: Unknown USE keyword (%s)"),
+				ttyputerr(_("Line %ld: Unknown USE keyword (%s)"),
 					io_leflineno, key);
 			}
-			if (io_lefignoretosemicolon(f, "USE") != 0) return(1);
+			if (io_lefignoretosemicolon(f, "USE")) return(TRUE);
 			continue;
 		}
 
@@ -654,34 +655,34 @@ INTSML io_lefreadpin(FILE *f, NODEPROTO *facet)
 			if (key == 0)
 			{
 				ttyputerr(_("EOF reading DIRECTION clause"));
-				return(1);
+				return(TRUE);
 			}
 			if (namesame(key, "INPUT") == 0) portbits = INPORT; else
 			if (namesame(key, "OUTPUT") == 0) portbits = OUTPORT; else
 			if (namesame(key, "INOUT") == 0) portbits = BIDIRPORT; else
 			{
-				ttyputerr(_("Line %d: Unknown DIRECTION keyword (%s)"),
+				ttyputerr(_("Line %ld: Unknown DIRECTION keyword (%s)"),
 					io_leflineno, key);
 			}
-			if (io_lefignoretosemicolon(f, "DIRECTION") != 0) return(1);
+			if (io_lefignoretosemicolon(f, "DIRECTION")) return(TRUE);
 			continue;
 		}
 
 		if (namesame(key, "PORT") == 0)
 		{
 			if (usebits != 0) portbits = usebits;
-			if (io_lefreadport(f, facet, pinname, portbits) != 0)
-				return(1);
+			if (io_lefreadport(f, facet, pinname, portbits))
+				return(TRUE);
 			continue;
 		}
 
-		ttyputerr(_("Line %d: Unknown PIN keyword (%s)"), io_leflineno, key);
-		return(1);
+		ttyputerr(_("Line %ld: Unknown PIN keyword (%s)"), io_leflineno, key);
+		return(TRUE);
 	}
-	return(0);
+	return(FALSE);
 }
 
-INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits)
+BOOLEAN io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits)
 {
 	REGISTER char *key;
 	REGISTER INTBIG i, j, lx, hx, ly, hy, intx, inty, first,
@@ -707,7 +708,7 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 		if (key == 0)
 		{
 			ttyputerr(_("EOF parsing PORT"));
-			return(1);
+			return(TRUE);
 		}
 
 		if (namesame(key, "END") == 0)
@@ -721,13 +722,13 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 			if (key == 0)
 			{
 				ttyputerr(_("EOF reading LAYER clause"));
-				return(1);
+				return(TRUE);
 			}
 			io_lefparselayer(key, &afunc, &layerfunc);
 			if (afunc == APUNKNOWN) ap = NOARCPROTO; else
 				ap = io_lefgetarc(afunc);
 			plnp = io_lefgetnode(layerfunc);
-			if (io_lefignoretosemicolon(f, "LAYER") != 0) return(1);
+			if (io_lefignoretosemicolon(f, "LAYER")) return(TRUE);
 			continue;
 		}
 
@@ -737,11 +738,11 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 			if (key == 0)
 			{
 				ttyputerr(_("EOF reading WIDTH clause"));
-				return(1);
+				return(TRUE);
 			}
 			width = (float)atof(key);
 			intwidth = scalefromdispunit(width, DISPUNITMIC);
-			if (io_lefignoretosemicolon(f, "WIDTH") != 0) return(1);
+			if (io_lefignoretosemicolon(f, "WIDTH")) return(TRUE);
 			continue;
 		}
 
@@ -749,14 +750,14 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 		{
 			if (plnp == NONODEPROTO)
 			{
-				ttyputerr(_("Line %d: No layers for RECT"), io_leflineno);
-				return(1);
+				ttyputerr(_("Line %ld: No layers for RECT"), io_leflineno);
+				return(TRUE);
 			}
 			key = io_lefgetkeyword(f);
 			if (key == 0)
 			{
 				ttyputerr(_("EOF reading RECT low X"));
-				return(1);
+				return(TRUE);
 			}
 			x = (float)atof(key);
 			lx = scalefromdispunit(x, DISPUNITMIC);
@@ -765,7 +766,7 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 			if (key == 0)
 			{
 				ttyputerr(_("EOF reading RECT low Y"));
-				return(1);
+				return(TRUE);
 			}
 			y = (float)atof(key);
 			ly = scalefromdispunit(y, DISPUNITMIC);
@@ -774,7 +775,7 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 			if (key == 0)
 			{
 				ttyputerr(_("EOF reading RECT high X"));
-				return(1);
+				return(TRUE);
 			}
 			x = (float)atof(key);
 			hx = scalefromdispunit(x, DISPUNITMIC);
@@ -783,12 +784,12 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 			if (key == 0)
 			{
 				ttyputerr(_("EOF reading RECT high Y"));
-				return(1);
+				return(TRUE);
 			}
 			y = (float)atof(key);
 			hy = scalefromdispunit(y, DISPUNITMIC);
 
-			if (io_lefignoretosemicolon(f, "RECT") != 0) return(1);
+			if (io_lefignoretosemicolon(f, "RECT")) return(TRUE);
 
 			/* make the pin */
 			if (hx < lx) { j = hx;   hx = lx;   lx = j; }
@@ -796,8 +797,8 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 			ni = newnodeinst(plnp, lx, hx, ly, hy, 0, 0, facet);
 			if (ni == NONODEINST)
 			{
-				ttyputerr(_("Line %d: Cannot create pin for RECT"), io_leflineno);
-				return(1);
+				ttyputerr(_("Line %ld: Cannot create pin for RECT"), io_leflineno);
+				return(TRUE);
 			}
 			endobjectchange((INTBIG)ni, VNODEINST);
 
@@ -815,8 +816,8 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 		{
 			if (ap == NOARCPROTO)
 			{
-				ttyputerr(_("Line %d: No layers for PATH"), io_leflineno);
-				return(1);
+				ttyputerr(_("Line %ld: No layers for PATH"), io_leflineno);
+				return(TRUE);
 			}
 			for(i=0; ; i++)
 			{
@@ -824,7 +825,7 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 				if (key == 0)
 				{
 					ttyputerr(_("EOF reading PATH clause"));
-					return(1);
+					return(TRUE);
 				}
 				if (strcmp(key, ";") == 0) break;
 				x = (float)atof(key);
@@ -833,7 +834,7 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 				if (key == 0)
 				{
 					ttyputerr(_("EOF reading PATH clause"));
-					return(1);
+					return(TRUE);
 				}
 				y = (float)atof(key);
 
@@ -844,7 +845,7 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 				{
 					/* queue path */
 					lp = io_lefnewpath();
-					if (lp == NOLEFPATH) return(1);
+					if (lp == NOLEFPATH) return(TRUE);
 
 					/* LINTED "lastintx" used in proper order */
 					lp->x[0] = lastintx;     lp->x[1] = intx;
@@ -869,7 +870,7 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 			if (key == 0)
 			{
 				ttyputerr(_("EOF reading VIA clause"));
-				return(1);
+				return(TRUE);
 			}
 			x = (float)atof(key);
 			intx = scalefromdispunit(x, DISPUNITMIC);
@@ -878,7 +879,7 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 			if (key == 0)
 			{
 				ttyputerr(_("EOF reading VIA clause"));
-				return(1);
+				return(TRUE);
 			}
 			y = (float)atof(key);
 			inty = scalefromdispunit(y, DISPUNITMIC);
@@ -904,13 +905,13 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 				afunc2 = APMETAL5;
 			} else
 			{
-				ttyputerr(_("Line %d: Unknown VIA type (%s)"), io_leflineno, key);
-				return(1);
+				ttyputerr(_("Line %ld: Unknown VIA type (%s)"), io_leflineno, key);
+				return(TRUE);
 			}
 			ap1 = io_lefgetarc(afunc1);
-			if (ap1 == NOARCPROTO) return(1);
+			if (ap1 == NOARCPROTO) return(TRUE);
 			ap2 = io_lefgetarc(afunc2);
-			if (ap2 == NOARCPROTO) return(1);
+			if (ap2 == NOARCPROTO) return(TRUE);
 			for(pin = el_curtech->firstnodeproto; pin != NONODEPROTO; pin = pin->nextnodeproto)
 			{
 				if (((pin->userbits&NFUNCTION)>>NFUNCTIONSH) != NPCONTACT) continue;
@@ -925,12 +926,12 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 			}
 			if (pin == NONODEPROTO)
 			{
-				ttyputerr(_("Line %d: No Via in current technology connects %s to %s"),
+				ttyputerr(_("Line %ld: No Via in current technology connects %s to %s"),
 					io_leflineno, arcfunctionname(afunc1),
 					arcfunctionname(afunc2));
-				return(1);
+				return(TRUE);
 			}
-			if (io_lefignoretosemicolon(f, "VIA") != 0) return(1);
+			if (io_lefignoretosemicolon(f, "VIA")) return(TRUE);
 
 			/* create the via */
 			defaultnodesize(pin, &sx, &sy);
@@ -939,15 +940,15 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 			ni = newnodeinst(pin, lx, hx, ly, hy, 0, 0, facet);
 			if (ni == NONODEINST)
 			{
-				ttyputerr(_("Line %d: Cannot create VIA for PATH"), io_leflineno);
-				return(1);
+				ttyputerr(_("Line %ld: Cannot create VIA for PATH"), io_leflineno);
+				return(TRUE);
 			}
 			endobjectchange((INTBIG)ni, VNODEINST);
 			continue;
 		}
 
-		ttyputerr(_("Line %d: Unknown PORT keyword (%s)"), io_leflineno, key);
-		return(1);
+		ttyputerr(_("Line %ld: Unknown PORT keyword (%s)"), io_leflineno, key);
+		return(TRUE);
 	}
 
 	/* look for paths that end at vias */
@@ -961,7 +962,7 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 			{
 				geom = nextobject(sea);
 				if (geom == NOGEOM) break;
-				if (geom->entrytype != OBJNODEINST) continue;
+				if (!geom->entryisnode) continue;
 				ni = geom->entryaddr.ni;
 				cx = (ni->lowx + ni->highx) / 2;
 				cy = (ni->lowy + ni->highy) / 2;
@@ -998,8 +999,8 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 			lp->ni[i] = newnodeinst(pin, lx, hx, ly, hy, 0, 0, facet);
 			if (lp->ni[i] == NONODEINST)
 			{
-				ttyputerr(_("Line %d: Cannot create pin for PATH"), io_leflineno);
-				return(1);
+				ttyputerr(_("Line %ld: Cannot create pin for PATH"), io_leflineno);
+				return(TRUE);
 			}
 			endobjectchange((INTBIG)lp->ni[i], VNODEINST);
 
@@ -1024,13 +1025,13 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 				lp->ni[1], lp->ni[1]->proto->firstportproto, lp->x[1], lp->y[1], facet);
 		if (ai == NOARCINST)
 		{
-			ttyputerr(_("Line %d: Cannot create arc for PATH"), io_leflineno);
-			return(1);
+			ttyputerr(_("Line %ld: Cannot create arc for PATH"), io_leflineno);
+			return(TRUE);
 		}
 	}
 	io_leffreepaths(lefpaths);
 
-	return(0);
+	return(FALSE);
 }
 
 /*
@@ -1064,7 +1065,7 @@ PORTPROTO *io_lefnewport(NODEPROTO *facet, NODEINST *ni, PORTPROTO *pp, char *th
 	return(ppt);
 }
 
-INTSML io_lefreadobs(FILE *f, NODEPROTO *facet)
+BOOLEAN io_lefreadobs(FILE *f, NODEPROTO *facet)
 {
 	REGISTER char *key;
 	INTBIG lfunc, arcfunc;
@@ -1080,7 +1081,7 @@ INTSML io_lefreadobs(FILE *f, NODEPROTO *facet)
 		if (key == 0)
 		{
 			ttyputerr(_("EOF parsing OBS"));
-			return(1);
+			return(TRUE);
 		}
 
 		if (namesame(key, "END") == 0) break;
@@ -1091,17 +1092,17 @@ INTSML io_lefreadobs(FILE *f, NODEPROTO *facet)
 			if (key == 0)
 			{
 				ttyputerr(_("EOF reading LAYER clause"));
-				return(1);
+				return(TRUE);
 			}
 			io_lefparselayer(key, &arcfunc, &lfunc);
 			if (lfunc == LFUNKNOWN)
 			{
-				ttyputerr(_("Line %d: Unknown layer name (%s)"), io_leflineno, key);
-				return(1);
+				ttyputerr(_("Line %ld: Unknown layer name (%s)"), io_leflineno, key);
+				return(TRUE);
 			}
 			np = io_lefgetnode(lfunc);
-			if (np == NONODEPROTO) return(1);
-			if (io_lefignoretosemicolon(f, "LAYER") != 0) return(1);
+			if (np == NONODEPROTO) return(TRUE);
+			if (io_lefignoretosemicolon(f, "LAYER")) return(TRUE);
 			continue;
 		}
 
@@ -1109,14 +1110,14 @@ INTSML io_lefreadobs(FILE *f, NODEPROTO *facet)
 		{
 			if (np == NONODEPROTO)
 			{
-				ttyputerr(_("Line %d: No layers for RECT"), io_leflineno);
-				return(1);
+				ttyputerr(_("Line %ld: No layers for RECT"), io_leflineno);
+				return(TRUE);
 			}
 			key = io_lefgetkeyword(f);
 			if (key == 0)
 			{
 				ttyputerr(_("EOF reading RECT low X"));
-				return(1);
+				return(TRUE);
 			}
 			x = (float)atof(key);
 			lx = scalefromdispunit(x, DISPUNITMIC);
@@ -1125,7 +1126,7 @@ INTSML io_lefreadobs(FILE *f, NODEPROTO *facet)
 			if (key == 0)
 			{
 				ttyputerr(_("EOF reading RECT low Y"));
-				return(1);
+				return(TRUE);
 			}
 			y = (float)atof(key);
 			ly = scalefromdispunit(y, DISPUNITMIC);
@@ -1134,7 +1135,7 @@ INTSML io_lefreadobs(FILE *f, NODEPROTO *facet)
 			if (key == 0)
 			{
 				ttyputerr(_("EOF reading RECT high X"));
-				return(1);
+				return(TRUE);
 			}
 			x = (float)atof(key);
 			hx = scalefromdispunit(x, DISPUNITMIC);
@@ -1143,12 +1144,12 @@ INTSML io_lefreadobs(FILE *f, NODEPROTO *facet)
 			if (key == 0)
 			{
 				ttyputerr(_("EOF reading RECT high Y"));
-				return(1);
+				return(TRUE);
 			}
 			y = (float)atof(key);
 			hy = scalefromdispunit(y, DISPUNITMIC);
 
-			if (io_lefignoretosemicolon(f, "RECT") != 0) return(1);
+			if (io_lefignoretosemicolon(f, "RECT")) return(TRUE);
 
 			/* make the pin */
 			if (hx < lx) { j = hx;   hx = lx;   lx = j; }
@@ -1156,17 +1157,17 @@ INTSML io_lefreadobs(FILE *f, NODEPROTO *facet)
 			ni = newnodeinst(np, lx, hx, ly, hy, 0, 0, facet);
 			if (ni == NONODEINST)
 			{
-				ttyputerr(_("Line %d: Cannot create node for RECT"), io_leflineno);
-				return(1);
+				ttyputerr(_("Line %ld: Cannot create node for RECT"), io_leflineno);
+				return(TRUE);
 			}
 			endobjectchange((INTBIG)ni, VNODEINST);
 			continue;
 		}
 	}
-	return(0);
+	return(FALSE);
 }
 
-INTSML io_lefignoretosemicolon(FILE *f, char *command)
+BOOLEAN io_lefignoretosemicolon(FILE *f, char *command)
 {
 	REGISTER char *key;
 
@@ -1177,11 +1178,11 @@ INTSML io_lefignoretosemicolon(FILE *f, char *command)
 		if (key == 0)
 		{
 			ttyputerr(_("EOF parsing %s"), command);
-			return(1);
+			return(TRUE);
 		}
 		if (strcmp(key, ";") == 0) break;
 	}
-	return(0);
+	return(FALSE);
 }
 
 char *io_lefgetkeyword(FILE *f)
@@ -1193,7 +1194,7 @@ char *io_lefgetkeyword(FILE *f)
 	while (io_lefline[io_leflinepos] == 0)
 	{
 		/* read a line from the file, exit at EOF */
-		if (xfgets(io_lefline, MAXLINE, f) != 0) return(0);
+		if (xfgets(io_lefline, MAXLINE, f)) return(0);
 		io_leflineno++;
 		if ((io_leflineno%50) == 0)
 		{
@@ -1236,7 +1237,7 @@ NODEPROTO *io_lefgetnode(INTBIG lfunc)
 	np = getpurelayernode(el_curtech, -1, lfunc);
 	if (np == NONODEPROTO)
 	{
-		ttyputerr(_("Line %d: Layer not in current technology"),
+		ttyputerr(_("Line %ld: Layer not in current technology"),
 			io_leflineno);
 		return(NONODEPROTO);
 	}
@@ -1248,10 +1249,10 @@ ARCPROTO *io_lefgetarc(INTBIG afunc)
 	REGISTER ARCPROTO *ap;
 
 	for(ap = el_curtech->firstarcproto; ap != NOARCPROTO; ap = ap->nextarcproto)
-		if (((INTSML)((ap->userbits&AFUNCTION)>>AFUNCTIONSH)) == afunc) break;
+		if ((INTBIG)((ap->userbits&AFUNCTION)>>AFUNCTIONSH) == afunc) break;
 	if (ap == NOARCPROTO)
 	{
-		ttyputerr(_("Line %d: Layer %s not in current technology"),
+		ttyputerr(_("Line %ld: Layer %s not in current technology"),
 			io_leflineno, arcfunctionname(afunc));
 		return(NOARCPROTO);
 	}
