@@ -39,17 +39,18 @@
 
 #include "global.h"
 #include "eio.h"
+#include "usr.h"
 #include "efunction.h"
 
 /* prototypes for local routines */
-static void io_lefoutfacet(FILE *out, NODEPROTO *facet, INTSML top, XARRAY trans);
-static char *io_lefoutlayername(TECHNOLOGY *tech, INTSML layer);
+static void io_lefoutfacet(FILE *out, NODEPROTO *facet, BOOLEAN top, XARRAY trans);
+static char *io_lefoutlayername(TECHNOLOGY *tech, INTBIG layer);
 static void io_lefoutspread(FILE *out, NODEPROTO *facet, NETWORK *net, NODEINST *ignore);
 static void io_lefwritepoly(FILE *out, POLYGON *poly, XARRAY trans, TECHNOLOGY *tech);
 
 static char io_lefoutcurlayer[200];
 
-INTSML io_writeleflibrary(LIBRARY *lib)
+BOOLEAN io_writeleflibrary(LIBRARY *lib)
 {
 	char file[100], *truename;
 	REGISTER char *name;
@@ -70,7 +71,7 @@ INTSML io_writeleflibrary(LIBRARY *lib)
 	if (np == NONODEPROTO)
 	{
 		ttyputerr(_("Must be editing a facet to generate LEF output"));
-		return(1);
+		return(TRUE);
 	}
 	(void)strcpy(file, np->cell->cellname);
 	(void)strcat(file, ".lef");
@@ -79,11 +80,12 @@ INTSML io_writeleflibrary(LIBRARY *lib)
 	if (io_fileout == NULL)
 	{
 		if (truename != 0) ttyputerr(_("Cannot write %s"), truename);
-		return(1);
+		return(TRUE);
 	}
 
 	/* write header information */
-	xprintf(io_fileout, "# %s\n\n", timetostring(getcurrenttime()));
+	if ((us_useroptions&NODATEORVERSION) == 0)
+		xprintf(io_fileout, "# %s\n\n", timetostring(getcurrenttime()));
 	xprintf(io_fileout, "NAMESCASESENSITIVE ON ;\n");
 	xprintf(io_fileout, "UNITS\n");
 	xprintf(io_fileout, "  DATABASE MICRONS 1 ;\n");
@@ -166,7 +168,7 @@ INTSML io_writeleflibrary(LIBRARY *lib)
 	/* write the obstructions (all of the metal) */
 	xprintf(io_fileout, "\n  OBS\n");
 	io_lefoutcurlayer[0] = 0;
-	io_lefoutfacet(io_fileout, np, 1, el_matid);
+	io_lefoutfacet(io_fileout, np, TRUE, el_matid);
 	xprintf(io_fileout, "  END\n\n");
 
 	/* clean up */
@@ -176,7 +178,7 @@ INTSML io_writeleflibrary(LIBRARY *lib)
 
 	/* tell the user that the file is written */
 	ttyputmsg(_("%s written"), truename);
-	return(0);
+	return(FALSE);
 }
 
 /*
@@ -234,7 +236,7 @@ void io_lefoutspread(FILE *out, NODEPROTO *facet, NETWORK *net, NODEINST *ignore
  * Routine to write all geometry in facet "facet" to file "out".  The
  * hierarchy is flattened.  The current facet is transformed by "trans".
  */
-void io_lefoutfacet(FILE *out, NODEPROTO *facet, INTSML top, XARRAY trans)
+void io_lefoutfacet(FILE *out, NODEPROTO *facet, BOOLEAN top, XARRAY trans)
 {
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
@@ -246,14 +248,14 @@ void io_lefoutfacet(FILE *out, NODEPROTO *facet, INTSML top, XARRAY trans)
 	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_tool->cluster);
 	for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
-		if (top != 0 && ni->temp1 != 0) continue;
+		if (top && ni->temp1 != 0) continue;
 		makerot(ni, localrot);   transmult(localrot, trans, thisrot);
 		if (ni->proto->primindex == 0)
 		{
 			/* subfacet: recurse */
 			maketrans(ni, localtran);
 			transmult(localtran, thisrot, subrot);
-			io_lefoutfacet(out, ni->proto, 0, subrot);
+			io_lefoutfacet(out, ni->proto, FALSE, subrot);
 		} else
 		{
 			/* primitive: find the metal layers */
@@ -269,7 +271,7 @@ void io_lefoutfacet(FILE *out, NODEPROTO *facet, INTSML top, XARRAY trans)
 	/* write metal layers for all arcs */
 	for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 	{
-		if (top != 0 && ai->temp1 != 0) continue;
+		if (top && ai->temp1 != 0) continue;
 		tot = arcpolys(ai, NOWINDOWPART);
 		for(i=0; i<tot; i++)
 		{
@@ -292,7 +294,7 @@ void io_lefwritepoly(FILE *out, POLYGON *poly, XARRAY trans, TECHNOLOGY *tech)
 	layername = io_lefoutlayername(tech, poly->layer);
 	if (*layername == 0) return;
 	xformpoly(poly, trans);
-	if (isbox(poly, &lx, &hx, &ly, &hy) == 0) return;
+	if (!isbox(poly, &lx, &hx, &ly, &hy)) return;
 	flx = scaletodispunit(lx, DISPUNITMIC);
 	fhx = scaletodispunit(hx, DISPUNITMIC);
 	fly = scaletodispunit(ly, DISPUNITMIC);
@@ -305,7 +307,7 @@ void io_lefwritepoly(FILE *out, POLYGON *poly, XARRAY trans, TECHNOLOGY *tech)
 	xprintf(out, "    RECT %g %g %g %g ;\n", flx, fly, fhx, fhy);
 }
 
-char *io_lefoutlayername(TECHNOLOGY *tech, INTSML layer)
+char *io_lefoutlayername(TECHNOLOGY *tech, INTBIG layer)
 {
 	REGISTER INTBIG fun;
 
