@@ -76,9 +76,9 @@ static struct
 static INTBIG io_l_writefacet(NODEPROTO*);
 static char *io_l_name(NODEINST*);
 static char *io_l_fixname(char*);
-static INTSML io_l_nodetype(NODEINST*);
+static INTBIG io_l_nodetype(NODEINST*);
 
-INTSML io_writellibrary(LIBRARY *lib)
+BOOLEAN io_writellibrary(LIBRARY *lib)
 {
 	char file[100], *truename;
 	REGISTER char *name;
@@ -89,7 +89,7 @@ INTSML io_writellibrary(LIBRARY *lib)
 	if (lib->curnodeproto == NONODEPROTO)
 	{
 		ttyputerr(_("Must be editing a facet to generate L output"));
-		return(1);
+		return(TRUE);
 	}
 	(void)strcpy(file, lib->curnodeproto->cell->cellname);
 	(void)strcat(file, ".L");
@@ -98,7 +98,7 @@ INTSML io_writellibrary(LIBRARY *lib)
 	if (io_fileout == NULL)
 	{
 		if (truename != 0) ttyputerr(_("Cannot write %s"), truename);
-		return(1);
+		return(TRUE);
 	}
 
 	xprintf(io_fileout, "L:: TECH ANY\n");
@@ -116,7 +116,7 @@ INTSML io_writellibrary(LIBRARY *lib)
 	/* tell the user that the file is written */
 	ttyputmsg(_("%s written"), truename);
 
-	return(0);
+	return(FALSE);
 }
 
 /*
@@ -189,7 +189,7 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 		}
 		lay = pp->connects[0]->protoname;
 		for(i=0; io_lports[i].arcfunct != 0; i++)
-			if ((INTSML)(((pp->connects[0]->userbits&AFUNCTION)>>AFUNCTIONSH)) == io_lports[i].arcfunct)
+			if ((INTBIG)(((pp->connects[0]->userbits&AFUNCTION)>>AFUNCTIONSH)) == io_lports[i].arcfunct)
 		{
 			lay = io_lports[i].portname;   break;
 		}
@@ -229,7 +229,7 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 				/* if pin is an export, don't write separate node statement */
 				if (subno->firstportexpinst != NOPORTEXPINST) continue;
 				for(j=0; io_lports[j].arcfunct != 0; j++)
-					if ((INTSML)(((subno->proto->firstportproto->connects[0]->userbits&
+					if ((INTBIG)(((subno->proto->firstportproto->connects[0]->userbits&
 						AFUNCTION)>>AFUNCTIONSH)) == io_lports[j].arcfunct) break;
 				if (io_lports[j].arcfunct != 0) type = io_lports[j].portname; else
 					type = "???";
@@ -251,7 +251,7 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 					{
 						if (io_lcontacts[k].arcfunct[j] == 0) continue;
 						for(l=0; aplist[l] != NOARCPROTO; l++)
-							if ((INTSML)(((aplist[l]->userbits&AFUNCTION) >> AFUNCTIONSH)) ==
+							if ((INTBIG)(((aplist[l]->userbits&AFUNCTION) >> AFUNCTIONSH)) ==
 								io_lcontacts[k].arcfunct[j]) break;
 						if (aplist[l] == NOARCPROTO) break;
 					}
@@ -323,7 +323,7 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 			if (subar->temp1 != 0) continue;
 			xprintf(io_fileout, "\tWIRE");
 			for(i=0; io_lports[i].arcfunct != 0; i++)
-				if ((INTSML)(((subar->proto->userbits&AFUNCTION)>>AFUNCTIONSH)) == io_lports[i].arcfunct)
+				if ((INTBIG)(((subar->proto->userbits&AFUNCTION)>>AFUNCTIONSH)) == io_lports[i].arcfunct)
 			{
 				xprintf(io_fileout, " %s", io_lports[i].portname);
 				break;
@@ -448,7 +448,7 @@ char *io_l_name(NODEINST *ni)
 	REGISTER VARIABLE *var;
 	static char line[30];
 
-	var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name);
+	var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
 	if (var != NOVARIABLE) return(io_l_fixname((char *)var->addr));
 	ttyputerr(_("L generation warning: no name on node %s"), describenodeinst(ni));
 	(void)sprintf(line, "c%ld", ni->temp1);
@@ -458,7 +458,7 @@ char *io_l_name(NODEINST *ni)
 char *io_l_fixname(char *name)
 {
 	REGISTER char *pt;
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 	static char *badname[] = {"VDD", "GND", 0};
 
 	/* check for reserved names */
@@ -494,7 +494,7 @@ char *io_l_fixname(char *name)
  *    INSTANCE   if a facet instance
  *    OTHERNODE  otherwise.
  */
-INTSML io_l_nodetype(NODEINST *ni)
+INTBIG io_l_nodetype(NODEINST *ni)
 {
 	REGISTER INTBIG i;
 	REGISTER PORTARCINST *pi;
