@@ -80,10 +80,10 @@ typedef struct Inextpadsnet
 static PADSNET *io_padsfirstnet;
 
 /* prototypes for local routines */
-static void io_padsdumpfacet(NODEPROTO *curfacet, char *prefix);
+static INTBIG io_padsdumpfacet(NODEPROTO *curfacet, char *prefix);
 static void io_padsmarkfacets(NODEPROTO *curfacet);
 
-INTSML io_writepadslibrary(LIBRARY *lib)
+BOOLEAN io_writepadslibrary(LIBRARY *lib)
 {
 	char file[100], *truename;
 	REGISTER INTBIG i, sorted, maxnetname, maxpackagename;
@@ -97,7 +97,7 @@ INTSML io_writepadslibrary(LIBRARY *lib)
 	if (curfacet == NONODEPROTO)
 	{
 		ttyputerr(_("Must be editing a facet to generate PADS output"));
-		return(1);
+		return(TRUE);
 	}
 	(void)strcpy(file, curfacet->cell->cellname);
 	(void)strcat(file, ".asc");
@@ -106,7 +106,7 @@ INTSML io_writepadslibrary(LIBRARY *lib)
 	if (io_fileout == NULL)
 	{
 		if (truename != 0) ttyputerr(_("Cannot write %s"), truename);
-		return(1);
+		return(TRUE);
 	}
 
    	xprintf(io_fileout, "!PADS-POWERPCB-V2\n\n*CLUSTER* ITEM\n\n\n*PART*\n");
@@ -116,7 +116,8 @@ INTSML io_writepadslibrary(LIBRARY *lib)
 	for(pp = curfacet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		pp->temp1 = 0;
 
-	io_padsdumpfacet(curfacet, "");		/* assemble parts list */
+	if (io_padsdumpfacet(curfacet, "") != 0)		/* assemble parts list */
+		ttyputmsg(_("Back-annotation information has been added (library must be saved)"));
 
 	xprintf(io_fileout, "\n*NET* \n");	/* cm - removed before netlist */
 
@@ -214,14 +215,15 @@ INTSML io_writepadslibrary(LIBRARY *lib)
 
 	/* tell the user that the file is written */
 	ttyputmsg(_("%s written"), truename);
-	return(0);
+	return(FALSE);
 }
 
 
 /*
  * Routine to write out all facets in the current library that are marked (temp1 != 0).
+ * Returns nonzero if backannotation has been added.
  */
-void io_padsdumpfacet(NODEPROTO *curfacet, char *prefix)
+INTBIG io_padsdumpfacet(NODEPROTO *curfacet, char *prefix)
 {
 	char *name;
 	char line[50], *newprefix, *tempname;
@@ -232,6 +234,11 @@ void io_padsdumpfacet(NODEPROTO *curfacet, char *prefix)
 	REGISTER PORTARCINST *pi;
 	REGISTER PORTPROTO *pp;
 	REGISTER PADSNET *en;
+	REGISTER INTBIG backannotate;
+
+	/* make sure that all arcs have network names on them */
+	backannotate = 0;
+	if (asktool(net_tool, "name-nets", (INTBIG)curfacet) != 0) backannotate++;
 
 	/* mark those facets that will be included in this dump */
 	io_padsmarkfacets(curfacet);
@@ -272,7 +279,7 @@ void io_padsdumpfacet(NODEPROTO *curfacet, char *prefix)
 				/* compute new prefix for nets in the subfacet */
 				(void)initinfstr();
 				(void)addstringtoinfstr(prefix);
-				var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name);
+				var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
 				if (var == NOVARIABLE)
 				{
 					sprintf(line, "NODE%ld.", (INTBIG)ni);
@@ -282,7 +289,7 @@ void io_padsdumpfacet(NODEPROTO *curfacet, char *prefix)
 					(void)addstringtoinfstr((char *)var->addr);
 					(void)addtoinfstr('.');
 				}
-				allocstring(&newprefix, returninfstr(), el_tempcluster);
+				(void)allocstring(&newprefix, returninfstr(), el_tempcluster);
 
 				/* store net names on ports for use inside the subfacet */
 				for(pp = subnp->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
@@ -295,12 +302,12 @@ void io_padsdumpfacet(NODEPROTO *curfacet, char *prefix)
 					(void)initinfstr();
 					(void)addstringtoinfstr(prefix);
 					(void)addstringtoinfstr(net->netname);
-					allocstring(&tempname, returninfstr(), io_tool->cluster);
+					(void)allocstring(&tempname, returninfstr(), io_tool->cluster);
 					pp->temp1 = (INTBIG)tempname;
 				}
 
 				/* recurse */
-				io_padsdumpfacet(subnp, newprefix);
+				if (io_padsdumpfacet(subnp, newprefix) != 0) backannotate++;
 
 				/* remark the facets at the current level and clean up memory */
 				io_padsmarkfacets(curfacet);
@@ -344,7 +351,7 @@ void io_padsdumpfacet(NODEPROTO *curfacet, char *prefix)
 
 					/* create a new net connection */
 					en = (PADSNET *)emalloc(sizeof (PADSNET), io_tool->cluster);
-					if (en == 0) return;
+					if (en == 0) return(backannotate);
 					net = pi->conarcinst->network;
 					if (net->temp1 != 0)
 					{
@@ -373,6 +380,7 @@ void io_padsdumpfacet(NODEPROTO *curfacet, char *prefix)
 			}
 		}
 	}
+	return(backannotate);
 }
 
 /*
