@@ -63,28 +63,28 @@ static INTBIG      io_plotrevy;
 static INTBIG      io_slx, io_shx, io_sly, io_shy;
 static INTBIG      io_ulx, io_uhx, io_uly, io_uhy;
 static WindowPtr   io_plotwin;
-static INTSML      io_thislayer, io_maxlayer;
+static INTBIG      io_thislayer, io_maxlayer;
 
 void io_setplotlayer(INTBIG);
 void io_setbounds(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, WindowPtr);
-INTSML io_plotpoly(POLYGON*, WINDOWPART*);
+void io_plotpoly(POLYGON*, WINDOWPART*);
 void io_plotdot(INTBIG, INTBIG);
-void io_plotline(INTBIG, INTBIG, INTBIG, INTBIG, INTSML);
-void io_plotpolygon(INTBIG*, INTBIG*, INTSML, INTSML, GRAPHICS*);
-void io_plottext(INTSML, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, char*);
+void io_plotline(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+void io_plotpolygon(INTBIG*, INTBIG*, INTBIG, INTBIG, GRAPHICS*);
+void io_plottext(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, char*);
 void io_xform(INTBIG*, INTBIG*);
 void io_maccopyhighlighted(void);
 
 /*
  * routine to write out a file to the Macintosh/Quickdraw system
  */
-INTSML io_writequickdrawlibrary(LIBRARY *lib)
+BOOLEAN io_writequickdrawlibrary(LIBRARY *lib)
 {
 	REGISTER NODEPROTO *np;
-	INTSML err, ix, swid, shei;
+	INTBIG err, ix, swid, shei;
 	INTBIG hlx, hhx, hly, hhy, gridlx, gridly, gridx, gridy, cx, cy, prod1, prod2, i,
 		revy, slx, shx, sly, shy, ulx, uhx, uly, uhy, sxs, sys, dxs, dys, saver, saveg,
-		saveb, white, *curstate;
+		saveb, white, *curstate, lambda;
 	VARIABLE *var;
 	REGISTER VARIABLE *varred, *vargreen, *varblue;
 	static POLYGON *poly = NOPOLYGON;
@@ -98,21 +98,28 @@ INTSML io_writequickdrawlibrary(LIBRARY *lib)
 	if (np == NONODEPROTO)
 	{
 		ttyputerr(_("No current facet to plot"));
-		return(1);
+		return(TRUE);
+	}
+
+	/* cannot write text-only facets */
+	if ((np->cellview->viewstate&TEXTVIEW) != 0)
+	{
+		ttyputerr(_("Cannot write textual facets"));
+		return(TRUE);
 	}
 
 	/* get printing control bits */
 	curstate = io_getstatebits();
 
 	/* determine area to plot */
-	if (io_getareatoprint(np, &slx, &shx, &sly, &shy, 1) != 0) return(1);
+	if (io_getareatoprint(np, &slx, &shx, &sly, &shy, TRUE)) return(TRUE);
 
 	/* open the window (to the printer) */
 	PrOpen();
 	if ((err = PrError()) != noErr)
 	{
-		ttyputerr(_("Printer error %d"), err);
-		return(1);
+		ttyputerr(_("Printer error %ld"), err);
+		return(TRUE);
 	}
 
 	/* see if any printing has already been done */
@@ -123,28 +130,28 @@ INTSML io_writequickdrawlibrary(LIBRARY *lib)
 		if (hPrint == 0)
 		{
 			ttyputerr(_("Cannot allocate print record"));
-			return(1);
+			return(TRUE);
 		}
 		PrintDefault(hPrint);
 		if ((err = PrError()) != noErr)
 		{
-			ttyputerr(_("Printer error %d"), err);
-			return(1);
+			ttyputerr(_("Printer error %ld"), err);
+			return(TRUE);
 		}
-		if (!PrStlDialog(hPrint)) return(1);
+		if (!PrStlDialog(hPrint)) return(TRUE);
 	} else
 	{
 		/* have already printed: validate print record */
 		PrValidate(hPrint);
 		if ((err = PrError()) != noErr)
 		{
-			ttyputerr(_("Printer error %d"), err);
-			return(1);
+			ttyputerr(_("Printer error %ld"), err);
+			return(TRUE);
 		}
 	}
 
 	/* do the "Print..." dialog */
-	if (!PrJobDialog(hPrint)) return(1);
+	if (!PrJobDialog(hPrint)) return(TRUE);
 
 	/* open the pseudo-window to the printer */
 	plotwin = PrOpenDoc(hPrint, 0, 0);
@@ -152,15 +159,15 @@ INTSML io_writequickdrawlibrary(LIBRARY *lib)
 	if (PrError())
 	{
 		ttyputerr(_("Error opening print page"));
-		return(1);
+		return(TRUE);
 	}
 	SetPort((WindowPtr)plotwin);
 
 	/* save background color and make it white */
-	varred = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_red);
-	vargreen = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_green);
-	varblue = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_blue);
-	if (varred == NOVARIABLE || vargreen == NOVARIABLE || varblue == NOVARIABLE) return(1);
+	varred = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_red_key);
+	vargreen = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_green_key);
+	varblue = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_blue_key);
+	if (varred == NOVARIABLE || vargreen == NOVARIABLE || varblue == NOVARIABLE) return(TRUE);
 	saver = ((INTBIG *)varred->addr)[0];
 	saveg = ((INTBIG *)vargreen->addr)[0];
 	saveb = ((INTBIG *)varblue->addr)[0];
@@ -219,7 +226,7 @@ INTSML io_writequickdrawlibrary(LIBRARY *lib)
 		
 		/* restore background color */
 		colormapload(&saver, &saveg, &saveb, 0, 0);
-		return(0);
+		return(FALSE);
 	}
 
 	TextFont(EFONT);
@@ -271,9 +278,10 @@ INTSML io_writequickdrawlibrary(LIBRARY *lib)
 	/* draw the grid if requested */
 	if ((el_curwindowpart->state&(GRIDON|GRIDTOOSMALL)) == GRIDON)
 	{
-		gridx = el_curwindowpart->gridx;
-		gridy = el_curwindowpart->gridy;
-		var = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER, us_gridfloats);
+		lambda = lib->lambda[np->tech->techindex];
+		gridx = muldiv(el_curwindowpart->gridx, lambda, WHOLE);
+		gridy = muldiv(el_curwindowpart->gridy, lambda, WHOLE);
+		var = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER, us_gridfloatskey);
 		if (var == NOVARIABLE || var->addr == 0)
 		{
 			gridlx = np->lowx  / gridx * gridx;
@@ -281,8 +289,7 @@ INTSML io_writequickdrawlibrary(LIBRARY *lib)
 		} else
 		{
 			grabpoint(np, &gridlx, &gridly);
-			var = getval((INTBIG)us_tool, VTOOL, VINTEGER, "USER_alignment_obj");
-			if (var != NOVARIABLE) gridalign(&gridlx, &gridly, var->addr);
+			gridalign(&gridlx, &gridly, 1);
 			gridlx += gridlx / gridx * gridx;
 			gridly += gridly / gridy * gridy;
 		}
@@ -361,7 +368,7 @@ INTSML io_writequickdrawlibrary(LIBRARY *lib)
 		
 	/* restore background color */
 	colormapload(&saver, &saveg, &saveb, 0, 0);
-	return(0);
+	return(FALSE);
 }
 
 /******************** LAYER ORDERING FOR GRAPHIC COPY/PRINT ********************/
@@ -399,29 +406,29 @@ void io_setbounds(INTBIG slx, INTBIG shx, INTBIG sly, INTBIG shy, INTBIG ulx, IN
 /*
  * routine to plot the polygon "poly"
  */
-INTSML io_plotpoly(POLYGON *poly, WINDOWPART *win)
+void io_plotpoly(POLYGON *poly, WINDOWPART *win)
 {
-	REGISTER INTSML k, type;
+	REGISTER INTBIG k, type;
 	INTBIG xl, xh, yl, yh, x, y, listx[4], listy[4], size,
 		centerx, centery, x1p, y1p, x2p, y2p, xa, ya, xb, yb, radius;
-	INTSML startangle, endangle, amt, style;
+	INTBIG startangle, endangle, amt, style;
 	unsigned char pat[8];
 	Rect r;
 	static POLYGON *polyspline = NOPOLYGON;
 	REGISTER TECHNOLOGY *tech;
 
 	/* ignore null layers */
-	if (poly->desc->bits == LAYERN || poly->desc->col == ALLOFF) return(1);
+	if (poly->desc->bits == LAYERN || poly->desc->col == ALLOFF) return;
 
 	/* only plot the desired layer */
 	if (io_thislayer < 0)
 	{
 		/* first outline filled areas in proper order */
-		if (poly->layer != -io_thislayer-1) return(1);
-		if (poly->style != FILLED && poly->style != FILLEDRECT) return(1);
+		if (poly->layer != -io_thislayer-1) return;
+		if (poly->style != FILLED && poly->style != FILLEDRECT) return;
 		if (isbox(poly, &xl, &xh, &yl, &yh))
 		{
-			if (xl == xh || yl == yh) return(1);
+			if (xl == xh || yl == yh) return;
 			io_xform(&xl, &yl);
 			io_xform(&xh, &yh);
 			xl--;   yh++;
@@ -436,7 +443,7 @@ INTSML io_plotpoly(POLYGON *poly, WINDOWPART *win)
 		} else
 		{
 			/* outlining stipple: expand polygon */
-			if (poly->count <= 2) return(1);
+			if (poly->count <= 2) return;
 			centerx = centery = 0;
 			for(k=0; k<poly->count; k++)
 			{
@@ -467,21 +474,21 @@ INTSML io_plotpoly(POLYGON *poly, WINDOWPART *win)
 				LineTo(x2p, io_plotrevy-y2p);
 			}
 		}
-		return(0);
+		return;
 	}
 
 	if (io_thislayer > 0)
 	{
 		/* then draw layers in proper order */
-		if (poly->layer != io_thislayer-1) return(1);
+		if (poly->layer != io_thislayer-1) return;
 	} else
 	{
 		/* final pass: draw layers not in the technology */
-		for(k=0; k<io_maxlayer; k++) if (io_nextplotlayer(k) == poly->layer) return(1);
+		for(k=0; k<io_maxlayer; k++) if (io_nextplotlayer(k) == poly->layer) return;
 	}
 
 	/* ignore grids */
-	if (poly->style == GRIDDOTS) return(0);
+	if (poly->style == GRIDDOTS) return;
 	style = poly->desc->bwstyle;
 
 	switch (poly->style)
@@ -592,7 +599,7 @@ INTSML io_plotpoly(POLYGON *poly, WINDOWPART *win)
 			PenPat((PatPtr)pat);
 			PaintOval(&r);
 
-		case CIRCLE:
+		case CIRCLE: case THICKCIRCLE:
 			centerx = poly->xv[0];   centery = poly->yv[0];
 			xa = poly->xv[1];        ya = poly->yv[1];
 			io_xform(&centerx, &centery);
@@ -608,7 +615,7 @@ INTSML io_plotpoly(POLYGON *poly, WINDOWPART *win)
 			FrameOval(&r);
 			break;
 
-		case CIRCLEARC:
+		case CIRCLEARC: case THICKCIRCLEARC:
 			centerx = poly->xv[0];   centery = poly->yv[0];
 			xa = poly->xv[1];        ya = poly->yv[1];
 			xb = poly->xv[2];        yb = poly->yv[2];
@@ -666,7 +673,6 @@ INTSML io_plotpoly(POLYGON *poly, WINDOWPART *win)
 			io_plottext(poly->style, xl, xh, yl, yh, size, poly->string);
 			break;
 	}
-	return(0);
 }
 
 void io_plotdot(INTBIG x, INTBIG y)
@@ -682,7 +688,7 @@ void io_plotdot(INTBIG x, INTBIG y)
 }
 
 /* draw a line */
-void io_plotline(INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2, INTSML pattern)
+void io_plotline(INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2, INTBIG pattern)
 {
 	static unsigned char pat0[] = {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF};
 	static unsigned char pat1h[] = {0xFF, 0, 0, 0, 0xFF, 0, 0, 0};
@@ -706,13 +712,13 @@ void io_plotline(INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2, INTSML pattern)
 	if (pattern == 3) PenSize(1, 1);
 }
 
-void io_plotpolygon(INTBIG *x, INTBIG *y, INTSML count, INTSML style, GRAPHICS *desc)
+void io_plotpolygon(INTBIG *x, INTBIG *y, INTBIG count, INTBIG style, GRAPHICS *desc)
 {
-	INTSML i;
+	INTBIG i;
 	unsigned char pat[8];
 	PolyHandle polyhandle;
 	static INTBIG *myx, *myy;
-	static INTSML len = 0;
+	static INTBIG len = 0;
 
 	if (count == 0) return;
 	if (count > len)
@@ -747,7 +753,7 @@ void io_plotpolygon(INTBIG *x, INTBIG *y, INTSML count, INTSML style, GRAPHICS *
 	KillPoly(polyhandle);
 }
 
-void io_plottext(INTSML type, INTBIG lx, INTBIG ux, INTBIG ly, INTBIG uy, INTBIG size,
+void io_plottext(INTBIG type, INTBIG lx, INTBIG ux, INTBIG ly, INTBIG uy, INTBIG size,
 	char *text)
 {
 	char localstring[256];
@@ -863,7 +869,7 @@ void io_maccopyhighlighted(void)
 {
 	PicHandle picture;
 	INTBIG len, slx, shx, sly, shy, ulx, uhx, uly, uhy, revy;
-	INTSML ix;
+	INTBIG ix;
 	CGrafPtr realwindow;
 	extern CGrafPtr gra_getwindow(WINDOWPART *win);
 
@@ -887,7 +893,7 @@ void io_maccopyhighlighted(void)
 	{
 		Rect sr;
 		CGrafPtr window;
-		INTSML revy, swid, shei;
+		INTBIG revy, swid, shei;
 
 		window = gra_getoffscreen(el_curwindowpart);
 		getwindowframesize(el_curwindowpart->frame, &swid, &shei);
