@@ -56,32 +56,32 @@ typedef struct
 	INTBIG  lineno;
 	INTBIG  paramtotal;
 	INTBIG  parameters;
-	INTSML *paramtype;
+	INTBIG *paramtype;
 	void  **paramvalue;
 } LISPTREE;
 
 static LISPTREE *sdfi_treestack[MAXDEPTH];
-static INTSML    sdfi_treedepth;
+static INTBIG    sdfi_treedepth;
 static LISPTREE *sdfi_treepos;
 static LISPTREE *sdfi_freelisptree = 0;
 
 static INTBIG sdfi_filesize;
 static INTBIG sdfi_lineno;
-static char *sdfi_design = NULL;		/* DESIGN keyword */
-static char *sdfi_sdfversion = NULL;	/* SDFVERSION keyword */
-static char *sdfi_date = NULL;			/* DATE keyword */
-static char *sdfi_vendor = NULL;		/* VENDOR keyword */
-static char *sdfi_program = NULL;		/* PROGRAM keyword */
-static char *sdfi_version = NULL;		/* VERSION keyword */
-static char *sdfi_voltage = NULL;		/* VOLTAGE keyword */
-static char *sdfi_process = NULL;		/* PROCESS keyword */
-static char *sdfi_temperature = NULL;	/* TEMPERATURE keyword */
-static char *sdfi_timescale = NULL;	/* TIMESCALE keyword */
-static char *sdfi_hiername = NULL;		/* current cell instance hierarchy name */
-static char *sdfi_celltype = NULL;		/* current CELLTYPE */
-static char *sdfi_instance = NULL;		/* current INSTANCE */
-static char *sdfi_divider = NULL;		/* hierarchy divider - if DIVIDER keyword not in SDF file defaults to . */
-static INTBIG sdfi_timeconvert = 1000; /* multiplier to convert time values to picoseconds */
+static char  *sdfi_design = NULL;		/* DESIGN keyword */
+static char  *sdfi_sdfversion = NULL;	/* SDFVERSION keyword */
+static char  *sdfi_date = NULL;			/* DATE keyword */
+static char  *sdfi_vendor = NULL;		/* VENDOR keyword */
+static char  *sdfi_program = NULL;		/* PROGRAM keyword */
+static char  *sdfi_version = NULL;		/* VERSION keyword */
+static char  *sdfi_voltage = NULL;		/* VOLTAGE keyword */
+static char  *sdfi_process = NULL;		/* PROCESS keyword */
+static char  *sdfi_temperature = NULL;	/* TEMPERATURE keyword */
+static char  *sdfi_timescale = NULL;	/* TIMESCALE keyword */
+static char  *sdfi_hiername = NULL;		/* current cell instance hierarchy name */
+static char  *sdfi_celltype = NULL;		/* current CELLTYPE */
+static char  *sdfi_instance = NULL;		/* current INSTANCE */
+static char  *sdfi_divider = NULL;		/* hierarchy divider - if DIVIDER keyword not in SDF file defaults to . */
+static INTBIG sdfi_timeconvert = 1000;	/* multiplier to convert time values to picoseconds */
 								/* if TIMESCALE keyword not in SDF file default time unit is 1ns */
 static INTBIG SDF_instance_key = 0;
 static INTBIG SDF_absolute_port_delay_key = 0;
@@ -89,20 +89,20 @@ static INTBIG SDF_absolute_iopath_delay_key = 0;
 static NODEPROTO *sdfi_curfacet = NONODEPROTO;
 
 /* prototypes for local routines */
-static INTSML     sdfi_addparameter(LISPTREE *tree, INTSML type, void *value);
+static BOOLEAN    sdfi_addparameter(LISPTREE *tree, INTBIG type, void *value);
 static LISPTREE  *sdfi_alloclisptree(void);
 static void       sdfi_killptree(LISPTREE *lt);
-static INTSML     sdfi_pushkeyword(char *pt);
+static BOOLEAN    sdfi_pushkeyword(char *pt);
 static LISPTREE  *sdfi_readfile(FILE *fp);
-static INTSML     sdfi_parsetree(LISPTREE *lt);
-static INTSML     sdfi_parsedelayfile(LISPTREE *lt);
-static INTSML     sdfi_parsecell(LISPTREE *lt);
-static INTSML     sdfi_parsedelay(LISPTREE *lt, NODEINST *ni);
-static INTSML     sdfi_parseabsolute(LISPTREE *lt, NODEINST *ni);
-static INTSML     sdfi_parseincrement(LISPTREE *lt, NODEINST *ni);
-static INTSML     sdfi_parseport(LISPTREE *lt, NODEINST *ni);
-static INTSML     sdfi_parseiopath(LISPTREE *lt, NODEINST *ni);
-static INTSML     sdfi_parsetimescale(LISPTREE *lt);
+static BOOLEAN    sdfi_parsetree(LISPTREE *lt);
+static BOOLEAN    sdfi_parsedelayfile(LISPTREE *lt);
+static BOOLEAN    sdfi_parsecell(LISPTREE *lt);
+static BOOLEAN    sdfi_parsedelay(LISPTREE *lt, NODEINST *ni);
+static BOOLEAN    sdfi_parseabsolute(LISPTREE *lt, NODEINST *ni);
+static BOOLEAN    sdfi_parseincrement(LISPTREE *lt, NODEINST *ni);
+static BOOLEAN    sdfi_parseport(LISPTREE *lt, NODEINST *ni);
+static BOOLEAN    sdfi_parseiopath(LISPTREE *lt, NODEINST *ni);
+static BOOLEAN    sdfi_parsetimescale(LISPTREE *lt);
 static NODEINST  *sdfi_getcellinstance(char *celltype, char *instance);
 static char      *sdfi_converttops(char *tstring);
 static void       sdfi_setstring(char **string, char *value);
@@ -127,7 +127,7 @@ void io_freesdfimemory(void)
 	sdfi_clearglobals();
 }
 
-INTSML io_readsdflibrary(LIBRARY *lib)
+BOOLEAN io_readsdflibrary(LIBRARY *lib)
 {
 	FILE *fp;
 	char *filename;
@@ -139,7 +139,7 @@ INTSML io_readsdflibrary(LIBRARY *lib)
 	if (sdfi_curfacet == NONODEPROTO)
 	{
 		ttyputerr(_("No current facet with which to merge data, aborting SDF input"));
-		return(1);
+		return(TRUE);
 	}
 
 	/* init some global variables */
@@ -155,15 +155,15 @@ INTSML io_readsdflibrary(LIBRARY *lib)
 	if (fp == NULL)
 	{
 		ttyputerr(_("File %s not found"), lib->libfile);
-		return(1);
+		return(TRUE);
 	}
 
 	/* prepare for input */
 	sdfi_filesize = filesize(fp);
-	if (DiaInitDialog(&us_progressdialog) != 0)
+	if (DiaInitDialog(&us_progressdialog))
 	{
 		xclose(fp);
-		return(1);
+		return(TRUE);
 	}
 	DiaPercent(1, 0);
 	DiaSetText(2, _("Reading SDF file..."));
@@ -175,16 +175,16 @@ INTSML io_readsdflibrary(LIBRARY *lib)
 	if (lt == 0)
 	{
 		ttyputerr(_("Error reading file"));
-		return(1);
+		return(TRUE);
 	}
 	ttyputmsg(_("SDF file %s is read"), lib->libfile);
 
 	/* parse the tree */
-	if (sdfi_parsetree(lt) != 0)
+	if (sdfi_parsetree(lt))
 	{
 		sdfi_killptree(lt);
 		ttyputerr(_("Errors occured during SDF file parsing"));
-		return(1);
+		return(TRUE);
 	}
 	ttyputmsg(_("Successfully parsed SDF file"));
 
@@ -227,7 +227,7 @@ INTSML io_readsdflibrary(LIBRARY *lib)
 
 	ttyputmsg(_("Back-annotation information has been added (library must be saved)"));
 
-	return(0);
+	return(FALSE);
 }
 
 /*
@@ -244,7 +244,7 @@ LISPTREE *sdfi_readfile(FILE *f)
 	/* make the tree top */
 	treetop = (LISPTREE *)emalloc((sizeof (LISPTREE)), io_tool->cluster);
 	if (treetop == 0) return(0);
-	if (allocstring(&treetop->keyword, "TOP", io_tool->cluster) != 0) return(0);
+	if (allocstring(&treetop->keyword, "TOP", io_tool->cluster)) return(0);
 	treetop->paramtotal = 0;
 	treetop->parameters = 0;
 
@@ -256,7 +256,7 @@ LISPTREE *sdfi_readfile(FILE *f)
 	for(;;)
 	{
 		/* get the next line of text */
-		if (xfgets(line, MAXLINE, f) != 0) break;
+		if (xfgets(line, MAXLINE, f)) break;
 		sdfi_lineno++;
 		if ((sdfi_lineno%50) == 0)
 		{
@@ -282,7 +282,7 @@ LISPTREE *sdfi_readfile(FILE *f)
 			{
 				save = pt[1];
 				pt[1] = 0;
-				if (sdfi_pushkeyword(pt) != 0) return(0);
+				if (sdfi_pushkeyword(pt)) return(0);
 				pt[1] = save;
 				pt++;
 				continue;
@@ -307,7 +307,7 @@ LISPTREE *sdfi_readfile(FILE *f)
 				ptend++;
 			}
 			save = *ptend;   *ptend = 0;
-			if (sdfi_pushkeyword(pt) != 0) return(0);
+			if (sdfi_pushkeyword(pt)) return(0);
 			*ptend = save;
 			pt = ptend;
 		}
@@ -323,9 +323,9 @@ LISPTREE *sdfi_readfile(FILE *f)
 
 /*
  * Routine to add the next keyword "keyword" to the lisp tree in the globals.
- * Returns nonzero on error.
+ * Returns true on error.
  */
-INTSML sdfi_pushkeyword(char *keyword)
+BOOLEAN sdfi_pushkeyword(char *keyword)
 {
 	REGISTER LISPTREE *newtree;
 	char *savekey;
@@ -336,7 +336,7 @@ INTSML sdfi_pushkeyword(char *keyword)
 		if (sdfi_treedepth >= MAXDEPTH)
 		{
 			ttyputerr(_("Nesting too deep (more than %d)"), MAXDEPTH);
-			return(1);
+			return(TRUE);
 		}
 
 		/* create a new tree branch */
@@ -346,18 +346,18 @@ INTSML sdfi_pushkeyword(char *keyword)
 		newtree->lineno = sdfi_lineno;
 
 		/* add branch to previous branch */
-		if (sdfi_addparameter(sdfi_treepos, PARAMBRANCH, newtree) != 0) return(1);
+		if (sdfi_addparameter(sdfi_treepos, PARAMBRANCH, newtree)) return(TRUE);
 
 		/* add keyword */
 		pt = &keyword[1];
 		while (*pt == ' ' && *pt == '\t') pt++;
-		if (allocstring(&newtree->keyword, pt, io_tool->cluster) != 0) return(1);
+		if (allocstring(&newtree->keyword, pt, io_tool->cluster)) return(TRUE);
 
 		/* push tree onto stack */
 		sdfi_treestack[sdfi_treedepth] = sdfi_treepos;
 		sdfi_treedepth++;
 		sdfi_treepos = newtree;
-		return(0);
+		return(FALSE);
 	}
 
 	if (strcmp(keyword, ")") == 0)
@@ -366,11 +366,11 @@ INTSML sdfi_pushkeyword(char *keyword)
 		if (sdfi_treedepth <= 0)
 		{
 			ttyputerr(_("Too many close parenthesis"));
-			return(1);
+			return(TRUE);
 		}
 		sdfi_treedepth--;
 		sdfi_treepos = sdfi_treestack[sdfi_treedepth];
-		return(0);
+		return(FALSE);
 	}
 
 	/* just add the atomic keyword */
@@ -379,18 +379,18 @@ INTSML sdfi_pushkeyword(char *keyword)
 		keyword++;
 		keyword[strlen(keyword)-1] = 0;
 	}
-	if (allocstring(&savekey, keyword, io_tool->cluster) != 0) return(1);
-	if (sdfi_addparameter(sdfi_treepos, PARAMATOM, savekey) != 0) return(1);
-	return(0);
+	if (allocstring(&savekey, keyword, io_tool->cluster)) return(TRUE);
+	if (sdfi_addparameter(sdfi_treepos, PARAMATOM, savekey)) return(TRUE);
+	return(FALSE);
 }
 
 /*
  * Routine to add a parameter of type "type" and value "value" to the tree element "tree".
- * Returns nonzero on memory error.
+ * Returns true on memory error.
  */
-INTSML sdfi_addparameter(LISPTREE *tree, INTSML type, void *value)
+BOOLEAN sdfi_addparameter(LISPTREE *tree, INTBIG type, void *value)
 {
-	REGISTER INTSML *newparamtypes;
+	REGISTER INTBIG *newparamtypes;
 	REGISTER INTBIG i, newlimit;
 	REGISTER void **newparamvalues;
 
@@ -402,10 +402,10 @@ INTSML sdfi_addparameter(LISPTREE *tree, INTSML type, void *value)
 			/* intelligent determination of parameter needs */
 			newlimit = 3;
 		}
-		newparamtypes = (INTSML *)emalloc(newlimit * SIZEOFINTSML, io_tool->cluster);
-		if (newparamtypes == 0) return(1);
+		newparamtypes = (INTBIG *)emalloc(newlimit * SIZEOFINTBIG, io_tool->cluster);
+		if (newparamtypes == 0) return(TRUE);
 		newparamvalues = (void **)emalloc(newlimit * (sizeof (void *)), io_tool->cluster);
-		if (newparamvalues == 0) return(1);
+		if (newparamvalues == 0) return(TRUE);
 		for(i=0; i<tree->parameters; i++)
 		{
 			newparamtypes[i] = tree->paramtype[i];
@@ -424,7 +424,7 @@ INTSML sdfi_addparameter(LISPTREE *tree, INTSML type, void *value)
 	tree->paramvalue[tree->parameters] = value;
 	tree->parameters++;
 
-	return(0);
+	return(FALSE);
 }
 
 LISPTREE *sdfi_alloclisptree(void)
@@ -445,7 +445,7 @@ LISPTREE *sdfi_alloclisptree(void)
 
 void sdfi_killptree(LISPTREE *lt)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 
 	if (lt->keyword != 0) efree(lt->keyword);
 	for(i=0; i<lt->parameters; i++)
@@ -472,9 +472,9 @@ void sdfi_killptree(LISPTREE *lt)
 /*
  * Routine to parse the entire tree and annotate current facet.
  */
-INTSML sdfi_parsetree(LISPTREE *lt)
+BOOLEAN sdfi_parsetree(LISPTREE *lt)
 {
-	REGISTER INTSML i, total;
+	REGISTER INTBIG i, total;
 	REGISTER LISPTREE *sublt;
 
 	/* look through top level for "delayfile" */
@@ -486,24 +486,24 @@ INTSML sdfi_parsetree(LISPTREE *lt)
 		if (namesame(sublt->keyword, "delayfile") != 0) continue;
 
 		/* create the primitive */
-		if (sdfi_parsedelayfile(sublt) != 0) return(1);
+		if (sdfi_parsedelayfile(sublt)) return(TRUE);
 		total++;
 	}
 	if (total == 0)
 	{
 		ttyputerr(_("No DELAYFILE definition found"));
-		return(1);
+		return(TRUE);
 	}
-	ttyputmsg(_("Found %d DELAYFILE %s"), total, makeplural(_("definition"), total));
-	return(0);
+	ttyputmsg(_("Found %ld DELAYFILE %s"), total, makeplural(_("definition"), total));
+	return(FALSE);
 }
 
 /*
  * Routine to parse delayfile definition.
  */
-INTSML sdfi_parsedelayfile(LISPTREE *lt)
+BOOLEAN sdfi_parsedelayfile(LISPTREE *lt)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 	REGISTER LISPTREE *scanlt, *ltsdfversion, *ltdesign, *ltdate, *ltvendor, *ltprogram,
 		*ltversion, *ltdivider, *ltvoltage, *ltprocess, *lttemperature, *lttimescale;
 
@@ -519,7 +519,7 @@ INTSML sdfi_parsedelayfile(LISPTREE *lt)
 			if (ltsdfversion != 0)
 			{
 				ttyputerr(_("Multiple 'sdfversion' sections for a delayfile (line %ld)"), scanlt->lineno);
-				return(1);
+				return(TRUE);
 			}
 			sdfi_setstring(&sdfi_sdfversion, (char *)scanlt->paramvalue[0]);
 			if (io_verbose > 0) ttyputmsg(_("Found SDFVERSION: %s"), sdfi_sdfversion);
@@ -532,7 +532,7 @@ INTSML sdfi_parsedelayfile(LISPTREE *lt)
 			if (ltdesign != 0)
 			{
 				ttyputerr(_("Multiple 'design' sections for a delayfile (line %ld)"), scanlt->lineno);
-				return(1);
+				return(TRUE);
 			}
 			sdfi_setstring(&sdfi_design, (char *)scanlt->paramvalue[0]);
 			if (io_verbose > 0) ttyputmsg(_("Found DESIGN: %s"), sdfi_design);
@@ -542,7 +542,7 @@ INTSML sdfi_parsedelayfile(LISPTREE *lt)
 			{
 				ttyputerr(_("Current facet (%s) does not match DESIGN (%s).  Aborting SDF input"),
 					sdfi_curfacet->cell->cellname, sdfi_design);
-				return(1);
+				return(TRUE);
 			}
 			ltdesign = scanlt;
 			continue;
@@ -553,7 +553,7 @@ INTSML sdfi_parsedelayfile(LISPTREE *lt)
 			if (ltdate != 0)
 			{
 				ttyputerr(_("Multiple 'date' sections for a delayfile (line %ld)"), scanlt->lineno);
-				return(1);
+				return(TRUE);
 			}
 			sdfi_setstring(&sdfi_date, (char *)scanlt->paramvalue[0]);
 			if (io_verbose > 0) ttyputmsg(_("Found DATE: %s"), sdfi_date);
@@ -566,7 +566,7 @@ INTSML sdfi_parsedelayfile(LISPTREE *lt)
 			if (ltvendor != 0)
 			{
 				ttyputerr(_("Multiple 'vendor' sections for a delayfile (line %ld)"), scanlt->lineno);
-				return(1);
+				return(TRUE);
 			}
 			sdfi_setstring(&sdfi_vendor, (char *)scanlt->paramvalue[0]);
 			if (io_verbose > 0) ttyputmsg(_("Found VENDOR: %s"), sdfi_vendor);
@@ -579,7 +579,7 @@ INTSML sdfi_parsedelayfile(LISPTREE *lt)
 			if (ltprogram != 0)
 			{
 				ttyputerr(_("Multiple 'program' sections for a delayfile (line %ld)"), scanlt->lineno);
-				return(1);
+				return(TRUE);
 			}
 			sdfi_setstring(&sdfi_program, (char *)scanlt->paramvalue[0]);
 			if (io_verbose > 0) ttyputmsg(_("Found PROGRAM: %s"), sdfi_program);
@@ -592,7 +592,7 @@ INTSML sdfi_parsedelayfile(LISPTREE *lt)
 			if (ltversion != 0)
 			{
 				ttyputerr(_("Multiple 'version' sections for a delayfile (line %ld)"), scanlt->lineno);
-				return(1);
+				return(TRUE);
 			}
 			sdfi_setstring(&sdfi_version, (char *)scanlt->paramvalue[0]);
 			if (io_verbose > 0) ttyputmsg(_("Found VERSION: %s"), sdfi_version);
@@ -605,7 +605,7 @@ INTSML sdfi_parsedelayfile(LISPTREE *lt)
 			if (ltdivider != 0)
 			{
 				ttyputerr(_("Multiple 'divider' sections for a delayfile (line %ld)"), scanlt->lineno);
-				return(1);
+				return(TRUE);
 			}
 
 			if (io_verbose > 0) ttyputmsg(_("Found DIVIDER: %s"), (char *)scanlt->paramvalue[0]);
@@ -614,7 +614,7 @@ INTSML sdfi_parsedelayfile(LISPTREE *lt)
 			if (namesame(sdfi_divider, ".") != 0 && namesame(sdfi_divider, "/") != 0)
 			{
 				ttyputerr(_("illegal DIVIDER - %s (line %ld)"), sdfi_divider, scanlt->lineno);
-				return(1);
+				return(TRUE);
 			}
 			ltdivider = scanlt;
 			continue;
@@ -625,7 +625,7 @@ INTSML sdfi_parsedelayfile(LISPTREE *lt)
 			if (ltvoltage != 0)
 			{
 				ttyputerr(_("Multiple 'voltage' sections for a delayfile (line %ld)"), scanlt->lineno);
-				return(1);
+				return(TRUE);
 			}
 			sdfi_setstring(&sdfi_voltage, (char *)scanlt->paramvalue[0]);
 			if (io_verbose > 0) ttyputmsg(_("Found VOLTAGE: %s"), sdfi_voltage);
@@ -638,7 +638,7 @@ INTSML sdfi_parsedelayfile(LISPTREE *lt)
 			if (ltprocess != 0)
 			{
 				ttyputerr(_("Multiple 'process' sections for a delayfile (line %ld)"), scanlt->lineno);
-				return(1);
+				return(TRUE);
 			}
 			sdfi_setstring(&sdfi_process, (char *)scanlt->paramvalue[0]);
 			if (io_verbose > 0) ttyputmsg(_("Found PROCESS: %s"), sdfi_process);
@@ -651,7 +651,7 @@ INTSML sdfi_parsedelayfile(LISPTREE *lt)
 			if (lttemperature != 0)
 			{
 				ttyputerr(_("Multiple 'temperature' sections for a delayfile (line %ld)"), scanlt->lineno);
-				return(1);
+				return(TRUE);
 			}
 			sdfi_setstring(&sdfi_temperature, (char *)scanlt->paramvalue[0]);
 			if (io_verbose > 0) ttyputmsg(_("Found TEMPERATURE: %s"), sdfi_temperature);
@@ -664,28 +664,28 @@ INTSML sdfi_parsedelayfile(LISPTREE *lt)
 			if (lttimescale != 0)
 			{
 				ttyputerr(_("Multiple 'timescale' sections for a delayfile (line %ld)"), scanlt->lineno);
-				return(1);
+				return(TRUE);
 			}
 			sdfi_setstring(&sdfi_timescale, (char *)scanlt->paramvalue[0]);
 			if (io_verbose > 0) ttyputmsg(_("Found TIMESCALE: %s"), sdfi_timescale);
 			lttimescale = scanlt;
-			if (sdfi_parsetimescale(scanlt) != 0) return(1);
+			if (sdfi_parsetimescale(scanlt)) return(TRUE);
 			continue;
 		}
 
 		if (namesame(scanlt->keyword, "cell") == 0)
 		{
-			if (sdfi_parsecell(scanlt) != 0) return(1);
+			if (sdfi_parsecell(scanlt)) return(TRUE);
 		}
 	}
 
-	return(0);
+	return(FALSE);
 }
 
 /*
  * Routine to parse timescale definition.
  */
-INTSML sdfi_parsetimescale(LISPTREE *lt)
+BOOLEAN sdfi_parsetimescale(LISPTREE *lt)
 {
 	char t1[200];
 
@@ -699,7 +699,7 @@ INTSML sdfi_parsetimescale(LISPTREE *lt)
 	} else
 	{
 		ttyputerr(_("illegal TIMESCALE - too many parameters (line %ld)"), lt->lineno);
-		return(1);
+		return(TRUE);
 	}
 
 	if      (namesame(t1,   "1us") == 0 || namesame(t1,   "1.0us") == 0) sdfi_timeconvert = 1000000;
@@ -714,20 +714,20 @@ INTSML sdfi_parsetimescale(LISPTREE *lt)
 	else
 	{
 		ttyputerr(_("illegal TIMESCALE - unknown unit or value (line %ld)"), lt->lineno);
-		return(1);
+		return(TRUE);
 	}
 
 	if (io_verbose > 0) ttyputmsg(_("timescale conversion = %ld"), sdfi_timeconvert);
 
-	return(0);
+	return(FALSE);
 }
 
 /*
  * Routine to parse cell definition.
  */
-INTSML sdfi_parsecell(LISPTREE *lt)
+BOOLEAN sdfi_parsecell(LISPTREE *lt)
 {
-	REGISTER INTSML i, j;
+	REGISTER INTBIG i, j;
 	INTBIG sl, len;
 	REGISTER LISPTREE *scanlt, *ltcelltype, *ltinstance;
 	NODEINST *ni;
@@ -746,7 +746,7 @@ INTSML sdfi_parsecell(LISPTREE *lt)
 			if (ltcelltype != 0)
 			{
 				ttyputerr(_("Multiple 'celltype' sections for a cell (line %ld)"), scanlt->lineno);
-				return(1);
+				return(TRUE);
 			}
 			sdfi_setstring(&sdfi_celltype, (char *)scanlt->paramvalue[0]);
 			if (io_verbose > 0) ttyputmsg(_("Found CELLTYPE: %s"), sdfi_celltype);
@@ -758,7 +758,7 @@ INTSML sdfi_parsecell(LISPTREE *lt)
 			if (ltinstance != 0)
 			{
 				ttyputerr(_("Multiple 'instance' sections for a cell (line %ld)"), scanlt->lineno);
-				return(1);
+				return(TRUE);
 			}
 			sdfi_setstring(&sdfi_instance, (char *)scanlt->paramvalue[0]);
 			if (io_verbose > 0) ttyputmsg(_("Found INSTANCE: %s"), sdfi_instance);
@@ -769,7 +769,7 @@ INTSML sdfi_parsecell(LISPTREE *lt)
 			if (ni != NONODEINST)
 			{
 				sa = newstringarray(io_tool->cluster);
-				if (sa == 0) return(1);
+				if (sa == 0) return(TRUE);
 				(void)initinfstr();
 				(void)addstringtoinfstr(sdfi_instance);
 				addtostringarray(sa, returninfstr());
@@ -787,7 +787,7 @@ INTSML sdfi_parsecell(LISPTREE *lt)
 			{
 				ttyputerr(_("No matching node for CELLTYPE: %s, INSTANCE: %s. Aborting SDF input"),
 					sdfi_celltype, sdfi_instance);
-				return(1);
+				return(TRUE);
 			}
 
 			ltinstance = scanlt;
@@ -795,18 +795,18 @@ INTSML sdfi_parsecell(LISPTREE *lt)
 		}
 		if (namesame(scanlt->keyword, "delay") == 0)
 		{
-			if (sdfi_parsedelay(scanlt, ni) != 0) return(1);
+			if (sdfi_parsedelay(scanlt, ni)) return(TRUE);
 		}
 	}
-	return(0);
+	return(FALSE);
 }
 
 /*
  * Routine to parse delay definition.
  */
-INTSML sdfi_parsedelay(LISPTREE *lt, NODEINST *ni)
+BOOLEAN sdfi_parsedelay(LISPTREE *lt, NODEINST *ni)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 	REGISTER LISPTREE *scanlt;
 
 	/* find all the pieces of delay */
@@ -816,22 +816,22 @@ INTSML sdfi_parsedelay(LISPTREE *lt, NODEINST *ni)
 		scanlt = (LISPTREE *)lt->paramvalue[i];
 		if (namesame(scanlt->keyword, "absolute") == 0)
 		{
-			if (sdfi_parseabsolute(scanlt, ni) != 0) return(1);
+			if (sdfi_parseabsolute(scanlt, ni)) return(TRUE);
 		}
 		if (namesame(scanlt->keyword, "increment") == 0)
 		{
-			if (sdfi_parseincrement(scanlt, ni) != 0) return(1);
+			if (sdfi_parseincrement(scanlt, ni)) return(TRUE);
 		}
 	}
-	return(0);
+	return(FALSE);
 }
 
 /*
  * Routine to parse delay definition.
  */
-INTSML sdfi_parseabsolute(LISPTREE *lt, NODEINST *ni)
+BOOLEAN sdfi_parseabsolute(LISPTREE *lt, NODEINST *ni)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 	REGISTER LISPTREE *scanlt;
 
 	/* find all the pieces of absolute */
@@ -841,23 +841,23 @@ INTSML sdfi_parseabsolute(LISPTREE *lt, NODEINST *ni)
 		scanlt = (LISPTREE *)lt->paramvalue[i];
 		if (namesame(scanlt->keyword, "port") == 0)
 		{
-			if (sdfi_parseport(scanlt, ni) != 0) return(1);
+			if (sdfi_parseport(scanlt, ni)) return(TRUE);
 		}
 		if (namesame(scanlt->keyword, "iopath") == 0)
 		{
-			if (sdfi_parseiopath(scanlt, ni) != 0) return(1);
+			if (sdfi_parseiopath(scanlt, ni)) return(TRUE);
 		}
 	}
 
-	return(0);
+	return(FALSE);
 }
 
 /*
  * Routine to parse delay definition.
  */
-INTSML sdfi_parseincrement(LISPTREE *lt, NODEINST *ni)
+BOOLEAN sdfi_parseincrement(LISPTREE *lt, NODEINST *ni)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 	REGISTER LISPTREE *scanlt;
 
 	/* find all the pieces of increment */
@@ -867,23 +867,23 @@ INTSML sdfi_parseincrement(LISPTREE *lt, NODEINST *ni)
 		scanlt = (LISPTREE *)lt->paramvalue[i];
 		if (namesame(scanlt->keyword, "port") == 0)
 		{
-			if (sdfi_parseport(scanlt, ni) != 0) return(1);
+			if (sdfi_parseport(scanlt, ni)) return(TRUE);
 		}
 		if (namesame(scanlt->keyword, "iopath") == 0)
 		{
-			if (sdfi_parseiopath(scanlt, ni) != 0) return(1);
+			if (sdfi_parseiopath(scanlt, ni)) return(TRUE);
 		}
 	}
 
-	return(0);
+	return(FALSE);
 }
 
 /*
  * Routine to parse port definition.
  */
-INTSML sdfi_parseport(LISPTREE *lt, NODEINST *ni)
+BOOLEAN sdfi_parseport(LISPTREE *lt, NODEINST *ni)
 {
-	REGISTER INTSML i, j, rvalues;
+	REGISTER INTBIG i, j, rvalues;
 	INTBIG sl, len;
 	REGISTER LISPTREE *scanlt;
 	PORTARCINST *pi;
@@ -987,7 +987,7 @@ INTSML sdfi_parseport(LISPTREE *lt, NODEINST *ni)
 	}
 
 	sa = newstringarray(io_tool->cluster);
-	if (sa == 0) return(1);
+	if (sa == 0) return(TRUE);
 
 	/* create string of transition delay values */
 	(void)initinfstr();
@@ -1026,15 +1026,15 @@ INTSML sdfi_parseport(LISPTREE *lt, NODEINST *ni)
 
 	if (portname != 0) efree((char *)portname);
 	for(i=0; i<12; i++) if (rvl[i].tvalue != 0) efree((char *)rvl[i].tvalue);
-	return(0);
+	return(FALSE);
 }
 
 /*
  * Routine to parse iopath definition.
  */
-INTSML sdfi_parseiopath(LISPTREE *lt, NODEINST *ni)
+BOOLEAN sdfi_parseiopath(LISPTREE *lt, NODEINST *ni)
 {
-	REGISTER INTSML i, j, rvalues;
+	REGISTER INTBIG i, j, rvalues;
 	INTBIG sl, len;
 	REGISTER LISPTREE *scanlt;
 	VARIABLE *var;
@@ -1136,7 +1136,7 @@ INTSML sdfi_parseiopath(LISPTREE *lt, NODEINST *ni)
 	}
 
 	sa = newstringarray(io_tool->cluster);
-	if (sa == 0) return(1);
+	if (sa == 0) return(TRUE);
 
 	/* create string of transition delay values */
 	(void)initinfstr();
@@ -1173,7 +1173,7 @@ INTSML sdfi_parseiopath(LISPTREE *lt, NODEINST *ni)
 	if (iportname != 0) efree((char *)iportname);
 	if (oportname != 0) efree((char *)oportname);
 	for(i=0; i<12; i++) if (rvl[i].tvalue != 0) efree((char *)rvl[i].tvalue);
-	return(0);
+	return(FALSE);
 }
 
 /*
@@ -1184,7 +1184,7 @@ NODEINST *sdfi_getcellinstance(char *celltype, char *instance)
 	NODEINST *ni;
 	VARIABLE *var;
 	char *pt, **instlist, *str, tmp[256];
-	INTSML i, count = 1;
+	INTBIG i, count = 1;
 
 	ni = NONODEINST;
 
@@ -1193,7 +1193,7 @@ NODEINST *sdfi_getcellinstance(char *celltype, char *instance)
 	{
 		for(ni = sdfi_curfacet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		{
-			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name);
+			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
 			if (var != NOVARIABLE)
 			{
 				if (strcmp((char *)var->addr, instance) == 0) break;
@@ -1226,7 +1226,7 @@ NODEINST *sdfi_getcellinstance(char *celltype, char *instance)
 	for (i=0; i<count; i++)
 	{
 		str = getkeyword(&pt, sdfi_divider);
-		if (allocstring(&instlist[i], str, io_tool->cluster) != 0) return(NONODEINST);
+		if (allocstring(&instlist[i], str, io_tool->cluster)) return(NONODEINST);
 		(void)tonextchar(&pt);
 	}
 
@@ -1234,7 +1234,7 @@ NODEINST *sdfi_getcellinstance(char *celltype, char *instance)
 	i = 0;
 	for(ni = sdfi_curfacet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
-		var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name);
+		var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
 		if (var != NOVARIABLE)
 		{
 			if (strcmp((char *)var->addr, instlist[i]) == 0)
@@ -1278,7 +1278,7 @@ NODEINST *sdfi_getcellinstance(char *celltype, char *instance)
 char *sdfi_converttops(char *tstring)
 {
 	INTBIG d1, d2, d3;
-	INTSML i;
+	INTBIG i;
 	char *pt, *str, t1[100], t2[100], t3[100];
 	static char ts[256];
 
