@@ -63,8 +63,8 @@ typedef struct
 {
 	char         *suename;
 	NODEPROTO   **intproto;
-	INTSML        netateoutput;
-	INTSML        rotation;
+	INTBIG        netateoutput;
+	INTBIG        rotation;
 	INTBIG        xoffset;
 	INTBIG        yoffset;
 	INTBIG        detailbits;
@@ -117,9 +117,6 @@ SUEEQUIV io_sueequivs[] =
 	{"capacitor",  &sch_capacitorprim,  0,   0,   0,  0, 0,            2, io_suecapacitorwires},
 	{"resistor",   &sch_resistorprim,   0, 900,   0,  0, 0,            2, io_sueresistorwires},
 	{"inductor",   &sch_inductorprim,   0,   0,   0,  0, 0,            0, 0},
-	{"dc_supply",  &sch_sourceprim,     0,   0,   0, H0, SOURCEVS,     2, io_suesourcewires},
-	{"dc_Isupply", &sch_sourceprim,     0,   0,   0, H0, SOURCECURSRC, 2, io_suesourcewires},
-	{"ammeter",    &sch_sourceprim,     0,   0,   0,  0, SOURCECURMTR, 0, 0},
 	{"cccs",       &sch_twoportprim,    0,   0,  Q1,-S6, TWOPCCCS,     4, io_suetwoportwires},
 	{"ccvs",       &sch_twoportprim,    0,   0,  Q1,-S6, TWOPCCVS,     4, io_suetwoportwires},
 	{"vcvs",       &sch_twoportprim,    0,   0,  Q1,-S6, TWOPVCVS,     4, io_suetwoportwires},
@@ -171,18 +168,15 @@ static char **io_suedirectories;
 static FILE  *io_suefilein;
 
 /* prototypes for local routines */
-static INTSML     io_sueadddirectory(char *directory);
-static INTBIG     io_suearraylength(char *name);
+static BOOLEAN    io_sueadddirectory(char *directory);
 static void       io_suecleardirectories(void);
-static NODEPROTO *io_suecreatepseudo(NODEPROTO *proto, INTBIG count);
-static char      *io_sueexpandname(char *portname, INTBIG count, INTBIG which);
 static char      *io_suefindbusname(ARCINST *ai);
-static INTSML     io_suefindnode(INTBIG *x, INTBIG *y, INTBIG ox, INTBIG oy, NODEPROTO *np,
+static BOOLEAN    io_suefindnode(INTBIG *x, INTBIG *y, INTBIG ox, INTBIG oy, NODEPROTO *np,
 					NODEINST **ni, PORTPROTO **pp, NODEINST *notthisnode, INTBIG lambda);
 static NODEINST  *io_suefindpinnode(INTBIG x, INTBIG y, NODEPROTO *np, PORTPROTO **thepp);
 static void       io_suefreenets(SUENET *firstsn);
 static void       io_suefreewires(SUEWIRE *firstsw);
-static INTSML     io_suegetnextline(char **keywords, INTSML curlydepth);
+static INTBIG     io_suegetnextline(char **keywords, INTBIG curlydepth);
 static NODEPROTO *io_suegetnodeproto(LIBRARY *lib, char *protoname);
 static void       io_suekillnet(SUENET *sn);
 static void       io_suekillwire(SUEWIRE *sw);
@@ -193,7 +187,7 @@ static SUENET    *io_suenewnet(void);
 static SUEWIRE   *io_suenewwire(void);
 static void       io_sueplacenets(SUENET *firstsuenet, NODEPROTO *facet);
 static void       io_sueparseparameters(char **keywords, INTBIG count, INTBIG *x, INTBIG *y, INTBIG lambda,
-					INTSML *rot, INTSML *trn, INTBIG *type, char **thename, char **thelabel, char **thetext);
+					INTBIG *rot, INTBIG *trn, INTBIG *type, char **thename, char **thelabel, char **thetext);
 static void       io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *facet, INTBIG lambda);
 static NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname);
 static NODEPROTO *io_suereadfromdisk(LIBRARY *lib, char *name);
@@ -223,7 +217,7 @@ void io_freesuememory(void)
 	io_suecleardirectories();
 }
 
-INTSML io_readsuelibrary(LIBRARY *lib)
+BOOLEAN io_readsuelibrary(LIBRARY *lib)
 {
 	REGISTER INTBIG len, i, filecount;
 	REGISTER NODEPROTO *topfacet;
@@ -236,7 +230,7 @@ INTSML io_readsuelibrary(LIBRARY *lib)
 	if (io_suefilein == 0)
 	{
 		ttyputerr(_("File %s not found"), lib->libfile);
-		return(1);
+		return(TRUE);
 	}
 
 	/* determine the facet name */
@@ -259,7 +253,7 @@ INTSML io_readsuelibrary(LIBRARY *lib)
 	for(i = len-1; i>0; i--)
 		if (topdirname[i] == DIRSEP) break;
 	topdirname[i+1] = 0;
-	if (io_sueadddirectory(topdirname) != 0) return(1);
+	if (io_sueadddirectory(topdirname)) return(TRUE);
 
 	/* find all subdirectories that start with "suelib_" and include them in the search */
 	filecount = filesindirectory(topdirname, &filelist);
@@ -269,10 +263,8 @@ INTSML io_readsuelibrary(LIBRARY *lib)
 		strcpy(dirname, topdirname);
 		strcat(dirname, filelist[i]);
 		if (fileexistence(dirname) != 2) continue;
-		len = strlen(dirname);
-		dirname[len++] = DIRSEP;
-		dirname[len] = 0;
-		if (io_sueadddirectory(dirname) != 0) return(1);
+		strcat(dirname, DIRSEPSTR);
+		if (io_sueadddirectory(dirname)) return(TRUE);
 	}
 
 	/* see if the current directory is inside of a SUELIB */
@@ -290,19 +282,17 @@ INTSML io_readsuelibrary(LIBRARY *lib)
 			strcpy(dirname, topdirname);
 			strcat(dirname, filelist[i]);
 			if (fileexistence(dirname) != 2) continue;
-			len = strlen(dirname);
-			dirname[len++] = DIRSEP;
-			dirname[len] = 0;
-			if (io_sueadddirectory(dirname) != 0) return(1);
+			strcat(dirname, DIRSEPSTR);
+			if (io_sueadddirectory(dirname)) return(TRUE);
 		}
 	}
 
 	/* prepare for input */
 	io_suefilesize = filesize(io_suefilein);
-	if (DiaInitDialog(&us_progressdialog) != 0)
+	if (DiaInitDialog(&us_progressdialog))
 	{
 		xclose(io_suefilein);
-		return(1);
+		return(TRUE);
 	}
 	io_suelineno = 0;
 
@@ -319,7 +309,7 @@ INTSML io_readsuelibrary(LIBRARY *lib)
 	xclose(io_suefilein);
 	ttyputmsg(_("%s read"), truesuefile);
 
-	return(0);
+	return(FALSE);
 }
 
 /*
@@ -331,12 +321,12 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 	char suevarname[200], *pt, *cpt, *startkey, save;
 	char **argnames, **argvalues, **newargnames, **newargvalues;
 	INTBIG outline[MAXICONPOINTS*2], x, y, type, dx, dy, px, py, pinx, piny, xoff, yoff,
-		numargs, namestrlen;
+		numargs, namestrlen, rot, trn, rotation;
 	REGISTER INTBIG count, i, lx, hx, ly, hy, curly, xshrink, yshrink,
 		varcount, varindex, varoffset, pos, invertoutput, lambda, detailbits,
 		keycount, cx, cy, p1x, p1y, p2x, p2y, start, extent, numextrawires, len,
-		iconx, icony, placeicon, newaddr, newtype, varissize;
-	INTSML rot, trn, rotation;
+		iconx, icony, newaddr, newtype, xpos, ypos;
+	REGISTER BOOLEAN halvesize, placeicon, varissize, isparam;
 	XARRAY trans;
 	double rextent, rstart;
 	REGISTER NODEPROTO *facet, *schemfacet, *iconfacet, *proto, *np;
@@ -380,7 +370,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 
 			if (count < 2)
 			{
-				ttyputerr(_("Facet %s, line %d: 'proc' is missing arguments: %s"),
+				ttyputerr(_("Facet %s, line %ld: 'proc' is missing arguments: %s"),
 					facetname, io_suelineno, io_sueorigline);
 				continue;
 			}
@@ -393,8 +383,8 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 					(void)addstringtoinfstr(facetname); else
 						(void)addstringtoinfstr(&keywords[1][10]);
 				(void)addstringtoinfstr("{sch}");
-				schemfacet = facet = newnodeproto(returninfstr(), lib);
-				placeicon = 0;
+				schemfacet = facet = us_newnodeproto(returninfstr(), lib);
+				placeicon = FALSE;
 			} else if (namesamen(keywords[1], "ICON_", 5) == 0)
 			{
 				/* create the icon facet */
@@ -403,10 +393,10 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 					(void)addstringtoinfstr(facetname); else
 						(void)addstringtoinfstr(&keywords[1][5]);
 				(void)addstringtoinfstr("{ic}");
-				iconfacet = facet = newnodeproto(returninfstr(), lib);
+				iconfacet = facet = us_newnodeproto(returninfstr(), lib);
 			} else
 			{
-				ttyputerr(_("Facet %s, line %d: unknown 'proc' statement: %s"),
+				ttyputerr(_("Facet %s, line %ld: unknown 'proc' statement: %s"),
 					facetname, io_suelineno, io_sueorigline);
 			}
 			continue;
@@ -417,7 +407,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 		{
 			if (count < 2)
 			{
-				ttyputerr(_("Facet %s, line %d: 'make' is missing arguments: %s"),
+				ttyputerr(_("Facet %s, line %ld: 'make' is missing arguments: %s"),
 					facetname, io_suelineno, io_sueorigline);
 				continue;
 			}
@@ -448,7 +438,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 				{
 					/* queue icon placement */
 					iconx = x;   icony = y;
-					placeicon = 1;
+					placeicon = TRUE;
 				}
 				continue;
 			}
@@ -575,31 +565,10 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 			/* now check for references to facets */
 			if (proto == NONODEPROTO)
 			{
-				/* see if the reference is arrayed */
-				len = io_suearraylength(thename);
-				if (len > 1)
-				{
-					/* arrayed node: search for the pseudo version */
-					strcpy(suevarname, keywords[1]);
-					strcat(suevarname, thename);
-					sprintf(suevarname, "%s-Size-%ld", keywords[1], len);
-					proto = io_suegetnodeproto(lib, suevarname);
-					if (proto == NONODEPROTO)
-					{
-						/* no pseudo version: create it from unarrayed version */
-						proto = io_suegetnodeproto(lib, keywords[1]);
-						if (proto == NONODEPROTO)
-							proto = io_suereadfromdisk(lib, keywords[1]);
-						if (proto != NONODEPROTO)
-							proto = io_suecreatepseudo(proto, len);
-					}
-				} else
-				{
-					/* nonarrayed node: find it or read it from disk */
-					proto = io_suegetnodeproto(lib, keywords[1]);
-					if (proto == NONODEPROTO)
-						proto = io_suereadfromdisk(lib, keywords[1]);
-				}
+				/* find node or read it from disk */
+				proto = io_suegetnodeproto(lib, keywords[1]);
+				if (proto == NONODEPROTO)
+					proto = io_suereadfromdisk(lib, keywords[1]);
 
 				/* set proper offsets for the facet */
 				if (proto != NONODEPROTO)
@@ -679,7 +648,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 					ppt = io_suenewexport(facet, ni, pp, thename);
 					if (ppt == NOPORTPROTO)
 					{
-						ttyputmsg(_("Facet %s, line %d, could not create port %s"), 
+						ttyputmsg(_("Facet %s, line %ld, could not create port %s"), 
 							facetname, io_suelineno, thename);
 					} else
 					{
@@ -691,10 +660,11 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 				} else
 				{
 					/* just name the node */
-					var = setvalkey((INTBIG)ni, VNODEINST, el_node_name, (INTBIG)thename,
+					var = setvalkey((INTBIG)ni, VNODEINST, el_node_name_key, (INTBIG)thename,
 						VSTRING|VDISPLAY);
 					if (var != NOVARIABLE)
 						defaulttextsize(3, var->textdescript);
+					net_setnodewidth(ni);
 				}
 			}
 
@@ -719,27 +689,38 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 					namesame(keywords[i], "-orient") == 0 ||
 					namesame(keywords[i], "-type") == 0 ||
 					namesame(keywords[i], "-name") == 0) continue;
-				varissize = 0;
+				varissize = FALSE;
+				halvesize = FALSE;
+				isparam = FALSE;
 				if (namesame(&keywords[i][1], "w") == 0)
 				{
 					strcpy(suevarname, "ATTR_width");
-					varissize = 1;
+					varissize = TRUE;
+					xpos = 2;
+					ypos = -4;
 				} else if (namesame(&keywords[i][1], "l") == 0)
 				{
 					strcpy(suevarname, "ATTR_length");
-					varissize = 1;
+					varissize = TRUE;
+					xpos = -2;
+					ypos = -4;
+					halvesize = TRUE;
 				} else
 				{
-					sprintf(suevarname, "SUE_%s", &keywords[i][1]);
+					sprintf(suevarname, "ATTR_%s", &keywords[i][1]);
 					for(pt = suevarname; *pt != 0; pt++) if (*pt == ' ')
 					{
-						ttyputmsg(_("Facet %s, line %d, bad variable name (%s)"), 
+						ttyputmsg(_("Facet %s, line %ld, bad variable name (%s)"), 
 							facetname, io_suelineno, suevarname);
 						break;
 					}
+					xpos = 0;
+					pos = (ni->highy - ni->lowy) / 2 - varindex * varoffset;
+					ypos = pos * 4 / lambda;
+					isparam = TRUE;
 				}
 				newtype = VSTRING;
-				if (varissize != 0)
+				if (varissize)
 				{
 					newaddr = atola(keywords[i+1]) * WHOLE / lib->lambda[el_curtech->techindex];
 					if (newaddr != 0) newtype = VFRACT; else
@@ -761,9 +742,15 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 				{
 					defaulttextdescript(var->textdescript, ni->geom);
 					varoffset = (ni->highy - ni->lowy) / (varcount+1);
-					pos = (ni->highy - ni->lowy) / 2 - varindex * varoffset;
 					varindex++;
-					TDSETOFF(var->textdescript, TDGETXOFF(var->textdescript), pos * 4 / lambda);
+					TDSETOFF(var->textdescript, xpos, ypos);
+					if (halvesize)
+						TDSETSIZE(var->textdescript, TDGETSIZE(var->textdescript)/2);
+					if (isparam)
+					{
+						TDSETISPARAM(var->textdescript, VTISPARAMETER);
+						TDSETDISPPART(var->textdescript, VTDISPLAYNAMEVALUE);
+					}
 				}
 			}
 			continue;
@@ -789,19 +776,18 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 				&type, &thename, &thelabel, &thetext);
 			strcpy(suevarname, thename);
 
-			if (net_buswidth(suevarname) > 1) proto = sch_buspinprim; else
-				proto = sch_wirepinprim;
+			proto = sch_buspinprim;
 			defaultnodesize(proto, &px, &py);
 			lx = x - px/2;   hx = lx + px;
 			ly = y - py/2;   hy = ly + py;
-			ni = newnodeinst(proto, lx, hx, ly, hy, trn, (INTSML)(rot%3600), facet);
+			ni = newnodeinst(proto, lx, hx, ly, hy, trn, rot%3600, facet);
 			if (ni == NONODEINST) continue;
 			endobjectchange((INTBIG)ni, VNODEINST);
 
 			ppt = io_suenewexport(facet, ni, proto->firstportproto, suevarname);
 			if (ppt == NOPORTPROTO)
 			{
-				ttyputmsg(_("Facet %s, line %d, could not create port %s"), 
+				ttyputmsg(_("Facet %s, line %ld, could not create port %s"), 
 					facetname, io_suelineno, suevarname);
 			} else
 			{
@@ -818,7 +804,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 		{
 			if (count != 9)
 			{
-				ttyputerr(_("Facet %s, line %d: needs 9 arguments, has %d: %s"),
+				ttyputerr(_("Facet %s, line %ld: needs 9 arguments, has %ld: %s"),
 					facetname, io_suelineno, count, io_sueorigline);
 				continue;
 			}
@@ -876,7 +862,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 			{
 				outline[i*2] -= cx;   outline[i*2+1] -= cy;
 			}
-			(void)setvalkey((INTBIG)ni, VNODEINST, el_trace, (INTBIG)outline,
+			(void)setvalkey((INTBIG)ni, VNODEINST, el_trace_key, (INTBIG)outline,
 				VINTEGER|VISARRAY|((keycount*2)<<VLENGTHSH));
 			endobjectchange((INTBIG)ni, VNODEINST);
 			continue;
@@ -888,7 +874,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 			/* extract parameters */
 			if (namesame(keywords[1], "$args") != 0)
 			{
-				ttyputerr(_("Facet %s, line %d: has unrecognized 'icon_setup'"),
+				ttyputerr(_("Facet %s, line %ld: has unrecognized 'icon_setup'"),
 					facetname, io_suelineno);
 				continue;
 			}
@@ -1019,11 +1005,12 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 			continue;
 		}
 
-		ttyputerr(_("Facet %s, line %d: unknown keyword (%s): %s"), facetname,
+		ttyputerr(_("Facet %s, line %ld: unknown keyword (%s): %s"), facetname,
 			io_suelineno, keywords[0], io_sueorigline);
 	}
+
 	/* place an icon instance in the schematic if requested */
-	if (placeicon != 0 && schemfacet != NONODEPROTO &&
+	if (placeicon && schemfacet != NONODEPROTO &&
 		iconfacet != NONODEPROTO)
 	{
 		px = iconfacet->highx - iconfacet->lowx;
@@ -1080,11 +1067,10 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
  * "-text"    placed into "thetext".
  */
 void io_sueparseparameters(char **keywords, INTBIG count, INTBIG *x, INTBIG *y, INTBIG lambda,
-	INTSML *rot, INTSML *trn, INTBIG *type, char **thename, char **thelabel, char **thetext)
+	INTBIG *rot, INTBIG *trn, INTBIG *type, char **thename, char **thelabel, char **thetext)
 {
 	char *pt;
-	REGISTER INTSML textloc;
-	REGISTER INTBIG i;
+	REGISTER INTBIG textloc, i;
 
 	*x = *y = 0;
 	*rot = 0;
@@ -1230,7 +1216,8 @@ INTBIG io_suemakey(INTBIG y, INTBIG lambda)
 void io_sueplacenets(SUENET *firstsuenet, NODEPROTO *facet)
 {
 	SUENET *sn;
-	REGISTER INTBIG pass, isbus;
+	REGISTER INTBIG pass;
+	REGISTER BOOLEAN isbus;
 	REGISTER ARCINST *ai, *bestai;
 	REGISTER INTBIG cx, cy, dist, bestdist, sea;
 	REGISTER GEOM *geom;
@@ -1253,7 +1240,7 @@ void io_sueplacenets(SUENET *firstsuenet, NODEPROTO *facet)
 			}
 
 			/* see if this is a bus */
-			if (net_buswidth(sn->label) > 1) isbus = 1; else isbus = 0;
+			if (net_buswidth(sn->label) > 1) isbus = TRUE; else isbus = FALSE;
 
 			sea = initsearch(sn->x, sn->x, sn->y, sn->y, facet);
 			bestai = NOARCINST;
@@ -1261,9 +1248,9 @@ void io_sueplacenets(SUENET *firstsuenet, NODEPROTO *facet)
 			{
 				geom = nextobject(sea);
 				if (geom == NOGEOM) break;
-				if (geom->entrytype != OBJARCINST) continue;
+				if (geom->entryisnode) continue;
 				ai = geom->entryaddr.ai;
-				if (isbus != 0)
+				if (isbus)
 				{
 					if (ai->proto != sch_busarc) continue;
 				} else
@@ -1334,7 +1321,7 @@ char *io_suefindbusname(ARCINST *ai)
 			len = strlen(pseudobusname);
 			for(oai = ai->parent->firstarcinst; oai != NOARCINST; oai = oai->nextarcinst)
 			{
-				var = getvalkey((INTBIG)oai, VARCINST, VSTRING, el_arc_name);
+				var = getvalkey((INTBIG)oai, VARCINST, VSTRING, el_arc_name_key);
 				if (var == NOVARIABLE) continue;
 				pt = (char *)var->addr;
 				if (namesame(pseudobusname, pt) == 0) break;
@@ -1362,7 +1349,7 @@ char *io_suesearchbusname(ARCINST *ai)
 	ai->temp1 = 1;
 	if (ai->proto == sch_busarc)
 	{
-		var = getvalkey((INTBIG)ai, VARCINST, VSTRING, el_arc_name);
+		var = getvalkey((INTBIG)ai, VARCINST, VSTRING, el_arc_name_key);
 		if (var != NOVARIABLE)
 		{
 			(void)initinfstr();
@@ -1418,14 +1405,17 @@ void io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *fac
 {
 	SUEWIRE *sw, *osw;
 	SUENET *sn;
-	REGISTER INTBIG i, j, propagatedbus, isbus, wid, px, py, lx, hx, ly, hy;
-	INTBIG xsize, ysize;
+	REGISTER INTBIG i, j, wid, px, py, lx, hx, ly, hy, sea, bits;
+	REGISTER BOOLEAN propagatedbus, isbus;
+	INTBIG xsize, ysize, x, y, ox, oy;
 	REGISTER NODEPROTO *proto;
+	REGISTER GEOM *geom;
 	REGISTER PORTEXPINST *pe;
 	NODEINST *ni;
-	REGISTER NODEINST *bottomni;
+	REGISTER ARCPROTO *ap;
+	REGISTER NODEINST *bottomni, *oni;
 	PORTPROTO *pp;
-	REGISTER PORTPROTO *bottompp;
+	REGISTER PORTPROTO *bottompp, *opp;
 	REGISTER ARCINST *ai;
 
 	/* mark all wire ends as "unassigned", all wire types as unknown */
@@ -1465,7 +1455,7 @@ void io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *fac
 				sw->pp[i] = pp;
 
 				/* determine whether this port is a bus */
-				isbus = 0;
+				isbus = FALSE;
 				bottomni = ni;   bottompp = pp;
 				while (bottomni->proto->primindex == 0)
 				{
@@ -1473,17 +1463,17 @@ void io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *fac
 					bottompp = bottompp->subportproto;
 				}
 				if (bottomni->proto == sch_wireconprim) continue;
-				if (bottomni->proto == sch_buspinprim) isbus = 1;
-				if (isbus == 0 && ni->proto == sch_offpageprim)
+				if (bottomni->proto == sch_buspinprim) isbus = TRUE;
+				if (!isbus && ni->proto == sch_offpageprim)
 				{
 					/* see if there is a bus port on this primitive */
 					for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
 					{
-						if (net_buswidth(pe->exportproto->protoname) > 1) isbus = 1;
+						if (net_buswidth(pe->exportproto->protoname) > 1) isbus = TRUE;
 					}
 				}
 
-				if (isbus != 0)
+				if (isbus)
 				{
 					sw->proto = sch_busarc;
 				} else
@@ -1496,10 +1486,10 @@ void io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *fac
 	}
 
 	/* now iteratively extend bus wires to connections with others */
-	propagatedbus = 1;
-	while (propagatedbus != 0)
+	propagatedbus = TRUE;
+	while (propagatedbus)
 	{
-		propagatedbus = 0;
+		propagatedbus = FALSE;
 		for(sw = firstsuewire; sw != NOSUEWIRE; sw = sw->nextsuewire)
 		{
 			if (sw->proto != sch_busarc) continue;
@@ -1514,7 +1504,7 @@ void io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *fac
 						{
 							/* common point found: continue the bus request */
 							osw->proto = sch_busarc;
-							propagatedbus = 1;
+							propagatedbus = TRUE;
 						}
 					}
 				}
@@ -1582,8 +1572,8 @@ void io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *fac
 		for(i=0; i<2; i++)
 		{
 			if (sw->ni[i] != NONODEINST) continue;
-			if (io_suefindnode(&sw->x[i], &sw->y[i], sw->x[1-i], sw->y[1-i], facet,
-				&sw->ni[i], &sw->pp[i], sw->ni[1-i], lambda) == 0)
+			if (!io_suefindnode(&sw->x[i], &sw->y[i], sw->x[1-i], sw->y[1-i], facet,
+				&sw->ni[i], &sw->pp[i], sw->ni[1-i], lambda))
 			{
 				if (sw->proto == sch_busarc) proto = sch_buspinprim; else
 					proto = sch_wirepinprim;
@@ -1660,294 +1650,53 @@ void io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *fac
 		}
 		endobjectchange((INTBIG)ai, VARCINST);
 	}
-}
-/*
- * Create a copy of "proto" that is arrayed "count" times.
- */
-NODEPROTO *io_suecreatepseudo(NODEPROTO *proto, INTBIG count)
-{
-	REGISTER NODEPROTO *iconnp, *contentsnp, *newnp, *type, *pinproto;
-	REGISTER NODEINST *ni, *newni, *end0, *end1, *pinni;
-	REGISTER PORTPROTO *port0, *port1, *pp;
-	REGISTER ARCPROTO *conproto;
-	REGISTER ARCINST *ai, *newai;
-	REGISTER VARIABLE *var;
-	REGISTER INTBIG i, sizex, sizey, slop, lxdiff, hxdiff, lydiff, hydiff,
-		diff, side, pinsizex, pinsizey, lx, hx, ly, hy, ox, oy, width;
-	INTBIG x, y;
-	char size[20], *expandedname;
 
-	/* get the original icon and contents */
-	contentsnp = iconview(proto);
-	if (contentsnp == NONODEPROTO) contentsnp = proto;
-	iconnp = iconview(proto);
-	if (iconnp == NONODEPROTO) iconnp = proto;
-
-	/* create the arrayed contents facet */
-	(void)initinfstr();
-	(void)addstringtoinfstr(proto->cell->cellname);
-	sprintf(size, "-Size-%ld{sch}", count);
-	(void)addstringtoinfstr(size);
-	newnp = newnodeproto(returninfstr(), proto->cell->lib);
-	if (newnp == NONODEPROTO) return(NONODEPROTO);
-
-	/* build the arrayed contents facet */
-	sizex = iconnp->highx - iconnp->lowx;
-	sizey = iconnp->highy - iconnp->lowy;
-	slop = maxi(sizex, sizey) / 5;
-	for(i=0; i<count; i++)
+	/* now look for implicit connections where "offpage" connectors touch */
+	for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
-		lx = (sizex+slop*2) * i + slop;   hx = lx + sizex;
-		ly = (sizey+slop*2) * i + slop;   hy = ly + sizey;
-		newni = newnodeinst(iconnp, lx, hx, ly, hy, 0, 0, newnp);
-		if (newni == NONODEINST) return(NONODEPROTO);
-		endobjectchange((INTBIG)newni, VNODEINST);
-		for(pp = iconnp->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+		if (ni->proto != sch_offpageprim) continue;
+		if (ni->firstportarcinst != NOPORTARCINST) continue;
+		pp = ni->proto->firstportproto->nextportproto;
+		portposition(ni, pp, &x, &y);
+		sea = initsearch(x, x, y, y, facet);
+		for(;;)
 		{
-			portposition(pp->subnodeinst, pp->subportproto, &x, &y);
-			lxdiff = abs(x-iconnp->lowx);   hxdiff = abs(x-iconnp->highx);
-			lydiff = abs(y-iconnp->lowy);   hydiff = abs(y-iconnp->highy);
-			diff = lxdiff;   side = 0;
-			if (hxdiff < diff) { diff = hxdiff;   side = 1; }
-			if (lydiff < diff) { diff = lydiff;   side = 2; }
-			if (hydiff < diff) { diff = hydiff;   side = 3; }
-			portposition(newni, pp, &x, &y);
-			switch (side)
+			geom = nextobject(sea);
+			if (geom == NOGEOM) break;
+			if (!geom->entryisnode) continue;
+			oni = geom->entryaddr.ni;
+			if (oni == ni) continue;
+			for(opp = oni->proto->firstportproto; opp != NOPORTPROTO; opp = opp->nextportproto)
 			{
-				case 0:		/* left side */
-					ox = x - slop;   oy = y;   break;
-				case 1:		/* right side */
-					ox = x + slop;   oy = y;   break;
-				case 2:		/* bottom side */
-					ox = x;   oy = y - slop;   break;
-				case 3:		/* top side */
-					ox = x;   oy = y + slop;   break;
-			}
-			width = net_buswidth(pp->protoname);
-			if (width > 1)
-			{
-				pinproto = sch_buspinprim;
-				conproto = sch_busarc;
-			} else
-			{
-				pinproto = sch_wirepinprim;
-				conproto = sch_wirearc;
-			}
-			pinsizex = pinproto->highx - pinproto->lowx;
-			pinsizey = pinproto->highy - pinproto->lowy;
-			lx = ox - pinsizex/2;   hx = lx + pinsizex;
-			ly = oy - pinsizey/2;   hy = ly + pinsizey;
-			pinni = newnodeinst(pinproto, lx, hx, ly, hy, 0, 0, newnp);
-			if (pinni == NONODEINST) return(NONODEPROTO);
-			endobjectchange((INTBIG)pinni, VNODEINST);
-			newai = newarcinst(conproto, conproto->nominalwidth, us_makearcuserbits(conproto),
-				newni, pp, x, y, pinni, pinproto->firstportproto, ox, oy, newnp);
-			if (newai == NOARCINST) continue;
-			expandedname = io_sueexpandname(pp->protoname, count, i);
-			var = setvalkey((INTBIG)newai, VARCINST, el_arc_name,
-				(INTBIG)expandedname, VSTRING|VDISPLAY);
-			if (var != NOVARIABLE)
-			{
-				defaulttextsize(4, var->textdescript);
-				switch (side)
+				portposition(oni, opp, &ox, &oy);
+				if (ox != x || oy != y) continue;
+				for(i=0; i<3; i++)
 				{
-					case 0:		/* left side */
-						TDSETPOS(var->textdescript, VTPOSUPLEFT);   break;
-					case 1:		/* right side */
-						TDSETPOS(var->textdescript, VTPOSUPRIGHT);  break;
-					case 2:		/* bottom side */
-						TDSETPOS(var->textdescript, VTPOSRIGHT);    break;
-					case 3:		/* top side */
-						TDSETPOS(var->textdescript, VTPOSRIGHT);    break;
-				}
-			}
-			endobjectchange((INTBIG)newai, VARCINST);
-		}
-	}
-	pinsizex = sch_buspinprim->highx - sch_buspinprim->lowx;
-	pinsizey = sch_buspinprim->highy - sch_buspinprim->lowy;
-	for(pp = iconnp->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
-	{
-		expandedname = io_sueexpandname(pp->protoname, count, -1);
-		portposition(pp->subnodeinst, pp->subportproto, &x, &y);
-		lxdiff = abs(x-iconnp->lowx);   hxdiff = abs(x-iconnp->highx);
-		lydiff = abs(y-iconnp->lowy);   hydiff = abs(y-iconnp->highy);
-		diff = lxdiff;   side = 0;
-		if (hxdiff < diff) { diff = hxdiff;   side = 1; }
-		if (lydiff < diff) { diff = lydiff;   side = 2; }
-		if (hydiff < diff) { diff = hydiff;   side = 3; }
-		switch (side)
-		{
-			case 0:		/* left side */
-				x = 0;
-				y = muldiv(y - iconnp->lowy, count*(sizey+slop*2), iconnp->highy - iconnp->lowy);
-				ox = x-slop*2;   oy = y;
-				break;
-			case 1:		/* right side */
-				x = count*(sizex+slop*2);
-				y = muldiv(y - iconnp->lowy, count*(sizey+slop*2), iconnp->highy - iconnp->lowy);
-				ox = x+slop*2;   oy = y;
-				break;
-			case 2:		/* bottom side */
-				x = muldiv(x - iconnp->lowx, count*(sizex+slop*2), iconnp->highx - iconnp->lowx);
-				y = 0;
-				ox = x;   oy = y-slop*2;
-				break;
-			case 3:		/* top side */
-				x = muldiv(x - iconnp->lowx, count*(sizex+slop*2), iconnp->highx - iconnp->lowx);
-				y = count*(sizey+slop*2);
-				ox = x;   oy = y+slop*2;
-				break;
-		}
-		lx = x - pinsizex/2;   hx = lx + pinsizex;
-		ly = y - pinsizey/2;   hy = ly + pinsizey;
-		pinni = newnodeinst(sch_buspinprim, lx, hx, ly, hy, 0, 0, newnp);
-		if (pinni == NONODEINST) continue;
-		endobjectchange((INTBIG)pinni, VNODEINST);
-		lx = ox - pinsizex/2;   hx = lx + pinsizex;
-		ly = oy - pinsizey/2;   hy = ly + pinsizey;
-		newni = newnodeinst(sch_buspinprim, lx, hx, ly, hy, 0, 0, newnp);
-		if (newni == NONODEINST) continue;
-		(void)newportproto(newnp, newni, sch_buspinprim->firstportproto, expandedname);
-		endobjectchange((INTBIG)newni, VNODEINST);
-		newai = newarcinst(sch_busarc, sch_busarc->nominalwidth, us_makearcuserbits(sch_busarc),
-			pinni, sch_buspinprim->firstportproto, x, y, newni, sch_buspinprim->firstportproto, ox, oy, newnp);
-	}
-
-	/* create the arrayed icon facet */
-	(void)initinfstr();
-	(void)addstringtoinfstr(proto->cell->cellname);
-	sprintf(size, "-Size-%ld{ic}", count);
-	(void)addstringtoinfstr(size);
-	newnp = newnodeproto(returninfstr(), proto->cell->lib);
-	if (newnp == NONODEPROTO) return(NONODEPROTO);
-	newnp->userbits |= WANTNEXPAND;
-
-	/* copy the icon to the arrayed icon */
-	for(ni = iconnp->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
-	{
-		type = ni->proto;
-		if (type == sch_wirepinprim && ni->firstportexpinst != NOPORTEXPINST)
-			type = sch_buspinprim;
-		newni = newnodeinst(type, ni->lowx, ni->highx, ni->lowy, ni->highy, ni->transpose,
-			ni->rotation, newnp);
-		if (newni == NONODEINST) return(NONODEPROTO);
-		if (copyvars((INTBIG)ni, VNODEINST, (INTBIG)newni, VNODEINST) != 0)
-			return(NONODEPROTO);
-		endobjectchange((INTBIG)newni, VNODEINST);
-		ni->temp1 = (INTBIG)newni;
-	}
-	for(ai = iconnp->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
-	{
-		end0 = (NODEINST *)ai->end[0].nodeinst->temp1;
-		end1 = (NODEINST *)ai->end[1].nodeinst->temp1;
-		if (end0->proto == ai->end[0].nodeinst->proto) port0 = ai->end[0].portarcinst->proto; else
-			port0 = sch_buspinprim->firstportproto;
-		if (end1->proto == ai->end[1].nodeinst->proto) port1 = ai->end[1].portarcinst->proto; else
-			port1 = sch_buspinprim->firstportproto;
-		newai = newarcinst(ai->proto, ai->width, ai->userbits, end0, port0, ai->end[0].xpos,
-			ai->end[0].ypos, end0, port1, ai->end[1].xpos, ai->end[1].ypos, newnp);
-		if (newai == NOARCINST) return(NONODEPROTO);
-		if (copyvars((INTBIG)ai, VARCINST, (INTBIG)newai, VARCINST) != 0)
-			return(NONODEPROTO);
-		endobjectchange((INTBIG)newai, VARCINST);
-	}
-	for(pp = iconnp->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
-	{
-		end0 = (NODEINST *)pp->subnodeinst->temp1;
-		if (end0->proto == pp->subnodeinst->proto) port0 = pp->subportproto; else
-			port0 = sch_buspinprim->firstportproto;
-		expandedname = io_sueexpandname(pp->protoname, count, -1);
-		(void)newportproto(newnp, end0, port0, expandedname);
-	}
-	return(newnp);
-}
-
-/*
- * Routine to convert port name "portname" to an expanded version that handles
- * "count" times as many signals.  If "which" is negative, expand to the full
- * size.  Otherwise expand only entry "which".
- */
-char *io_sueexpandname(char *portname, INTBIG count, INTBIG which)
-{
-	REGISTER char *pt, *pt2, *endpart, save;
-	REGISTER INTBIG i, index, startindex;
-	char arrbounds[30];
-
-	/* copy the name part */
-	(void)initinfstr();
-	for(pt = portname; *pt != 0; pt++)
-	{
-		if (*pt == '[') break;
-		(void)addtoinfstr(*pt);
-	}
-
-	/* if there is just a name, array it and stop */
-	if (*pt == 0)
-	{
-		if (which < 0)
-			sprintf(arrbounds, "[1:%ld]", count); else
-				sprintf(arrbounds, "[%ld]", which+1);
-		(void)addstringtoinfstr(arrbounds);
-		return(returninfstr());
-	}
-
-	/* arraying an array: magnify each element */
-	(void)addtoinfstr(*pt++);
-	for(;;)
-	{
-		for(endpart = pt; *endpart != 0; endpart++)
-			if (*endpart == ':' || *endpart == ']' || *endpart == ',') break;
-		if (*endpart == ':')
-		{
-			*endpart = 0;
-			startindex = myatoi(pt);
-			*endpart++ = ':';
-			pt2 = endpart;
-			for(endpart = pt2; *endpart != 0; endpart++)
-				if (*endpart == ']' || *endpart == ',') break;
-			save = *endpart;   *endpart = 0;
-			index = myatoi(pt2);
-			if (which < 0)
-				sprintf(arrbounds, "%ld:%ld", startindex*count-count+1, index*count); else
-					sprintf(arrbounds, "%ld:%ld", which*(index-startindex+1)+1, (which+1)*(index-startindex+1));
-			(void)addstringtoinfstr(arrbounds);
-		} else
-		{
-			save = *endpart;   *endpart = 0;
-			if (isanumber(pt) != 0)
-			{
-				index = myatoi(pt);
-				if (which < 0)
-					sprintf(arrbounds, "%ld:%ld", index*count-count+1, index*count); else
-						sprintf(arrbounds, "%ld", index*count-count+which+1);
-				(void)addstringtoinfstr(arrbounds);
-			} else
-			{
-				if (which < 0)
-				{
-					for(i=0; i<count; i++)
+					switch (i)
 					{
-						if (i != 0) (void)addtoinfstr(',');
-						(void)addstringtoinfstr(pt);
-						sprintf(arrbounds, "_%ld", i+1);
-						(void)addstringtoinfstr(arrbounds);
+						case 0: ap = sch_busarc;      break;
+						case 1: ap = sch_wirearc;     break;
+						case 2: ap = gen_unroutedarc; break;
 					}
-				} else
-				{
-					(void)addstringtoinfstr(pt);
-					sprintf(arrbounds, "_%ld", which+1);
-					(void)addstringtoinfstr(arrbounds);
+					for(j=0; pp->connects[j] != NOARCPROTO; j++)
+						if (pp->connects[j] == ap) break;
+					if (pp->connects[j] == NOARCPROTO) continue;
+					for(j=0; opp->connects[j] != NOARCPROTO; j++)
+						if (opp->connects[j] == ap) break;
+					if (opp->connects[j] == NOARCPROTO) continue;
+					break;
 				}
+
+				wid = defaultarcwidth(ap);
+				bits = us_makearcuserbits(ap);
+				ai = newarcinst(ap, wid, bits, ni, pp, x, y, oni, opp, x, y, facet);
+				if (ai != NOARCINST)
+					endobjectchange((INTBIG)ai, VARCINST);
+				break;
 			}
+			if (opp != NOPORTPROTO) break;
 		}
-		*endpart = save;
-		if (*endpart == 0) { addtoinfstr(']');   break; }
-		(void)addtoinfstr(*endpart);
-		if (*endpart == ']') break;
-		pt = endpart + 1;
 	}
-	return(returninfstr());
 }
 
 /*
@@ -1965,8 +1714,8 @@ PORTPROTO *io_suewiredport(NODEINST *ni, INTBIG *x, INTBIG *y, INTBIG ox, INTBIG
 	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_tool->cluster);
 	for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 	{
-		shapeportpoly(ni, pp, poly, 0);
-		if (isinside(*x, *y, poly) != 0) return(pp);
+		shapeportpoly(ni, pp, poly, FALSE);
+		if (isinside(*x, *y, poly)) return(pp);
 	}
 	if ((ni->lowx+ni->highx) / 2 != *x ||
 		(ni->lowy+ni->highy) / 2 != *y) return(NOPORTPROTO);
@@ -1986,33 +1735,6 @@ PORTPROTO *io_suewiredport(NODEINST *ni, INTBIG *x, INTBIG *y, INTBIG ox, INTBIG
 	return(bestpp);
 }
 
-/*
- * Routine to return the length of the arrayed name "name".  Returns zero
- * if the name is not arrayed.
- */
-INTBIG io_suearraylength(char *name)
-{
-	REGISTER char *pt;
-	REGISTER INTBIG numopen, numclose;
-
-	if (name == 0) return(1);
-	numopen = numclose = 0;
-	for(pt = name; *pt != 0; pt++)
-	{
-		if (*pt == '[') numopen++;
-		if (*pt == ']') numclose++;
-	}
-	if (numopen == 0 && numclose == 0)
-	{
-		(void)initinfstr();
-		(void)addtoinfstr('[');
-		(void)addstringtoinfstr(name);
-		(void)addtoinfstr(']');
-		return(net_buswidth(returninfstr()));
-	}
-	return(net_buswidth(name));
-}
-
 /*
  * Routine to find the pin at (x, y) and return it.
  */
@@ -2030,7 +1752,7 @@ NODEINST *io_suefindpinnode(INTBIG x, INTBIG y, NODEPROTO *np, PORTPROTO **thepp
 	{
 		geom = nextobject(sea);
 		if (geom == NOGEOM) break;
-		if (geom->entrytype != OBJNODEINST) continue;
+		if (!geom->entryisnode) continue;
 		ni = geom->entryaddr.ni;
 
 		/* find closest port */
@@ -2052,7 +1774,7 @@ NODEINST *io_suefindpinnode(INTBIG x, INTBIG y, NODEPROTO *np, PORTPROTO **thepp
 /*
  * Routine to find the node at (x, y) and return it.
  */
-INTSML io_suefindnode(INTBIG *x, INTBIG *y, INTBIG ox, INTBIG oy,
+BOOLEAN io_suefindnode(INTBIG *x, INTBIG *y, INTBIG ox, INTBIG oy,
 	NODEPROTO *np, NODEINST **rni, PORTPROTO **rpp, NODEINST *notthisnode, INTBIG lambda)
 {
 	REGISTER GEOM *geom;
@@ -2070,7 +1792,7 @@ INTSML io_suefindnode(INTBIG *x, INTBIG *y, INTBIG ox, INTBIG oy,
 	{
 		geom = nextobject(sea);
 		if (geom == NOGEOM) break;
-		if (geom->entrytype != OBJNODEINST) continue;
+		if (!geom->entryisnode) continue;
 		ni = geom->entryaddr.ni;
 		if (ni == notthisnode) continue;
 
@@ -2084,7 +1806,7 @@ INTSML io_suefindnode(INTBIG *x, INTBIG *y, INTBIG ox, INTBIG oy,
 			if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_tool->cluster);
 
 			/* get the polygon describing the port */
-			shapeportpoly(ni, pp, poly, 0);
+			shapeportpoly(ni, pp, poly, FALSE);
 			getbbox(poly, &plx, &phx, &ply, &phy);
 
 			/* find out if the line crosses the polygon */
@@ -2102,7 +1824,7 @@ INTSML io_suefindnode(INTBIG *x, INTBIG *y, INTBIG ox, INTBIG oy,
 				thisy = oy;
 			} else
 			{
-				if (isinside(ox, oy, poly) == 0) continue;
+				if (!isinside(ox, oy, poly)) continue;
 				thisx = ox;
 				thisy = oy;
 			}
@@ -2122,10 +1844,10 @@ INTSML io_suefindnode(INTBIG *x, INTBIG *y, INTBIG ox, INTBIG oy,
 	}
 
 	/* report the hit */
-	if (bestpp == NOPORTPROTO) return(0);
+	if (bestpp == NOPORTPROTO) return(FALSE);
 	*rni = bestni;   *rpp = bestpp;
 	*x = bestx;      *y = besty;
-	return(1);
+	return(TRUE);
 }
 
 /*
@@ -2191,16 +1913,17 @@ NODEPROTO *io_suereadfromdisk(LIBRARY *lib, char *name)
  * it up into space-separated keywords.  Returns the number
  * of keywords (-1 on EOF)
  */
-INTSML io_suegetnextline(char **keywords, INTSML curlydepth)
+INTBIG io_suegetnextline(char **keywords, INTBIG curlydepth)
 {
 	char *pt;
-	REGISTER INTBIG filepos, inblank, keypos, lineno;
+	REGISTER INTBIG filepos, keypos, lineno;
+	REGISTER BOOLEAN inblank;
 
 	for(lineno=0; ; lineno++)
 	{
 		if (io_suelastline[0] == 0)
 		{
-			if (xfgets(io_suelastline, MAXLINE, io_suefilein) != 0) return(-1);
+			if (xfgets(io_suelastline, MAXLINE, io_suefilein)) return(-1);
 			io_suelineno++;
 			if ((io_suelineno%50) == 0)
 			{
@@ -2223,7 +1946,7 @@ INTSML io_suegetnextline(char **keywords, INTSML curlydepth)
 	strcpy(io_sueorigline, io_suecurline);
 
 	/* parse the line */
-	inblank = 1;
+	inblank = TRUE;
 	keypos = 0;
 	for(pt=io_suecurline; *pt != 0; pt++)
 	{
@@ -2232,39 +1955,39 @@ INTSML io_suegetnextline(char **keywords, INTSML curlydepth)
 		if ((*pt == ' ' || *pt == '\t') && curlydepth == 0)
 		{
 			*pt = 0;
-			inblank = 1;
+			inblank = TRUE;
 		} else
 		{
-			if (inblank != 0)
+			if (inblank)
 			{
 				keywords[keypos++] = pt;
 			}
-			inblank = 0;
+			inblank = FALSE;
 		}
 	}
-	return((INTSML)keypos);
+	return(keypos);
 }
 
 /*
  * Routine to add "directory" to the list of places where SUE files may be found.
  */
-INTSML io_sueadddirectory(char *directory)
+BOOLEAN io_sueadddirectory(char *directory)
 {
 	REGISTER INTBIG newnumdir, i;
 	char **newdir;
 
 	newnumdir = io_suenumdirectories + 1;
 	newdir = (char **)emalloc(newnumdir * (sizeof (char *)), io_tool->cluster);
-	if (newdir == 0) return(1);
+	if (newdir == 0) return(TRUE);
 	for(i=0; i<io_suenumdirectories; i++)
 		newdir[i] = io_suedirectories[i];
 	newdir[io_suenumdirectories] = (char *)emalloc(strlen(directory)+1, io_tool->cluster);
-	if (newdir[io_suenumdirectories] == 0) return(1);
+	if (newdir[io_suenumdirectories] == 0) return(TRUE);
 	strcpy(newdir[io_suenumdirectories], directory);
 	if (io_suenumdirectories > 0) efree((char *)io_suedirectories);
 	io_suedirectories = newdir;
 	io_suenumdirectories = newnumdir;
-	return(0);
+	return(FALSE);
 }
 
 void io_suecleardirectories(void)
