@@ -108,8 +108,8 @@ static char *io_keyword;
 
 /* prototypes for local routines */
 static void io_newlib(void);
-static INTSML io_getkeyword(void);
-static INTSML io_grabbuffers(INTBIG);
+static BOOLEAN io_getkeyword(void);
+static BOOLEAN io_grabbuffers(INTBIG);
 static PORTPROTO *io_getport(char*, NODEPROTO*);
 static void io_null(void);
 static void io_newlib(void);
@@ -344,12 +344,18 @@ static struct keyroutine io_arcendroutines[] =
    {NULL, NULL}
 };
 
-INTSML io_readtextlibrary(LIBRARY *lib)
+BOOLEAN io_readtextlibrary(LIBRARY *lib)
 {
-	return(io_doreadtextlibrary(lib, 1));
+	REGISTER LIBRARY *olib;
+
+	/* mark all libraries as "not being read" */
+	for(olib = el_curlib; olib != NOLIBRARY; olib = olib->nextlibrary)
+		olib->temp1 = 0;
+
+	return(io_doreadtextlibrary(lib, TRUE));
 }
 
-INTSML io_doreadtextlibrary(LIBRARY *lib, INTSML newprogress)
+BOOLEAN io_doreadtextlibrary(LIBRARY *lib, BOOLEAN newprogress)
 {
 	struct keyroutine *table;
 	REGISTER char *pp;
@@ -366,14 +372,14 @@ INTSML io_doreadtextlibrary(LIBRARY *lib, INTSML newprogress)
 
 	/* initialize the input string buffers */
 	if (io_maxinputline == 0)
-		if (io_grabbuffers(1000) != 0) return(1);
+		if (io_grabbuffers(1000)) return(TRUE);
 
 	io_txtindata.textfilein = xopen(truepath(lib->libfile), io_filetypetlib,
 		el_libdir, &filename);
 	if (io_txtindata.textfilein == NULL)
 	{
 		ttyputerr(_("File %s not found"), lib->libfile);
-		return(1);
+		return(TRUE);
 	}
 
 	/* update the library file name if the true location is different */
@@ -386,12 +392,12 @@ INTSML io_doreadtextlibrary(LIBRARY *lib, INTSML newprogress)
 		io_txtindata.filelength = filesize(io_txtindata.textfilein);
 		if (io_txtindata.filelength > 0)
 		{
-			if (newprogress != 0)
+			if (newprogress)
 			{
-				if (DiaInitDialog(&us_eprogressdialog) != 0)
+				if (DiaInitDialog(&us_eprogressdialog))
 				{
 					xclose(io_txtindata.textfilein);
-					return(1);
+					return(TRUE);
 				}
 			}
 			(void)initinfstr();
@@ -410,7 +416,7 @@ INTSML io_doreadtextlibrary(LIBRARY *lib, INTSML newprogress)
 			io_txtindata.linenumber, io_keyword);
 		xclose(io_txtindata.textfilein);
 		if (io_verbose < 0 && io_txtindata.filelength > 0) DiaDoneDialog();
-		return(1);
+		return(TRUE);
 	}
 
 	/* force the library name to be the proper file name without the "txt" */
@@ -420,7 +426,7 @@ INTSML io_doreadtextlibrary(LIBRARY *lib, INTSML newprogress)
 	j = strlen(pp);
 	if (j > 4 && namesame(&pp[j-4], ".txt") == 0) j -= 4;
 	for(i=0; i<j; i++) (void)addtoinfstr(pp[i]);
-	if (reallocstring(&lib->libname, returninfstr(), lib->cluster) != 0)
+	if (reallocstring(&lib->libname, returninfstr(), lib->cluster))
 		longjmp(io_filerror, (INTBIG)_("No memory"));
 
 	io_txtindata.curlib = lib;
@@ -481,7 +487,7 @@ INTSML io_doreadtextlibrary(LIBRARY *lib, INTSML newprogress)
 
 	/* set the former version number on the library */
 	nextchangequiet();
-	(void)setvalkey((INTBIG)io_txtindata.curlib, VLIBRARY, makekey("LIB_former_version"),
+	(void)setval((INTBIG)io_txtindata.curlib, VLIBRARY, "LIB_former_version",
 		(INTBIG)io_txtindata.version, VSTRING|VDONTSAVE);
 	efree(io_txtindata.version);
 
@@ -536,9 +542,6 @@ INTSML io_doreadtextlibrary(LIBRARY *lib, INTSML newprogress)
 					lib->libname);
 	}
 
-	/* clean up the library */
-	io_fixnewlib(io_txtindata.curlib, 0);
-
 	/* print any variable-related error messages */
 	if (io_txtindata.nodeinsterror != 0)
 		ttyputmsg(_("Warning: %ld invalid NODEINST pointers"), io_txtindata.nodeinsterror);
@@ -561,13 +564,16 @@ INTSML io_doreadtextlibrary(LIBRARY *lib, INTSML newprogress)
 		io_txtindata.curlib->curnodeproto = io_txtindata.nodeprotolist[io_txtindata.mainfacet]; else
 			io_txtindata.curlib->curnodeproto = NONODEPROTO;
 	if (io_txtindata.facetcount != 0) efree((char *)io_txtindata.nodeprotolist);
-	if (io_verbose < 0 && io_txtindata.filelength > 0 && newprogress != 0) DiaDoneDialog();
-	return(0);
+	if (io_verbose < 0 && io_txtindata.filelength > 0 && newprogress) DiaDoneDialog();
+
+	/* clean up the library */
+	io_fixnewlib(io_txtindata.curlib, 0);
+	return(FALSE);
 }
 
 /******************** GENERAL PARSING ROUTINES ********************/
 
-INTSML io_getkeyword(void)
+BOOLEAN io_getkeyword(void)
 {
 	REGISTER INTBIG c, cindex, inquote;
 
@@ -587,7 +593,7 @@ INTSML io_getkeyword(void)
 	}
 
 	/* if the file ended, quit now */
-	if (c == EOF) return(1);
+	if (c == EOF) return(TRUE);
 
 	/* collect the word */
 	cindex = 0;
@@ -596,13 +602,13 @@ INTSML io_getkeyword(void)
 	for(;;)
 	{
 		c = xgetc(io_txtindata.textfilein);
-		if (c == EOF) return(1);
+		if (c == EOF) return(TRUE);
 		io_txtindata.fileposition++;
 		if (c == '\n' || (c == ' ' && inquote == 0)) break;
 		if (cindex >= io_maxinputline)
 		{
 			/* try to allocate more space */
-			if (io_grabbuffers(io_maxinputline*2) != 0) break;
+			if (io_grabbuffers(io_maxinputline*2)) break;
 		}
 		if (c == '"' && (cindex == 0 || io_keyword[cindex-1] != '^'))
 			inquote = 1 - inquote;
@@ -615,13 +621,13 @@ INTSML io_getkeyword(void)
 			ttyputmsg(_("%ld lines read"), io_txtindata.linenumber);
 	}
 	io_keyword[cindex] = 0;
-	return(0);
+	return(FALSE);
 }
 
 /*
  * routine to allocate the keyword buffer to be the specified size
  */
-INTSML io_grabbuffers(INTBIG size)
+BOOLEAN io_grabbuffers(INTBIG size)
 {
 	REGISTER char *p;
 	REGISTER INTBIG i;
@@ -631,7 +637,7 @@ INTSML io_grabbuffers(INTBIG size)
 	if (p == 0)
 	{
 		ttyputnomemory();
-		return(1);
+		return(TRUE);
 	}
 
 	/* if there was an old buffer, copy it */
@@ -644,7 +650,7 @@ INTSML io_grabbuffers(INTBIG size)
 	/* set the new size and buffer */
 	io_maxinputline = size;
 	io_keyword = p;
-	return(0);
+	return(FALSE);
 }
 
 /*
@@ -655,7 +661,7 @@ INTSML io_grabbuffers(INTBIG size)
 PORTPROTO *io_getport(char *line, NODEPROTO *np)
 {
 	REGISTER PORTPROTO *pp;
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 
 	for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		if (namesame(line, pp->protoname) == 0) return(pp);
@@ -831,6 +837,8 @@ void io_lambda(void)
 void io_getvar(void)
 {
 	REGISTER INTBIG i, j, count, type, len, naddr, ntype, *store, key, ret;
+	REGISTER BOOLEAN err;
+	REGISTER float *fstore;
 	UINTBIG descript[TEXTDESCRIPTSIZE];
 	REGISTER char *pt, *start;
 	REGISTER VARIABLE *var;
@@ -885,18 +893,18 @@ void io_getvar(void)
 			longjmp(io_filerror, (INTBIG)_("Missing ':' in variable"));
 
 		/* get the variable name */
-		j = initinfstr();
+		err = initinfstr();
 		for(pt = io_keyword; *pt != 0; pt++)
 		{
 			if (*pt == '^' && pt[1] != 0)
 			{
 				pt++;
-				j += addtoinfstr(*pt);
+				err |= addtoinfstr(*pt);
 			}
 			if (*pt == '(' || *pt == '[' || *pt == ':') break;
-			j += addtoinfstr(*pt);
+			err |= addtoinfstr(*pt);
 		}
-		if (j != 0) longjmp(io_filerror, (INTBIG)_("No memory"));
+		if (err) longjmp(io_filerror, (INTBIG)_("No memory"));
 		key = makekey(returninfstr());
 
 		/* get optional length */
@@ -930,11 +938,14 @@ void io_getvar(void)
 				len = (type&VLENGTH) >> VLENGTHSH;
 				store = emalloc((len * SIZEOFINTBIG), el_tempcluster);
 				if (store == 0) longjmp(io_filerror, (INTBIG)_("No memory"));
+				fstore = (float *)store;
 			} else
 			{
 				store = emalloc(((len+1) * SIZEOFINTBIG), el_tempcluster);
 				if (store == 0) longjmp(io_filerror, (INTBIG)_("No memory"));
+				fstore = (float *)store;
 				store[len] = -1;
+				if ((type&VTYPE) == VFLOAT) fstore[len] = castfloat(-1);
 			}
 			pt = io_keyword;
 			if (*pt++ != '[')
@@ -979,7 +990,9 @@ void io_getvar(void)
 					}
 				} else
 				{
-					store[j] = io_decode(start, type);
+					if ((type&VTYPE) == VFLOAT)
+						fstore[j] = castfloat(io_decode(start, type)); else
+							store[j] = io_decode(start, type);
 				}
 			}
 			if (naddr != -1)
@@ -1158,7 +1171,7 @@ void io_libms(void)
 void io_libvie(void)
 {
 	REGISTER char *pt;
-	REGISTER INTSML len;
+	REGISTER INTBIG len;
 	REGISTER VIEW *v;
 
 	pt = io_keyword;
@@ -1228,7 +1241,7 @@ void io_celnam(void)
 	{
 		*pt = 0;
 		if (allocstring(&cellname, io_keyword,
-			io_txtindata.curlib->cluster) != 0)
+			io_txtindata.curlib->cluster))
 				longjmp(io_filerror, (INTBIG)_("No memory for facet name"));
 		pt++;
 		pt[strlen(pt)-1] = 0;
@@ -1238,7 +1251,7 @@ void io_celnam(void)
 	} else
 	{
 		if (allocstring(&cellname, io_keyword,
-			io_txtindata.curlib->cluster) != 0)
+			io_txtindata.curlib->cluster))
 				longjmp(io_filerror, (INTBIG)_("No memory for facet name"));
 	}
 	cell = db_findcellname(cellname, io_txtindata.curlib);
@@ -1283,10 +1296,10 @@ void io_celrev(void)
  */
 void io_celext(void)
 {
-	INTBIG k, len, insx, insy, filetype;
+	INTBIG k, len, insx, insy, filetype, filelen;
 	REGISTER LIBRARY *elib;
 	REGISTER char *libname, *pt;
-	char *filename, *libfile, *oldline2, *oldline3;
+	char *filename, *libfile, *oldline2, *oldline3, *libfilename, *libfilepath;
 	FILE *io;
 	REGISTER CELL *cell;
 	char *cellname;
@@ -1308,6 +1321,18 @@ void io_celext(void)
 	(void)addstringtoinfstr(skippath(libfile));
 	libname = returninfstr();
 	len = strlen(libname);
+	filelen = strlen(libfile);
+	if (len < filelen)
+	{
+		libfilename = &libfile[filelen-len-1];
+		*libfilename++ = 0;
+		libfilepath = libfile;
+	} else
+	{
+		libfilename = libfile;
+		libfilepath = "";
+	}
+
 	filetype = io_filetypetlib;
 	if (len > 5 && namesame(&libname[len-5], ".elib") == 0)
 	{
@@ -1321,19 +1346,28 @@ void io_celext(void)
 	if (elib == NOLIBRARY)
 	{
 		/* library does not exist: see if file is there */
-		io = xopen(truepath(libfile), filetype, el_libdir, &filename);
+		io = xopen(libfilename, filetype, truepath(libfilepath), &filename);
+		if (io == 0)
+		{
+			/* try the library area */
+			io = xopen(libfilename, filetype, el_libdir, &filename);
+		}
 		if (io != 0)
 		{
 			xclose(io);
-			ttyputmsg(_("Reading referenced library %s"), libfile);
+			ttyputmsg(_("Reading referenced library %s"), libname);
 		} else
 		{
 			(void)initinfstr();
 			(void)formatinfstr(_("Reference library '%s'"), libname);
 			pt = fileselect(returninfstr(), filetype, "");
-			if (pt != 0) strcpy(libfile, pt);
+			if (pt != 0)
+			{
+				strcpy(libfile, pt);
+				filename = libfile;
+			}
 		}
-		elib = newlibrary(libname, libfile);
+		elib = newlibrary(libname, filename);
 		if (elib == NOLIBRARY) return;
 
 		/* read the external library */
@@ -1344,16 +1378,17 @@ void io_celext(void)
 			(void)allocstring(&oldline3, DiaGetText(3), el_tempcluster);
 		}
 
-		len = strlen(libfile);
+		len = strlen(libfilename);
 		io_libinputrecursivedepth++;
-		if (len > 4 && namesame(&libfile[len-4], ".txt") == 0)
+		io_libinputreadmany++;
+		if (len > 4 && namesame(&libfilename[len-4], ".txt") == 0)
 		{
 			/* ends in ".txt", presume text file */
-			k = io_doreadtextlibrary(elib, 0);
+			(void)io_doreadtextlibrary(elib, FALSE);
 		} else
 		{
 			/* all other endings: presume binary file */
-			k = io_doreadbinlibrary(elib, 0);
+			(void)io_doreadbinlibrary(elib, FALSE);
 		}
 		io_libinputrecursivedepth--;
 		for(k=0; k<el_maxtools; k++)
@@ -1389,7 +1424,7 @@ void io_celext(void)
 			(void)addstringtoinfstr(io_txtindata.curnodeproto->cellview->sviewname);
 			(void)addtoinfstr('}');
 		}
-		ttyputerr(_("Cannot find facet %s in library %s..creating dummy verision"),
+		ttyputerr(_("Cannot find facet %s in library %s..creating dummy version"),
 			returninfstr(), elib->libname);
 	} else
 	{
@@ -1457,7 +1492,7 @@ void io_celext(void)
 		ni->lowx = np->lowx;   ni->highx = ni->lowx + insx;
 		ni->lowy = np->lowy;   ni->highy = ni->lowy + insy;
 		ni->geom = allocgeom(io_txtindata.curlib->cluster);
-		ni->geom->entrytype = OBJNODEINST;   ni->geom->entryaddr.ni = ni;
+		ni->geom->entryisnode = TRUE;   ni->geom->entryaddr.ni = ni;
 		linkgeom(ni->geom, np);
 
 		ni = allocnodeinst(io_txtindata.curlib->cluster);
@@ -1468,7 +1503,7 @@ void io_celext(void)
 		ni->highx = np->highx;   ni->lowx = ni->highx - insx;
 		ni->highy = np->highy;   ni->lowy = ni->highy - insy;
 		ni->geom = allocgeom(io_txtindata.curlib->cluster);
-		ni->geom->entrytype = OBJNODEINST;   ni->geom->entryaddr.ni = ni;
+		ni->geom->entryisnode = TRUE;   ni->geom->entryaddr.ni = ni;
 		linkgeom(ni->geom, np);
 	}
 }
@@ -1544,7 +1579,7 @@ void io_celnet(void) {}
  */
 void io_celnoc(void)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 	REGISTER NODEINST *ni;
 	REGISTER GEOM **geomlist;
 
@@ -1582,7 +1617,7 @@ void io_celnoc(void)
  */
 void io_celarc(void)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 	REGISTER ARCINST *ai;
 	REGISTER GEOM **geomlist;
 
@@ -1618,7 +1653,7 @@ void io_celarc(void)
  */
 void io_celptc(void)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 
 	io_txtindata.portprotocount = atoi(io_keyword);
 	if (io_txtindata.portprotocount == 0) return;
@@ -1645,7 +1680,7 @@ void io_celptc(void)
  */
 void io_celdon(void)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
 	REGISTER PORTARCINST *pi;
@@ -1679,7 +1714,7 @@ void io_celdon(void)
 	}
 
 	/* create geometry structure in the facet */
-	if (geomstructure(io_txtindata.curnodeproto) != 0)
+	if (geomstructure(io_txtindata.curnodeproto))
 		longjmp(io_filerror, (INTBIG)_("No memory for geometry structure"));
 
 	/* fill geometry module for each nodeinst */
@@ -1687,7 +1722,7 @@ void io_celdon(void)
 	{
 		ni = io_txtindata.nodelist[i];
 		geom = ni->geom;
-		geom->entrytype = OBJNODEINST;  geom->entryaddr.ni = ni;
+		geom->entryisnode = TRUE;  geom->entryaddr.ni = ni;
 		linkgeom(geom, io_txtindata.curnodeproto);
 	}
 
@@ -1695,9 +1730,9 @@ void io_celdon(void)
 	for(i=0; i<io_txtindata.arcinstcount; i++)
 	{
 		ai = io_txtindata.arclist[i];
-		(void)setshrinkvalue(ai, 0);
+		(void)setshrinkvalue(ai, FALSE);
 		geom = ai->geom;
-		geom->entrytype = OBJARCINST;  geom->entryaddr.ai = ai;
+		geom->entryisnode = FALSE;  geom->entryaddr.ai = ai;
 		linkgeom(geom, io_txtindata.curnodeproto);
 	}
 
@@ -1728,7 +1763,7 @@ void io_nodtyp(void)
 	REGISTER TECHNOLOGY *tech;
 	REGISTER char *pt, *line;
 	char orig[50];
-	static INTBIG orignodename = 0;
+	static INTBIG orignodenamekey = 0;
 
 	line = io_keyword;
 	if (*line == '[')
@@ -1770,10 +1805,10 @@ void io_nodtyp(void)
 		{
 			(void)strcpy(orig, "artwork:");
 			(void)strcat(orig, line);
-			if (orignodename == 0) orignodename = makekey("NODE_original_name");
+			if (orignodenamekey == 0) orignodenamekey = makekey("NODE_original_name");
 			nextchangequiet();
 			(void)setvalkey((INTBIG)io_txtindata.curnodeinst, VNODEINST,
-				orignodename, (INTBIG)orig, VSTRING|VDONTSAVE);
+				orignodenamekey, (INTBIG)orig, VSTRING|VDONTSAVE);
 		}
 		if (io_txtindata.curnodeinst->proto != NONODEPROTO) return;
 
@@ -1810,7 +1845,7 @@ void io_nodhy(void)
 void io_nodnam(void)
 {
 	nextchangequiet();
-	(void)setvalkey((INTBIG)io_txtindata.curnodeinst, VNODEINST, el_node_name,
+	(void)setvalkey((INTBIG)io_txtindata.curnodeinst, VNODEINST, el_node_name_key,
 		(INTBIG)io_keyword, VSTRING|VDISPLAY);
 }
 
@@ -1886,7 +1921,7 @@ void io_nodusb(void)
  */
 void io_newpor(void)
 {
-	REGISTER INTSML i, cindex;
+	REGISTER INTBIG i, cindex;
 	REGISTER PORTPROTO *pp;
 
 	if (io_txtindata.version[0] == '1')
@@ -2026,7 +2061,7 @@ void io_arctyp(void)
 void io_arcnam(void)
 {
 	nextchangequiet();
-	(void)setvalkey((INTBIG)io_txtindata.curarcinst, VARCINST, el_arc_name,
+	(void)setvalkey((INTBIG)io_txtindata.curarcinst, VARCINST, el_arc_name_key,
 		(INTBIG)io_keyword, VSTRING|VDISPLAY);
 }
 
@@ -2140,7 +2175,7 @@ void io_newpt(void)
  */
 void io_ptnam(void)
 {
-	if (allocstring(&io_txtindata.curportproto->protoname, io_keyword, io_txtindata.curlib->cluster) != 0)
+	if (allocstring(&io_txtindata.curportproto->protoname, io_keyword, io_txtindata.curlib->cluster))
 		longjmp(io_filerror, (INTBIG)_("No memory for portproto name"));
 }
 
