@@ -36,14 +36,14 @@ static INTBIG io_facetnumber, io_nodeinsterror, io_portarcinsterror, io_portexpi
 
 /* prototypes for local routines */
 static void io_textrecurse(NODEPROTO*);
-static INTSML io_countvars(INTSML, VARIABLE*);
-static void io_writevars(INTSML, VARIABLE*, NODEPROTO*);
+static INTBIG io_countvars(INTBIG, VARIABLE*);
+static void io_writevars(INTBIG, VARIABLE*, NODEPROTO*);
 static char *io_makestring(VARIABLE*, NODEPROTO*);
-static INTSML io_makestringvar(INTBIG, INTBIG, NODEPROTO*);
-static INTSML io_addstring(char*);
+static BOOLEAN io_makestringvar(INTBIG, INTBIG, NODEPROTO*);
+static BOOLEAN io_addstring(char*);
 static void io_printname(char*, FILE*);
 
-INTSML io_writetextlibrary(LIBRARY *lib)
+BOOLEAN io_writetextlibrary(LIBRARY *lib)
 {
 	REGISTER char *name;
 	char file[256], *truename;
@@ -62,13 +62,14 @@ INTSML io_writetextlibrary(LIBRARY *lib)
 	(void)strcpy(file, lib->libfile);
 	name = &file[strlen(file)-5];
 	if (strcmp(name, ".elib") == 0) *name = 0;
-	(void)strcat(file, ".txt");
+	name = &file[strlen(file)-4];
+	if (strcmp(name, ".txt") != 0) (void)strcat(file, ".txt");
 	name = truepath(file);
 	io_fileout = xcreate(name, io_filetypetlib, _("Readable Dump File"), &truename);
 	if (io_fileout == NULL)
 	{
 		if (truename != 0) ttyputerr(_("Cannot write %s"), truename);
-		return(1);
+		return(TRUE);
 	}
 
 	/* clear error counters */
@@ -83,6 +84,8 @@ INTSML io_writetextlibrary(LIBRARY *lib)
 	io_facetnumber = 0;
 	for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 		if (np->firstinst == NONODEINST) io_textrecurse(np);
+	for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+		if (np->temp1 < 0) io_textrecurse(np);
 	if (io_facetnumber > 0)
 	{
 		facets = (NODEPROTO **)emalloc((io_facetnumber * sizeof(NODEPROTO *)),
@@ -90,7 +93,7 @@ INTSML io_writetextlibrary(LIBRARY *lib)
 		if (facets == 0)
 		{
 			ttyputnomemory();
-			return(1);
+			return(TRUE);
 		}
 		for(olib = el_curlib; olib != NOLIBRARY; olib = olib->nextlibrary)
 		{
@@ -105,7 +108,7 @@ INTSML io_writetextlibrary(LIBRARY *lib)
 	/* write header information */
 	xprintf(io_fileout, "****library: \"%s\"\n", lib->libname);
 	xprintf(io_fileout, "version: %s\n", el_version);
-	xprintf(io_fileout, "aids: %d\n", el_maxtools);
+	xprintf(io_fileout, "aids: %ld\n", el_maxtools);
 	for(i=0; i<el_maxtools; i++)
 	{
 		xprintf(io_fileout, "aidname: %s\n", el_tools[i].toolname);
@@ -113,7 +116,7 @@ INTSML io_writetextlibrary(LIBRARY *lib)
 			io_writevars(el_tools[i].numvar, el_tools[i].firstvar, NONODEPROTO);
 	}
 	xprintf(io_fileout, "userbits: %ld\n", lib->userbits);
-	xprintf(io_fileout, "techcount: %d\n", el_maxtech);
+	xprintf(io_fileout, "techcount: %ld\n", el_maxtech);
 	for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
 	{
 		xprintf(io_fileout, "techname: %s lambda: %ld\n", tech->techname, lib->lambda[tech->techindex]);
@@ -138,7 +141,7 @@ INTSML io_writetextlibrary(LIBRARY *lib)
 		if (*np->cellview->sviewname != 0)
 			xprintf(io_fileout, "{%s}", np->cellview->sviewname);
 		xprintf(io_fileout, "\n");
-		xprintf(io_fileout, "version: %d\n", np->version);
+		xprintf(io_fileout, "version: %ld\n", np->version);
 		xprintf(io_fileout, "creationdate: %ld\n", np->creationdate);
 		xprintf(io_fileout, "revisiondate: %ld\n", np->revisiondate);
 
@@ -238,7 +241,7 @@ INTSML io_writetextlibrary(LIBRARY *lib)
 			xprintf(io_fileout, "userbits: %ld\n", ai->userbits);
 			for(i=0; i<2; i++)
 			{
-				xprintf(io_fileout, "*end: %d\n", i);
+				xprintf(io_fileout, "*end: %ld\n", i);
 				xprintf(io_fileout, "node: %ld\n", ai->end[i].nodeinst->temp1);
 				xprintf(io_fileout, "nodeport: %s\n", ai->end[i].portarcinst->proto->protoname);
 				xprintf(io_fileout, "xpos: %ld ypos: %ld\n", ai->end[i].xpos, ai->end[i].ypos);
@@ -271,7 +274,7 @@ INTSML io_writetextlibrary(LIBRARY *lib)
 	ttyputmsg(_("%s written"), truename);
 	lib->userbits &= ~(LIBCHANGEDMAJOR | LIBCHANGEDMINOR);
 	if (io_facetnumber > 0) efree((char *)facets);
-	return(0);
+	return(FALSE);
 }
 
 /*
@@ -295,9 +298,9 @@ void io_textrecurse(NODEPROTO *np)
 /*
  * routine to return the number of permanent variables on an object
  */
-INTSML io_countvars(INTSML numvar, VARIABLE *firstvar)
+INTBIG io_countvars(INTBIG numvar, VARIABLE *firstvar)
 {
-	REGISTER INTSML i, j;
+	REGISTER INTBIG i, j;
 
 	i = 0;
 	for(j=0; j<numvar; j++)
@@ -310,31 +313,29 @@ INTSML io_countvars(INTSML numvar, VARIABLE *firstvar)
  * "curnodeproto" such that any references to objects in a facet must be in
  * this facet.
  */
-void io_writevars(INTSML numvar, VARIABLE *firstvar, NODEPROTO *curnodeproto)
+void io_writevars(INTBIG numvar, VARIABLE *firstvar, NODEPROTO *curnodeproto)
 {
 	REGISTER char *pt;
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 	REGISTER VARIABLE *var;
 
 	i = io_countvars(numvar, firstvar);
 	if (i == 0) return;
 
-	xprintf(io_fileout, "variables: %d\n", i);
+	xprintf(io_fileout, "variables: %ld\n", i);
 	for(i=0; i<numvar; i++)
 	{
 		var = &firstvar[i];
 		if ((var->type & VDONTSAVE) != 0) continue;
 		pt = io_makestring(var, curnodeproto);
-		if (pt == 0) return;
+		if (pt == 0) pt = "";
 		io_printname((char *)var->key, io_fileout);
 		if ((var->type&(VLENGTH|VISARRAY)) != VISARRAY)
 		{
-			/* need to write both words!!! */
 			xprintf(io_fileout, "[0%o,0%o/0%o]: ", var->type, var->textdescript[0],
 				var->textdescript[1]);
 		} else
 		{
-			/* need to write both words!!! */
 			xprintf(io_fileout, "(%ld)[0%o,0%o/0%o]: ", getlength(var), var->type,
 				var->textdescript[0], var->textdescript[1]);
 		}
@@ -348,9 +349,10 @@ void io_writevars(INTSML numvar, VARIABLE *firstvar, NODEPROTO *curnodeproto)
  */
 char *io_makestring(VARIABLE *var, NODEPROTO *curnodeproto)
 {
-	REGISTER INTSML err;
+	REGISTER BOOLEAN err;
 	REGISTER INTBIG i, len;
 	char line[50];
+	REGISTER char *pt;
 
 	if (var == NOVARIABLE) return(0);
 
@@ -360,18 +362,18 @@ char *io_makestring(VARIABLE *var, NODEPROTO *curnodeproto)
 		len = getlength(var);
 		for(i=0; i<len; i++)
 		{
-			if (i == 0) err += addtoinfstr('['); else
-				err += addtoinfstr(',');
+			if (i == 0) err |= addtoinfstr('['); else
+				err |= addtoinfstr(',');
 
 			if ((var->type&VTYPE) == VGENERAL)
 			{
 				if ((i&1) == 0)
 				{
 					(void)sprintf(line, "0%lo", ((INTBIG *)var->addr)[i+1]);
-					err += addstringtoinfstr(line);
+					err |= addstringtoinfstr(line);
 				} else
 				{
-					err += io_makestringvar(((INTBIG *)var->addr)[i], ((INTBIG *)var->addr)[i-1],
+					err |= io_makestringvar(((INTBIG *)var->addr)[i], ((INTBIG *)var->addr)[i-1],
 						curnodeproto);
 				}
 			} else
@@ -379,35 +381,36 @@ char *io_makestring(VARIABLE *var, NODEPROTO *curnodeproto)
 				switch ((var->type&VTYPE))
 				{
 					case VCHAR:
-						err += io_makestringvar(var->type, ((INTBIG)((char *)var->addr)[i]),
+						err |= io_makestringvar(var->type, ((INTBIG)((char *)var->addr)[i]),
 							curnodeproto);
 						break;
 
 					case VDOUBLE:
-						err += io_makestringvar(var->type, ((INTBIG)((double *)var->addr)[i]),
+						err |= io_makestringvar(var->type, ((INTBIG)((double *)var->addr)[i]),
 							curnodeproto);
 						break;
 
 					default:
-						err += io_makestringvar(var->type, ((INTBIG *)var->addr)[i], curnodeproto);
+						err |= io_makestringvar(var->type, ((INTBIG *)var->addr)[i], curnodeproto);
 						break;
 				}
 			}
 		}
-		err += addtoinfstr(']');
-	} else err += io_makestringvar(var->type, var->addr, curnodeproto);
-	if (err != 0) return(0);
-	return(returninfstr());
+		err |= addtoinfstr(']');
+	} else err |= io_makestringvar(var->type, var->addr, curnodeproto);
+	pt = returninfstr();
+	if (err) pt = 0;
+	return(pt);
 }
 
 /*
  * routine to make a string from the value in "addr" which has a type in
- * "type".  Returns nonzero if there is a memory allocation error.
+ * "type".  Returns true if there is a memory allocation error.
  */
-INTSML io_makestringvar(INTBIG type, INTBIG addr, NODEPROTO *curnodeproto)
+BOOLEAN io_makestringvar(INTBIG type, INTBIG addr, NODEPROTO *curnodeproto)
 {
 	char line[100];
-	REGISTER INTSML err;
+	REGISTER BOOLEAN err;
 	REGISTER INTBIG cindex;
 	REGISTER NODEINST *ni;
 	REGISTER NODEPROTO *np;
@@ -431,14 +434,13 @@ INTSML io_makestringvar(INTBIG type, INTBIG addr, NODEPROTO *curnodeproto)
 			return(addstringtoinfstr(line));
 		case VADDRESS:
 			(void)sprintf(line, "0%lo", addr);
-			err = addstringtoinfstr(line);
-			return(err);
+			return(addstringtoinfstr(line));
 		case VCHAR:
 			return(addtoinfstr((char)addr));
 		case VSTRING:
 			err = addtoinfstr('"');
-			err += io_addstring((char *)addr);
-			err += addtoinfstr('"');
+			err |= io_addstring((char *)addr);
+			err |= addtoinfstr('"');
 			return(err);
 		case VFLOAT:
 			(void)sprintf(line, "%f", castfloat(addr));
@@ -466,8 +468,8 @@ INTSML io_makestringvar(INTBIG type, INTBIG addr, NODEPROTO *curnodeproto)
 			} else
 			{
 				err = io_addstring(np->tech->techname);
-				err += addtoinfstr(':');
-				err += io_addstring(np->primname);
+				err |= addtoinfstr(':');
+				err |= io_addstring(np->primname);
 				return(err);
 			}
 		case VPORTARCINST:
@@ -506,8 +508,8 @@ INTSML io_makestringvar(INTBIG type, INTBIG addr, NODEPROTO *curnodeproto)
 			ap = (ARCPROTO *)addr;
 			if (ap == NOARCPROTO) return(addstringtoinfstr("NOARCPROTO"));
 			err = io_addstring(ap->tech->techname);
-			err += addtoinfstr(':');
-			err += io_addstring(ap->protoname);
+			err |= addtoinfstr(':');
+			err |= io_addstring(ap->protoname);
 			return(err);
 		case VGEOM:
 			io_geomerror++;
@@ -520,8 +522,8 @@ INTSML io_makestringvar(INTBIG type, INTBIG addr, NODEPROTO *curnodeproto)
 			lib = (LIBRARY *)addr;
 			if (lib == NOLIBRARY) return(addstringtoinfstr("NOLIBRARY"));
 			err = addtoinfstr('"');
-			err += io_addstring(lib->libname);
-			err += addtoinfstr('"');
+			err |= io_addstring(lib->libname);
+			err |= addtoinfstr('"');
 			return(err);
 		case VTECHNOLOGY:
 			tech = (TECHNOLOGY *)addr;
@@ -537,25 +539,36 @@ INTSML io_makestringvar(INTBIG type, INTBIG addr, NODEPROTO *curnodeproto)
 			if (rtn == NORTNODE) return(addstringtoinfstr("NORTNODE"));
 			(void)sprintf(line, "rtn%ld", (INTBIG)rtn);
 			return(addstringtoinfstr(line));
+		case VNETWORK:
+		case VCELL:
+		case VVIEW:
+		case VWINDOWPART:
+		case VGRAPHICS:
+		case VSHORT:
+		case VCONSTRAINT:
+		case VGENERAL:
+		case VWINDOWFRAME:
+		case VPOLYGON:
+			break;
 	}
-	return(0);
+	return(FALSE);
 }
 
 /*
  * routine to add the string "str" to the infinite string and to quote the
- * special characters '[', ']', '"', and '^'.  The routine returns nonzero
+ * special characters '[', ']', '"', and '^'.  The routine returns true
  * if there is memory problem with the infinite string package.
  */
-INTSML io_addstring(char *str)
+BOOLEAN io_addstring(char *str)
 {
-	REGISTER INTSML err;
+	REGISTER BOOLEAN err;
 
-	err = 0;
+	err = FALSE;
 	while (*str != 0)
 	{
 		if (*str == '[' || *str == ']' || *str == '"' || *str == '^')
-			err += addtoinfstr('^');
-		err += addtoinfstr(*str++);
+			err |= addtoinfstr('^');
+		err |= addtoinfstr(*str++);
 	}
 	return(err);
 }
