@@ -43,9 +43,9 @@ static INTBIG io_vhdlcurline;
 static void io_vhdlreadfile(LIBRARY *lib, FILE *io);
 
 /*
- * Routine to read the VHDL file into library "lib".  Returns nonzero on error.
+ * Routine to read the VHDL file into library "lib".  Returns true on error.
  */
-INTSML io_readvhdllibrary(LIBRARY *lib)
+BOOLEAN io_readvhdllibrary(LIBRARY *lib)
 {
 	REGISTER FILE *io;
 	char *pt;
@@ -55,17 +55,17 @@ INTSML io_readvhdllibrary(LIBRARY *lib)
 	if ((io = xopen(lib->libfile, io_filetypevhdl, "", &pt)) == NULL)
 	{
 		ttyputerr(_("File %s not found"), lib->libfile);
-		return(1);
+		return(TRUE);
 	}
 
 	/* determine file length */
 	io_vhdllength = filesize(io);
 	if (io_verbose < 0 && io_vhdllength > 0)
 	{
-		if (DiaInitDialog(&us_progressdialog) != 0)
+		if (DiaInitDialog(&us_progressdialog))
 		{
 			xclose(io);
-			return(1);
+			return(TRUE);
 		}
 		DiaPercent(1, 0);
 	}
@@ -78,15 +78,15 @@ INTSML io_readvhdllibrary(LIBRARY *lib)
 		DiaPercent(1, 100);
 		DiaDoneDialog();
 	}
-	return(0);
+	return(FALSE);
 }
 
 void io_vhdlreadfile(LIBRARY *lib, FILE *io)
 {
 	char *pt, *start, text[MAXCHARS], facetname[256], endtag[256];
-	REGISTER INTSML save, sectionnamelen;
+	REGISTER char save;
 	enum {SECTIONNONE, SECTIONCOMPONENT, SECTIONENTITY, SECTIONARCHITECTURE} sectiontype;
-	REGISTER INTBIG i, len, curLength;
+	REGISTER INTBIG i, len, curLength, sectionnamelen;
 	REGISTER NODEPROTO *storagefacet;
 	void *stringarray;
 	REGISTER VARIABLE *var;
@@ -97,7 +97,7 @@ void io_vhdlreadfile(LIBRARY *lib, FILE *io)
 	for(;;)
 	{
 		if (stopping(STOPREASONVHDL)) break;
-		if (xfgets(text, MAXCHARS, io) != 0) break;
+		if (xfgets(text, MAXCHARS, io)) break;
 		io_vhdlcurline++;
 		if ((io_vhdlcurline % 100) == 0)
 		{
@@ -129,7 +129,7 @@ void io_vhdlreadfile(LIBRARY *lib, FILE *io)
 					*pt = 0;
 					strcpy(endtag, start);
 					strcpy(facetname, start);
-					*pt = (char)save;
+					*pt = save;
 
 					if (sectiontype == SECTIONARCHITECTURE)
 					{
@@ -143,7 +143,7 @@ void io_vhdlreadfile(LIBRARY *lib, FILE *io)
 							save = *pt;
 							*pt = 0;
 							strcpy(facetname, start);
-							*pt = (char)save;
+							*pt = save;
 						}
 					}
 
@@ -158,7 +158,7 @@ void io_vhdlreadfile(LIBRARY *lib, FILE *io)
 						/* already there: start with the existing VHDL */
 						stringarray = newstringarray(io_tool->cluster);
 						var = getvalkey((INTBIG)storagefacet, VNODEPROTO, VSTRING|VISARRAY,
-							el_facet_message);
+							el_facet_message_key);
 						if (var != NOVARIABLE)
 						{
 							len = getlength(var);
@@ -199,7 +199,7 @@ void io_vhdlreadfile(LIBRARY *lib, FILE *io)
 					case SECTIONCOMPONENT:
 						if (namesamen(pt, "component", 9) == 0)
 						{
-							stringarraytotextfacet(stringarray, storagefacet, 1);
+							stringarraytotextfacet(stringarray, storagefacet, TRUE);
 							killstringarray(stringarray);
 							storagefacet = NONODEPROTO;
 						}
@@ -211,11 +211,11 @@ void io_vhdlreadfile(LIBRARY *lib, FILE *io)
 						save = *pt;   *pt = 0;
 						if (namesame(start, endtag) == 0)
 						{
-							stringarraytotextfacet(stringarray, storagefacet, 1);
+							stringarraytotextfacet(stringarray, storagefacet, TRUE);
 							killstringarray(stringarray);
 							storagefacet = NONODEPROTO;
 						}
-						*pt = (char)save;
+						*pt = save;
 						break;
 					default:
 						break;
