@@ -57,7 +57,7 @@ typedef struct Ipolylist
 {
 	POLYGON          *poly;
 	TECHNOLOGY       *tech;
-	INTSML            networknum;
+	INTBIG            networknum;
 	struct Ipolylist *nextpolylist;
 } POLYLIST;
 
@@ -71,7 +71,7 @@ typedef struct Iobject
 		NODEINST   *ni;
 		ARCINST    *ai;
 	} inst;
-	INTSML          insttype;
+	BOOLEAN         isnode;
 	POLYLIST       *firstpolylist;
 	INTBIG          lowx, highx, lowy, highy;
 	struct Iobject *nextobject;
@@ -95,34 +95,34 @@ typedef struct Iline
 
 typedef struct Itecharray
 {
-	INTSML            *layer;
-	INTSML             taindex;
+	INTBIG            *layer;
+	INTBIG             taindex;
 	struct Itecharray *nexttecharray;
 } TECH_ARRAY;
 static TECH_ARRAY *com_conv_layer;
 
 /* prototypes for local routines */
 static void com_buildtechnologies(void);
-static OBJECT *com_make_ni_object(NODEINST*, OBJECT*, XARRAY, INTSML, INTBIG, INTBIG, INTBIG, INTBIG);
+static OBJECT *com_make_ni_object(NODEINST*, OBJECT*, XARRAY, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 static void com_fillnode(NODEINST*);
-static LINE *com_sort(LINE*, INTSML);
-static void com_computeline_hi_and_low(LINE*, INTSML);
-static INTSML com_lineup_firstrow(LINE*, LINE*, INTSML, INTBIG);
-static INTSML com_findleastlow(LINE*, INTSML);
-static INTSML com_compact(LINE*, LINE*, INTSML, INTSML, NODEPROTO*);
-static INTBIG com_checkinst(OBJECT*, LINE*, INTSML, OBJECT**, POLYLIST **, POLYLIST **, NODEPROTO*);
-static INTBIG com_minseparate(OBJECT*, INTSML, POLYLIST*, LINE*, INTSML, OBJECT**, POLYLIST **, NODEPROTO*);
-static INTBIG com_check(INTSML, INTSML, OBJECT*, INTBIG, INTBIG, INTBIG, INTBIG, INTSML, INTSML, OBJECT*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTSML);
-static INTSML com_cropnodeinst(POLYLIST*, INTBIG*, INTBIG*, INTBIG*, INTBIG*, INTSML, INTSML);
-static INTSML com_in_bound(INTBIG, INTBIG, INTBIG, INTBIG);
+static LINE *com_sort(LINE*, INTBIG);
+static void com_computeline_hi_and_low(LINE*, INTBIG);
+static BOOLEAN com_lineup_firstrow(LINE*, LINE*, INTBIG, INTBIG);
+static INTBIG com_findleastlow(LINE*, INTBIG);
+static BOOLEAN com_compact(LINE*, LINE*, INTBIG, BOOLEAN, NODEPROTO*);
+static INTBIG com_checkinst(OBJECT*, LINE*, INTBIG, OBJECT**, POLYLIST **, POLYLIST **, NODEPROTO*);
+static INTBIG com_minseparate(OBJECT*, INTBIG, POLYLIST*, LINE*, INTBIG, OBJECT**, POLYLIST **, NODEPROTO*);
+static INTBIG com_check(INTBIG, INTBIG, OBJECT*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, OBJECT*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+static BOOLEAN com_cropnodeinst(POLYLIST*, INTBIG*, INTBIG*, INTBIG*, INTBIG*, INTBIG, INTBIG);
+static BOOLEAN com_in_bound(INTBIG, INTBIG, INTBIG, INTBIG);
 static void com_fixed_nonfixed(LINE*, LINE*);
 static void com_undo_fixed_nonfixed(LINE*, LINE*);
 static void com_noslide(LINE*);
 static void com_slide(LINE*);
-static INTSML com_move(LINE*, INTBIG, INTBIG, INTSML);
-static INTSML com_convertpintonode_layer(INTSML, TECHNOLOGY*);
+static BOOLEAN com_move(LINE*, INTBIG, INTBIG, BOOLEAN);
+static INTBIG com_convertpintonode_layer(INTBIG, TECHNOLOGY*);
 static void com_subsmash(NODEPROTO*);
-static void com_add_poly_polylist(POLYGON*, OBJECT*, INTSML, TECHNOLOGY*);
+static void com_add_poly_polylist(POLYGON*, OBJECT*, INTBIG, TECHNOLOGY*);
 static OBJECT *com_allocate_object(void);
 static void com_add_object_to_object(OBJECT**, OBJECT*);
 static LINE *com_make_object_line(LINE*, OBJECT*);
@@ -131,9 +131,9 @@ static void com_freeobject(OBJECT*);
 static char *com_describeline(LINE*);
 static void com_addlinedescription(LINE*);
 static char *com_describeobject(OBJECT*);
-static void com_createobjects(NODEINST*, INTSML, OBJECT**, OBJECT**);
-static OBJECT *com_make_ai_object(ARCINST*, OBJECT*, XARRAY, INTSML, INTBIG, INTBIG, INTBIG, INTBIG);
-static INTSML com_examineonefacet(NODEPROTO*, INTSML, INTSML);
+static void com_createobjects(NODEINST*, INTBIG, OBJECT**, OBJECT**);
+static OBJECT *com_make_ai_object(ARCINST*, OBJECT*, XARRAY, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+static BOOLEAN com_examineonefacet(NODEPROTO*, INTBIG, BOOLEAN);
 static void comp_optionsdlog(void);
 
 /* the COMPACTOR tool table */
@@ -166,11 +166,11 @@ COMCOMP com_compactp = {comopt, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP,
 	0, " \t", M_("Compactor action"), M_("show defaults")};
 
        TOOL     *com_tool;
-static INTBIG    com_spread;			/* cached key for "COM_spread" */
-static INTSML    com_debug;
+static INTBIG    com_spread_key;		/* variable key for "COM_spread" */
+static BOOLEAN   com_debug;
 static INTBIG    com_maxboundary, com_lowbound;
 static INTBIG    com_flatindex;			/* counter for unique network numbers */
-static INTSML    com_do_axis;
+static INTBIG    com_do_axis;
 
 /************************ CONTROL ***********************/
 
@@ -182,10 +182,10 @@ void com_init(INTBIG *argc, char *argv[], TOOL *thistool)
 	/* miscellaneous initialization during pass 2 */
 	if (thistool == NOTOOL)
 	{
-		com_spread = makekey("COM_spread");
+		com_spread_key = makekey("COM_spread");
 		nextchangequiet();
-		(void)setvalkey((INTBIG)com_tool, VTOOL, com_spread, 0, VINTEGER|VDONTSAVE);
-		com_debug = 0;
+		(void)setvalkey((INTBIG)com_tool, VTOOL, com_spread_key, 0, VINTEGER|VDONTSAVE);
+		com_debug = FALSE;
 		com_do_axis = VERTICAL;
 		com_conv_layer = NOTECHARRAY;
 		registertechnologycache(com_buildtechnologies, 0, 0);
@@ -205,7 +205,7 @@ void com_buildtechnologies(void)
 {
 	REGISTER TECHNOLOGY *tech;
 	REGISTER TECH_ARRAY *cur_tech_array, *next_techarray;
-	REGISTER INTSML j, k;
+	REGISTER INTBIG j, k;
 	REGISTER INTBIG layer;
 
 	/* first free the former list of layer conversions */
@@ -227,7 +227,7 @@ void com_buildtechnologies(void)
 		cur_tech_array->nexttecharray = com_conv_layer;
 		com_conv_layer = cur_tech_array;
 
-		cur_tech_array->layer = (INTSML *)emalloc((sizeof(INTSML) * tech->layercount),
+		cur_tech_array->layer = (INTBIG *)emalloc(SIZEOFINTBIG * tech->layercount,
 			com_tool->cluster);
 
 		/* define the layer translation for pseudo layers and regular layers */
@@ -269,7 +269,7 @@ void com_done(void)
 
 void com_slice(void)
 {
-	REGISTER INTSML change;
+	REGISTER BOOLEAN change;
 	REGISTER NODEPROTO *np;
 
 	np = getcurfacet();
@@ -279,7 +279,7 @@ void com_slice(void)
 	if ((net_tool->toolstate&TOOLON) == 0)
 	{
 		ttyputerr(_("Network tool must be running...turning it on"));
-		toolturnon(net_tool, 0);
+		toolturnon(net_tool, FALSE);
 		return;
 	}
 
@@ -287,31 +287,31 @@ void com_slice(void)
 	if (com_do_axis == VERTICAL) com_do_axis = HORIZONTAL; else
 		com_do_axis = VERTICAL;
 
-	change = com_examineonefacet(np, com_do_axis, 1);
+	change = com_examineonefacet(np, com_do_axis, TRUE);
 
 	if (!change)
 	{
 		 ttyputmsg(_("No further change.  Compactor turned off"));
-		 toolturnoff(com_tool, 0);
+		 toolturnoff(com_tool, FALSE);
 	} else setactivity(_("Compaction"));
 }
 
-INTSML com_set(INTSML count, char *par[])
+void com_set(INTBIG count, char *par[])
 {
 	REGISTER NODEPROTO *np;
-	REGISTER INTSML l, i;
+	REGISTER INTBIG l;
 	REGISTER char *pp;
 	REGISTER VARIABLE *var;
 
 	if (count == 0)
 	{
-		var = getvalkey((INTBIG)com_tool, VTOOL, VINTEGER, com_spread);
+		var = getvalkey((INTBIG)com_tool, VTOOL, VINTEGER, com_spread_key);
 		if (var != NOVARIABLE)
 		{
 			if (var->addr != 0) ttyputmsg(M_("Compactor will spread if necessary")); else
 				ttyputmsg(M_("Compactor will not spread designs"));
 		}
-		return(0);
+		return;
 	}
 
 	l = strlen(pp = par[0]);
@@ -324,25 +324,25 @@ INTSML com_set(INTSML count, char *par[])
 			if (count <= 1)
 			{
 				ttyputerr(M_("Aborted"));
-				return(1);
+				return;
 			}
 		}
 		l = strlen(pp = par[1]);
 		if (namesamen(pp, "spread", l) == 0)
 		{
-			(void)setvalkey((INTBIG)com_tool, VTOOL, com_spread, 0, VINTEGER|VDONTSAVE);
+			(void)setvalkey((INTBIG)com_tool, VTOOL, com_spread_key, 0, VINTEGER|VDONTSAVE);
 			ttyputverbose(M_("Compactor will not spread designs"));
-			return(0);
+			return;
 		}
 		ttyputbadusage("telltool compaction not");
-		return(1);
+		return;
 	}
 
 	if (namesamen(pp, "spread", l) == 0)
 	{
-		(void)setvalkey((INTBIG)com_tool, VTOOL, com_spread, 1, VINTEGER|VDONTSAVE);
+		(void)setvalkey((INTBIG)com_tool, VTOOL, com_spread_key, 1, VINTEGER|VDONTSAVE);
 		ttyputverbose(M_("Compactor will spread if necessary"));
-		return(0);
+		return;
 	}
 
 	if (namesamen(pp, "check", l) == 0)
@@ -351,30 +351,27 @@ INTSML com_set(INTSML count, char *par[])
 		if ((net_tool->toolstate&TOOLON) == 0)
 		{
 			ttyputerr(M_("Network tool must be running...turning it on"));
-			toolturnon(net_tool, 0);
+			toolturnon(net_tool, FALSE);
 			ttyputerr(M_("...now reissue the compaction command"));
-			return(1);
+			return;
 		}
 
 		if (count <= 1)
 		{
-			ttyputmsg(M_("Do you want horizontal or vertical compaction? "));
-			i = (INTSML)ttygetchar();
-			if (i == (INTSML)'v' || i == (INTSML)'V') com_do_axis = VERTICAL; else
-				if (i == (INTSML)'h' || i == (INTSML)'H') com_do_axis = HORIZONTAL; else
+			count = ttygetparam(M_("Direction to compact:"), &comhvp, MAXPARS-1,
+				&par[1]) + 1;
+			if (count <= 1)
 			{
-				ttyputerr(M_("Unknown compaction axis: '%c', expected 'v' or 'h'"), i);
-				return(1);
+				ttyputerr(M_("Aborted"));
+				return;
 			}
-		} else
+		}
+		l = strlen(pp = par[1]);
+		if (namesamen(pp, "horizontal", l) == 0) com_do_axis = HORIZONTAL; else
+		if (namesamen(pp, "vertical", l) == 0) com_do_axis = VERTICAL; else
 		{
-			l = strlen(pp = par[1]);
-			if (namesamen(pp, "horizontal", l) == 0) com_do_axis = HORIZONTAL; else
-			if (namesamen(pp, "vertical", l) == 0) com_do_axis = VERTICAL; else
-			{
-				ttyputbadusage("telltool compaction check");
-				return(1);
-			}
+			ttyputbadusage("telltool compaction check");
+			return;
 		}
 
 		if (count >= 3)
@@ -383,12 +380,12 @@ INTSML com_set(INTSML count, char *par[])
 			if (np == NONODEPROTO)
 			{
 				ttyputerr(M_("No facet named %s"), par[2]);
-				return(1);
+				return;
 			}
 			if (np->primindex != 0)
 			{
 				ttyputerr(M_("Can only compact facets, not primitives"));
-				return(1);
+				return;
 			}
 		} else
 		{
@@ -396,30 +393,29 @@ INTSML com_set(INTSML count, char *par[])
 			if (np == NONODEPROTO)
 			{
 				ttyputerr(_("No current facet"));
-				return(1);
+				return;
 			}
 		}
 
-		(void)com_examineonefacet(np, com_do_axis, 0);
+		(void)com_examineonefacet(np, com_do_axis, FALSE);
 		ttyputmsg(_("Facet %s compacted"), describenodeproto(np));
-		return(0);
+		return;
 	}
 
 	if (namesamen(pp, "debug-toggle", l) == 0)
 	{
-		if (com_debug == 0)
+		if (!com_debug)
 		{
-			com_debug = 1;
+			com_debug = TRUE;
 			ttyputmsg(M_("Compactor will print debugging information"));
 		} else
 		{
-			com_debug = 0;
+			com_debug = FALSE;
 			ttyputmsg(M_("Compactor will not print debugging information"));
 		}
-		return(0);
+		return;
 	}
 	ttyputbadusage("telltool compaction");
-	return(1);
 }
 
 /************************ COMPACTION ***********************/
@@ -427,24 +423,24 @@ INTSML com_set(INTSML count, char *par[])
 /*
  * routine to do vertical compaction (if "axis" is VERTICAL) or horizontal
  * compaction (if "axis" is HORIZONTAL) to facet "np".  Displays state if
- * "verbose" is nonzero.  Returns nonzero if a change was made.
+ * "verbose" is nonzero.  Returns true if a change was made.
  */
-INTSML com_examineonefacet(NODEPROTO *np, INTSML axis, INTSML verbose)
+BOOLEAN com_examineonefacet(NODEPROTO *np, INTBIG axis, BOOLEAN verbose)
 {
 	REGISTER NODEINST *ni;
 	REGISTER PORTPROTO *pp, *opp;
 	REGISTER OBJECT *cur_object, **thisobject, **otherobject;
 	OBJECT *object1, *object2;
 	REGISTER LINE *linecomp, *linestretch, *cur_line;
-	REGISTER INTSML i, change;
-	REGISTER INTBIG max;
+	REGISTER BOOLEAN change;
+	REGISTER INTBIG i, max;
 
-	if (stopping(STOPREASONCOMPACT)) return(0);
+	if (stopping(STOPREASONCOMPACT)) return(FALSE);
 
 	if (np == NONODEPROTO)
 	{
 		ttyputmsg(_("No current facet to compact"));
-		return(0);
+		return(FALSE);
 	}
 
 	/* determine maximum drc surround for entire technology */
@@ -456,7 +452,7 @@ INTSML com_examineonefacet(NODEPROTO *np, INTSML axis, INTSML verbose)
 	}
 	if (com_maxboundary < 0) com_maxboundary = 0;
 
-	if (verbose != 0)
+	if (verbose)
 	{
 		if (axis == HORIZONTAL) ttyputmsg(_("Doing a horizontal compaction")); else
 			ttyputmsg(_("Doing a vertical compaction"));
@@ -503,7 +499,7 @@ INTSML com_examineonefacet(NODEPROTO *np, INTSML axis, INTSML verbose)
 		linestretch = com_make_object_line(NOLINE, *otherobject);
 
 	/* print the stretch object */
-	if (com_debug != 0)
+	if (com_debug)
 	{
 		(void)initinfstr();
 		if (linestretch != NOLINE)
@@ -511,7 +507,7 @@ INTSML com_examineonefacet(NODEPROTO *np, INTSML axis, INTSML verbose)
 				cur_object = cur_object->nextobject)
 		{
 			(void)addtoinfstr(' ');
-			if (cur_object->insttype == OBJARCINST)
+			if (!cur_object->isnode)
 				(void)addstringtoinfstr(describearcinst(cur_object->inst.ai)); else
 					(void)addstringtoinfstr(describenodeinst(cur_object->inst.ni));
 		}
@@ -522,7 +518,7 @@ INTSML com_examineonefacet(NODEPROTO *np, INTSML axis, INTSML verbose)
 	linecomp = com_sort(linecomp, axis);
 
 	/* print the merged structure */
-	if (com_debug != 0)
+	if (com_debug)
 	{
 		if (axis == VERTICAL) ttyputmsg(M_("Bottom-to-top:")); else
 			ttyputmsg(M_("Left-to-right:"));
@@ -546,7 +542,7 @@ INTSML com_examineonefacet(NODEPROTO *np, INTSML axis, INTSML verbose)
 	change = com_compact(linecomp, linestretch, axis, change, np);
 
 	/* restore rigidity if no changes were made */
-	if (change == 0) com_undo_fixed_nonfixed(linecomp, linestretch);
+	if (!change) com_undo_fixed_nonfixed(linecomp, linestretch);
 
 	/* allow the streteching line to slide again */
 	com_slide(linestretch);
@@ -559,7 +555,7 @@ INTSML com_examineonefacet(NODEPROTO *np, INTSML axis, INTSML verbose)
 
 /******************** SUPPORT ROUTINES ********************/
 
-void com_createobjects(NODEINST *ni, INTSML axis, OBJECT **thisobject,
+void com_createobjects(NODEINST *ni, INTBIG axis, OBJECT **thisobject,
 	OBJECT **otherobject)
 {
 	REGISTER OBJECT *new_object, *second_object;
@@ -631,7 +627,7 @@ void com_createobjects(NODEINST *ni, INTSML axis, OBJECT **thisobject,
  * defined by "low1", "high1" and "low2", "high2" before being added to "object".
  */
 OBJECT *com_make_ai_object(ARCINST *ai, OBJECT *object, XARRAY newtrans,
-	INTSML axis, INTBIG low1, INTBIG high1, INTBIG low2, INTBIG high2)
+	INTBIG axis, INTBIG low1, INTBIG high1, INTBIG low2, INTBIG high2)
 {
 	REGISTER OBJECT *new_object;
 	REGISTER INTBIG j, tot;
@@ -644,7 +640,7 @@ OBJECT *com_make_ai_object(ARCINST *ai, OBJECT *object, XARRAY newtrans,
 		new_object = com_allocate_object();
 		if (new_object == NOOBJECT) return(NOOBJECT);
 		new_object->inst.ai = (ARCINST *)ai;
-		new_object->insttype = OBJARCINST;
+		new_object->isnode = FALSE;
 		new_object->nextobject = NOOBJECT;
 		new_object->firstpolylist = NOPOLYLIST;
 		new_object->lowx = ai->geom->lowx;
@@ -687,7 +683,7 @@ OBJECT *com_make_ai_object(ARCINST *ai, OBJECT *object, XARRAY newtrans,
 		}
 
 		/* add the polygon */
-		com_add_poly_polylist(poly, new_object, (INTSML)ai->temp1,
+		com_add_poly_polylist(poly, new_object, ai->temp1,
 			ai->proto->tech);
 	}
 	return(new_object);
@@ -702,7 +698,7 @@ OBJECT *com_make_ai_object(ARCINST *ai, OBJECT *object, XARRAY newtrans,
  * "object".
  */
 OBJECT *com_make_ni_object(NODEINST *ni, OBJECT *object, XARRAY newtrans,
-	INTSML axis, INTBIG low1, INTBIG high1, INTBIG low2, INTBIG high2)
+	INTBIG axis, INTBIG low1, INTBIG high1, INTBIG low2, INTBIG high2)
 {
 	REGISTER OBJECT *new_object;
 	XARRAY trans, t1, temp;
@@ -718,7 +714,7 @@ OBJECT *com_make_ni_object(NODEINST *ni, OBJECT *object, XARRAY newtrans,
 		new_object = com_allocate_object();
 		if (new_object == NOOBJECT) return(NOOBJECT);
 		new_object->inst.ni = ni;
-		new_object->insttype = OBJNODEINST;
+		new_object->isnode = TRUE;
 		new_object->nextobject = NOOBJECT;
 		new_object->firstpolylist = NOPOLYLIST;
 		new_object->lowx = ni->geom->lowx;
@@ -807,7 +803,7 @@ OBJECT *com_make_ni_object(NODEINST *ni, OBJECT *object, XARRAY newtrans,
 
 			if (poly->portproto == NOPORTPROTO) pindex = -1; else
 				pindex = poly->portproto->temp1;
-			com_add_poly_polylist(poly, new_object, (INTSML)pindex, ni->proto->tech);
+			com_add_poly_polylist(poly, new_object, pindex, ni->proto->tech);
 		}
 	}
 	return(new_object);
@@ -858,13 +854,13 @@ void com_fillnode(NODEINST *ni)
 /*
  * routine to sort line by center val from least to greatest
  */
-LINE *com_sort(LINE *line, INTSML axis)
+LINE *com_sort(LINE *line, INTBIG axis)
 {
 	REGISTER LINE *new_line, *cur_line, *bestline;
 	REGISTER OBJECT *cur_object;
 	REGISTER INTBIG bestval;
 	float ave, ctr, len, totallen;
-	REGISTER INTSML first;
+	REGISTER BOOLEAN first;
 
 	if (line == NOLINE)
 	{
@@ -902,14 +898,14 @@ LINE *com_sort(LINE *line, INTSML axis)
 	for(;;)
 	{
 		if (line == NOLINE) break;
-		first = 1;
+		first = TRUE;
 		for(cur_line = line; cur_line != NOLINE; cur_line = cur_line->nextline)
 		{
-			if (first != 0)
+			if (first)
 			{
 				bestval = cur_line->val;
 				bestline = cur_line;
-				first = 0;
+				first = FALSE;
 			} else if (cur_line->val > bestval)
 			{
 				bestval = cur_line->val;
@@ -932,25 +928,25 @@ LINE *com_sort(LINE *line, INTSML axis)
 	return(new_line);
 }
 
-void com_computeline_hi_and_low(LINE *line, INTSML axis)
+void com_computeline_hi_and_low(LINE *line, INTBIG axis)
 {
-	REGISTER INTSML first_time;
+	REGISTER BOOLEAN first_time;
 	REGISTER INTBIG lx, hx, ly, hy;
 	REGISTER OBJECT *cur_object;
 
 	/* find smallest and highest vals for the each object */
-	first_time = 1;
+	first_time = TRUE;
 	for(cur_object = line->firstobject; cur_object != NOOBJECT;
 		cur_object = cur_object->nextobject)
 	{
-		if (cur_object->insttype == OBJARCINST) continue;
+		if (!cur_object->isnode) continue;
 		if (first_time)
 		{
 			lx = cur_object->lowx;
 			hx = cur_object->highx;
 			ly = cur_object->lowy;
 			hy = cur_object->highy;
-			first_time = 0;
+			first_time = FALSE;
 		} else
 		{
 			if (cur_object->lowx < lx) lx = cur_object->lowx;
@@ -974,16 +970,16 @@ void com_computeline_hi_and_low(LINE *line, INTSML axis)
 	}
 }
 
-INTSML com_lineup_firstrow(LINE *line, LINE *other_line, INTSML axis, INTBIG lowbound)
+BOOLEAN com_lineup_firstrow(LINE *line, LINE *other_line, INTBIG axis, INTBIG lowbound)
 {
 	REGISTER INTBIG i;
-	REGISTER INTSML change;
+	REGISTER BOOLEAN change;
 
-	change = 0;
+	change = FALSE;
 	i = line->low - lowbound;
 	if (i > 0)
 	{
-		if (com_debug != 0)
+		if (com_debug)
 			ttyputmsg(M_("Lining up the first row to low edge %s"), latoa(lowbound));
 		if (axis == HORIZONTAL) change = com_move(line, i, 0, change); else
 			change = com_move(line, 0, i, change);
@@ -997,36 +993,36 @@ INTSML com_lineup_firstrow(LINE *line, LINE *other_line, INTSML axis, INTBIG low
  * finds the smallest low value (lowx for VERTICAL, lowy for HORIZ case)
  * stores it in line->low.
  */
-INTSML com_findleastlow(LINE *line, INTSML axis)
+INTBIG com_findleastlow(LINE *line, INTBIG axis)
 {
-	REGISTER INTSML first_time;
+	REGISTER BOOLEAN first_time;
 	REGISTER INTBIG low, thislow;
 	REGISTER OBJECT *cur_object;
 
 	if (line == NOLINE) return(0);
 
 	/* find smallest low for the each object */
-	first_time = 1;
+	first_time = TRUE;
 	for(cur_object = line->firstobject; cur_object != NOOBJECT;
 		cur_object = cur_object->nextobject)
 	{
-		if (cur_object->insttype == OBJARCINST) continue;
+		if (!cur_object->isnode) continue;
 		if (axis == HORIZONTAL) thislow = cur_object->lowx; else
 			thislow = cur_object->lowy;
 
 		/* LINTED "low" used in proper order */
-		if (first_time == 0) low = mini(low, thislow); else
+		if (!first_time) low = mini(low, thislow); else
 		{
 			low = thislow;
-			first_time = 0;
+			first_time = FALSE;
 		}
 	}
 	line->low = low;
 
-	return((INTSML)low);
+	return(low);
 }
 
-INTSML com_compact(LINE *line, LINE *other_line, INTSML axis, INTSML change,
+BOOLEAN com_compact(LINE *line, LINE *other_line, INTBIG axis, BOOLEAN change,
 	NODEPROTO *facet)
 {
 	REGISTER LINE *cur_line, *prev_line;
@@ -1038,7 +1034,7 @@ INTSML com_compact(LINE *line, LINE *other_line, INTSML axis, INTSML change,
 	REGISTER VARIABLE *var;
 
 	spread = 0;
-	var = getvalkey((INTBIG)com_tool, VTOOL, VINTEGER, com_spread);
+	var = getvalkey((INTBIG)com_tool, VTOOL, VINTEGER, com_spread_key);
 	if (var != NOVARIABLE && var->addr != 0) spread++;
 
 	/* loop through all lines that may compact */
@@ -1081,7 +1077,7 @@ INTSML com_compact(LINE *line, LINE *other_line, INTSML axis, INTSML change,
 			/* no constraints: allow overlap */
 			best_motion = cur_line->low - com_lowbound;
 		}
-		if (com_debug != 0)
+		if (com_debug)
 		{
 			ttyputmsg(M_("Moving object '%s' by %s"), com_describeline(cur_line),
 				latoa(best_motion));
@@ -1117,10 +1113,10 @@ INTSML com_compact(LINE *line, LINE *other_line, INTSML axis, INTSML change,
 	return(change);
 }
 
-INTBIG com_checkinst(OBJECT *object, LINE *line, INTSML axis, OBJECT **oreason,
+INTBIG com_checkinst(OBJECT *object, LINE *line, INTBIG axis, OBJECT **oreason,
 	POLYLIST **opreason, POLYLIST **preason, NODEPROTO *facet)
 {
-	REGISTER INTSML layer;
+	REGISTER INTBIG layer;
 	REGISTER INTBIG this_motion, best_motion;
 	REGISTER POLYGON *poly;
 	REGISTER POLYLIST *polys;
@@ -1160,13 +1156,14 @@ INTBIG com_checkinst(OBJECT *object, LINE *line, INTSML axis, OBJECT **oreason,
  * overlap).  The object "reason" is set to the object that is causing the
  * constraint.
  */
-INTBIG com_minseparate(OBJECT *object, INTSML nlayer, POLYLIST *npolys,
-	LINE *line, INTSML axis, OBJECT **oreason, POLYLIST **preason,
+INTBIG com_minseparate(OBJECT *object, INTBIG nlayer, POLYLIST *npolys,
+	LINE *line, INTBIG axis, OBJECT **oreason, POLYLIST **preason,
 	NODEPROTO *facet)
 {
-	REGISTER INTBIG bound, dist, con, geom_lo, ai_hi, ni_hi,
+	REGISTER INTBIG bound, dist, geom_lo, ai_hi, ni_hi,
 		best_motion, this_motion, fun, minsize, nminsize;
-	REGISTER INTSML pindex, nindex, layer;
+	REGISTER INTBIG pindex, nindex, layer;
+	REGISTER BOOLEAN con;
 	REGISTER POLYGON *poly, *npoly;
 	INTBIG lx, hx, ly, hy, xl, xh, yl, yh, edge;
 	REGISTER OBJECT *cur_object;
@@ -1186,7 +1183,7 @@ INTBIG com_minseparate(OBJECT *object, INTSML nlayer, POLYLIST *npolys,
 	if (bound < 0) return(DEFAULT_VAL);
 
 	/* can only handle orthogonal rectangles for now */
-	if (isbox(npoly, &lx, &hx, &ly, &hy) == 0) return(bound);
+	if (!isbox(npoly, &lx, &hx, &ly, &hy)) return(bound);
 
 	best_motion = DEFAULT_VAL;
 	if (axis == HORIZONTAL) geom_lo = object->lowx; else
@@ -1196,7 +1193,7 @@ INTBIG com_minseparate(OBJECT *object, INTSML nlayer, POLYLIST *npolys,
 	for(cur_object = line->firstobject; cur_object != NOOBJECT;
 		cur_object = cur_object->nextobject)
 	{
-		if (cur_object->insttype == OBJNODEINST)
+		if (cur_object->isnode)
 		{
 			if (axis == HORIZONTAL) ni_hi = cur_object->highx; else
 				ni_hi = cur_object->highy;
@@ -1218,9 +1215,9 @@ INTBIG com_minseparate(OBJECT *object, INTSML nlayer, POLYLIST *npolys,
 					pindex = polys->networknum;
 
 					/* see whether the two objects are electrically connected */
-					if (pindex == nindex && pindex != -1) con = 1;
-						else con = 0;
-					if (isbox(poly, &xl, &xh, &yl, &yh) == 0)
+					if (pindex == nindex && pindex != -1) con = TRUE;
+						else con = FALSE;
+					if (!isbox(poly, &xl, &xh, &yl, &yh))
 					{
 						this_motion = geom_lo - ni_hi - bound;
 						if (this_motion == DEFAULT_VAL) continue;
@@ -1236,7 +1233,7 @@ INTBIG com_minseparate(OBJECT *object, INTSML nlayer, POLYLIST *npolys,
 					/* see how close they can get */
 					minsize = polyminsize(poly);
 					dist = drcmindistance(tech, facet->cell->lib, nlayer, nminsize,
-						layer, minsize, con, 0, &edge, 0);
+						layer, minsize, con, FALSE, &edge, 0);
 					if (dist < 0) continue;
 
 					/*
@@ -1249,9 +1246,9 @@ INTBIG com_minseparate(OBJECT *object, INTSML nlayer, POLYLIST *npolys,
 					if (nlayer == layer)
 					{
 						fun = layerfunction(tech, nlayer) & LFTYPE;
-						if (con != 0)
+						if (con)
 						{
-							if (layeriscontact(fun) == 0) continue;
+							if (!layeriscontact(fun)) continue;
 						} else
 						{
 							if (fun == LFSUBSTRATE || fun == LFWELL ||
@@ -1300,10 +1297,10 @@ INTBIG com_minseparate(OBJECT *object, INTSML nlayer, POLYLIST *npolys,
 
 					/* see whether the two objects are electrically connected */
 					pindex = polys->networknum;
-					if (nindex == -1 || pindex == nindex) con = 1; else con = 0;
+					if (nindex == -1 || pindex == nindex) con = TRUE; else con = FALSE;
 
 					/* warning: non-manhattan arcs are ignored here */
-					if (isbox(poly, &xl, &xh, &yl, &yh) == 0)
+					if (!isbox(poly, &xl, &xh, &yl, &yh))
 					{
 						this_motion = geom_lo - ai_hi - bound;
 						if (this_motion == DEFAULT_VAL) continue;
@@ -1319,7 +1316,7 @@ INTBIG com_minseparate(OBJECT *object, INTSML nlayer, POLYLIST *npolys,
 					/* see how close they can get */
 					minsize = polyminsize(poly);
 					dist = drcmindistance(tech, facet->cell->lib, nlayer, nminsize,
-						poly->layer, minsize, con, 0, &edge, 0);
+						poly->layer, minsize, con, FALSE, &edge, 0);
 					if (dist < 0) continue;
 
 					/*
@@ -1355,18 +1352,18 @@ INTBIG com_minseparate(OBJECT *object, INTSML nlayer, POLYLIST *npolys,
  * "object2" are (lx2-hx2,ly2-hy2).  If the objects are in bounds, the spacing
  * between them is returned.  Otherwise, DEFAULT_VAL is returned.
  */
-INTBIG com_check(INTSML layer1, INTSML index1, OBJECT *object1, INTBIG lx1, INTBIG hx1,
-	INTBIG ly1, INTBIG hy1, INTSML layer2, INTSML index2, OBJECT *object2, INTBIG lx2,
-	INTBIG hx2, INTBIG ly2, INTBIG hy2, INTBIG dist, INTSML axis)
+INTBIG com_check(INTBIG layer1, INTBIG index1, OBJECT *object1, INTBIG lx1, INTBIG hx1,
+	INTBIG ly1, INTBIG hy1, INTBIG layer2, INTBIG index2, OBJECT *object2, INTBIG lx2,
+	INTBIG hx2, INTBIG ly2, INTBIG hy2, INTBIG dist, INTBIG axis)
 {
 	/* crop out parts of a box covered by a similar layer on the other node */
-	if (object1->insttype == OBJNODEINST)
+	if (object1->isnode)
 	{
 		if (com_cropnodeinst(object1->firstpolylist, &lx2, &hx2, &ly2, &hy2,
 			layer2, index2))
 				return(DEFAULT_VAL);
 	}
-	if (object2->insttype == OBJNODEINST)
+	if (object2->isnode)
 	{
 		if (com_cropnodeinst(object2->firstpolylist, &lx1, &hx1, &ly1, &hy1,
 			layer1, index1))
@@ -1385,11 +1382,11 @@ INTBIG com_check(INTSML layer1, INTSML index1, OBJECT *object1, INTBIG lx1, INTB
  * routine to crop the box on layer "nlayer", electrical index "nindex"
  * and bounds (lx-hx, ly-hy) against the nodeinst "ni".  Only those layers
  * in the nodeinst that are the same layer and the same electrical index
- * are checked.  The routine returns non-zero if the bounds are reduced
+ * are checked.  The routine returns true if the bounds are reduced
  * to nothing.
  */
-INTSML com_cropnodeinst(POLYLIST *polys, INTBIG *bx, INTBIG *by,
-	INTBIG *ux, INTBIG *uy, INTSML nlayer, INTSML nindex)
+BOOLEAN com_cropnodeinst(POLYLIST *polys, INTBIG *bx, INTBIG *by,
+	INTBIG *ux, INTBIG *uy, INTBIG nlayer, INTBIG nindex)
 {
 	INTBIG xl, xh, yl, yh;
 	REGISTER INTBIG temp;
@@ -1400,16 +1397,16 @@ INTSML com_cropnodeinst(POLYLIST *polys, INTBIG *bx, INTBIG *by,
 	{
 		if (cur_polys->networknum != nindex) continue;
 		if (cur_polys->poly->layer != nlayer) continue;
-		if (isbox(cur_polys->poly, &xl, &xh, &yl, &yh) == 0) continue;
+		if (!isbox(cur_polys->poly, &xl, &xh, &yl, &yh)) continue;
 		if (xl > xh) { temp = xl; xl = xh; xh = temp; }
 		if (yl > yh) { temp = yl; yl = yh; yh = temp; }
 		temp = cropbox(bx, ux, by, uy, xl, xh, yl, yh);
-		if (temp > 0) return(1);
+		if (temp > 0) return(TRUE);
 	}
-	return(0);
+	return(FALSE);
 }
 
-INTSML com_in_bound(INTBIG ll, INTBIG lh, INTBIG rl, INTBIG rh)
+BOOLEAN com_in_bound(INTBIG ll, INTBIG lh, INTBIG rl, INTBIG rh)
 {
 	if (rh > ll && rl < lh) return(1);
 	return(0);
@@ -1428,7 +1425,7 @@ void com_fixed_nonfixed(LINE *fixline, LINE *nfixline)
 	{
 		for(cur_object = cur_line->firstobject; cur_object != NOOBJECT;
 			cur_object = cur_object->nextobject)
-				if (cur_object->insttype == OBJARCINST)    /* arc rigid */
+				if (!cur_object->isnode)    /* arc rigid */
 					(void)(*el_curconstraint->setobject)((INTBIG)cur_object->inst.ai,
 						VARCINST, CHANGETYPETEMPRIGID, 0);
 	}
@@ -1436,7 +1433,7 @@ void com_fixed_nonfixed(LINE *fixline, LINE *nfixline)
 	{
 		for(cur_object = cur_line->firstobject; cur_object != NOOBJECT;
 			cur_object = cur_object->nextobject)
-				if (cur_object->insttype == OBJARCINST)   /* arc unrigid */
+				if (!cur_object->isnode)   /* arc unrigid */
 					(void)(*el_curconstraint->setobject)((INTBIG)cur_object->inst.ai,
 						VARCINST, CHANGETYPETEMPUNRIGID, 0);
 	}
@@ -1455,7 +1452,7 @@ void com_undo_fixed_nonfixed(LINE *fixline, LINE *nfixline)
 	{
 		for(cur_object = cur_line->firstobject; cur_object != NOOBJECT;
 			cur_object = cur_object->nextobject)
-				if (cur_object->insttype == OBJARCINST)
+				if (!cur_object->isnode)
 					(void)(*el_curconstraint->setobject)
 						((INTBIG)cur_object->inst.ai, VARCINST,
 							CHANGETYPEREMOVETEMP, 0);
@@ -1464,7 +1461,7 @@ void com_undo_fixed_nonfixed(LINE *fixline, LINE *nfixline)
 	{
 		for(cur_object = cur_line->firstobject; cur_object != NOOBJECT;
 			cur_object = cur_object->nextobject)
-				if (cur_object->insttype == OBJARCINST)
+				if (!cur_object->isnode)
 					(void)(*el_curconstraint->setobject)
 						((INTBIG)cur_object->inst.ai, VARCINST,
 							CHANGETYPEREMOVETEMP, 0);
@@ -1486,7 +1483,7 @@ void com_noslide(LINE *line)
 		for(cur_object = cur_line->firstobject; cur_object != NOOBJECT;
 			cur_object = cur_object->nextobject)
 		{
-			if (cur_object->insttype == OBJARCINST)
+			if (!cur_object->isnode)
 			{
 				ai = cur_object->inst.ai;
 				ai->temp2 = ai->userbits;
@@ -1510,7 +1507,7 @@ void com_slide(LINE *line)
 		for(cur_object = cur_line->firstobject; cur_object != NOOBJECT;
 			cur_object = cur_object->nextobject)
 		{
-			if (cur_object->insttype == OBJARCINST)
+			if (!cur_object->isnode)
 			{
 				ai = cur_object->inst.ai;
 				ai->userbits = (ai->userbits & ~CANTSLIDE) |
@@ -1521,28 +1518,28 @@ void com_slide(LINE *line)
 }
 
 /*
- * moves a object of instances distance (movex, movey), and returns a 1 if
+ * moves a object of instances distance (movex, movey), and returns a true if
  * there is actually a move
  */
-INTSML com_move(LINE *line, INTBIG movex, INTBIG movey, INTSML change)
+BOOLEAN com_move(LINE *line, INTBIG movex, INTBIG movey, BOOLEAN change)
 {
 	REGISTER OBJECT *cur_object;
 	REGISTER POLYLIST *polys;
 	REGISTER INTBIG move;
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 
 	if (movex == 0) move = movey; else move = movex;
-	if (line == NOLINE) return(0);
+	if (line == NOLINE) return(FALSE);
 	if (!change && move != 0)
 	{
 		(void)asktool(us_tool, "clear");
-		change = 1;
+		change = TRUE;
 	}
 
 	for(cur_object = line->firstobject; cur_object != NOOBJECT;
 		cur_object = cur_object->nextobject)
 	{
-		if (cur_object->insttype == OBJNODEINST)
+		if (cur_object->isnode)
 		{
 			startobjectchange((INTBIG)cur_object->inst.ni, VNODEINST);
 			modifynodeinst(cur_object->inst.ni, -movex, -movey, -movex, -movey, 0, 0);
@@ -1578,10 +1575,10 @@ INTSML com_move(LINE *line, INTBIG movex, INTBIG movey, INTSML change)
  * convert a PIN layer to its corresponding real layer.  Need this since the
  * design rules require "real" layers.
  */
-INTSML com_convertpintonode_layer(INTSML layer, TECHNOLOGY *tech)
+INTBIG com_convertpintonode_layer(INTBIG layer, TECHNOLOGY *tech)
 {
 	REGISTER TECH_ARRAY *cur_technology;
-	REGISTER INTSML newlay;
+	REGISTER INTBIG newlay;
 
 	/* null layers do not convert */
 	if (layer < 0) return(layer);
@@ -1589,7 +1586,7 @@ INTSML com_convertpintonode_layer(INTSML layer, TECHNOLOGY *tech)
 	/* make sure range of layers is valid */
 	if (layer >= tech->layercount)
 	{
-		ttyputmsg(_("Compactor cannot find layer %d of technology %s"),
+		ttyputmsg(_("Compactor cannot find layer %ld of technology %s"),
 			layer, tech->techname);
 		return(layer);
 	}
@@ -1612,7 +1609,7 @@ INTSML com_convertpintonode_layer(INTSML layer, TECHNOLOGY *tech)
 	/* make sure conversion is valid */
 	if (newlay >= tech->layercount)
 	{
-		ttyputmsg(_("Converted layer %d to bogus layer %d in technology %s"),
+		ttyputmsg(_("Converted layer %ld to bogus layer %ld in technology %s"),
 			layer, newlay, tech->techname);
 		return(layer);
 	}
@@ -1664,7 +1661,7 @@ void com_subsmash(NODEPROTO *topfacet)
  * routine to link polygon "poly" into object "object" with network number
  * "networknum"
  */
-void com_add_poly_polylist(POLYGON *poly, OBJECT *object, INTSML networknum,
+void com_add_poly_polylist(POLYGON *poly, OBJECT *object, INTBIG networknum,
 	TECHNOLOGY *tech)
 {
 	REGISTER POLYLIST *new_polys;
@@ -1772,7 +1769,7 @@ void com_addlinedescription(LINE *cur_line)
 		cur_object = cur_object->nextobject)
 	{
 		if (cur_object != cur_line->firstobject) (void)addtoinfstr(' ');
-		if (cur_object->insttype == OBJARCINST)
+		if (!cur_object->isnode)
 			(void)addstringtoinfstr(describearcinst(cur_object->inst.ai)); else
 				(void)addstringtoinfstr(describenodeinst(cur_object->inst.ni));
 	}
@@ -1781,7 +1778,7 @@ void com_addlinedescription(LINE *cur_line)
 /* debugging routine to return a description of object "cur_object" */
 char *com_describeobject(OBJECT *cur_object)
 {
-	if (cur_object->insttype == OBJARCINST)
+	if (!cur_object->isnode)
 		return(describearcinst(cur_object->inst.ai));
 	return(describenodeinst(cur_object->inst.ni));
 }
@@ -1807,11 +1804,11 @@ void comp_optionsdlog(void)
 	REGISTER INTBIG itemHit, spread, origspread;
 	REGISTER VARIABLE *var;
 
-	if (DiaInitDialog(&com_optionsdialog) != 0) return;
-	var = getval((INTBIG)com_tool, VTOOL, VINTEGER, "COM_spread");
+	if (DiaInitDialog(&com_optionsdialog)) return;
+	var = getvalkey((INTBIG)com_tool, VTOOL, VINTEGER, com_spread_key);
 	if (var == NOVARIABLE) origspread = 0; else origspread = var->addr;
 	if (origspread != 0) DiaSetControl(DCMO_CANSPREAD, 1);
-	if (com_debug != 0) DiaSetControl(DCMO_VERBOSE, 1);
+	if (com_debug) DiaSetControl(DCMO_VERBOSE, 1);
 
 	/* loop until done */
 	for(;;)
@@ -1830,9 +1827,9 @@ void comp_optionsdlog(void)
 		if (DiaGetControl(DCMO_CANSPREAD) != 0) spread = 1; else
 			spread = 0;
 		if (spread != origspread)
-			(void)setval((INTBIG)com_tool, VTOOL, "COM_spread", spread, VINTEGER);
-		if (DiaGetControl(DCMO_VERBOSE) != 0) com_debug = 1; else
-			com_debug = 0;
+			(void)setvalkey((INTBIG)com_tool, VTOOL, com_spread_key, spread, VINTEGER);
+		if (DiaGetControl(DCMO_VERBOSE) != 0) com_debug = TRUE; else
+			com_debug = FALSE;
 	}
 	DiaDoneDialog();
 }
