@@ -35,6 +35,7 @@
 #include "efunction.h"
 #include "egraphics.h"
 #include "erc.h"
+#include "usr.h"
 #include "edialogs.h"
 
 /* the ERC tool table */
@@ -53,6 +54,7 @@ typedef struct Iwellcon
 {
 	INTBIG           x, y;
 	INTBIG           netnum;
+	INTBIG           onproperrail;
 	INTBIG           fun;
 	NODEPROTO       *np;
 	struct Iwellcon *nextwellcon;
@@ -75,7 +77,7 @@ typedef struct Iwellarea
 	INTBIG            lx, hx, ly, hy;
 	INTBIG            netnum;
 	POLYGON           *poly;
-	INTSML            layer;
+	INTBIG            layer;
 	TECHNOLOGY        *tech;
 	NODEPROTO         *facet;
 	struct Iwellarea  *nextwellarea;
@@ -86,15 +88,7 @@ static WELLAREA *erc_firstwellarea = NOWELLAREA;
 
 /* miscellaneous */
 
-/* the meaning of "ERC_options" */
-#define PWELLCONOPTIONS   03
-#define PWELLCONPERAREA    0
-#define PWELLCONONCE       1
-#define PWELLCONIGNORE     2
-#define NWELLCONOPTIONS  014
-#define NWELLCONPERAREA    0
-#define NWELLCONONCE      04
-#define NWELLCONIGNORE   010
+#define DEFERCBITS      (PWELLONGROUND|NWELLONPOWER)
 
        TOOL       *erc_tool;					/* this tool */
 static NODEPROTO  *erc_facet;
@@ -113,9 +107,9 @@ static void         erc_analyzefacet(NODEPROTO *facet);
 static void         erc_freeallwellareas(void);
 static void         erc_freeallwellcons(void);
 static void         erc_gatherwells(NODEPROTO *np, XARRAY trans);
-static void         erc_getpolygon(INTSML layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *y, INTSML count);
+static void         erc_getpolygon(INTBIG layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *y, INTBIG count);
 static void         erc_optionsdlog(void);
-static INTSML       erc_welllayer(TECHNOLOGY *tech, INTSML layer);
+static INTBIG       erc_welllayer(TECHNOLOGY *tech, INTBIG layer);
 
 /************************ CONTROL ***********************/
 
@@ -130,6 +124,8 @@ void erc_init(INTBIG *argc, char *argv[], TOOL *thistool)
 	/* copy tool pointer during pass 1 */
 	erc_tool = thistool;
 	erc_optionskey = makekey("ERC_options");
+	nextchangequiet();
+	setvalkey((INTBIG)erc_tool, VTOOL, erc_optionskey, DEFERCBITS, VINTEGER|VDONTSAVE);
 	DiaDeclareHook("ercopt", &erc_tablep, erc_optionsdlog);
 }
 
@@ -144,16 +140,16 @@ void erc_done(void)
 /*
  * Handle commands to the tool from the user.
  */
-INTSML erc_set(INTSML count, char *par[])
+void erc_set(INTBIG count, char *par[])
 {
-	REGISTER INTSML l;
+	REGISTER INTBIG l;
 	REGISTER NODEPROTO *np;
 	REGISTER char *pp;
 
 	if (count == 0)
 	{
 		ttyputusage("telltool erc analyze");
-		return(0);
+		return;
 	}
 
 	l = strlen(pp = par[0]);
@@ -162,13 +158,11 @@ INTSML erc_set(INTSML count, char *par[])
 	{
 		/* analyze facet */
 		np = getcurfacet();
-		if (np == NONODEPROTO) return(0);
 		erc_analyzefacet(np);
-		return(0);
+		return;
 	}
 
 	ttyputbadusage("telltool erc");
-	return(1);
 }
 
 /******************** ANALYSIS ********************/
@@ -178,24 +172,36 @@ INTSML erc_set(INTSML count, char *par[])
  */
 void erc_analyzefacet(NODEPROTO *facet)
 {
-	REGISTER INTBIG errors, minsep, dist, layertype;
+	REGISTER INTBIG errors, minsep, dist, layertype, largestnetnum, welltype,
+		desiredcontact, perareabit;
 	REGISTER NODEPROTO *np;
 	REGISTER TECHNOLOGY *tech;
-	REGISTER char *abortseq, *errormsg;
+	REGISTER BOOLEAN con;
+	REGISTER char *abortseq, *errormsg, *nocontacterror;
 	char errmsg[200];
 	REGISTER WELLCON *wc, *owc;
 	REGISTER VARIABLE *var;
 	REGISTER PORTPROTO *pp, *opp;
 	REGISTER WELLAREA *wa, *owa;
 	REGISTER void *err;
+	float elapsed;
 	INTBIG edge;
 	extern DIALOG us_progressdialog;
 
+	initerrorlogging(_("ERC"));
+	if (facet == NONODEPROTO)
+	{
+		termerrorlogging(TRUE);
+		ttyputerr(_("Must be editing a facet before analyzing wells"));
+		return;
+	}
+
 	/* make sure network tool is on */
 	if ((net_tool->toolstate&TOOLON) == 0)
 	{
+		termerrorlogging(TRUE);
 		ttyputerr(_("Network tool must be running...turning it on"));
-		toolturnon(net_tool, 0);
+		toolturnon(net_tool, FALSE);
 		return;
 	}
 
@@ -206,18 +212,24 @@ void erc_analyzefacet(NODEPROTO *facet)
 	if (abortseq != 0)
 		(void)formatinfstr(_(" (type %s to abort)"), abortseq);
 	ttyputmsg(returninfstr());
-	if (DiaInitDialog(&us_progressdialog) != 0) return;
+	if (DiaInitDialog(&us_progressdialog))
+	{
+		termerrorlogging(TRUE);
+		return;
+	}
 	DiaPercent(1, 0);
 	DiaSetText(2, _("Preparing to analyze..."));
 
+	/* begin counting elapsed time */
+	starttimer();
+
 	/* initialize to analyze facet */
-	initerrorlogging(_("ERC"), facet, NONODEPROTO);
 	erc_freeallwellcons();
 	erc_freeallwellareas();
 	erc_worstpwelldist = erc_worstnwelldist = 0;
 	erc_facet = facet;
 	var = getvalkey((INTBIG)erc_tool, VTOOL, VINTEGER, erc_optionskey);
-	if (var == NOVARIABLE) erc_options = 0; else
+	if (var == NOVARIABLE) erc_options = DEFERCBITS; else
 		erc_options = var->addr;
 
 	/* put global network information on the ports of this facet */
@@ -267,6 +279,55 @@ void erc_analyzefacet(NODEPROTO *facet)
 	mergedone(erc_getpolygon);
 	DiaPercent(1, 100);
 
+	/* number the well areas according to topology of contacts in them */
+	if (erc_firstwellcon == NOWELLCON) largestnetnum = 0; else
+	{
+		largestnetnum = erc_firstwellcon->netnum;
+		for(wc = erc_firstwellcon; wc != NOWELLCON; wc = wc->nextwellcon)
+			if (wc->netnum > largestnetnum)
+				largestnetnum = wc->netnum;
+	}
+	for(wa = erc_firstwellarea; wa != NOWELLAREA; wa = wa->nextwellarea)
+	{
+		wa->netnum = ++largestnetnum;
+		welltype = erc_welllayer(wa->tech, wa->layer);
+		if (welltype != 1 && welltype != 2) continue;
+		if (welltype == 1)
+		{
+			/* P-well */
+			desiredcontact = NPWELL;
+			perareabit = PWELLCONPERAREA;
+			nocontacterror = _("No P-Well contact found in this area");
+		} else
+		{
+			/* N-Well */
+			desiredcontact = NPSUBSTRATE;
+			perareabit = NWELLCONPERAREA;
+			nocontacterror = _("No N-Well contact found in this area");
+		}
+
+		/* find a contact in the area */
+		for(wc = erc_firstwellcon; wc != NOWELLCON; wc = wc->nextwellcon)
+		{
+			if (wc->fun != desiredcontact) continue;
+			if (wc->x < wa->lx || wc->x > wa->hx ||
+				wc->y < wa->ly || wc->y > wa->hy) continue;
+			if (!isinside(wc->x, wc->y, wa->poly)) continue;
+			wa->netnum = wc->netnum;
+			break;
+		}
+
+		/* if no contact, issue appropriate errors */
+		if (wc == NOWELLCON)
+		{
+			if ((erc_options&PWELLCONOPTIONS) == perareabit)
+			{
+				err = logerror(nocontacterror, erc_facet, 0);
+				addpolytoerror(err, wa->poly);
+			}
+		}
+	}
+
 	/* make sure all of the contacts are on the same net */
 	DiaSetText(2, _("Reporting errors..."));
 	for(wc = erc_firstwellcon; wc != NOWELLCON; wc = wc->nextwellcon)
@@ -276,9 +337,27 @@ void erc_analyzefacet(NODEPROTO *facet)
 			if (wc->fun == NPWELL) errormsg = _("P-Well contact is floating"); else
 				errormsg = _("N-Well contact is floating");
 			err = logerror(errormsg, erc_facet, 0);
-			(void)addpointtoerror(err, wc->x, wc->y);
+			addpointtoerror(err, wc->x, wc->y);
 			continue;
 		}
+		if (wc->onproperrail == 0)
+		{
+			if (wc->fun == NPWELL)
+			{
+				if ((erc_options&PWELLONGROUND) != 0)
+				{
+					err = logerror(_("P-Well contact not connected to ground"), erc_facet, 0);
+					addpointtoerror(err, wc->x, wc->y);
+				}
+			} else
+			{
+				if ((erc_options&NWELLONPOWER) != 0)
+				{
+					err = logerror(_("N-Well contact not connected to power"), erc_facet, 0);
+					addpointtoerror(err, wc->x, wc->y);
+				}
+			}
+		}
 		for(owc = wc->nextwellcon; owc != NOWELLCON; owc = owc->nextwellcon)
 		{
 			if (owc->netnum == 0) continue;
@@ -287,8 +366,8 @@ void erc_analyzefacet(NODEPROTO *facet)
 			if (wc->fun == NPWELL) errormsg = _("P-Well contacts are not connected"); else
 				errormsg = _("N-Well contacts are not connected");
 			err = logerror(errormsg, erc_facet, 0);
-			(void)addpointtoerror(err, wc->x, wc->y);
-			(void)addpointtoerror(err, owc->x, owc->y);
+			addpointtoerror(err, wc->x, wc->y);
+			addpointtoerror(err, owc->x, owc->y);
 			break;
 		}
 	}
@@ -321,9 +400,10 @@ void erc_analyzefacet(NODEPROTO *facet)
 		for(owa = wa->nextwellarea; owa != NOWELLAREA; owa = owa->nextwellarea)
 		{
 			if (wa->tech != owa->tech || wa->layer != owa->layer) continue;
-			if (wa->netnum == owa->netnum && wa->netnum >= 0)
-				minsep = drcmindistance(wa->tech, facet->cell->lib, wa->layer, 0, wa->layer, 0, 1, 0, &edge, 0); else
-					minsep = drcmindistance(wa->tech, facet->cell->lib, wa->layer, 0, wa->layer, 0, 0, 0, &edge, 0);
+			if (wa->netnum == owa->netnum && wa->netnum >= 0) con = TRUE; else
+				con = FALSE;
+			minsep = drcmindistance(wa->tech, facet->cell->lib, wa->layer, 0, wa->layer, 0,
+				con, FALSE, &edge, 0);
 			if (minsep < 0) continue;
 			if (wa->lx > owa->hx+minsep || owa->lx > wa->hx+minsep ||
 				wa->ly > owa->hy+minsep || owa->ly > wa->hy+minsep) continue;
@@ -352,8 +432,8 @@ void erc_analyzefacet(NODEPROTO *facet)
 						break;
 				}
 				err = logerror(errmsg, erc_facet, 0);
-				(void)addpolytoerror(err, wa->poly);
-				(void)addpolytoerror(err, owa->poly);
+				addpolytoerror(err, wa->poly);
+				addpolytoerror(err, owa->poly);
 			}
 		}
 	}
@@ -377,7 +457,7 @@ void erc_analyzefacet(NODEPROTO *facet)
 			case 4:
 				err = logerror("N-Select area", erc_facet, 0);
 		}
-		(void)addpolytoerror(err, wa->poly);
+		addpolytoerror(err, wa->poly);
 	}
 #endif
 
@@ -429,13 +509,23 @@ void erc_analyzefacet(NODEPROTO *facet)
 	/* report the number of networks */
 	DiaDoneDialog();
 	ttyputmsg(_("%ld networks found"), erc_globalnetnumber);
-	
+
+	/* stop counting time */
+	elapsed = endtimer();
+	if (elapsed > 60.0 && (us_useroptions&BEEPAFTERLONGJOB) != 0)
+		ttybeep(1);
+
 	/* report the number of errors found */
 	errors = numerrors();
 	if (errors == 0)
-		ttyputmsg(_("No ERC errors found")); else
-			ttyputmsg(_("FOUND %ld ERC %s"), errors, makeplural(_("ERROR"), errors));
-	termerrorlogging();
+	{
+		ttyputmsg(_("No ERC errors found (%s)"), explainduration(elapsed));
+	} else
+	{
+		ttyputmsg(_("FOUND %ld ERC %s (%s)"), errors, makeplural(_("ERROR"), errors),
+			explainduration(elapsed));
+	}
+	termerrorlogging(TRUE);
 }
 
 /*
@@ -530,11 +620,35 @@ void erc_gatherwells(NODEPROTO *np, XARRAY trans)
 					wc->fun = nfun;
 					if (ni->firstportarcinst != NOPORTARCINST)
 					{
-						wc->netnum = ni->firstportarcinst->conarcinst->network->temp1;
+						net = ni->firstportarcinst->conarcinst->network;
 					} else if (ni->firstportexpinst != NOPORTEXPINST)
 					{
-						wc->netnum = ni->firstportexpinst->exportproto->network->temp1;
-					} else wc->netnum = 0;
+						net = ni->firstportexpinst->exportproto->network;
+					} else net = NONETWORK;
+					wc->onproperrail = 0;
+					if (net == NONETWORK) wc->netnum = 0; else
+					{
+						wc->netnum = net->temp1;
+						if (nfun == NPWELL)
+						{
+							/* PWell: must be on ground */
+							for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+							{
+								if ((pp->userbits&STATEBITS) != GNDPORT) continue;
+								if (pp->network == net) break;
+							}
+							if (pp != NOPORTPROTO) wc->onproperrail = 1;
+						} else
+						{
+							/* NWell: must be on power */
+							for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+							{
+								if ((pp->userbits&STATEBITS) != PWRPORT) continue;
+								if (pp->network == net) break;
+							}
+							if (pp != NOPORTPROTO) wc->onproperrail = 1;
+						}
+					}
 					wc->nextwellcon = erc_firstwellcon;
 					erc_firstwellcon = wc;
 				}
@@ -581,14 +695,12 @@ void erc_gatherwells(NODEPROTO *np, XARRAY trans)
  * Coroutine of the polygon merging package that is given a merged polygon with
  * "count" points in (x,y) with area "area".
  */
-void erc_getpolygon(INTSML layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *y, INTSML count)
+void erc_getpolygon(INTBIG layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *y, INTBIG count)
 {
-	REGISTER INTSML i, first, welltype;
-	REGISTER INTBIG dist, bestdist, desiredcontact, perareabit, prev, xp, yp;
+	REGISTER INTBIG i, first, welltype;
+	REGISTER INTBIG dist, bestdist, desiredcontact, prev, xp, yp;
 	REGISTER WELLCON *wc, *bestwc;
 	REGISTER WELLAREA *wa;
-	REGISTER void *err;
-	REGISTER char *nocontacterror;
 	static INTBIG checkstop = 0;
 
 	erc_polyscrunched += count;
@@ -615,7 +727,6 @@ void erc_getpolygon(INTSML layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *y, INTSML
 	wa->poly->count = count;
 	wa->poly->style = FILLED;
 	wa->layer = layer;
-	wa->netnum = 0;
 	wa->tech = tech;
 	getbbox(wa->poly, &wa->lx, &wa->hx, &wa->ly, &wa->hy);
 	wa->nextwellarea = erc_firstwellarea;
@@ -624,41 +735,8 @@ void erc_getpolygon(INTSML layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *y, INTSML
 	/* special checks for the well areas */
 	welltype = erc_welllayer(tech, layer);
 	if (welltype != 1 && welltype != 2) return;
-	if (welltype == 1)
-	{
-		/* P-well */
-		desiredcontact = NPWELL;
-		perareabit = PWELLCONPERAREA;
-		nocontacterror = _("No P-Well contact found in this area");
-	} else
-	{
-		/* N-Well */
+	if (welltype == 1) desiredcontact = NPWELL; else
 		desiredcontact = NPSUBSTRATE;
-		perareabit = NWELLCONPERAREA;
-		nocontacterror = _("No N-Well contact found in this area");
-	}
-
-	/* find a contact in the area */
-	for(wc = erc_firstwellcon; wc != NOWELLCON; wc = wc->nextwellcon)
-	{
-		if (wc->fun != desiredcontact) continue;
-		if (wc->x < wa->lx || wc->x > wa->hx ||
-			wc->y < wa->ly || wc->y > wa->hy) continue;
-		if (isinside(wc->x, wc->y, wa->poly) == 0) continue;
-		wa->netnum = wc->netnum;
-		break;
-	}
-
-	/* if no contact, issue appropriate errors */
-	if (wc == NOWELLCON)
-	{
-		if ((erc_options&PWELLCONOPTIONS) == perareabit)
-		{
-			err = logerror(nocontacterror, erc_facet, 0);
-			(void)addpolytoerror(err, wa->poly);
-		}
-		return;
-	}
 
 	/* find the worst distance to the edge of the area */
 	for(i=0; i<count*2; i++)
@@ -683,7 +761,7 @@ void erc_getpolygon(INTSML layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *y, INTSML
 			if (wc->fun != desiredcontact) continue;
 			if (wc->x < wa->lx || wc->x > wa->hx ||
 				wc->y < wa->ly || wc->y > wa->hy) continue;
-			if (isinside(wc->x, wc->y, wa->poly) == 0) continue;
+			if (!isinside(wc->x, wc->y, wa->poly)) continue;
 			dist = computedistance(wc->x, wc->y, xp, yp);
 			if (first != 0 || dist < bestdist)
 			{
@@ -727,7 +805,7 @@ void erc_getpolygon(INTSML layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *y, INTSML
  *   3: P-Select
  *   4: N-Select
  */
-INTSML erc_welllayer(TECHNOLOGY *tech, INTSML layer)
+INTBIG erc_welllayer(TECHNOLOGY *tech, INTBIG layer)
 {
 	REGISTER INTBIG fun, funpure;
 
@@ -808,8 +886,8 @@ WELLAREA *erc_allocwellarea(void)
 /* ERC: Options Dialog */
 static DIALOGITEM erc_optionsdialogitems[] =
 {
- /*  1 */ {0, {108,396,132,460}, BUTTON, N_("OK")},
- /*  2 */ {0, {108,296,132,360}, BUTTON, N_("Cancel")},
+ /*  1 */ {0, {132,396,156,460}, BUTTON, N_("OK")},
+ /*  2 */ {0, {132,296,156,360}, BUTTON, N_("Cancel")},
  /*  3 */ {0, {32,8,48,228}, RADIO, N_("Must have contact in every area")},
  /*  4 */ {0, {56,8,72,228}, RADIO, N_("Must have at least 1 contact")},
  /*  5 */ {0, {80,8,96,228}, RADIO, N_("Do not check for contacts")},
@@ -817,9 +895,11 @@ static DIALOGITEM erc_optionsdialogitems[] =
  /*  7 */ {0, {32,248,48,480}, RADIO, N_("Must have contact in every area")},
  /*  8 */ {0, {56,248,72,480}, RADIO, N_("Must have at least 1 contact")},
  /*  9 */ {0, {80,248,96,480}, RADIO, N_("Do not check for contacts")},
- /* 10 */ {0, {8,284,24,384}, MESSAGE, N_("For N-Well:")}
+ /* 10 */ {0, {8,284,24,384}, MESSAGE, N_("For N-Well:")},
+ /* 11 */ {0, {104,8,120,228}, CHECK, N_("Must connect to Ground")},
+ /* 12 */ {0, {104,248,120,480}, CHECK, N_("Must connect to Power")}
 };
-static DIALOG erc_optionsdialog = {{50,75,191,564}, N_("ERC Options"), 0, 10, erc_optionsdialogitems};
+static DIALOG erc_optionsdialog = {{50,75,215,564}, N_("ERC Options"), 0, 12, erc_optionsdialogitems};
 
 /* special items for the "ERC Options" dialog: */
 #define DERO_PWELLEACH   3		/* PWell contact in each area (radio) */
@@ -828,15 +908,17 @@ static DIALOG erc_optionsdialog = {{50,75,191,564}, N_("ERC Options"), 0, 10, er
 #define DERO_NWELLEACH   7		/* NWell contact in each area (radio) */
 #define DERO_NWELLONCE   8		/* NWell contact once (radio) */
 #define DERO_NWELLNOT    9		/* NWell contact not needed (radio) */
+#define DERO_PWELLGND   11		/* PWell must connect to ground (check) */
+#define DERO_NWELLVDD   12		/* NWell must connect to power (check) */
 
 void erc_optionsdlog(void)
 {
 	REGISTER INTBIG itemHit, ercoptions, oldoptions;
 	REGISTER VARIABLE *var;
 
-	if (DiaInitDialog(&erc_optionsdialog) != 0) return;
+	if (DiaInitDialog(&erc_optionsdialog)) return;
 	var = getvalkey((INTBIG)erc_tool, VTOOL, VINTEGER, erc_optionskey);
-	if (var == NOVARIABLE) ercoptions = 0; else
+	if (var == NOVARIABLE) ercoptions = DEFERCBITS; else
 		ercoptions = var->addr;
 	oldoptions = ercoptions;
 	switch (ercoptions & PWELLCONOPTIONS)
@@ -851,6 +933,8 @@ void erc_optionsdlog(void)
 		case NWELLCONONCE:    DiaSetControl(DERO_NWELLONCE, 1);   break;
 		case NWELLCONIGNORE:  DiaSetControl(DERO_NWELLNOT, 1);    break;
 	}
+	if ((ercoptions&PWELLONGROUND) != 0) DiaSetControl(DERO_PWELLGND, 1);
+	if ((ercoptions&NWELLONPOWER) != 0) DiaSetControl(DERO_NWELLVDD, 1);
 
 	/* loop until done */
 	for(;;)
@@ -875,6 +959,11 @@ void erc_optionsdlog(void)
 			DiaSetControl(itemHit, 1);
 			continue;
 		}
+		if (itemHit == DERO_PWELLGND || itemHit == DERO_NWELLVDD)
+		{
+			DiaSetControl(itemHit, 1 - DiaGetControl(itemHit));
+			continue;
+		}
 	}
 
 	if (itemHit != CANCEL)
@@ -887,6 +976,8 @@ void erc_optionsdlog(void)
 		if (DiaGetControl(DERO_NWELLEACH) != 0) ercoptions |= NWELLCONPERAREA; else
 			if (DiaGetControl(DERO_NWELLONCE) != 0) ercoptions |= NWELLCONONCE; else
 				ercoptions |= NWELLCONIGNORE;
+		if (DiaGetControl(DERO_PWELLGND) != 0) ercoptions |= PWELLONGROUND;
+		if (DiaGetControl(DERO_NWELLVDD) != 0) ercoptions |= NWELLONPOWER;
 		if (ercoptions != oldoptions)
 			(void)setvalkey((INTBIG)erc_tool, VTOOL, erc_optionskey, ercoptions, VINTEGER);
 	}
