@@ -48,6 +48,8 @@ static KEYWORD leopt[] =
 {
 	{"analyze-path",       0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	{"analyze-facet",      0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{"analyze-network",    0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{"show-loads",         0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	{"estimate-delay",     0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	{"set-options",        0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	{"set-capacitance",    0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
@@ -96,16 +98,13 @@ typedef struct Ilenode
 	INTBIG           numoutputnodes;	/* size of array of output nodes */
 } LENODE;
 
-#define DISPLAYCAPACITANCE  01
-#define HIGHLIGHTCOMPONENTS 02
-#define DEFAULTSTATE        DISPLAYCAPACITANCE
-
        TOOL     *le_tool;					/* this tool */
-static INTBIG    le_capacitance;			/* cached key for "LE_capacitance" */
-static INTBIG    le_nodeeffort;				/* cached key for "LE_node_effort" */
-static INTBIG    le_fanout;					/* cached key for "LE_fanout" */
-static INTBIG    le_state;					/* cached key for "LE_state" */
-static INTBIG    le_maximumstageeffort;		/* cached key for "LE_maximum_stage_effort" */
+static INTBIG    le_capacitance_key;		/* variable key for "LE_capacitance" */
+static INTBIG    le_nodeeffort_key;			/* variable key for "LE_node_effort" */
+static INTBIG    le_fanout_key;				/* variable key for "LE_fanout" */
+static INTBIG    le_state_key;				/* variable key for "LE_state" */
+       INTBIG    le_wire_ratio_key;			/* variable key for "LE_wire_ratio" */
+static INTBIG    le_maximumstageeffort_key;	/* variable key for "LE_maximum_stage_effort" */
 static LENODE   *le_lastlenode;				/* for propagating capacitance values */
 static double    le_lastcapacitance;		/* for propagating capacitance values */
 static LENODE   *le_firstlenode;			/* first in list of LE nodes in the path */
@@ -115,6 +114,7 @@ static LENODE   *le_lenodefree;				/* list of free LE nodes */
 static void      le_addlinkage(LENODE *out, PORTARCINST *outpi, LENODE *in, PORTARCINST *inpi);
 static LENODE   *le_alloclenode(void);
 static void      le_analyzefacet(void);
+static void      le_analyzenetwork(void);
 static void      le_analyzepath(void);
 static char     *le_describenode(LENODE *le);
 static void      le_estimatedelay(NODEPROTO *facet);
@@ -127,6 +127,7 @@ static double    le_getcapacitance(ARCINST *ai);
 static INTBIG    le_getgatetype(NODEINST *ni, INTBIG *inputs);
 static double    le_getlogeffort(LENODE *le);
 static double    le_getparasitics(LENODE *le);
+static char     *le_nextarcs(void);
 static NODEINST *le_propagate(NODEPROTO *facet, INTBIG edge);
 static void      le_propagatebranch(PORTARCINST *tpi, LENODE *final, double capacitance,
 					double *onpath, double *offpath);
@@ -134,6 +135,9 @@ static void      le_setarccapacitance(ARCINST *ai, double c);
 static void      le_setcapacitance(void);
 static void      le_setlogicaleffort(void);
 static void      le_setoptions(void);
+static void      le_showloads(void);
+static int       le_sortbyproductsize(const void *e1, const void *e2);
+static BOOLEAN   le_topofarcs(char **c);
 static void      le_unwind(NODEINST *start, NODEINST *prev);
 
 /************************ CONTROL ***********************/
@@ -149,13 +153,16 @@ void le_init(INTBIG *argc, char *argv[], TOOL *thistool)
 	/* ignore pass 2 initialization */
 	if (thistool == NOTOOL)
 	{
-		le_capacitance = makekey("LE_capacitance");
-		le_nodeeffort = makekey("LE_node_effort");
-		le_fanout = makekey("LE_fanout");
-		le_state = makekey("LE_state");
-		le_maximumstageeffort = makekey("LE_maximum_stage_effort");
+		le_capacitance_key = makekey("LE_capacitance");
+		le_nodeeffort_key = makekey("LE_node_effort");
+		le_fanout_key = makekey("LE_fanout");
+		le_state_key = makekey("LE_state");
+		le_wire_ratio_key = makekey("LE_wire_ratio");
+		le_maximumstageeffort_key = makekey("LE_maximum_stage_effort");
 		le_firstlenode = NOLENODE;
 		le_lenodefree = NOLENODE;
+		nextchangequiet();
+		setvalkey((INTBIG)le_tool, VTOOL, le_state_key, DEFAULTSTATE, VINTEGER|VDONTSAVE);
 		return;
 	}
 
@@ -182,9 +189,9 @@ void le_done(void)
 /*
  * Handle commands to the tool from the user.
  */
-INTSML le_set(INTSML count, char *par[])
+void le_set(INTBIG count, char *par[])
 {
-	REGISTER INTSML l;
+	REGISTER INTBIG l;
 	REGISTER VARIABLE *var;
 	REGISTER NODEPROTO *np;
 	REGISTER INTBIG state;
@@ -192,79 +199,112 @@ INTSML le_set(INTSML count, char *par[])
 
 	if (count == 0)
 	{
-		ttyputusage("telltool logeffort (analyze-path | analyze-facet | set-options | set-capacitance | set-node-effort)");
-		return(0);
+		ttyputusage("telltool logeffort (analyze-path | analyze-facet | analyze-network | show-loads | set-options | set-capacitance | set-node-effort)");
+		return;
 	}
 
 	l = strlen(pp = par[0]);
-
 	if (namesamen(pp, "analyze-facet", l) == 0 && l >= 9)
 	{
-		var = getvalkey((INTBIG)le_tool, VTOOL, VINTEGER, le_state);
+		var = getvalkey((INTBIG)le_tool, VTOOL, VINTEGER, le_state_key);
 		if (var == NOVARIABLE) state = DEFAULTSTATE; else
 			state = var->addr;
 		le_gatherfacet(state & HIGHLIGHTCOMPONENTS);
-		if (le_firstlenode == NOLENODE) return(1);
+		if (le_firstlenode == NOLENODE) return;
 		le_analyzefacet();
-		return(0);
+		return;
 	}
-
 	if (namesamen(pp, "analyze-path", l) == 0 && l >= 9)
 	{
-		var = getvalkey((INTBIG)le_tool, VTOOL, VINTEGER, le_state);
+		var = getvalkey((INTBIG)le_tool, VTOOL, VINTEGER, le_state_key);
 		if (var == NOVARIABLE) state = DEFAULTSTATE; else
 			state = var->addr;
 		le_gatherpath(state & HIGHLIGHTCOMPONENTS);
-		if (le_firstlenode == NOLENODE) return(1);
+		if (le_firstlenode == NOLENODE) return;
 		le_analyzepath();
-		return(0);
+		return;
 	}
-
 	if (namesamen(pp, "estimate-delay", l) == 0)
 	{
 		/* analyze facet */
 		np = getcurfacet();
-		if (np == NONODEPROTO) return(0);
+		if (np == NONODEPROTO) return;
 		le_estimatedelay(np);
-		return(0);
+		return;
+	}
+	if (namesamen(pp, "show-loads", l) == 0 && l >= 2)
+	{
+		le_showloads();
+		return;
+	}
+	if (namesamen(pp, "analyze-network", l) == 0 && l >= 2)
+	{
+		le_analyzenetwork();
+		return;
 	}
-
 	if (namesamen(pp, "set-options", l) == 0 && l >= 5)
 	{
 		le_setoptions();
-		return(0);
+		return;
 	}
 	if (namesamen(pp, "set-capacitance", l) == 0 && l >= 5)
 	{
 		le_setcapacitance();
-		return(0);
+		return;
 	}
 	if (namesamen(pp, "set-node-effort", l) == 0 && l >= 5)
 	{
 		le_setlogicaleffort();
-		return(0);
+		return;
 	}
 
 	ttyputbadusage("telltool logeffort");
-	return(1);
 }
 
 /* Logical Effort Options dialog */
 static DIALOGITEM le_leoptionsdialogitems[] =
 {
- /*  1 */ {0, {96,180,120,244}, BUTTON, N_("OK")},
- /*  2 */ {0, {96,12,120,76}, BUTTON, N_("Cancel")},
+ /*  1 */ {0, {196,204,220,268}, BUTTON, N_("OK")},
+ /*  2 */ {0, {132,204,156,268}, BUTTON, N_("Cancel")},
  /*  3 */ {0, {8,8,24,160}, MESSAGE, N_("Maximum Stage Gain")},
  /*  4 */ {0, {8,168,24,220}, EDITTEXT, ""},
  /*  5 */ {0, {36,8,52,244}, CHECK, N_("Display intermediate capacitances")},
- /*  6 */ {0, {64,8,80,192}, CHECK, N_("Highlight components")}
+ /*  6 */ {0, {64,8,80,192}, CHECK, N_("Highlight components")},
+ /*  7 */ {0, {112,8,220,180}, SCROLL, ""},
+ /*  8 */ {0, {224,8,240,92}, MESSAGE, N_("Wire ratio:")},
+ /*  9 */ {0, {224,96,240,180}, EDITTEXT, ""},
+ /* 10 */ {0, {92,8,108,180}, MESSAGE, N_("Wire ratio for each layer:")}
 };
-static DIALOG le_leoptionsdialog = {{75,75,206,329}, N_("Logical Effort Options"), 0, 6, le_leoptionsdialogitems};
+static DIALOG le_leoptionsdialog = {{75,75,324,352}, N_("Logical Effort Options"), 0, 10, le_leoptionsdialogitems};
 
 /* special items for the "Logical Effort Options" dialog: */
 #define DLEO_MAXGAIN    4		/* Maximum Stage Gain (edit text) */
 #define DLEO_INTERCAP   5		/* Show intermediate capacitances (check) */
 #define DLEO_HIGHCOMP   6		/* Highlight components (check) */
+#define DLEO_ARCLIST    7		/* List of arcs (scroll) */
+#define DLEO_WIRERATIO  9		/* Arc wire ratio (edit text) */
+
+static ARCPROTO *le_posarcs;
+BOOLEAN le_topofarcs(char **c)
+{
+	le_posarcs = el_curtech->firstarcproto;
+	return(TRUE);
+}
+
+char *le_nextarcs(void)
+{
+	REGISTER ARCPROTO *ap;
+
+	ap = le_posarcs;
+	if (ap != NOARCPROTO)
+	{
+		le_posarcs = ap->nextarcproto;
+		(void)initinfstr();
+		(void)formatinfstr("%s (%ld)", describearcproto(ap), ap->temp1);
+		return(returninfstr());
+	}
+	return(0);
+}
 
 /*
  * Routine to interactively set the logical effort options.
@@ -272,21 +312,32 @@ static DIALOG le_leoptionsdialog = {{75,75,206,329}, N_("Logical Effort Options"
 void le_setoptions(void)
 {
 	INTBIG itemHit;
-	INTBIG state, newstate;
+	INTBIG state, newstate, i, lineno;
 	float maxstageeffort, newmaxstageeffort;
 	REGISTER VARIABLE *var;
-	char line[50];
+	REGISTER ARCPROTO *ap;
+	char line[200], *pt;
 
-	if (DiaInitDialog(&le_leoptionsdialog) != 0) return;
-	var = getvalkey((INTBIG)le_tool, VTOOL, VINTEGER, le_state);
+	if (DiaInitDialog(&le_leoptionsdialog)) return;
+	var = getvalkey((INTBIG)le_tool, VTOOL, VINTEGER, le_state_key);
 	if (var == NOVARIABLE) state = DEFAULTSTATE; else
 		state = var->addr;
 	if ((state&DISPLAYCAPACITANCE) != 0) DiaSetControl(DLEO_INTERCAP, 1);
 	if ((state&HIGHLIGHTCOMPONENTS) != 0) DiaSetControl(DLEO_HIGHCOMP, 1);
-	var = getvalkey((INTBIG)le_tool, VTOOL, VFLOAT, le_maximumstageeffort);
+	var = getvalkey((INTBIG)le_tool, VTOOL, VFLOAT, le_maximumstageeffort_key);
 	if (var == NOVARIABLE) maxstageeffort = MAXSTAGEEFFORT; else
 		maxstageeffort = castfloat(var->addr);
 
+	/* handle wire ratios */
+	for(ap = el_curtech->firstarcproto; ap != NOARCPROTO; ap = ap->nextarcproto)
+	{
+		var = getvalkey((INTBIG)ap, VARCPROTO, VINTEGER, le_wire_ratio_key);
+		if (var != NOVARIABLE) ap->temp1 = var->addr; else
+			ap->temp1 = DEFWIRERATIO;
+	}
+	DiaInitTextDialog(DLEO_ARCLIST, le_topofarcs, le_nextarcs,
+		DiaNullDlogDone, 0, SCSELMOUSE|SCREPORT);
+
 	sprintf(line, "%g", maxstageeffort);
 	DiaSetText(-DLEO_MAXGAIN, line);
 	for(;;)
@@ -295,7 +346,37 @@ void le_setoptions(void)
 		if (itemHit == OK || itemHit == CANCEL) break;
 		if (itemHit == DLEO_INTERCAP || itemHit == DLEO_HIGHCOMP)
 		{
-			DiaSetControl(itemHit, (INTSML)(1 - DiaGetControl(itemHit)));
+			DiaSetControl(itemHit, 1 - DiaGetControl(itemHit));
+			continue;
+		}
+		if (itemHit == DLEO_ARCLIST)
+		{
+			lineno = DiaGetCurLine(DLEO_ARCLIST);
+			if (lineno < 0) continue;
+			strcpy(line, DiaGetScrollLine(DLEO_ARCLIST, lineno));
+			for(pt = line; *pt != 0; pt++) if (*pt == ' ') break;
+			*pt = 0;
+			ap = getarcproto(line);
+			if (ap == NOARCPROTO) continue;
+			sprintf(line, "%ld", ap->temp1);
+			DiaSetText(DLEO_WIRERATIO, line);
+			continue;
+		}
+		if (itemHit == DLEO_WIRERATIO)
+		{
+			lineno = DiaGetCurLine(DLEO_ARCLIST);
+			if (lineno < 0) continue;
+			strcpy(line, DiaGetScrollLine(DLEO_ARCLIST, lineno));
+			for(pt = line; *pt != 0; pt++) if (*pt == ' ') break;
+			*pt = 0;
+			ap = getarcproto(line);
+			if (ap == NOARCPROTO) continue;
+			i = atoi(DiaGetText(DLEO_WIRERATIO));
+			if (i == ap->temp1) continue;
+			ap->temp1 = i;
+			(void)initinfstr();
+			(void)formatinfstr("%s (%ld)", describearcproto(ap), ap->temp1);
+			DiaSetScrollLine(DLEO_ARCLIST, lineno, returninfstr());
 			continue;
 		}
 	}
@@ -305,11 +386,25 @@ void le_setoptions(void)
 		if (DiaGetControl(DLEO_INTERCAP) != 0) newstate |= DISPLAYCAPACITANCE;
 		if (DiaGetControl(DLEO_HIGHCOMP) != 0) newstate |= HIGHLIGHTCOMPONENTS;
 		if (newstate != state)
-			(void)setvalkey((INTBIG)le_tool, VTOOL, le_state, newstate, VINTEGER);
+			(void)setvalkey((INTBIG)le_tool, VTOOL, le_state_key, newstate, VINTEGER);
 		newmaxstageeffort = (float)atof(DiaGetText(DLEO_MAXGAIN));
 		if (newmaxstageeffort != maxstageeffort)
-			(void)setvalkey((INTBIG)le_tool, VTOOL, le_maximumstageeffort,
+			(void)setvalkey((INTBIG)le_tool, VTOOL, le_maximumstageeffort_key,
 				castint(newmaxstageeffort), VFLOAT);
+		for(ap = el_curtech->firstarcproto; ap != NOARCPROTO; ap = ap->nextarcproto)
+		{
+			var = getvalkey((INTBIG)ap, VARCPROTO, VINTEGER, le_wire_ratio_key);
+			if (var != NOVARIABLE) i = var->addr; else
+				i = DEFWIRERATIO;
+			if (i == ap->temp1) continue;
+			if (ap->temp1 == DEFWIRERATIO)
+			{
+				delvalkey((INTBIG)ap, VARCPROTO, le_wire_ratio_key);
+			} else
+			{
+				setvalkey((INTBIG)ap, VARCPROTO, le_wire_ratio_key, ap->temp1, VINTEGER);
+			}
+		}
 	}
 	DiaDoneDialog();
 }
@@ -344,7 +439,7 @@ void le_setcapacitance(void)
 		ttyputerr(_("Select an arc first"));
 		return;
 	}
-	if (DiaInitDialog(&le_capacitancedialog) != 0) return;
+	if (DiaInitDialog(&le_capacitancedialog)) return;
 	c = le_getcapacitance(ai);
 	if (c == 0.0) DiaSetText(-DLEC_CAPVALUE, "1.0"); else
 	{
@@ -361,11 +456,11 @@ void le_setcapacitance(void)
 		c = atof(DiaGetText(DLEC_CAPVALUE));
 		if (c == 0.0)
 		{
-			var = getvalkey((INTBIG)ai, VARCINST, VSTRING, le_capacitance);
+			var = getvalkey((INTBIG)ai, VARCINST, VSTRING, le_capacitance_key);
 			if (var != NOVARIABLE)
 			{
 				startobjectchange((INTBIG)ai, VARCINST);
-				delvalkey((INTBIG)ai, VARCINST, le_capacitance);
+				(void)delvalkey((INTBIG)ai, VARCINST, le_capacitance_key);
 				endobjectchange((INTBIG)ai, VARCINST);
 			}
 		} else
@@ -414,7 +509,7 @@ void le_setlogicaleffort(void)
 	statle.ni = ni;
 	statle.inputs = inputs;
 	e = le_getlogeffort(&statle);
-	if (DiaInitDialog(&le_logeffortdialog) != 0) return;
+	if (DiaInitDialog(&le_logeffortdialog)) return;
 
 	sprintf(line, "%g", e);
 	DiaSetText(-DLEE_EFFVALUE, line);
@@ -428,7 +523,7 @@ void le_setlogicaleffort(void)
 		pt = DiaGetText(DLEE_EFFVALUE);
 		startobjectchange((INTBIG)ni, VNODEINST);
 		sprintf(line, "g=%s", pt);
-		setvalkey((INTBIG)ni, VNODEINST, le_nodeeffort, (INTBIG)line, VSTRING|VDISPLAY);
+		setvalkey((INTBIG)ni, VNODEINST, le_nodeeffort_key, (INTBIG)line, VSTRING|VDISPLAY);
 		endobjectchange((INTBIG)ni, VNODEINST);
 	}
 	DiaDoneDialog();
@@ -444,7 +539,7 @@ void le_setarccapacitance(ARCINST *ai, double c)
 
 	sprintf(line, "C=%g", c);
 	startobjectchange((INTBIG)ai, VARCINST);
-	var = setvalkey((INTBIG)ai, VARCINST, le_capacitance, (INTBIG)line,
+	var = setvalkey((INTBIG)ai, VARCINST, le_capacitance_key, (INTBIG)line,
 		VSTRING|VDISPLAY);
 	if (var != NOVARIABLE)
 	{
@@ -522,7 +617,7 @@ void le_analyzepath(void)
 	ttyputmsg(_("Minimum path delay is %g"), Dhat);
 
 	/* determine whether or not to set capacitance values */
-	var = getvalkey((INTBIG)le_tool, VTOOL, VINTEGER, le_state);
+	var = getvalkey((INTBIG)le_tool, VTOOL, VINTEGER, le_state_key);
 	if (var == NOVARIABLE) state = DEFAULTSTATE; else
 		state = var->addr;
 	displaycapacitance = state & DISPLAYCAPACITANCE;
@@ -541,7 +636,7 @@ void le_analyzepath(void)
 		h = CoutI / CinI;
 		sprintf(line, "h=%g", h);
 		startobjectchange((INTBIG)le->ni, VNODEINST);
-		setvalkey((INTBIG)le->ni, VNODEINST, le_fanout, (INTBIG)line, VSTRING|VDISPLAY);
+		setvalkey((INTBIG)le->ni, VNODEINST, le_fanout_key, (INTBIG)line, VSTRING|VDISPLAY);
 		endobjectchange((INTBIG)le->ni, VNODEINST);
 
 		/* shift input capacitance to the output of the previous node */
@@ -590,10 +685,10 @@ ttyputmsg("      N Gates = %g, P Gates = %g", n_gate->area/flambda/flambda, p_ga
 		{
 			nextap = ap->nextareaperim;
 			fun = layerfunction(ap->tech, ap->layer);
-			if ((fun&LFTYPE) != LFDIFF && layerismetal(fun) == 0 && layerispoly(fun) == 0) continue;
+			if ((fun&LFTYPE) != LFDIFF && !layerismetal(fun) && !layerispoly(fun)) continue;
 			coefficient = 1.0f;
-			if (layerismetal(fun) != 0) coefficient = 0.1f;
-			if (layerispoly(fun) != 0) coefficient = 0.1f;
+			if (layerismetal(fun)) coefficient = 0.1f;
+			if (layerispoly(fun)) coefficient = 0.1f;
 ttyputmsg("      Layer %s has %g x %g = %g", layername(ap->tech, ap->layer),
 	ap->area/flambda/flambda, coefficient, ap->area*coefficient/flambda/flambda);
 			numerator += (float)ap->area * coefficient;
@@ -646,6 +741,276 @@ if (n_active->width+p_active->width == 0) ttyputmsg("   Denominator undefined");
 #endif
 }
 
+/******************** LOAD CALCULATION ********************/
+
+void le_showloads(void)
+{
+	REGISTER NODEPROTO *np;
+	REGISTER NETWORK *net, **netlist;
+	REGISTER ARCPROTO *ap;
+	REGISTER VARIABLE *var;
+	REGISTER INTBIG lambda, gwidth, gtotal, atotal, wirelen, fun, load, wireratio, thisload, thiswl,
+		total, i;
+	float areatotal;
+	REGISTER char *lname;
+	REGISTER AREAPERIM *arpe, *firstarpe, *nextarpe;
+	TRANSISTORINFO *p_gate, *n_gate, *p_active, *n_active;
+
+	/* get the current facet */
+	np = getcurfacet();
+	if (np == NONODEPROTO)
+	{
+		ttyputerr(_("No current facet"));
+		return;
+	}
+	lambda = lambdaoffacet(np);
+
+	/* gather product information for all nets in the facet */
+	for(net = np->firstnetwork; net != NONETWORK; net = net->nextnetwork)
+	{
+		/* gather geometry on this network */
+		firstarpe = net_gathergeometry(net, &p_gate, &n_gate, &p_active, &n_active);
+
+		/* see if there are gates on the network */
+		gtotal = net_transistor_p_gate.count + net_transistor_n_gate.count;
+		if (gtotal > 0)
+		{
+			/* sum the metal half-perimeters on the network */
+			wirelen = 0;
+			for(arpe = firstarpe; arpe != NOAREAPERIM; arpe = arpe->nextareaperim)
+			{
+				fun = layerfunction(arpe->tech, arpe->layer);
+				if (!layerismetal(fun)) continue;
+				wirelen += arpe->perimeter / 2;
+			}
+			gwidth = net_transistor_p_gate.width+net_transistor_n_gate.width;
+			net->temp2 = muldiv(wirelen, gwidth, lambda);
+		} else net->temp2 = 0;
+
+		/* free the area/perimeter information */
+		for(arpe = firstarpe; arpe != NOAREAPERIM; arpe = nextarpe)
+		{
+			nextarpe = arpe->nextareaperim;
+			efree((char *)arpe);
+		}
+	}
+
+	/* now sort the networks by this product number in "temp2" */
+	total = 0;
+	for(net = np->firstnetwork; net != NONETWORK; net = net->nextnetwork)
+		if (net->temp2 != 0) total++;
+	if (total == 0)
+	{
+		ttyputmsg(_("There are no networks with load information"));
+		return;
+	}
+	netlist = (NETWORK **)emalloc(total * (sizeof (NETWORK *)), le_tool->cluster);
+	if (netlist == 0) return;
+	total = 0;
+	for(net = np->firstnetwork; net != NONETWORK; net = net->nextnetwork)
+		if (net->temp2 != 0) netlist[total++] = net;
+
+	/* sort by product number */
+	esort(netlist, total, sizeof (NETWORK *), le_sortbyproductsize);
+
+	/* now report the results */
+	for(i=0; i<total; i++)
+	{
+		/* gather geometry on this network */
+		net = netlist[i];
+		ttyputmsg(_("For network %s:"), describenetwork(net));
+		firstarpe = net_gathergeometry(net, &p_gate, &n_gate, &p_active, &n_active);
+
+		/* determine the wire length */
+		load = wirelen = 0;
+		areatotal = 0.0;
+		for(arpe = firstarpe; arpe != NOAREAPERIM; arpe = arpe->nextareaperim)
+		{
+			lname = layername(arpe->tech, arpe->layer);
+			fun = layerfunction(arpe->tech, arpe->layer);
+			if (!layerismetal(fun)) continue;
+			ap = getarconlayer(arpe->layer, arpe->tech);
+			wireratio = DEFWIRERATIO;
+			if (ap != NOARCPROTO)
+			{
+				var = getvalkey((INTBIG)ap, VARCPROTO, VINTEGER, le_wire_ratio_key);
+				if (var != NOVARIABLE) wireratio = var->addr;
+			}
+			lname = layername(arpe->tech, arpe->layer);
+			thiswl = arpe->perimeter / 2;
+			thisload = thiswl / wireratio;
+			ttyputmsg("  Layer %s wire-length (%s) / wire ratio (%ld) = load (%s)",
+				lname, latoa(thiswl), wireratio, latoa(thisload));
+			load += thisload;
+			wirelen += thiswl;
+			areatotal += arpe->area;
+		}
+
+		gwidth = net_transistor_p_gate.width+net_transistor_n_gate.width;
+		ttyputmsg(_("  Total wire-length (%s) x gate-widths (%s) = product (%s); average wire-width = %g"),
+			latoa(wirelen), latoa(gwidth), latoa(muldiv(wirelen, gwidth, lambda)),
+				areatotal / (float)wirelen / (float)lambda);
+
+		atotal = net_transistor_p_active.count + net_transistor_n_active.count;
+		if (atotal > 0)
+		{
+			(void)initinfstr();
+			(void)formatinfstr(_("  Load = %s"), latoa(load));
+			if (net_transistor_p_active.width != 0)
+				(void)formatinfstr("; load / P-active-width (%s) = %g", latoa(net_transistor_p_active.width),
+					(float)load / (float)net_transistor_p_active.width);
+			if (net_transistor_n_active.width != 0)
+				(void)formatinfstr("; load / N-active-width (%s) = %g", latoa(net_transistor_n_active.width),
+					(float)load / (float)net_transistor_n_active.width);
+			ttyputmsg("%s", returninfstr());
+		}
+
+		for(arpe = firstarpe; arpe != NOAREAPERIM; arpe = nextarpe)
+		{
+			nextarpe = arpe->nextareaperim;
+			efree((char *)arpe);
+		}
+	}
+	efree((char *)netlist);
+}
+
+/*
+ * Helper routine for to sort NETWORK objects by product in "temp2"
+ */
+int le_sortbyproductsize(const void *e1, const void *e2)
+{
+	REGISTER NETWORK *net1, *net2;
+
+	net1 = *((NETWORK **)e1);
+	net2 = *((NETWORK **)e2);
+	return(net1->temp2 - net2->temp2);
+}
+
+void le_analyzenetwork(void)
+{
+	REGISTER NETWORK **netlist, *net;
+	REGISTER NODEPROTO *np;
+	REGISTER ARCPROTO *ap;
+	REGISTER INTBIG i, j, k, widest, len, lambda, total, gtotal, atotal,
+		fun, metpolhalfperim, load, wireratio, additionalload;
+	REGISTER char *lname, *pad;
+	REGISTER VARIABLE *var;
+	REGISTER AREAPERIM *arpe, *firstarpe, **arpelist;
+	TRANSISTORINFO *p_gate, *n_gate, *p_active, *n_active;
+	float ratio;
+
+	netlist = net_gethighlightednets(0);
+	if (netlist[0] == NONETWORK) return;
+	for(k=0; netlist[k] != NONETWORK; k++)
+	{
+		net = netlist[k];
+
+		/* gather geometry on this network */
+		np = net->parent;
+		firstarpe = net_gathergeometry(net, &p_gate, &n_gate, &p_active, &n_active);
+
+		/* copy the linked list to an array for sorting */
+		total = 0;
+		for(arpe = firstarpe; arpe != NOAREAPERIM; arpe = arpe->nextareaperim)
+			if (arpe->layer >= 0) total++;
+		if (total == 0)
+		{
+			ttyputmsg(_("No geometry on network '%s' in facet %s"), describenetwork(net),
+				describenodeproto(np));
+			continue;
+		}
+		arpelist = (AREAPERIM **)emalloc(total * (sizeof (AREAPERIM *)), net_tool->cluster);
+		if (arpelist == 0) return;
+		i = 0;
+		for(arpe = firstarpe; arpe != NOAREAPERIM; arpe = arpe->nextareaperim)
+			if (arpe->layer >= 0) arpelist[i++] = arpe;
+
+		/* sort the layers */
+		esort(arpelist, total, sizeof (AREAPERIM *), net_areaperimdepthascending);
+
+		ttyputmsg(_("For network '%s' in facet %s:"), describenetwork(net),
+			describenodeproto(np));
+		lambda = lambdaoffacet(np);
+		widest = 0;
+		for(i=0; i<total; i++)
+		{
+			arpe = arpelist[i];
+			lname = layername(arpe->tech, arpe->layer);
+			len = strlen(lname);
+			if (len > widest) widest = len;
+		}
+		metpolhalfperim = 0;
+		for(i=0; i<total; i++)
+		{
+			arpe = arpelist[i];
+			lname = layername(arpe->tech, arpe->layer);
+			(void)initinfstr();
+			for(j=strlen(lname); j<widest; j++) (void)addtoinfstr(' ');
+			pad = returninfstr();
+			(void)initinfstr();
+			(void)formatinfstr(_("Layer %s:%s area=%7g  half-perimeter=%s"), lname, pad,
+				arpe->area/(float)lambda/(float)lambda, latoa(arpe->perimeter/2));
+			fun = layerfunction(arpe->tech, arpe->layer);
+			if (layerispoly(fun) != 0 || layerismetal(fun) != 0)
+			{
+				ap = getarconlayer(arpe->layer, arpe->tech);
+				wireratio = DEFWIRERATIO;
+				if (ap != NOARCPROTO)
+				{
+					var = getvalkey((INTBIG)ap, VARCPROTO, VINTEGER, le_wire_ratio_key);
+					if (var != NOVARIABLE) wireratio = var->addr;
+				}
+				additionalload = arpe->perimeter / 2 / wireratio;
+				metpolhalfperim += additionalload;
+				(void)formatinfstr(_(" / wire-ratio (%ld) = %s"), wireratio,
+					latoa(additionalload));
+			}
+			if (arpe->perimeter != 0)
+			{
+				ratio = (arpe->area / (float)lambda) / (float)(arpe->perimeter/2);
+				(void)formatinfstr(_("; area/half-perimeter = %g"), ratio);
+			}
+			ttyputmsg("%s", returninfstr());
+			efree((char *)arpe);
+		}
+		efree((char *)arpelist);
+		gtotal = net_transistor_p_gate.count + net_transistor_n_gate.count;
+		if (gtotal > 0)
+		{
+			(void)initinfstr();
+			formatinfstr(_("Connects to the gate of %ld %s (total width %s, average length %s)"),
+				gtotal, makeplural(_("transistor"), gtotal),
+					latoa(net_transistor_p_gate.width+net_transistor_n_gate.width),
+						latoa((net_transistor_p_gate.length+net_transistor_n_gate.length)/gtotal));
+			ttyputmsg("%s", returninfstr());
+		}
+		atotal = net_transistor_p_active.count + net_transistor_n_active.count;
+		if (atotal > 0)
+		{
+			(void)initinfstr();
+			formatinfstr(_("Connects to the active of %ld %s (total width %s, average length %s)"),
+				atotal, makeplural(_("transistor"), atotal),
+					latoa(net_transistor_p_active.width+net_transistor_n_active.width),
+						latoa((net_transistor_p_active.length+net_transistor_n_active.length)/atotal));
+			ttyputmsg("%s", returninfstr());
+		}
+		if (metpolhalfperim > 0 && gtotal > 0 && atotal > 0)
+		{
+			ttyputmsg("---------- Load Calculations:");
+			ttyputmsg("Sum of Metal and Poly half-perimeters / wire-ratio = %s", latoa(metpolhalfperim));
+			load = metpolhalfperim + net_transistor_p_gate.width+net_transistor_n_gate.width;
+			ttyputmsg("  Sum + gate-width (%s) = %s (Load)",
+				latoa(net_transistor_p_gate.width+net_transistor_n_gate.width), latoa(load));
+			if (net_transistor_p_active.width != 0)
+				ttyputmsg("  Load / P-active-width (%s) = %g", latoa(net_transistor_p_active.width),
+					(float)load / (float)net_transistor_p_active.width);
+			if (net_transistor_n_active.width != 0)
+				ttyputmsg("  Load / N-active-width (%s) = %g", latoa(net_transistor_n_active.width),
+					(float)load / (float)net_transistor_n_active.width);
+		}
+	}
+}
+
 /******************** FACET EXTRACTION ********************/
 
 /*
@@ -654,7 +1019,8 @@ if (n_active->width+p_active->width == 0) ttyputmsg("   Denominator undefined");
  */
 void le_gatherfacet(INTBIG show)
 {
-	REGISTER INTSML inport, oinport, first, which;
+	REGISTER INTBIG inport, oinport, which;
+	REGISTER BOOLEAN first;
 	REGISTER INTBIG arrowsize, x, y, i, type;
 	INTBIG count[2], inputs;
 	REGISTER NODEINST *ni;
@@ -829,11 +1195,11 @@ void le_gatherfacet(INTBIG show)
 
 	/* display the nodes */
 	(void)initinfstr();
-	first = 0;
+	first = FALSE;
 	for(le = le_firstlenode; le != NOLENODE; le = le->nextlenode)
 	{
-		if (first != 0) (void)addtoinfstr('\n');
-		first++;
+		if (first) (void)addtoinfstr('\n');
+		first = TRUE;
 		(void)formatinfstr("FACET=%s FROM=0%lo;-1;0",
 			describenodeproto(np), (INTBIG)le->ni->geom);
 	}
@@ -925,7 +1291,7 @@ void le_analyzefacet(void)
 	double h, needed, maxstageeffort;
 
 	/* determine maximum stage effort */
-	var = getvalkey((INTBIG)le_tool, VTOOL, VFLOAT, le_maximumstageeffort);
+	var = getvalkey((INTBIG)le_tool, VTOOL, VFLOAT, le_maximumstageeffort_key);
 	if (var == NOVARIABLE) maxstageeffort = MAXSTAGEEFFORT; else
 		maxstageeffort = (double)castfloat(var->addr);
 
@@ -963,7 +1329,7 @@ void le_analyzefacet(void)
 	}
 
 	/* determine whether or not to set capacitance values */
-	var = getvalkey((INTBIG)le_tool, VTOOL, VINTEGER, le_state);
+	var = getvalkey((INTBIG)le_tool, VTOOL, VINTEGER, le_state_key);
 	if (var == NOVARIABLE) state = DEFAULTSTATE; else
 		state = var->addr;
 	displaycapacitance = state & DISPLAYCAPACITANCE;
@@ -982,7 +1348,7 @@ void le_analyzefacet(void)
 		h = le->cout / le->cin;
 		sprintf(line, "h=%g", h);
 		startobjectchange((INTBIG)le->ni, VNODEINST);
-		setvalkey((INTBIG)le->ni, VNODEINST, le_fanout, (INTBIG)line, VSTRING|VDISPLAY);
+		setvalkey((INTBIG)le->ni, VNODEINST, le_fanout_key, (INTBIG)line, VSTRING|VDISPLAY);
 		endobjectchange((INTBIG)le->ni, VNODEINST);
 	}
 }
@@ -995,8 +1361,8 @@ void le_analyzefacet(void)
  */
 void le_gatherpath(INTBIG show)
 {
-	REGISTER INTSML first, which;
-	REGISTER INTBIG edge, x, y, arrowsize, agree, disagree;
+	REGISTER BOOLEAN first;
+	REGISTER INTBIG edge, x, y, arrowsize, agree, disagree, which;
 	REGISTER NODEINST *ret, *ni;
 	REGISTER ARCINST *ai;
 	REGISTER NODEPROTO *np;
@@ -1023,7 +1389,7 @@ void le_gatherpath(INTBIG show)
 		ni->temp1 = ni->temp2 = 0;
 	for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 		ai->temp1 = ai->temp2 = 0;
-	if (list[0]->entrytype == OBJNODEINST)
+	if (list[0]->entryisnode)
 	{
 		ni = list[0]->entryaddr.ni;
 		ni->temp1 = 1;
@@ -1036,7 +1402,7 @@ void le_gatherpath(INTBIG show)
 		ai->end[1].nodeinst->temp1 = 1;
 		cstart = le_getcapacitance(ai);
 	}
-	if (list[1]->entrytype == OBJNODEINST)
+	if (list[1]->entryisnode)
 	{
 		ni = list[1]->entryaddr.ni;
 		ni->temp1 = -1;
@@ -1139,12 +1505,12 @@ void le_gatherpath(INTBIG show)
 	/* display the path between the nodes */
 	(void)asktool(us_tool, "clear");
 	(void)initinfstr();
-	first = 0;
+	first = FALSE;
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		if (ni->temp2 == 0) continue;
-		if (first != 0) (void)addtoinfstr('\n');
-		first++;
+		if (first) (void)addtoinfstr('\n');
+		first = TRUE;
 		(void)formatinfstr("FACET=%s FROM=0%lo;-1;0",
 			describenodeproto(np), (INTBIG)ni->geom);
 	}
@@ -1564,7 +1930,7 @@ char *le_describenode(LENODE *le)
 			(void)addstringtoinfstr(describenodeproto(le->ni->proto));
 			break;
 	}
-	var = getvalkey((INTBIG)le->ni, VNODEINST, VSTRING, el_node_name);
+	var = getvalkey((INTBIG)le->ni, VNODEINST, VSTRING, el_node_name_key);
 	if (var != NOVARIABLE)
 	{
 		(void)addstringtoinfstr("[");
@@ -1584,7 +1950,7 @@ double le_getlogeffort(LENODE *le)
 	REGISTER char *pt;
 
 	/* see if there is an override on the node */
-	var = getvalkey((INTBIG)le->ni, VNODEINST, VSTRING, le_nodeeffort);
+	var = getvalkey((INTBIG)le->ni, VNODEINST, VSTRING, le_nodeeffort_key);
 	if (var != NOVARIABLE)
 	{
 		pt = (char *)var->addr;
@@ -1616,7 +1982,7 @@ double le_getlogeffort(LENODE *le)
 				case 3: return(12.0);
 				case 4: return(32.0);
 			}
-			ttyputmsg(_("Cannot handle %d-input XOR gates"));
+			ttyputmsg(_("Cannot handle %ld-input XOR gates"), le->inputs);
 			return(0.0);
 		case LENMOS:     return(1.0/3.0);
 		case LEPMOS:     return(2.0/3.0);
@@ -1654,7 +2020,7 @@ double le_getcapacitance(ARCINST *ai)
 	REGISTER VARIABLE *var;
 	REGISTER char *pt;
 
-	var = getvalkey((INTBIG)ai, VARCINST, VSTRING, le_capacitance);
+	var = getvalkey((INTBIG)ai, VARCINST, VSTRING, le_capacitance_key);
 	if (var == NOVARIABLE) return(0.0);
 
 	pt = (char *)var->addr;
