@@ -38,19 +38,18 @@
 #include "usr.h"
 #include "tecgen.h"
 
-INTSML build_node_arc_list( NODEINST**, INTBIG*, TECHNOLOGY*, INTBIG*, ARCINST**, NODEINST**, NODEPROTO* );
-INTSML add_node( NODEINST* node, NODEINST** list );
-INTSML remove_node( NODEINST*, NODEINST** list, INTBIG *count );
-INTSML add_arc( ARCINST* arc, ARCINST** list );
-INTSML remove_arc( ARCINST* arc, ARCINST** list );
-INTSML nodes_equal( NODEINST*, NODEINST* );
-NODEINST* arc_to_PL( ARCINST*, NODEPROTO* );
-INTSML arc_crossings( ARCINST**, NODEINST**, NODEPROTO* );
-INTSML contains_point( GEOM*, INTSML, INTSML );
-INTSML t_crossings( ARCINST**, NODEINST**, NODEPROTO* );
-INTSML make_arc_geom( ARCINST**, NODEPROTO* );
-INTSML via_to_contact( NODEINST**, INTBIG*, TECHNOLOGY*, INTBIG*, ARCINST**, NODEINST**, NODEPROTO* );
-INTSML contains_node( NODEINST*, NODEINST* );
+static void      build_node_arc_list( NODEINST**, INTBIG*, TECHNOLOGY*, INTBIG*, ARCINST**, NODEINST**, NODEPROTO* );
+static void      add_node( NODEINST* node, NODEINST** list );
+static void      remove_node( NODEINST*, NODEINST** list, INTBIG *count );
+static void      add_arc( ARCINST* arc, ARCINST** list );
+static void      remove_arc( ARCINST* arc, ARCINST** list );
+static NODEINST *arc_to_PL( ARCINST*, NODEPROTO* );
+static void      arc_crossings( ARCINST**, NODEINST**, NODEPROTO* );
+static void      t_crossings( ARCINST**, NODEINST**, NODEPROTO* );
+static void      make_arc_geom( ARCINST**, NODEPROTO* );
+static void      via_to_contact( NODEINST**, INTBIG*, TECHNOLOGY*, INTBIG*, ARCINST**, NODEINST**, NODEPROTO* );
+static BOOLEAN   contains_node( NODEINST*, NODEINST* );
+
 
 /*
  * Routine to convert facet "facet" from pure-layer nodes to real nodes and arcs.
@@ -103,7 +102,7 @@ void net_conv_to_internal( NODEPROTO *facet )
 		if (((nodelooper->proto->userbits & NFUNCTION) >> NFUNCTIONSH) != NPNODE) continue;
 		plnodelist[nodecounter++] = nodelooper;
 	}
-	ttyputmsg(_("There are %d pure-layer nodes"), nodecounter);
+	ttyputmsg(_("There are %ld pure-layer nodes"), nodecounter);
 
 	/* setup equivalent layers to handle CIF layer unification */
 	equivlayers = (INTBIG *)emalloc(tech->layercount * SIZEOFINTBIG, net_tool->cluster);
@@ -167,7 +166,7 @@ void net_conv_to_internal( NODEPROTO *facet )
 
 	/* create all the nodes in the lists, and store the pointers */
 	/* in a new list for use in the arcs */
-	for( nodes; nodes != NONODEINST; nodes = nodes->nextnodeinst )
+	for( ; nodes != NONODEINST; nodes = nodes->nextnodeinst )
 	{
 		db_node = newnodeinst( nodes->proto, 
 					            nodes->lowx, 
@@ -183,7 +182,7 @@ void net_conv_to_internal( NODEPROTO *facet )
 		/* search through all arcs and change their ends to point */
 		/* to NODEINST*'s in the database */
 		arclooper = arcs;
-		for( arclooper; arclooper != NOARCINST; arclooper = arclooper->nextarcinst )
+		for( ; arclooper != NOARCINST; arclooper = arclooper->nextarcinst )
 		{
 			if( arclooper->end[0].nodeinst == nodes )
 			{
@@ -198,7 +197,7 @@ void net_conv_to_internal( NODEPROTO *facet )
 	}
 
 	/* create arc insts */
-	for( arcs; arcs != NOARCINST; arcs = arcs->nextarcinst )
+	for( ; arcs != NOARCINST; arcs = arcs->nextarcinst )
 	{
 		db_arc = newarcinst( arcs->proto,
 			 			   arcs->width,
@@ -237,7 +236,7 @@ typedef struct
 	NODEPROTO *propercontact;			/* contact primitive */
 } CONTACT;
 
-INTSML via_to_contact( NODEINST** parselist, INTBIG *parselistcount,
+void via_to_contact( NODEINST** parselist, INTBIG *parselistcount,
 					   TECHNOLOGY *tech,
 					   INTBIG *equivlayers,
 					   ARCINST** arcs, 
@@ -266,9 +265,9 @@ INTSML via_to_contact( NODEINST** parselist, INTBIG *parselistcount,
 		if (fun != NPCONTACT && fun != NPWELL && fun != NPSUBSTRATE) continue;
 		contactcount++;
 	}
-	if (contactcount == 0) return(0);
+	if (contactcount == 0) return;
 	contactlist = (CONTACT *)emalloc(contactcount * (sizeof (CONTACT)), net_tool->cluster);
-	if (contactlist == 0) return(0);
+	if (contactlist == 0) return;
 	contactcount = 0;
 	for(prim = tech->firstnodeproto; prim != NONODEPROTO; prim = prim->nextnodeproto)
 	{
@@ -285,7 +284,7 @@ INTSML via_to_contact( NODEINST** parselist, INTBIG *parselistcount,
 			shapenodepoly(ni, i, poly);
 			if (poly->tech != tech) continue;
 			fun = layerfunction(tech, poly->layer) & LFTYPE;
-			if (layeriscontact(fun) != 0) contactlist[contactcount].cutlayer = equivlayers[poly->layer]; else
+			if (!layeriscontact(fun)) contactlist[contactcount].cutlayer = equivlayers[poly->layer]; else
 			{
 				if (otherlayercount >= MAXORIGLAYERS) continue;
 				contactlist[contactcount].otherlayers[otherlayercount] = equivlayers[poly->layer];
@@ -394,7 +393,6 @@ INTSML via_to_contact( NODEINST** parselist, INTBIG *parselistcount,
 		/* kill infinite loop by putting looper back to where it was before the contact */
 		i--;
 	} /*outside of for */
-	return(0);
 }
 
 
@@ -406,7 +404,7 @@ typedef struct
 } ARCDESC;
 
 /* break down each PL node into 2 nodes and 1 arc. */
-INTSML  build_node_arc_list( NODEINST** parselist,
+void  build_node_arc_list( NODEINST** parselist,
 							 INTBIG   *parselistcount,
 							 TECHNOLOGY *tech,
 							 INTBIG *equivlayers,
@@ -437,7 +435,7 @@ INTSML  build_node_arc_list( NODEINST** parselist,
 	for(ap = tech->firstarcproto; ap != NOARCPROTO; ap = ap->nextarcproto)
 		arccount++;
 	arclist = (ARCDESC *)emalloc(arccount * (sizeof (ARCDESC)), net_tool->cluster);
-	if (arclist == 0) return(0);
+	if (arclist == 0) return;
 	arccount = 0;
 	for(ap = tech->firstarcproto; ap != NOARCPROTO; ap = ap->nextarcproto)
 	{
@@ -547,8 +545,8 @@ INTSML  build_node_arc_list( NODEINST** parselist,
 		{
 			for(pp1 = nodeinst1->proto->firstportproto; pp1 != NOPORTPROTO; pp1 = pp1->nextportproto)
 			{
-				shapeportpoly(nodeinst1, pp1, poly, 0);
-				if (isinside(px1, py1, poly) != 0) break;
+				shapeportpoly(nodeinst1, pp1, poly, FALSE);
+				if (isinside(px1, py1, poly)) break;
 			}
 			if (pp1 != NOPORTPROTO) break;
 		}
@@ -573,8 +571,8 @@ INTSML  build_node_arc_list( NODEINST** parselist,
 		{
 			for(pp2 = nodeinst2->proto->firstportproto; pp2 != NOPORTPROTO; pp2 = pp2->nextportproto)
 			{
-				shapeportpoly(nodeinst2, pp2, poly, 0);
-				if (isinside(px2, py2, poly) != 0) break;
+				shapeportpoly(nodeinst2, pp2, poly, FALSE);
+				if (isinside(px2, py2, poly)) break;
 			}
 			if (pp2 != NOPORTPROTO) break;
 		}
@@ -615,7 +613,6 @@ INTSML  build_node_arc_list( NODEINST** parselist,
 
 	/* free arc structure */
 	efree((char *)arclist);
-	return(0);
 }
 
 
@@ -673,7 +670,7 @@ NODEINST* arc_to_PL( ARCINST* arc, NODEPROTO* facet )
 
 
 
-INTSML arc_crossings( ARCINST** arcs, NODEINST** nodes, NODEPROTO* facet )
+void arc_crossings( ARCINST** arcs, NODEINST** nodes, NODEPROTO* facet )
 {
 	ARCINST* a1;
 	ARCINST* a2;
@@ -686,7 +683,7 @@ INTSML arc_crossings( ARCINST** arcs, NODEINST** nodes, NODEPROTO* facet )
 	ARCINST* newarc4;
 	INTBIG newxpos;
 	INTBIG newypos;
-	INTSML cross_found;
+	BOOLEAN cross_found;
 
 	ARCINST* delete_arc_list = NOARCINST;
 
@@ -698,7 +695,7 @@ INTSML arc_crossings( ARCINST** arcs, NODEINST** nodes, NODEPROTO* facet )
 			/* check if the arcs are of the same type */
 			if( a1->proto == a2->proto )
 			{
-				cross_found = 0;
+				cross_found = FALSE;
 
 				/* calculate coords of each, store them like pl nodes for comparison */
 				n1 = arc_to_PL( a1, facet );
@@ -724,7 +721,7 @@ INTSML arc_crossings( ARCINST** arcs, NODEINST** nodes, NODEPROTO* facet )
 					newnode->rotation = 0;
 					newnode->parent = a1->parent;
 					newnode->proto = a1->end[0].nodeinst->proto;
-					cross_found = 1;
+					cross_found = TRUE;
 				}
 
 
@@ -749,10 +746,10 @@ INTSML arc_crossings( ARCINST** arcs, NODEINST** nodes, NODEPROTO* facet )
 					newnode->rotation = 0;
 					newnode->parent = a1->parent;
 					newnode->proto = a1->end[0].nodeinst->proto;
-					cross_found = 1;
+					cross_found = TRUE;
 				} /* if( n1 instersects n2 )  */
 
-				if( cross_found == 1 )
+				if( cross_found )
 				{
 				/* create 4 new arcs and delete these 2 */
 				newarc1 = allocarcinst(facet->cell->cluster);
@@ -845,7 +842,7 @@ INTSML arc_crossings( ARCINST** arcs, NODEINST** nodes, NODEPROTO* facet )
 				}
 
 
-				cross_found = 0;
+				cross_found = FALSE;
 				}
 				
 
@@ -853,23 +850,21 @@ INTSML arc_crossings( ARCINST** arcs, NODEINST** nodes, NODEPROTO* facet )
 		}  /* for a2 */
 	} /* for a1 */
 
+#if 0		/* should delete arc list here */
 	/* loop through arcs list and remove all the arcs in the delete list */
-
 	if( delete_arc_list == NOARCINST )
 	{
-		/*ttyputmsg(_("delete_arc_list is null")); */
 	}
+#endif
 
 	for( ; delete_arc_list != NOARCINST; delete_arc_list = delete_arc_list->nextarcinst )
 	{
 	/*	remove_arc( delete_arc_list, arcs ); */
 	}
-
-	return(0);
 }
 
 
-INTSML make_arc_geom( ARCINST** arcs, NODEPROTO* facet )
+void make_arc_geom( ARCINST** arcs, NODEPROTO* facet )
 {
 	GEOM* geom;
 	ARCINST* arcinst;
@@ -922,12 +917,10 @@ INTSML make_arc_geom( ARCINST** arcs, NODEPROTO* facet )
 		/* store in the arc */
 		arcinst->geom = geom;
 	}
-
-	return(0);
 }
 
 
-INTSML t_crossings( ARCINST** arcs, NODEINST** nodes, NODEPROTO* facet )
+void t_crossings( ARCINST** arcs, NODEINST** nodes, NODEPROTO* facet )
 {
 	ARCINST* looper;
 	ARCINST* comparearc;
@@ -935,8 +928,8 @@ INTSML t_crossings( ARCINST** arcs, NODEINST** nodes, NODEPROTO* facet )
 	ARCINST* newarc1;
 	ARCINST* newarc2;
 	ARCINST* newarc3;
-	INTSML xpos;
-	INTSML ypos;
+	INTBIG xpos;
+	INTBIG ypos;
 
 	/* since geometries are null in the arcs currently, create them for all of them */
 	make_arc_geom( arcs, facet );
@@ -1113,18 +1106,16 @@ INTSML t_crossings( ARCINST** arcs, NODEINST** nodes, NODEPROTO* facet )
 			} /* same tech */
 		} /* for looping nodes */
 	} /* looping arcs */
-	
-	return(0);
 }
 
 /********************************** SUPPORT **********************************/
 
-INTSML remove_arc( ARCINST* arc, ARCINST** list )
+void remove_arc( ARCINST* arc, ARCINST** list )
 {
 	ARCINST* looper;
 	looper = *list;
 
-	for( looper; looper != NOARCINST; looper = looper->nextarcinst )
+	for( ; looper != NOARCINST; looper = looper->nextarcinst )
 	{
 		ttyputmsg(_("in the for loop"));
 
@@ -1158,32 +1149,27 @@ INTSML remove_arc( ARCINST* arc, ARCINST** list )
 				looper->nextarcinst->lastarcinst =
 					looper->lastarcinst;
 			}
-			return(0);
+			return;
 		}
 	}
-	return(0);
 }
 
 
-INTSML add_arc( ARCINST* arc, ARCINST** list )
+void add_arc( ARCINST* arc, ARCINST** list )
 {
 	arc->nextarcinst = *list;
 	*list = arc;
-
-	return(0);
 }
 
 
-INTSML add_node( NODEINST* node, NODEINST** list )
+void add_node( NODEINST* node, NODEINST** list )
 {
 	node->nextnodeinst = *list;
 	*list = node;
-
-	return(0);
 }
 
 
-INTSML remove_node( NODEINST* node, NODEINST** list, INTBIG *count)
+void remove_node( NODEINST* node, NODEINST** list, INTBIG *count)
 {
 	INTBIG i, j;
 
@@ -1194,47 +1180,19 @@ INTSML remove_node( NODEINST* node, NODEINST** list, INTBIG *count)
 		(*count)--;
 		for(j=i; j < *count; j++) list[j] = list[j+1];
 		startobjectchange((INTBIG)node, VNODEINST);
-		killnodeinst(node);
+		(void)killnodeinst(node);
 	}
-	return(0);
 }
 
 
-INTSML contains_node( NODEINST* outside, NODEINST* inside )
+BOOLEAN contains_node( NODEINST* outside, NODEINST* inside )
 {
 	if (outside->highx > inside->highx &&
 		outside->lowx < inside->lowx &&
 		outside->lowy < inside->lowy &&
 		outside->highy > inside->highy )
 	{
-		return (1);
+		return (TRUE);
 	}
-	return (0);
-}
-
-
-INTSML nodes_equal( NODEINST* n1, NODEINST* n2 )
-{
-	if( n1->highx == n2->highx &&
-		n1->lowx == n2->lowx &&
-		n1->highy == n2->highy &&
-		n1->lowy == n2->lowy &&
-		n1->proto == n2->proto )
-	{
-		return(1);
-	}
-	return(0);
-}
-
-
-INTSML contains_point( GEOM* geom, INTSML xpos, INTSML ypos )
-{
-	if( geom->highx >= xpos &&
-		geom->lowx <= xpos &&
-		geom->highy >= ypos &&
-		geom->lowy <= ypos )
-	{
-		return(1);
-	}
-	return(0);
+	return (FALSE);
 }
