@@ -109,10 +109,10 @@ void pla_init(INTBIG *argc, char *argv[], TOOL *thistool)
 
 	/* initialize the nMOS PLA generator */
 	pla_fin = NULL;
-	pla_verbose = OFF;
+	pla_verbose = FALSE;
 	pla_userbits = FIXANG;
-	pla_buttingcontact = ON;
-	pla_samesideoutput = OFF;
+	pla_buttingcontact = TRUE;
+	pla_samesideoutput = FALSE;
 	pla_VddWidth = 0;
 	pla_GndWidth = 0;
 	(void)strcpy(pla_infile, INFILE);
@@ -121,15 +121,15 @@ void pla_init(INTBIG *argc, char *argv[], TOOL *thistool)
 	pla_org = pla_icg = pla_icv = pla_ocg = pla_ocv = NOVDDGND;
 
 	/* setup file descriptor */
-	pla_filetypeplatab = setupfiletype("", "*.*", MACFSTAG('TEXT'), 0, "platab", _("PLA table"));
+	pla_filetypeplatab = setupfiletype("", "*.*", MACFSTAG('TEXT'), FALSE, "platab", _("PLA table"));
 }
 
 /*
  * This routine is called each time the user issues the command,
  */
-INTSML pla_set(INTSML count, char *par[])
+void pla_set(INTBIG count, char *par[])
 {
-	REGISTER INTSML len;
+	REGISTER INTBIG len;
 	REGISTER char *pp;
 
 	if (count == 0)
@@ -138,7 +138,7 @@ INTSML pla_set(INTSML count, char *par[])
 		if (count == 0)
 		{
 			ttyputerr(M_("Aborted"));
-			return(1);
+			return;
 		}
 	}
 	len = strlen(pp = par[0]);
@@ -148,10 +148,10 @@ INTSML pla_set(INTSML count, char *par[])
 		if (count < 3)
 		{
 			pla_displayoptions();
-			return(0);
+			return;
 		}
 		pla_setoption(par[1], par[2]);
-		return(0);
+		return;
 	}
 
 	if (namesamen(pp, "cmos", len) == 0)
@@ -162,7 +162,7 @@ INTSML pla_set(INTSML count, char *par[])
 			if (count == 1)
 			{
 				ttyputerr(M_("Aborted"));
-				return(1);
+				return;
 			}
 		}
 
@@ -170,44 +170,43 @@ INTSML pla_set(INTSML count, char *par[])
 		if (namesamen(pp, "generate-pla", len) == 0)
 		{
 			plac_generate();
-			return(0);
+			return;
 		}
 		if (namesamen(pp, "decoder", len) == 0)
 		{
 			plac_dec();
-			return(0);
+			return;
 		}
 		if (namesamen(pp, "n-plane", len) == 0)
 		{
 			plac_n_generate();
-			return(0);
+			return;
 		}
 		if (namesamen(pp, "p-plane", len) == 0)
 		{
 			plac_p_generate();
-			return(0);
+			return;
 		}
 		ttyputbadusage("telltool pla cmos");
-		return(1);
+		return;
 	}
 
 	/* Invalid control to the PLA generator.  Print a small summary */
 	ttyputbadusage("telltool pla");
-	return(1);
 }
 
 void pla_slice(void)
 {
-	if (pla_Make() == ERRORRET)
+	if (pla_Make())
 	{
 		ttyputerr(_("nMOS PLA '%s' is incompletely defined"), pla_name);
 		if (pla_fin != NULL) xclose(pla_fin);
-		toolturnoff(pla_tool, 0);
+		toolturnoff(pla_tool, FALSE);
 		setactivity(_("Incomplete nMOS PLA generated"));
 		return;
 	}
 	xclose(pla_fin);
-	toolturnoff(pla_tool, 0);
+	toolturnoff(pla_tool, FALSE);
 	setactivity(_("nMOS PLA generated"));
 }
 
