@@ -29,7 +29,7 @@
  */
 
 #include "config.h"
-#if PLAAID
+#if PLATOOL
 
 #include "global.h"
 #include "pla.h"
@@ -38,7 +38,7 @@
 extern COMCOMP us_yesnop, us_colorreadp;		/* from usrcom.c */
 
 /*
- * routine called for the command "tellaid pla cmos generate-pla"
+ * routine called for the command "telltool pla cmos generate-pla"
  */
 void plac_generate(void)
 {
@@ -147,7 +147,7 @@ void plac_generate(void)
 }
 
 /*
- * routine called for the command "tellaid pla cmos decoder"
+ * routine called for the command "telltool pla cmos decoder"
  */
 void plac_dec(void)
 {
@@ -216,7 +216,7 @@ void plac_dec(void)
 }
 
 /*
- * routine called for the command "tellaid pla cmos p-plane"
+ * routine called for the command "telltool pla cmos p-plane"
  */
 void plac_p_generate(void)
 {
@@ -258,7 +258,7 @@ void plac_p_generate(void)
 }
 
 /*
- * routine called for the command "tellaid pla cmos n-plane"
+ * routine called for the command "telltool pla cmos n-plane"
  */
 void plac_n_generate(void)
 {
@@ -351,4 +351,4 @@ INTBIG plac_read_hw(FILE *file, INTBIG *height, INTBIG *width, INTBIG *height_in
 	return(eof);
 }
 
-#endif  /* PLAAID - at top */
+#endif  /* PLATOOL - at top */
