@@ -61,7 +61,7 @@ NODEPROTO *plac_or_plane(LIBRARY *library, NODEPROTO *or_np, char *facet_name,
 	var = getval((INTBIG)or_np, VNODEPROTO, VINTEGER, "PLA_data_cols");
 	if (var != NOVARIABLE) columns = (INTBIG)((INTBIG *)var->addr); else
 	{
-		ttyputerr(_("DATA_cols defaulting to 2"));
+		ttyputerr(M_("DATA_cols defaulting to 2"));
 		columns = 2;
 	}
 
@@ -104,7 +104,7 @@ NODEPROTO *plac_or_plane(LIBRARY *library, NODEPROTO *or_np, char *facet_name,
 				modifynodeinst(new_ni, 0, 0, 0, 0, 1800, 0);
 
 				/* mirror */
-				modifynodeinst(new_ni, 0, 0, 0, 0, (INTSML)amt_1, (INTSML)(1-new_ni->transpose*2));
+				modifynodeinst(new_ni, 0, 0, 0, 0, amt_1, 1-new_ni->transpose*2);
 			}
 			if (last_buf_ni == NONODEINST)
 			{
@@ -208,7 +208,7 @@ NODEPROTO *plac_or_plane(LIBRARY *library, NODEPROTO *or_np, char *facet_name,
 				modifynodeinst(new_ni, 0, 0, 0, 0, 1800, 0);
 
 				/* mirror */
-				modifynodeinst(new_ni, 0, 0, 0, 0, (INTSML)amt_1, (INTSML)(1-new_ni->transpose*2));
+				modifynodeinst(new_ni, 0, 0, 0, 0, amt_1, 1-new_ni->transpose*2);
 			}
 			if (last_buf_ni == NONODEINST)
 			{
