@@ -147,7 +147,7 @@ NODEINST *plac_make_instance(NODEPROTO *pla_facet, NODEPROTO *Inst_proto, INTBIG
 		/* do a horizontal mirror */
 		if (node_inst->transpose == 0) amt = 2700; else
 			amt = 900;
-		modifynodeinst(node_inst, 0, 0, 0, 0, (INTSML)amt, (INTSML)(1-node_inst->transpose*2));
+		modifynodeinst(node_inst, 0, 0, 0, 0, amt, 1-node_inst->transpose*2);
 	}
 	return(node_inst);
 }
