@@ -115,8 +115,9 @@ ARCPROTO  *pla_pa_proto;		/* Poly arc */
 ARCPROTO  *pla_ma_proto;		/* Metal arc */
 
 /*  Options accessible to the designer */
-INTSML  pla_verbose, pla_userbits, pla_buttingcontact, pla_samesideoutput;
-INTSML  pla_inputs, pla_outputs, pla_pterms;
+BOOLEAN pla_verbose, pla_buttingcontact, pla_samesideoutput;
+INTBIG  pla_userbits;
+INTBIG  pla_inputs, pla_outputs, pla_pterms;
 INTBIG  pla_VddWidth;			/* VDD width in use */
 INTBIG  pla_GndWidth;			/* Vdd and Gnd Widths in use */
 char    pla_infile[100];		/* Name of the input file */
@@ -136,19 +137,19 @@ VDDGND   *pla_ocv;				/* Output facet Vdd points */
 FILE     *pla_fin;				/* Pointer to the input file */
 
 /* prototypes for local routines */
-static void   pla_Flag(INTSML);
-static INTSML pla_GetVal(void);
-static INTSML pla_ReadOffEqualSign(void);
-static void   pla_Recover(void);
-static void   pla_SetFlag(void);
-static void   pla_SetName(void);
-static INTSML pla_SkipChars(void);
-static char  *pla_onoffmessage(INTBIG onoff);
+static void    pla_Flag(INTBIG);
+static INTBIG  pla_GetVal(void);
+static BOOLEAN pla_ReadOffEqualSign(void);
+static void    pla_Recover(void);
+static void    pla_SetFlag(void);
+static void    pla_SetName(void);
+static BOOLEAN pla_SkipChars(void);
+static char   *pla_onoffmessage(INTBIG onoff);
 
 /* Set the given option to ON or OFF */
-void pla_Flag(INTSML option)
+void pla_Flag(INTBIG option)
 {
-	INTSML onoroff;
+	INTBIG onoroff;
 	char keyword[16];
 
 	onoroff = pla_GetKeyWord(keyword);
@@ -156,37 +157,39 @@ void pla_Flag(INTSML option)
 	{
 		if (onoroff != ON && onoroff != OFF)
 		{
-			ttyputerr(_("'%s' may be set to ON or OFF only"), pla_KeyWords[option]);
+			ttyputerr(M_("'%s' may be set to ON or OFF only"), pla_KeyWords[option]);
 			return;
 		}
 		switch(option)
 		{
 			case VERBOSE:
-				pla_verbose = onoroff;
-				if (pla_verbose == ON)
-					ttyputmsg(M_("'verbose' set to %s"), pla_onoffmessage(pla_verbose == ON));
+				if (onoroff == 0) pla_verbose = FALSE; else
+					pla_verbose = TRUE;
+				if (pla_verbose)
+					ttyputmsg(M_("'verbose' set to %s"), pla_onoffmessage(pla_verbose));
 				break;
 			case FLEXIBLE:
 				if (onoroff == ON) pla_userbits &= ~FIXED; else
 					pla_userbits |= FIXED;
-				if (pla_verbose == ON)
+				if (pla_verbose)
 					ttyputmsg(M_("'flexible' set to %s"), pla_onoffmessage(pla_userbits&FIXED));
 				break;
 			case FIXEDANGLE:
 				if (onoroff == ON) pla_userbits |= FIXANG; else
 					pla_userbits &= ~FIXANG;
-				if (pla_verbose == ON)
+				if (pla_verbose)
 					ttyputmsg(M_("'fixedangle' set to %s"), pla_onoffmessage(pla_userbits&FIXANG));
 				break;
 			case BUTTINGCONTACT:
-				pla_buttingcontact = onoroff;
-				if (pla_verbose == ON)
-					ttyputmsg(M_("'buttingcontact' set to %s"), pla_onoffmessage(pla_buttingcontact == ON));
+				if (onoroff == 0) pla_buttingcontact = FALSE; else
+					pla_buttingcontact = TRUE;
+				if (pla_verbose)
+					ttyputmsg(M_("'buttingcontact' set to %s"), pla_onoffmessage(pla_buttingcontact));
 				break;
 			case SAMESIDEOUTPUT:
-				pla_samesideoutput = ON;
-				if (pla_verbose == ON)
-					ttyputmsg(M_("'samesideoutput' set to %s"), pla_onoffmessage(pla_samesideoutput == ON));
+				pla_samesideoutput = TRUE;
+				if (pla_verbose)
+					ttyputmsg(M_("'samesideoutput' set to %s"), pla_onoffmessage(pla_samesideoutput));
 				break;
 		}
 	}
@@ -197,14 +200,14 @@ void pla_Flag(INTSML option)
  * pla_KeyWords[] in pla.c.  Return ERRORRET on end-of-file else return OK.
  * The keyoword fround is returned via the input parameter.
  */
-INTSML pla_GetKeyWord(char *keyword)
+INTBIG pla_GetKeyWord(char *keyword)
 {
 	char *savekeywordaddr;
-	INTSML k, c;
+	INTBIG k, c;
 
 	savekeywordaddr = keyword;
 
-	if (pla_SkipChars() == ERRORRET) return(ERRORRET);
+	if (pla_SkipChars()) return(ERRORRET);
 	while((c = xgetc(pla_fin)) != EOF)
 	{
 		if ((c >= 'A' && c <= 'Z') || (c >= 'a' && c <= 'z') ||
@@ -224,16 +227,16 @@ INTSML pla_GetKeyWord(char *keyword)
 }
 
 /* Get a number from the input stream */
-INTSML pla_GetVal(void)
+INTBIG pla_GetVal(void)
 {
 	char keyword[16];
-	INTSML n;
+	INTBIG n;
 
 	if (pla_GetKeyWord(keyword) != ERRORRET)
 	{
 		if ((n = atoi(keyword)) == 0)
 		{
-			ttyputerr(_("Inappropriate numbers in input"));
+			ttyputerr(M_("Inappropriate numbers in input"));
 			return(ERRORRET);
 		}
 		return(n);
@@ -241,10 +244,10 @@ INTSML pla_GetVal(void)
 	return(ERRORRET);
 }
 
-INTSML pla_ProcessFlags(void)
+BOOLEAN pla_ProcessFlags(void)
 {
 	char keyword[16];
-	INTSML position;
+	INTBIG position;
 
 	while((position = pla_GetKeyWord(keyword)) != ERRORRET)
 	{
@@ -258,39 +261,38 @@ INTSML pla_ProcessFlags(void)
 				pla_SetFlag();
 				break;
 			case BEGIN:		/* PLA definition begins */
-				return(OK);
+				return(FALSE);
 			case UNDEFINED:
-				ttyputerr(_("undefined string in input: '%s'"), keyword);
+				ttyputerr(M_("undefined string in input: '%s'"), keyword);
 				pla_Recover();
 				break;
 			default:		/* Error.  We shouldn't be here */
-				ttyputerr(_("unknown error while reading input."));
-				ttyputerr(_("	'%s' was read."), keyword);
+				ttyputerr(M_("unknown error while reading '%s'"), keyword);
 				pla_Recover();
 				break;
 		}
 	}
-	return(ERRORRET);
+	return(TRUE);
 }
 
-INTSML pla_ReadOffEqualSign(void)
+BOOLEAN pla_ReadOffEqualSign(void)
 {
 	char keyword[16];
 
 	if (pla_GetKeyWord(keyword) != ERRORRET)
 	{
-		if (namesame(keyword, "=") == 0) return(OK);
-		ttyputerr(_("equal sign expected. Read '%s' instead."), keyword);
+		if (namesame(keyword, "=") == 0) return(FALSE);
+		ttyputerr(M_("equal sign expected. Read '%s' instead."), keyword);
 		pla_Recover();
 	}
-	return(ERRORRET);
+	return(TRUE);
 }
 
 void pla_Recover(void)
 {
 	char keyword[16];
 
-	ttyputmsg(_("Skipping text until next 'set' or 'begin' directive ..."));
+	ttyputmsg(M_("Skipping text until next 'set' or 'begin' directive ..."));
 
 	while(pla_GetKeyWord(keyword) != ERRORRET)
 	{
@@ -314,7 +316,7 @@ void pla_Recover(void)
 void pla_SetFlag(void)
 {
 	char keyword[16];
-	INTSML position;
+	INTBIG position;
 
 	position = pla_GetKeyWord(keyword);
 	if (position != ERRORRET)
@@ -322,48 +324,48 @@ void pla_SetFlag(void)
 		switch(position)
 		{
 			case SET:
-				ttyputerr(_("set must be followed by an option name"));
+				ttyputerr(M_("Set must be followed by an option name"));
 				pla_Recover();
 				break;
 			case EQUAL:
-				ttyputerr(_("option name missing"));
+				ttyputerr(M_("option name missing"));
 				pla_Recover();
 				break;
 			case INPUTS:
-				if (pla_ReadOffEqualSign() != ERRORRET) pla_inputs = pla_GetVal();
-				if (pla_verbose == ON) ttyputmsg(M_("'inputs' set to %d"), pla_inputs);
+				if (!pla_ReadOffEqualSign()) pla_inputs = pla_GetVal();
+				if (pla_verbose) ttyputmsg(M_("'inputs' set to %ld"), pla_inputs);
 				break;
 			case OUTPUTS:
-				if (pla_ReadOffEqualSign() != ERRORRET) pla_outputs = pla_GetVal();
-				if (pla_verbose == ON) ttyputmsg(M_("'outputs' set to %d"), pla_outputs);
+				if (!pla_ReadOffEqualSign()) pla_outputs = pla_GetVal();
+				if (pla_verbose) ttyputmsg(M_("'outputs' set to %ld"), pla_outputs);
 				break;
 			case PTERMS:
-				if (pla_ReadOffEqualSign() != ERRORRET) pla_pterms = pla_GetVal();
-				if (pla_verbose == ON) ttyputmsg(M_("'pterms' set to %d"), pla_pterms);
+				if (!pla_ReadOffEqualSign()) pla_pterms = pla_GetVal();
+				if (pla_verbose) ttyputmsg(M_("'pterms' set to %ld"), pla_pterms);
 				break;
 			case VDDWIDTH:
-				if (pla_ReadOffEqualSign() != ERRORRET)
+				if (!pla_ReadOffEqualSign())
 					pla_VddWidth = pla_lam * pla_GetVal();
 				if (pla_VddWidth < 4 * pla_lam) pla_VddWidth = 4 * pla_lam;
 				pla_halfVdd = pla_VddWidth / 2;
-				if (pla_verbose == ON) ttyputmsg(M_("'Vdd Width' set to %s"), latoa(pla_VddWidth));
+				if (pla_verbose) ttyputmsg(M_("'Vdd Width' set to %s"), latoa(pla_VddWidth));
 				break;
 			case GNDWIDTH:
-				if (pla_ReadOffEqualSign() != ERRORRET)
+				if (!pla_ReadOffEqualSign())
 					pla_GndWidth = pla_lam * pla_GetVal();
 				if (pla_GndWidth < 4 * pla_lam) pla_GndWidth = 4 * pla_lam;
 				pla_halfGnd = pla_GndWidth / 2;
-				if (pla_verbose == ON) ttyputmsg(M_("'Gnd Width' set to %s"), latoa(pla_GndWidth));
+				if (pla_verbose) ttyputmsg(M_("'Gnd Width' set to %s"), latoa(pla_GndWidth));
 				break;
 			case VERBOSE:
 			case FLEXIBLE:
 			case FIXEDANGLE:
 			case BUTTINGCONTACT:
 			case SAMESIDEOUTPUT:
-				if (pla_ReadOffEqualSign() != ERRORRET) pla_Flag(position);
+				if (!pla_ReadOffEqualSign()) pla_Flag(position);
 				break;
 			case NAME:
-				if (pla_ReadOffEqualSign() != ERRORRET) pla_SetName();
+				if (!pla_ReadOffEqualSign()) pla_SetName();
 				break;
 			case ONE:
 			case ZERO:
@@ -373,7 +375,7 @@ void pla_SetFlag(void)
 			case BEGIN:
 			case ON:
 			case OFF:
-				ttyputerr(_("invalid option name '%s'."), keyword);
+				ttyputerr(M_("invalid option name '%s'."), keyword);
 				pla_Recover();
 				break;
 		}
@@ -386,11 +388,11 @@ void pla_SetName(void)
 	char keyword[32];
 
 	if (pla_GetKeyWord(keyword) != ERRORRET) (void)strcpy(pla_name, keyword);
-	if (pla_verbose == ON)
+	if (pla_verbose)
 		ttyputmsg(M_("Name of the PLA set to '%s'"), pla_name);
 }
 
-INTSML pla_SkipChars(void)
+BOOLEAN pla_SkipChars(void)
 {
 	INTSML c;
 
@@ -404,7 +406,7 @@ INTSML pla_SkipChars(void)
 			(c >= '0' && c <= '9') || (c == '='))
 		{
 			xungetc((char)c, pla_fin);
-			return(OK);
+			return(FALSE);
 		}
 		if (c == '{' || c == ';')  /* Skip over Comments */
 		{
@@ -417,24 +419,24 @@ INTSML pla_SkipChars(void)
 					while((c = xgetc(pla_fin)) != EOF && c != '\n') ;
 					break;
 			}
-			if (c == EOF) return(ERRORRET);
+			if (c == EOF) return(FALSE);
 		}
 	}
-	return(OK);
+	return(TRUE);
 }
 
 void pla_displayoptions(void)
 {
 	ttyputmsg(M_("nMOS PLA options and current values:"));
 	ttyputmsg(M_("       Input file = %s"), pla_infile);
-	ttyputmsg(M_(" Number of Inputs = %d"), pla_inputs);
-	ttyputmsg(M_("Number of Outputs = %d"), pla_outputs);
-	ttyputmsg(M_(" Number of Pterms = %d"), pla_pterms);
-	ttyputmsg(M_("	       Verbose = %s"), pla_onoffmessage(pla_verbose == ON));
+	ttyputmsg(M_(" Number of Inputs = %ld"), pla_inputs);
+	ttyputmsg(M_("Number of Outputs = %ld"), pla_outputs);
+	ttyputmsg(M_(" Number of Pterms = %ld"), pla_pterms);
+	ttyputmsg(M_("	       Verbose = %s"), pla_onoffmessage(pla_verbose));
 	ttyputmsg(M_("	      Flexible = %s"), pla_onoffmessage(pla_userbits&FIXED));
 	ttyputmsg(M_("       Fixedangle = %s"), pla_onoffmessage(pla_userbits&FIXANG));
-	ttyputmsg(M_("   Buttingcontact = %s"), pla_onoffmessage(pla_buttingcontact == ON));
-	ttyputmsg(M_("   Samesideoutput = %s"), pla_onoffmessage(pla_samesideoutput == ON));
+	ttyputmsg(M_("   Buttingcontact = %s"), pla_onoffmessage(pla_buttingcontact));
+	ttyputmsg(M_("   Samesideoutput = %s"), pla_onoffmessage(pla_samesideoutput));
 	ttyputmsg(M_("	     VDD Width = %s"), latoa(pla_VddWidth));
 	ttyputmsg(M_("	     Gnd Width = %s"), latoa(pla_GndWidth));
 	ttyputmsg(M_("  Name of the PLA = %s"), pla_name);
@@ -442,24 +444,24 @@ void pla_displayoptions(void)
 
 char *pla_onoffmessage(INTBIG onoff)
 {
-	if (onoff != 0) return(_("ON"));
-	return(_("OFF"));
+	if (onoff != 0) return(M_("ON"));
+	return(M_("OFF"));
 }
 
 void pla_setoption(char *option, char *value)
 {
-	INTSML k, val, len;
+	INTBIG k, val, len;
 
 	len = strlen(option);
 	if (namesame(option, NULLSTR) == 0)
 	{
-		ttyputerr(_("Set must be followed by an option name"));
+		ttyputerr(M_("Set must be followed by an option name"));
 		return;
 	}
 
 	if (namesame(value, NULLSTR) == 0)
 	{
-		ttyputerr(_("Options must be set to some value; not nil."));
+		ttyputerr(M_("Options must be set to some value; not nil."));
 		return;
 	}
 	for(k = 0; k < MAXKEYWORDS; k++)
@@ -474,14 +476,15 @@ void pla_setoption(char *option, char *value)
 		if (namesamen(value, "on", len) == 0) val = 1; else
 			if (namesamen(value, "off", len) == 0) val = 0; else
 		{
-			ttyputerr(_("Value must be ON or OFF"));
+			ttyputerr(M_("Value must be ON or OFF"));
 			return;
 		}
 		switch(k)
 		{
 			case VERBOSE:
-				pla_verbose = val;
-				ttyputverbose(M_("'verbose' set to %s"), pla_onoffmessage(pla_verbose == ON));
+				if (val != 0) pla_verbose = TRUE; else
+					pla_verbose = FALSE;
+				ttyputverbose(M_("'verbose' set to %s"), pla_onoffmessage(pla_verbose));
 				break;
 			case FLEXIBLE:
 				if (val == ON) pla_userbits &= ~FIXED; else
@@ -494,12 +497,14 @@ void pla_setoption(char *option, char *value)
 				ttyputverbose(M_("'fixedangle' set to %s"), pla_onoffmessage(pla_userbits&FIXANG));
 				break;
 			case BUTTINGCONTACT:
-				pla_buttingcontact = val;
-				ttyputverbose(M_("'buttingcontact' set to %s"), pla_onoffmessage(pla_buttingcontact == ON));
+				if (val != 0) pla_buttingcontact = TRUE; else
+					pla_buttingcontact = FALSE;
+				ttyputverbose(M_("'buttingcontact' set to %s"), pla_onoffmessage(pla_buttingcontact));
 				break;
 			case SAMESIDEOUTPUT:
-				pla_samesideoutput = val;
-				ttyputverbose(M_("'samesideoutput' set to %s"), pla_onoffmessage(pla_samesideoutput == ON));
+				if (val != 0) pla_samesideoutput = TRUE; else
+					pla_samesideoutput = FALSE;
+				ttyputverbose(M_("'samesideoutput' set to %s"), pla_onoffmessage(pla_samesideoutput));
 				break;
 		}
 		return;
@@ -512,18 +517,18 @@ void pla_setoption(char *option, char *value)
 		{
 			case INPUTS:
 				pla_inputs = val;
-				ttyputverbose(M_("Inputs set to %d"), pla_inputs);
+				ttyputverbose(M_("Inputs set to %ld"), pla_inputs);
 				break;
 			case OUTPUTS:
 				pla_outputs = val;
-				ttyputverbose(M_("Outputs set to %d"), pla_inputs);
+				ttyputverbose(M_("Outputs set to %ld"), pla_outputs);
 				break;
 			case PTERMS:
 				pla_pterms = val;
-				ttyputverbose(M_("Product terms set to %d"), pla_inputs);
+				ttyputverbose(M_("Product terms set to %ld"), pla_pterms);
 				break;
 			case VDDWIDTH:
-				if (val < 4) ttyputerr(_("Vdd Width must be at least 4 lambda")); else
+				if (val < 4) ttyputerr(M_("Vdd Width must be at least 4 lambda")); else
 				{
 					pla_VddWidth = val*pla_lam;
 					pla_halfVdd  = pla_VddWidth / 2;
@@ -531,7 +536,7 @@ void pla_setoption(char *option, char *value)
 				}
 				break;
 			case GNDWIDTH:
-				if (val < 4) ttyputerr(_("Ground Width must be at least 4 lambda")); else
+				if (val < 4) ttyputerr(M_("Ground Width must be at least 4 lambda")); else
 				{
 					pla_GndWidth = val*pla_lam;
 					pla_halfGnd  = pla_GndWidth / 2;
