@@ -42,7 +42,7 @@
 #include "planmos.h"
 
 /* prototypes for local routines */
-static PROGTRANS *pla_FindPColTrans(INTSML, PROGTRANS*);
+static PROGTRANS *pla_FindPColTrans(INTBIG, PROGTRANS*);
 static FACETIST  *pla_PlaceInputs(INTBIG, INTBIG, INTBIG, NODEPROTO*);
 static FACETIST  *pla_PlaceOutputs(INTBIG, INTBIG, INTBIG, NODEPROTO*);
 static FACETIST  *pla_PlacePullupsonAND(INTBIG, INTBIG, INTBIG, NODEPROTO*);
@@ -50,20 +50,20 @@ static FACETIST  *pla_PlacePullupsonOR(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, N
 static PROGTRANS *pla_Program(INTBIG, INTBIG, INTBIG, NODEPROTO*);
 static PROGTRANS *pla_ProgramAND(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 static PROGTRANS *pla_ProgramOR(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
-static INTSML     pla_ProgramPLA(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*);
+static BOOLEAN    pla_ProgramPLA(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*);
 
 /*
  * Make the PLA.  First define all the primitives and then
  * call pla_ProgramPLA to program the planes.
  */
-INTSML pla_Make(void)
+BOOLEAN pla_Make(void)
 {
 	INTBIG inX, inY,               /* Dimensions of Input facet */
 		  puX, puY,               /* Dimensions of Double Pullup facet */
 		  outX, outY,             /* Dimensions of Output facet */
 		  progX, progY,           /* Dimensions of Programming Transistor */
 		  connectX, connectY;     /* Dimensions of Connect facet */
-	INTSML pos;
+	INTBIG pos;
 	char keyword[32], *filename;
 	TECHNOLOGY *tech;
 
@@ -72,17 +72,17 @@ INTSML pla_Make(void)
 	if (pla_fin == NULL)
 	{
 		ttyputerr(_("File '%s' not found, use 'telltool pla nmos file FILE'"), pla_infile);
-		return(ERRORRET);
+		return(TRUE);
 	}
-	if (pla_verbose == ON)
-		ttyputmsg(_("File '%s' has been opened for reading"), pla_infile);
+	if (pla_verbose)
+		ttyputmsg(M_("File '%s' has been opened for reading"), pla_infile);
 
 	/* Set the Technology to the Default Technology (nmos) */
 	tech = gettechnology(PLADEFTECH);
 	if (tech == NOTECHNOLOGY)
 	{
-		ttyputerr(_("'%s' is an undefined technology"), PLADEFTECH);
-		return(ERRORRET);
+		ttyputerr(M_("'%s' is an undefined technology"), PLADEFTECH);
+		return(TRUE);
 	}
 	if (el_curtech != tech)
 		ttyputmsg(_("Warning: current technology should be %s"), tech->techname);
@@ -115,8 +115,8 @@ INTSML pla_Make(void)
 		pla_etran_proto == NONODEPROTO || pla_bc_proto  == NONODEPROTO ||
 		pla_bp_proto    == NONODEPROTO)
 	{
-		ttyputerr(_("Cannot find primitive prototypes of nmos technology"));
-		return(ERRORRET);
+		ttyputerr(M_("Cannot find primitive prototypes of nmos technology"));
+		return(TRUE);
 	}
 
 	/* Create all the facet prototypes.  Facets are defined in planfacets.c */
@@ -124,7 +124,7 @@ INTSML pla_Make(void)
 	if (pla_pu_proto  == NONODEPROTO)
 	{
 		ttyputerr(_("Cannot create pullup facet"));
-		return(ERRORRET);
+		return(TRUE);
 	}
 	puX = pla_pu_proto->highx - pla_pu_proto->lowx;
 	puY = pla_pu_proto->highy - pla_pu_proto->lowy;
@@ -133,7 +133,7 @@ INTSML pla_Make(void)
 	if (pla_in_proto == NONODEPROTO)
 	{
 		ttyputerr(_("Cannot create input facet"));
-		return(ERRORRET);
+		return(TRUE);
 	}
 	inX = pla_in_proto->highx - pla_in_proto->lowx;
 	inY = pla_in_proto->highy - pla_in_proto->lowy;
@@ -142,7 +142,7 @@ INTSML pla_Make(void)
 	if (pla_connect_proto == NONODEPROTO)
 	{
 		ttyputerr(_("Cannot create connect facet"));
-		return(ERRORRET);
+		return(TRUE);
 	}
 	connectX = pla_connect_proto->highx - pla_connect_proto->lowx;
 	connectY = pla_connect_proto->highy - pla_connect_proto->lowy;
@@ -151,7 +151,7 @@ INTSML pla_Make(void)
 	if (pla_prog_proto== NONODEPROTO)
 	{
 		ttyputerr(_("Cannot create program facet"));
-		return(ERRORRET);
+		return(TRUE);
 	}
 	progX = pla_prog_proto->highx - pla_prog_proto->lowx;
 	progY = pla_prog_proto->highy - pla_prog_proto->lowy;
@@ -160,12 +160,12 @@ INTSML pla_Make(void)
 	if (pla_out_proto == NONODEPROTO)
 	{
 		ttyputerr(_("Cannot create output facet"));
-		return(ERRORRET);
+		return(TRUE);
 	}
 	outX = pla_out_proto->highx - pla_out_proto->lowx;
 	outY = pla_out_proto->highy - pla_out_proto->lowy;
 
-	if (pla_verbose == ON)
+	if (pla_verbose)
 	{
 		ttyputmsg(M_("Facets have been defined with sizes given below:"));
 		ttyputmsg(M_("Pullup  = %sx%s"), latoa(puX), latoa(puY));
@@ -181,7 +181,7 @@ INTSML pla_Make(void)
 	 */
 	for(;;)
 	{
-		if (pla_ProcessFlags() == ERRORRET) break;
+		if (pla_ProcessFlags()) break;
 
 		pla_facet = NONODEPROTO;
 		pla_alv = pla_atg = pla_arg = pla_otv = NOVDDGND;
@@ -189,40 +189,40 @@ INTSML pla_Make(void)
 
 		if (pla_inputs == 0)
 		{
-			ttyputerr(_("Use 'telltool pla nmos inputs VALUE' to set inputs"));
-			return(ERRORRET);
+			ttyputerr(_("No inputs set"));
+			return(TRUE);
 		}
 		if (pla_outputs == 0)
 		{
-			ttyputerr(_("Use 'telltool pla nmos outputs VALUE' to set outputs"));
-			return(ERRORRET);
+			ttyputerr(_("No outputs set"));
+			return(TRUE);
 		}
 		if (pla_pterms == 0)
 		{
-			ttyputerr(_("Use 'telltool pla nmos pterms VALUE' to set prod. terms"));
-			return(ERRORRET);
+			ttyputerr(_("No product terms set"));
+			return(TRUE);
 		}
 		if (namesame(pla_name, DEFNAME) == 0)
-			(void)sprintf(pla_name, "PLA-%d-%d-%d", pla_inputs, pla_pterms, pla_outputs);
+			(void)sprintf(pla_name, "PLA-%ld-%ld-%ld", pla_inputs, pla_pterms, pla_outputs);
 
 		pla_facet = newnodeproto(pla_name, el_curlib);
 		if (pla_facet == NONODEPROTO)
 		{
-			ttyputerr(_("Cannot create '%s' prototype"), pla_name);
-			return(ERRORRET);
+			ttyputerr(_("Cannot create '%s' facet"), pla_name);
+			return(TRUE);
 		}
 
 		ttyputmsg(_("Defining '%s'"), pla_name);
-		if (pla_verbose == ON)
+		if (pla_verbose)
 			ttyputmsg(M_("Beginning to program the AND and OR planes."));
 		if (pla_ProgramPLA(inX, inY, puX, puY, outX, outY, connectX,
-			connectY, pla_facet) == ERRORRET)
+			connectY, pla_facet))
 				ttyputerr(_("PLA '%s' is incompletely defined"), pla_name);
 
 		while((pos = pla_GetKeyWord(keyword)) != ERRORRET)
 			if (pos == END) break;
 	}
-	return(OK);
+	return(FALSE);
 }
 
 /*
@@ -231,24 +231,24 @@ INTSML pla_Make(void)
  * which needs to be connected to the programming transistor to be
  * placed on the pterm row.
  */
-PROGTRANS *pla_FindPColTrans(INTSML pterm, PROGTRANS *trans)
+PROGTRANS *pla_FindPColTrans(INTBIG pterm, PROGTRANS *trans)
 {
-	INTSML column;
+	INTBIG column;
 
 	column = trans->column;
 
 	while (trans->uprogtrans != NOPROGTRANS)
 	{
 		if (trans->column != column)
-			ttyputerr(_("FindPColTrans: Column mismatch: wanted %d, got %d/%d"),
+			ttyputerr(M_("FindPColTrans: Column mismatch: wanted %ld, got %ld/%ld"),
 				column, trans->column, trans->row);
 		trans = trans->uprogtrans;
 	}
 
 	if (trans->row >= pterm)
 	{
-		ttyputerr(_("FindPColTrans: Error.  Gone past row %d in column %d"), pterm, trans->column);
-		ttyputerr(_("   Last progtrans in this column is at row=%d"), trans->row);
+		ttyputerr(M_("FindPColTrans: Error.  Gone past row %ld in column %ld"), pterm, trans->column);
+		ttyputerr(M_("   Last progtrans in this column is at row=%ld"), trans->row);
 		return(NOPROGTRANS);
 	}
 	return(trans);
@@ -264,7 +264,7 @@ FACETIST *pla_PlaceInputs(INTBIG puX, INTBIG inX, INTBIG inY, NODEPROTO *pla)
 {
 	FACETIST *ptr, *prevptr, *firstptr;
 	VDDGND *cicv, *picv, *cicg, *picg;
-	INTSML i;
+	INTBIG i;
 	INTBIG llXpos, llYpos, VddYpos, GndYpos;
 	char portname[16];
 
@@ -277,35 +277,28 @@ FACETIST *pla_PlaceInputs(INTBIG puX, INTBIG inX, INTBIG inY, NODEPROTO *pla)
 	firstptr= NOFACETIST;
 	cicv = picv = cicg = picg = NOVDDGND;
 
-	if (pla_verbose == ON) ttyputmsg(M_("Placing the input facets"));
+	if (pla_verbose) ttyputmsg(M_("Placing the input facets"));
 
 	for(i = 1; i <= pla_inputs; i++)
 	{
-		if (pla_verbose == ON) ttyputmsg(M_("Placing input facet %d"), i);
+		if (pla_verbose) ttyputmsg(M_("Placing input facet %ld"), i);
 		ptr = (FACETIST *)emalloc(sizeof(FACETIST), pla_tool->cluster);
-		if (ptr == NOFACETIST)
-		{
-			ttyputerr(_("PlaceInputs: ran out of storage space. i=%d"), i);
-			break;
-		} else if (ptr == NOFACETIST) break;
+		if (ptr == NOFACETIST) return(NOFACETIST);
 		ptr->findex = i;    /* remember which input this facet corresponds to */
 		ptr->facetinst = newnodeinst(pla_in_proto, llXpos, llXpos+inX,
 			llYpos, llYpos+inY, NOTRANS, NOROT, pla);
-		if (ptr->facetinst == NONODEINST)
-			ttyputerr(_("PlaceInputs: cannot instance input# %d"), i);
+		if (ptr->facetinst == NONODEINST) return(NOFACETIST);
 
 		/* Record the Gnd and Vdd points for later connection */
 		cicg = pla_MkVddGnd(INFACETGND, &picg);
 		cicg->inst = ptr->facetinst;
 		cicg->port = pla_AssignPort(ptr->facetinst, llXpos+6*pla_lam, GndYpos);
-		if (cicg->port->port == NOPORTPROTO)
-			ttyputerr(_("PlaceInputs: can't access Gnd contact"));
+		if (cicg->port->port == NOPORTPROTO) return(NOFACETIST);
 
 		cicv = pla_MkVddGnd(INFACETVDD, &picv);
 		cicv->inst = ptr->facetinst;
 		cicv->port = pla_AssignPort(ptr->facetinst, llXpos+5*pla_lam, VddYpos);
-		if (cicv->port->port == NOPORTPROTO)
-			ttyputerr(_("PlaceInputs: can't access Vdd contact"));
+		if (cicv->port->port == NOPORTPROTO) return(NOFACETIST);
 
 		/* Find the ports that connect into the PLA */
 		ptr->lport = pla_AssignPort(ptr->facetinst, llXpos+2*pla_lam, llYpos+inY-pla_lam);
@@ -314,16 +307,15 @@ FACETIST *pla_PlaceInputs(INTBIG puX, INTBIG inX, INTBIG inY, NODEPROTO *pla)
 
 		if (ptr->lport->port == NOPORTPROTO ||
 			ptr->rport->port == NOPORTPROTO || ptr->gport->port == NOPORTPROTO)
-				ttyputerr(_("PlaceInputs: cannot access ports into PLA"));
+				return(NOFACETIST);
 
 		/* Initialize the progtrans ends */
 		ptr->rcoltrans = ptr->lcoltrans = NOPROGTRANS;
 
 		/* Export the input point giving it a name */
-		(void)sprintf(portname, "Input%d", i);
+		(void)sprintf(portname, "Input%ld", i);
 		if (newportproto(pla, ptr->facetinst, pla_FindPort(ptr->facetinst,llXpos+10*pla_lam,
-			llYpos+pla_lam), portname) == NOPORTPROTO)
-				ttyputerr(_("PlaceInputs: cannot export port Input%d"), i);
+			llYpos+pla_lam), portname) == NOPORTPROTO) return(NOFACETIST);
 
 		if (prevptr != NOFACETIST) prevptr->nextfacet = ptr;
 		prevptr = ptr;
@@ -341,7 +333,7 @@ FACETIST *pla_PlaceOutputs(INTBIG orLeft, INTBIG outX, INTBIG outY, NODEPROTO *p
 {
 	FACETIST *ptr, *prevptr, *firstptr;
 	VDDGND *cocv, *pocv, *cocg, *pocg;
-	INTSML o;
+	INTBIG o;
 	INTBIG llXpos, llYpos, VddYpos, GndYpos;
 	char portname[16];
 
@@ -353,23 +345,18 @@ FACETIST *pla_PlaceOutputs(INTBIG orLeft, INTBIG outX, INTBIG outY, NODEPROTO *p
 	prevptr = firstptr = NOFACETIST;
 	cocv = pocv = cocg = pocg = NOVDDGND;
 
-	if (pla_verbose == ON) ttyputmsg(M_("Placing the output facets"));
+	if (pla_verbose) ttyputmsg(M_("Placing the output facets"));
 
 	for(o = 1; o <= (pla_outputs+pla_outputs%2)/2; o++)
 	{
-		if (pla_verbose == ON) ttyputmsg(M_("Placing output facet %d"), o);
+		if (pla_verbose) ttyputmsg(M_("Placing output facet %ld"), o);
 
 		ptr = (FACETIST *)emalloc(sizeof(FACETIST), pla_tool->cluster);
-		if (ptr == NOFACETIST)
-		{
-			ttyputerr(_("PlaceOutputs: ran out of storage space. o=%d"), o);
-			break;
-		} else if (ptr == NOFACETIST) break;
+		if (ptr == NOFACETIST) return(NOFACETIST);
 		ptr->findex = o;
 		ptr->facetinst = newnodeinst(pla_out_proto, llXpos, llXpos+outX,
 			llYpos, llYpos+outY, NOTRANS, NOROT, pla);
-		if (ptr->facetinst == NONODEINST)
-			ttyputerr(_("PlaceOutputs: cannot instance output# %d"), o);
+		if (ptr->facetinst == NONODEINST) return(NOFACETIST);
 
 		/*
 		 * Connect the facets together in metal on the Gnd line if more than
@@ -379,14 +366,12 @@ FACETIST *pla_PlaceOutputs(INTBIG orLeft, INTBIG outX, INTBIG outY, NODEPROTO *p
 		cocg = pla_MkVddGnd(OUTFACETGND, &pocg);
 		cocg->inst = ptr->facetinst;
 		cocg->port = pla_AssignPort(ptr->facetinst, llXpos+outX-5*pla_lam, GndYpos);
-		if (cocg->port->port == NOPORTPROTO)
-			ttyputerr(_("PlaceOutputs: can't access Gnd contact"));
+		if (cocg->port->port == NOPORTPROTO) return(NOFACETIST);
 
 		cocv = pla_MkVddGnd(OUTFACETVDD, &pocv);
 		cocv->inst = ptr->facetinst;
 		cocv->port = pla_AssignPort(ptr->facetinst, llXpos+5*pla_lam, VddYpos);
-		if (cocv->port->port == NOPORTPROTO)
-			ttyputerr(_("PlaceOutputs: can't access Vdd contact"));
+		if (cocv->port->port == NOPORTPROTO) return(NOFACETIST);
 
 		/* Find the ports that connect into the PLA */
 		ptr->lport = pla_AssignPort(ptr->facetinst, llXpos+5*pla_lam, llYpos+outY-2*pla_lam);
@@ -394,20 +379,20 @@ FACETIST *pla_PlaceOutputs(INTBIG orLeft, INTBIG outX, INTBIG outY, NODEPROTO *p
 		ptr->gport = NOPORT;
 
 		if (ptr->lport->port == NOPORTPROTO || ptr->rport->port == NOPORTPROTO)
-			ttyputerr(_("PlaceOutputs: cant access ports to connect into PLA"));
+			return(NOFACETIST);
 
 		/* Initialize the progtrans ends */
 		ptr->rcoltrans = ptr->lcoltrans = NOPROGTRANS;
 
 		/* Export the output ports */
-		(void)sprintf(portname, "Output%d", 2*o-1);
+		(void)sprintf(portname, "Output%ld", 2*o-1);
 		if (newportproto(pla, ptr->facetinst,
 			pla_FindPort(ptr->facetinst,llXpos+pla_lam,llYpos+pla_lam), portname) == NOPORTPROTO)
-				ttyputerr(_("PlaceOutputs: cant export port Output%d"), 2*o-1);
-		(void)sprintf(portname, "Output%d", 2*o);
+				return(NOFACETIST);
+		(void)sprintf(portname, "Output%ld", 2*o);
 		if (newportproto(pla, ptr->facetinst,
 			pla_FindPort(ptr->facetinst,llXpos+11*pla_lam, llYpos+pla_lam), portname) == NOPORTPROTO)
-				ttyputerr(_("PlaceOutputs: cannot export port Output%d"), 2*o);
+				return(NOFACETIST);
 
 		if (prevptr != NOFACETIST) prevptr->nextfacet = ptr;
 		prevptr = ptr;
@@ -426,7 +411,7 @@ FACETIST *pla_PlacePullupsonAND(INTBIG puX, INTBIG puY, INTBIG inY, NODEPROTO *p
 	FACETIST *ptr, *prevptr, *firstptr;
 	VDDGND *calv, *palv;
 	INTBIG llXpos, llYpos;
-	INTSML p;
+	INTBIG p;
 
 	llXpos = 0;
 	llYpos = inY + 2*pla_lam - (pla_VddWidth - 4*pla_lam);
@@ -435,37 +420,30 @@ FACETIST *pla_PlacePullupsonAND(INTBIG puX, INTBIG puY, INTBIG inY, NODEPROTO *p
 	firstptr= NOFACETIST;
 	calv = palv = NOVDDGND;
 
-	if (pla_verbose == ON)
+	if (pla_verbose)
 		ttyputmsg(M_("Placing the pullup facets on the left edge of the AND-plane"));
 
 	for(p = 1; p <= pla_pterms; p++)
 	{
-		if (pla_verbose == ON)
-			ttyputmsg(M_("Placing pullup facet %d in AND-plane"), p);
+		if (pla_verbose)
+			ttyputmsg(M_("Placing pullup facet %ld in AND-plane"), p);
 
 		ptr = (FACETIST *)emalloc(sizeof(FACETIST), pla_tool->cluster);
-		if (ptr == NOFACETIST)
-		{
-			ttyputerr(_("PlacePullupsonAND: ran out of storage space, p=%d"), p);
-			break;
-		} else if (ptr == NOFACETIST) break;
+		if (ptr == NOFACETIST) return(NOFACETIST);
 		ptr->findex = p;
 		ptr->facetinst = newnodeinst(pla_pu_proto, llXpos, llXpos+puX,
 			llYpos, llYpos+puY, NOTRANS, NOROT, pla);
-		if (ptr->facetinst == NONODEINST)
-			ttyputerr(_("PlacePullupsonAND: cannot instance pu# %d"), p);
+		if (ptr->facetinst == NONODEINST) return(NOFACETIST);
 
 		/* Remember the Vdd points for later connection */
 		calv = pla_MkVddGnd(ANDLEFTVDD, &palv);
 		calv->inst = ptr->facetinst;
 		calv->port = pla_AssignPort(ptr->facetinst, pla_halfVdd, llYpos+4*pla_lam);
-		if (calv->port->port == NOPORTPROTO)
-			ttyputerr(_("PlacePullupsonAND: can't access Vdd contact"));
+		if (calv->port->port == NOPORTPROTO) return(NOFACETIST);
 
 		/* Mark the diffusion end of the pu for connections across the plane */
 		ptr->lport = pla_AssignPort(ptr->facetinst, llXpos+puX-2*pla_lam,llYpos+3*pla_lam);
-		if (ptr->lport->port == NOPORTPROTO)
-			ttyputerr(_("PlacePullupsonAND: cannot access bc port of pullup"));
+		if (ptr->lport->port == NOPORTPROTO) return(NOFACETIST);
 
 		ptr->rport = NOPORT;
 		ptr->rcoltrans = ptr->lcoltrans = NOPROGTRANS;
@@ -488,7 +466,7 @@ FACETIST *pla_PlacePullupsonOR(INTBIG andY, INTBIG orLeft, INTBIG inY, INTBIG pu
 	FACETIST *ptr, *prevptr, *firstptr;
 	VDDGND *cotv, *potv;
 	INTBIG llXpos, llYpos, VddYpos, cX, cY, bc_portY;
-	INTSML i;
+	INTBIG i;
 
 	inY = inY - (pla_VddWidth - 4*pla_lam); /* Compensate for Extra Vdd Width */
 	cX = orLeft + 5*pla_lam;	      /* Center coordinates */
@@ -502,38 +480,31 @@ FACETIST *pla_PlacePullupsonOR(INTBIG andY, INTBIG orLeft, INTBIG inY, INTBIG pu
 	prevptr = firstptr = NOFACETIST;
 	cotv = potv = NOVDDGND;
 
-	if (pla_verbose == ON)
+	if (pla_verbose)
 		ttyputmsg(M_("Placing the pullups on the %s edge of the OR-plane"),
-			(pla_samesideoutput == ON) ? M_("top") : M_("bottom"));
+			pla_samesideoutput ? M_("top") : M_("bottom"));
 
 	for(i = 1; i <= pla_outputs; i++)
 	{
-		if (pla_verbose == ON)
-			ttyputmsg(M_("Placing pullup facet %d in OR-plane"), i);
+		if (pla_verbose)
+			ttyputmsg(M_("Placing pullup facet %ld in OR-plane"), i);
 
 		ptr = (FACETIST *)emalloc(sizeof(FACETIST), pla_tool->cluster);
-		if (ptr == NOFACETIST)
-		{
-			ttyputerr(_("PlacePullupsonOR: ran out of storage space, i=%d"), i);
-			break;
-		} else if (ptr == NOFACETIST) break;
+		if (ptr == NOFACETIST) return(NOFACETIST);
 		ptr->findex = i;
 		ptr->facetinst = newnodeinst(pla_pu_proto, llXpos, llXpos+puX,
 			llYpos, llYpos+puY, NOTRANS, 2700, pla);
-		if (ptr->facetinst == NONODEINST)
-			ttyputerr(_("PlacePullupsonOR: cannot instance pu# %d"), i);
+		if (ptr->facetinst == NONODEINST) return(NOFACETIST);
 
 		/* Remember the Vdd points for later connection */
 		cotv = pla_MkVddGnd(ORTOPVDD, &potv);
 		cotv->inst = ptr->facetinst;
 		cotv->port = pla_AssignPort(ptr->facetinst, llXpos+puX/2, VddYpos);
-		if (cotv->port->port == NOPORTPROTO)
-			ttyputerr(_("PlacePullupsonOR: can't access Vdd contact"));
+		if (cotv->port->port == NOPORTPROTO) return(NOFACETIST);
 
 		/* Mark the diffusion end of the pu for connections across the plane */
 		ptr->lport = pla_AssignPort(ptr->facetinst, llXpos+puX/2-pla_lam, bc_portY);
-		if (ptr->lport->port == NOPORTPROTO)
-			ttyputerr(_("PlacePullupsonOR: cannot access bc port of pullup"));
+		if (ptr->lport->port == NOPORTPROTO) return(NOFACETIST);
 
 		ptr->rport = NOPORT;
 		ptr->rcoltrans = ptr->lcoltrans = NOPROGTRANS;
@@ -557,7 +528,7 @@ FACETIST *pla_PlacePullupsonOR(INTBIG andY, INTBIG orLeft, INTBIG inY, INTBIG pu
 PROGTRANS *pla_Program(INTBIG lowx, INTBIG lowy, INTBIG orientation, NODEPROTO *pla)
 {
 	INTBIG highx, highy, Ylen, Xlen, centerx, centery;
-	INTSML rot;
+	INTBIG rot;
 	NODEINST *inst;
 	PROGTRANS *trans;
 
@@ -586,13 +557,13 @@ PROGTRANS *pla_Program(INTBIG lowx, INTBIG lowy, INTBIG orientation, NODEPROTO *
 	trans = (PROGTRANS *)emalloc(sizeof(PROGTRANS), pla_tool->cluster);
 	if (trans == NOPROGTRANS)
 	{
-		ttyputerr(_("Program: ran out of storage for PROGTRANS"));
+		ttyputerr(M_("Program: ran out of storage for PROGTRANS"));
 		return(NOPROGTRANS);
 	} else if (trans == NOPROGTRANS) return(NOPROGTRANS);
 
 	inst = newnodeinst(pla_prog_proto, lowx, highx, lowy, highy, NOTRANS, rot, pla);
 	if (inst == NONODEINST)
-		ttyputerr(_("Program: cannot instance programming trans"));
+		ttyputerr(M_("Program: cannot instance programming trans"));
 
 	trans->trans = inst;
 
@@ -632,7 +603,7 @@ PROGTRANS *pla_Program(INTBIG lowx, INTBIG lowy, INTBIG orientation, NODEPROTO *
 		trans->metalport->port  == NOPORTPROTO ||
 		trans->polyblport->port == NOPORTPROTO ||
 		trans->polytrport->port == NOPORTPROTO))
-			ttyputerr(_("Program: cannot find transistor ports"));
+			ttyputerr(M_("Program: cannot find transistor ports"));
 
 	trans->uprogtrans = trans->rprogtrans = NOPROGTRANS;
 
@@ -701,7 +672,7 @@ PROGTRANS *pla_ProgramOR(INTBIG out, INTBIG row, INTBIG orLeft, INTBIG puY, INTB
  * Pullup facets on the AND plane.  This means that the LL corner of
  * Output facets will be on the negative  side of Y axis.
  */
-INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG outX, INTBIG outY,
+BOOLEAN pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG outX, INTBIG outY,
 	INTBIG connectX, INTBIG connectY, NODEPROTO *pla)
 {
 	INTBIG i, o, p, out,		/* Loop control variables */
@@ -736,7 +707,7 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 	orLeft = puX + andX + connectX;
 	orRight = orLeft + orX + 3*pla_lam;  /* 3 is the metal-metal separation */
 
-	if (pla_verbose == ON)
+	if (pla_verbose)
 	{
 		ttyputmsg(M_("Dimensions of the planes:"));
 		ttyputmsg(M_("  andX = %s,    andY = %s"), latoa(andX), latoa(andY));
@@ -746,9 +717,13 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 
 	/* Place all the input, output and pullup facets */
 	PullupAND = pla_PlacePullupsonAND(puX, puY, inY, pla);
+	if (PullupAND == NOFACETIST) return(TRUE);
 	PullupOR  = pla_PlacePullupsonOR(andY, orLeft, inY, puX, puY, pla);
+	if (PullupOR == NOFACETIST) return(TRUE);
 	Inputs    = pla_PlaceInputs(puX, inX, inY, pla);
+	if (Inputs == NOFACETIST) return(TRUE);
 	Outputs   = pla_PlaceOutputs(orLeft, outX, outY, pla);
+	if (Outputs == NOFACETIST) return(TRUE);
 
 	/* Initialize all the pointers */
 	ptermptr = PullupAND;
@@ -759,30 +734,20 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 	/* Place the programming transistors */
 	for(p = 1; p <= pla_pterms; p++)
 	{
-		if (ptermptr == NOFACETIST)
-		{
-			ttyputerr(_("ProgramPLA: insufficient number of pullups on AND plane"));
-			return(ERRORRET);
-		}
+		if (ptermptr == NOFACETIST) return(TRUE);
 
-		if (pla_verbose == ON) ttyputmsg(M_("Programming row %ld."), p);
+		if (pla_verbose) ttyputmsg(M_("Programming row %ld."), p);
 
 		CurRow   = ptermptr->findex;
-		if (CurRow != p)
-			ttyputerr(_("ProgramPLA: Row Mismatch. CurRow=%ld, p=%ld"), CurRow, p);
+		if (CurRow != p) return(TRUE);
 
 		/* Program the AND plane */
 		for(i = 1; i <= pla_inputs; i++)
 		{
-			if (inptr == NOFACETIST)
-			{
-				ttyputerr(_(" ProgramPLA: insufficient number of input facets"));
-				return(ERRORRET);
-			}
+			if (inptr == NOFACETIST) return(TRUE);
 
 			CurCol = inptr->findex;
-			if (CurCol != i)
-				ttyputerr(_("ProgramPLA: Column Mismatch. CurCol=%ld, input=%ld"), CurCol,i);
+			if (CurCol != i) return(TRUE);
 
 			PColTrans = NOPROGTRANS;
 
@@ -794,7 +759,7 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 			if ((val = pla_GetKeyWord(keyword)) == ERRORRET)
 			{
 				ttyputerr(_("End-of-File while programming AND plane"));
-				return(ERRORRET);
+				return(TRUE);
 			}
 			switch(val)
 			{
@@ -814,21 +779,21 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 
 		   /*
 			* This point is not being programmed.
-			* It could also mean errror. However, that would have been
+			* It could also mean error. However, that would have been
 			* pointed out by pla_ProgramAND.
 			*/
 			if (CurTrans == NOPROGTRANS)
 			{
-				if (pla_verbose == ON)
+				if (pla_verbose)
 					ttyputmsg(M_("row=%ld, ANDcolumn=%ld not programmed."), CurRow, CurCol);
 				inptr = inptr->nextfacet;
 				continue;
 			}
 
-			if (pla_verbose == ON) ttyputmsg(M_("row=%ld, ANDcolumn=%ld programmed."), CurRow, CurCol);
+			if (pla_verbose) ttyputmsg(M_("row=%ld, ANDcolumn=%ld programmed."), CurRow, CurCol);
 
-			CurTrans->row = (INTSML)CurRow;
-			CurTrans->column = (INTSML)CurCol;
+			CurTrans->row = CurRow;
+			CurTrans->column = CurCol;
 
 		   /*
 			* This is the first transistor on this row.
@@ -844,12 +809,12 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 				case ONE:
 					if (inptr->rcoltrans == NOPROGTRANS)
 						inptr->rcoltrans = CurTrans; else
-							PColTrans = pla_FindPColTrans((INTSML)p, inptr->rcoltrans);
+							PColTrans = pla_FindPColTrans(p, inptr->rcoltrans);
 					break;
 				case ZERO:
 					if (inptr->lcoltrans == NOPROGTRANS)
 						inptr->lcoltrans = CurTrans; else
-							PColTrans = pla_FindPColTrans((INTSML)p, inptr->lcoltrans);
+							PColTrans = pla_FindPColTrans(p, inptr->lcoltrans);
 					break;
 			}
 			if (PColTrans != NOPROGTRANS) PColTrans->uprogtrans = CurTrans;
@@ -867,8 +832,7 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 		connect = newnodeinst(pla_connect_proto, orLeft-connectX, orLeft,
 			inY+(p-1)*puY, inY+(p-1)*puY+connectY, NOTRANS, NOROT, pla);
 
-		if (connect == NONODEINST)
-			ttyputerr(_("ProgramPLA: cannot instance connect facet. p=%ld"), p);
+		if (connect == NONODEINST) return(TRUE);
 
 		/*
 		 * Instance a progtrans structure and place the connect facet in it
@@ -878,11 +842,11 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 		if (CurTrans == NOPROGTRANS)
 		{
 			ttyputnomemory();
-			return(ERRORRET);
-		} else if (CurTrans == NOPROGTRANS) return(ERRORRET);
+			return(TRUE);
+		} else if (CurTrans == NOPROGTRANS) return(TRUE);
 
 		/* Fill in the details for this connect facet */
-		CurTrans->row = (INTSML)CurRow;
+		CurTrans->row = CurRow;
 		CurTrans->column = -1;	/* Undefined */
 		CurTrans->trans = connect;
 		CurTrans->diffport = pla_AssignPort(connect, orLeft-pla_lam-pla_halfGnd,
@@ -897,7 +861,7 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 
 		if ((CurTrans->metalport->port == NOPORTPROTO ||
 			CurTrans->diffport->port == NOPORTPROTO || CurTrans->polytrport->port == NOPORTPROTO))
-				ttyputerr(_("ProgramPLA: cannot find connect facet ports. p=%ld"), p);
+				return(TRUE);
 
 		CurTrans->uprogtrans = CurTrans->rprogtrans = NOPROGTRANS;
 
@@ -907,7 +871,7 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 			 * Error.  This means that no programming transistors were
 			 * placed on this row in the AND plane.
 			 */
-			ttyputerr(_(" *** Warning: Nothing on AND plane on row %ld"), p);
+			ttyputerr(_("*** Warning: Nothing on AND plane on row %ld"), p);
 			ptermptr->lcoltrans = CurTrans;
 		} else PRowTrans->rprogtrans = CurTrans;
 
@@ -916,24 +880,19 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 			PRowTrans->metalport->port, PRowTrans->metalport->x, PRowTrans->metalport->y,
 				CurTrans->trans, CurTrans->metalport->port, CurTrans->metalport->x,
 					CurTrans->metalport->y, pla) == NOARCINST)
-						ttyputerr(_("Cannot connect to connect facet. row=%ld"), CurRow);
+						return(TRUE);
 
 		PRowTrans = CurTrans;
 
 		for(o = 1; o <= (pla_outputs+pla_outputs%2)/2; o++)
 		{
-			if (outptr == NOFACETIST)
-			{
-				ttyputerr(_(" ProgramPLA: insufficient number of output facets"));
-				return(ERRORRET);
-			}
+			if (outptr == NOFACETIST) return(TRUE);
 
 			/*
 			 * Each output facet corresponds to two vertical columns of output.
 			 *  So run in a loop twice.
 			 */
-			if (o != outptr->findex)
-				ttyputerr(_("ProgramPLA: Column Mismatch. outfacet#=%d, o=%d"), outptr->findex, o);
+			if (o != outptr->findex) return(TRUE);
 
 			for(out = 1; out >= 0; out--)
 			{
@@ -945,7 +904,7 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 					if ((val = pla_GetKeyWord(keyword)) == ERRORRET)
 					{
 						ttyputerr(_("End-of-File while programming OR plane"));
-						return(ERRORRET);
+						return(TRUE);
 					}
 					switch(val)
 					{
@@ -964,16 +923,16 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 					if (CurTrans == NOPROGTRANS)
 					{
 						/* This point is not being programmed */
-						if (pla_verbose == ON)
+						if (pla_verbose)
 							ttyputmsg(M_("row=%ld, ORcolumn=%ld not programmed."), CurRow, CurCol);
 						continue;
 					}
 
-					if (pla_verbose == ON)
+					if (pla_verbose)
 						ttyputmsg(M_("row=%ld, ORcolumn=%ld programmed."), CurRow, CurCol);
 
-					CurTrans->row = (INTSML)CurRow;
-					CurTrans->column = (INTSML)CurCol;
+					CurTrans->row = CurRow;
+					CurTrans->column = CurCol;
 
 					PRowTrans->rprogtrans = CurTrans;
 					PRowTrans = CurTrans;
@@ -983,12 +942,12 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 						case 1:
 							if (outptr->lcoltrans == NOPROGTRANS)
 								outptr->lcoltrans = CurTrans; else
-									PColTrans = pla_FindPColTrans((INTSML)p, outptr->lcoltrans);
+									PColTrans = pla_FindPColTrans(p, outptr->lcoltrans);
 							break;
 						case 0:
 							if (outptr->rcoltrans == NOPROGTRANS)
 								outptr->rcoltrans = CurTrans; else
-									PColTrans = pla_FindPColTrans((INTSML)p, outptr->rcoltrans);
+									PColTrans = pla_FindPColTrans(p, outptr->rcoltrans);
 							break;
 					}
 					if (PColTrans != NOPROGTRANS)
@@ -1012,7 +971,7 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 	pla_ConnectPlanes(inY, andY, orRight, Inputs, Outputs, PullupAND, PullupOR, pla);
 
 	pla_RunVddGnd(puX, andX, pla);
-	return(OK);
+	return(FALSE);
 }
 
 #endif  /* PLATOOL - at top */
