@@ -142,10 +142,10 @@ COMCOMP ro_routerp = {routeropt, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP,
 static RCHECK *ro_rcheckfree;
 
 static TOOL      *ro_source;			/* source of batch of changes */
-       INTBIG     ro_statekey;			/* cached key for "ROUT_state" */
+       INTBIG     ro_statekey;			/* variable key for "ROUT_state" */
        INTBIG     ro_state;				/* cached value for "ROUT_state" */
-static INTBIG     ro_optionskey;		/* cached key for "ROUT_options" */
-       INTBIG     ro_preferedkey;		/* cached key for "ROUT_prefered_arc" */
+static INTBIG     ro_optionskey;		/* variable key for "ROUT_options" */
+       INTBIG     ro_preferedkey;		/* variable key for "ROUT_prefered_arc" */
        ARCINST   *ro_createdarc;		/* last created arc for mimicing */
        NODEINST  *ro_deletednodes[2];	/* nodes at end of last deleted arc */
        PORTPROTO *ro_deletedports[2];	/* ports on nodes at end of last deleted arc */
@@ -164,11 +164,11 @@ static INTBIG     *ro_findnetlisty;
 static RCHECK *ro_allocrcheck(void);
 static void    ro_queuercheck(NODEINST*);
 static void    ro_unroutecurrent(void);
-static INTSML  ro_unroutenet(NETWORK *net);
+static BOOLEAN ro_unroutenet(NETWORK *net);
 static void    ro_optionsdlog(void);
 static void    ro_pastetopology(NODEPROTO *np);
 static int     ro_sortinstspatially(const void *e1, const void *e2);
-static INTSML  ro_makeunroutedconnection(NODEINST *fni, PORTPROTO *fpp, NODEINST *tni, PORTPROTO *tpp);
+static BOOLEAN ro_makeunroutedconnection(NODEINST *fni, PORTPROTO *fpp, NODEINST *tni, PORTPROTO *tpp);
 
 /*
  * routine to allocate a new check module from the pool (if any) or memory
@@ -289,7 +289,7 @@ void ro_done(void)
 #endif
 }
 
-INTSML ro_set(INTSML count, char *par[])
+void ro_set(INTBIG count, char *par[])
 {
 	REGISTER INTBIG l, savestate;
 	REGISTER NODEPROTO *np;
@@ -314,7 +314,7 @@ INTSML ro_set(INTSML count, char *par[])
 		if (var != NOVARIABLE)
 			ttyputmsg(M_("Default arc for river routing is %s"),
 				describearcproto(((ARCPROTO *)var->addr)));
-		return(0);
+		return;
 	}
 
 	l = strlen(pp = par[0]);
@@ -323,18 +323,18 @@ INTSML ro_set(INTSML count, char *par[])
 	{
 		(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_statekey,
 			(ro_state & ~STITCHMODE) | NOSTITCH, VINTEGER|VDONTSAVE);
-		return(0);
+		return;
 	}
 
 	if (namesamen(pp, "auto-stitch", l) == 0)
 	{
-		if (count <= 1) return(0);
+		if (count <= 1) return;
 		l = strlen(pp = par[1]);
 		if (namesamen(pp, "enable", l) == 0)
 		{
 			(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_statekey,
 				(ro_state & ~STITCHMODE) | AUTOSTITCH, VINTEGER|VDONTSAVE);
-			return(0);
+			return;
 		}
 		if (namesamen(pp, "stitch-now", l) == 0)
 		{
@@ -344,17 +344,17 @@ INTSML ro_set(INTSML count, char *par[])
 				if (np == NONODEPROTO)
 				{
 					ttyputerr(_("No facet named %s"), par[2]);
-					return(1);
+					return;
 				}
 				if (np->primindex != 0)
 				{
 					ttyputerr(M_("Can only stitch facets, not primitives"));
-					return(1);
+					return;
 				}
 				if (np->cell->lib != el_curlib)
 				{
 					ttyputerr(_("Can only stitch facets in the current library"));
-					return(1);
+					return;
 				}
 			} else
 			{
@@ -362,7 +362,7 @@ INTSML ro_set(INTSML count, char *par[])
 				if (np == NONODEPROTO)
 				{
 					ttyputerr(_("No current facet"));
-					return(1);
+					return;
 				}
 			}
 
@@ -383,7 +383,7 @@ INTSML ro_set(INTSML count, char *par[])
 			/* restore routing state */
 			ro_state = savestate;
 			ttyputverbose(M_("Facet %s stitched"), describenodeproto(np));
-			return(0);
+			return;
 		}
 		if (namesamen(pp, "highlighted-stitch-now", l) == 0)
 		{
@@ -391,7 +391,7 @@ INTSML ro_set(INTSML count, char *par[])
 			if (list[0] == NOGEOM)
 			{
 				ttyputerr(_("Select an area to be stitched"));
-				return(1);
+				return;
 			}
 			for(l=0; list[l] != NOGEOM; l++)
 				ro_queuercheck(list[l]->entryaddr.ni);
@@ -406,10 +406,10 @@ INTSML ro_set(INTSML count, char *par[])
 			/* restore routing state */
 			ro_state = savestate;
 			ttyputverbose(M_("Stitching complete"));
-			return(0);
+			return;
 		}
 		ttyputbadusage("telltool routing auto-stitch");
-		return(1);
+		return;
 	}
 
 	if (namesamen(pp, "mimic-stitch", l) == 0 && l > 1)
@@ -417,50 +417,50 @@ INTSML ro_set(INTSML count, char *par[])
 		if (count < 2)
 		{
 			ttyputusage("telltool routing mimic-stitch OPTION");
-			return(1);
+			return;
 		}
 		l = strlen(pp = par[1]);
 		if (namesamen(pp, "do-now", l) == 0)
 		{
-			ro_mimicstitch(1);
-			return(0);
+			ro_mimicstitch(TRUE);
+			return;
 		}
 		if (namesamen(pp, "enable", l) == 0)
 		{
 			(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_statekey,
 				(ro_state & ~STITCHMODE) | MIMICSTITCH, VINTEGER|VDONTSAVE);
-			return(0);
+			return;
 		}
 		if (namesamen(pp, "stitch-and-unstitch", l) == 0 && l >= 8)
 		{
 			(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_optionskey,
 				ro_getoptions() | MIMICUNROUTES, VINTEGER);
 			ttyputverbose(M_("Mimic stitcher will route and unroute"));
-			return(0);
+			return;
 		}
 		if (namesamen(pp, "stitch-only", l) == 0 && l >= 8)
 		{
 			(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_optionskey,
 				ro_getoptions() & ~MIMICUNROUTES, VINTEGER);
 			ttyputverbose(M_("Mimic stitcher will only route, not unroute"));
-			return(0);
+			return;
 		}
 		if (namesamen(pp, "port-general", l) == 0 && l >= 8)
 		{
 			(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_optionskey,
 				ro_getoptions() | MIMICIGNOREPORTS, VINTEGER);
 			ttyputverbose(M_("Mimic stitcher will route to any port"));
-			return(0);
+			return;
 		}
 		if (namesamen(pp, "port-specific", l) == 0 && l >= 8)
 		{
 			(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_optionskey,
 				ro_getoptions() & ~MIMICIGNOREPORTS, VINTEGER);
 			ttyputverbose(M_("Mimic stitcher will rout only to similar ports"));
-			return(0);
+			return;
 		}
 		ttyputbadusage("telltool routing mimic-stitching");
-		return(1);
+		return;
 	}
 
 	if (namesamen(pp, "river-route", l) == 0)
@@ -471,12 +471,12 @@ INTSML ro_set(INTSML count, char *par[])
 			if (np == NONODEPROTO)
 			{
 				ttyputerr(_("No facet named %s"), par[1]);
-				return(1);
+				return;
 			}
 			if (np->primindex != 0)
 			{
 				ttyputerr(M_("Can only route facets, not primitives"));
-				return(1);
+				return;
 			}
 		} else
 		{
@@ -484,13 +484,13 @@ INTSML ro_set(INTSML count, char *par[])
 			if (np == NONODEPROTO)
 			{
 				ttyputerr(_("No current facet"));
-				return(1);
+				return;
 			}
 		}
 
-		if (ro_river(np) == 0) ttyputmsg(_("Routing not successful")); else
-			ttyputverbose(M_("Facet %s river-routed"), describenodeproto(np));
-		return(0);
+		if (ro_river(np)) ttyputverbose(M_("Facet %s river-routed"), describenodeproto(np)); else
+			ttyputmsg(_("Routing not successful"));			
+		return;
 	}
 
 	if (namesamen(pp, "maze-route", l) == 0 && l > 1)
@@ -498,20 +498,20 @@ INTSML ro_set(INTSML count, char *par[])
 		l = strlen(pp = par[1]);
 		if (namesamen(pp, "route", l) == 0)
 		{
-			if (count <= 2) return(0);
+			if (count <= 2) return;
 			l = strlen(pp = par[2]);
 			if (namesamen(pp, "cell", l) == 0)
 			{
 				ro_mazeroutecell();
-				return(0);
+				return;
 			}
 			if (namesamen(pp, "selected", l) == 0)
 			{
 				ro_mazerouteselected();
-				return(0);
+				return;
 			}
 			ttyputbadusage("telltool routing maze-route");
-			return(1);
+			return;
 		}
 		if (namesamen(pp, "set", l) == 0)
 		{
@@ -520,7 +520,7 @@ INTSML ro_set(INTSML count, char *par[])
 				ttyputmsg(M_("Routing grid: %sx%s"), latoa(ro_mazegridx), latoa(ro_mazegridy));
 				ttyputmsg(M_("Routing offset: (%s,%s)"), latoa(ro_mazeoffsetx), latoa(ro_mazeoffsety));
 				ttyputmsg(M_("Routing boundary: %s"), latoa(ro_mazeboundary));
-				return(0);
+				return;
 			}
 
 			l = strlen(pp = par[2]);
@@ -529,24 +529,24 @@ INTSML ro_set(INTSML count, char *par[])
 				ro_mazegridx = atola(par[3]);
 				ro_mazegridy = atola(par[4]);
 				ttyputmsg(M_("Routing grid: %sx%s"), latoa(ro_mazegridx), latoa(ro_mazegridy));
-				return 0;
+				return;
 			}
 			if (namesamen(pp, "offset", l) == 0)
 			{
 				ro_mazeoffsetx = atola(par[3]);
 				ro_mazeoffsety = atola(par[4]);
 				ttyputmsg(M_("Routing offset: (%s,%s)"), latoa(ro_mazeoffsetx), latoa(ro_mazeoffsety));
-				return 0;
+				return;
 			}
 			if (namesamen(pp, "boundary", l) == 0)
 			{
 				ro_mazeboundary = atola(par[3]);
 				ttyputmsg(M_("Routing boundary: %s"), latoa(ro_mazeboundary));
-				return 0;
+				return;
 			}
 
 			ttyputbadusage("telltool routing maze-route set");
-			return(1);
+			return;
 		}
 	}
 
@@ -554,7 +554,7 @@ INTSML ro_set(INTSML count, char *par[])
 	if (namesamen(pp, "par-route", l) == 0 && l >= 3)
 	{
 		ro_par();
-		return(0);
+		return;
 	}
 #endif
 
@@ -564,10 +564,10 @@ INTSML ro_set(INTSML count, char *par[])
 		if (np == NONODEPROTO)
 		{
 			ttyputerr(_("No current facet"));
-			return(1);
+			return;
 		}
 		ro_copiedtopofacet = np;
-		return(0);
+		return;
 	}
 	if (namesamen(pp, "paste-topology", l) == 0 && l >= 3)
 	{
@@ -575,10 +575,10 @@ INTSML ro_set(INTSML count, char *par[])
 		if (np == NONODEPROTO)
 		{
 			ttyputerr(_("No current facet"));
-			return(1);
+			return;
 		}
 		ro_pastetopology(np);
-		return(0);
+		return;
 	}
 
 	if (namesamen(pp, "use-arc", l) == 0)
@@ -586,30 +586,30 @@ INTSML ro_set(INTSML count, char *par[])
 		if (count < 2)
 		{
 			ttyputusage("telltool routing use-arc ARCPROTO");
-			return(1);
+			return;
 		}
 		if (strcmp(par[1], "*") == 0)
 		{
 			if (getvalkey((INTBIG)ro_tool, VTOOL, VARCPROTO, ro_preferedkey) != NOVARIABLE)
 				(void)delvalkey((INTBIG)ro_tool, VTOOL, ro_preferedkey);
 			ttyputverbose(M_("No arc will be presumed for stitching"));
-			return(0);
+			return;
 		}
 		ap = getarcproto(par[1]);
 		if (ap == NOARCPROTO)
 		{
 			ttyputerr(M_("No arc prototype called %s"), par[1]);
-			return(1);
+			return;
 		}
 		ttyputverbose(M_("Default stitching arc will be %s"), describearcproto(ap));
 		(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_preferedkey, (INTBIG)ap, VARCPROTO);
-		return(0);
+		return;
 	}
 
 	if (namesamen(pp, "unroute", l) == 0)
 	{
 		ro_unroutecurrent();
-		return(0);
+		return;
 	}
 
 	if (namesamen(pp, "not", l) == 0)
@@ -617,7 +617,7 @@ INTSML ro_set(INTSML count, char *par[])
 		if (count <= 1)
 		{
 			ttyputusage("telltool routing not OPTION");
-			return(1);
+			return;
 		}
 		l = strlen(pp = par[1]);
 		if (namesamen(pp, "select", l) == 0)
@@ -625,10 +625,10 @@ INTSML ro_set(INTSML count, char *par[])
 			(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_statekey,
 				ro_state & ~SELECT, VINTEGER|VDONTSAVE);
 			ttyputverbose(M_("Wire placement not subject to approval"));
-			return(0);
+			return;
 		}
 		ttyputbadusage("telltool routing not");
-		return(1);
+		return;
 	}
 
 	if (namesamen(pp, "select", l) == 0)
@@ -636,11 +636,10 @@ INTSML ro_set(INTSML count, char *par[])
 		(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_statekey,
 			ro_state | SELECT, VINTEGER|VDONTSAVE);
 		ttyputverbose(M_("Wire placement subject to approval"));
-		return(0);
+		return;
 	}
 
 	ttyputbadusage("telltool routing");
-	return(1);
 }
 
 void ro_slice(void)
@@ -658,7 +657,7 @@ void ro_slice(void)
 			setactivity(_("Facets stitched"));
 			break;
 		case MIMICSTITCH:
-			ro_mimicstitch(0);
+			ro_mimicstitch(FALSE);
 			setactivity(_("Facets stitched"));
 			break;
 	}
@@ -666,33 +665,27 @@ void ro_slice(void)
 
 /******************** DATABASE CHANGES ********************/
 
-void ro_startbatch(TOOL *source, INTSML undoredo)
+void ro_startbatch(TOOL *source, BOOLEAN undoredo)
 {
 	ro_source = source;
 }
 
 void ro_modifynodeinst(NODEINST *ni, INTBIG oldlx, INTBIG oldly, INTBIG oldhx,
-	INTBIG oldhy, INTSML oldrot, INTSML oldtran)
+	INTBIG oldhy, INTBIG oldrot, INTBIG oldtran)
 {
 	if ((ro_state&STITCHMODE) == AUTOSTITCH)
 	{
 		if (ro_source != ro_tool) ro_queuercheck(ni);
 	}
-	ro_createdarc = NOARCINST;
-	ro_deletedarc = NOARCPROTO;
 }
 
 void ro_modifyarcinst(ARCINST *ai, INTBIG oldxA, INTBIG oldyA, INTBIG oldxB,
 	INTBIG oldyB, INTBIG oldwid, INTBIG oldlen)
 {
-	ro_createdarc = NOARCINST;
-	ro_deletedarc = NOARCPROTO;
 }
 
 void ro_modifyportproto(PORTPROTO *pp, NODEINST *oldsubni, PORTPROTO *oldsubpp)
 {
-	ro_createdarc = NOARCINST;
-	ro_deletedarc = NOARCPROTO;
 }
 
 void ro_newobject(INTBIG addr, INTBIG type)
@@ -708,17 +701,11 @@ void ro_newobject(INTBIG addr, INTBIG type)
 			ni = (NODEINST *)addr;
 			ro_queuercheck(ni);
 		}
-		ro_createdarc = NOARCINST;
-		ro_deletedarc = NOARCPROTO;
 	} else if ((type&VTYPE) == VARCINST)
 	{
 		ai = (ARCINST *)addr;
 		ro_createdarc = ai;
 		ro_deletedarc = NOARCPROTO;
-	} else if ((type&VTYPE) == VPORTPROTO || (type&VTYPE) == VNODEPROTO)
-	{
-		ro_createdarc = NOARCINST;
-		ro_deletedarc = NOARCPROTO;
 	}
 }
 
@@ -737,9 +724,6 @@ void ro_killobject(INTBIG addr, INTBIG type)
 		ro_deletedports[0] = ai->end[0].portarcinst->proto;
 		ro_deletedports[1] = ai->end[1].portarcinst->proto;
 	}
-	if ((type&VTYPE) == VNODEINST || (type&VTYPE) == VPORTPROTO ||
-		(type&VTYPE) == VNODEPROTO)
-			ro_createdarc = NOARCINST;
 }
 
 void ro_newvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG newtype)
@@ -765,10 +749,10 @@ void ro_unroutecurrent(void)
 	REGISTER NODEPROTO *np;
 	REGISTER ARCINST *ai;
 	REGISTER INTBIG i, selectcount;
-	REGISTER INTSML found;
+	REGISTER BOOLEAN found;
 
 	/* see what is highlighted */
-	list = us_gethighlighted(OBJARCINST, 0, 0);
+	list = us_gethighlighted(WANTARCINST, 0, 0);
 	for(selectcount=0; list[selectcount] != NOGEOM; selectcount++) ;
 	if (selectcount == 0)
 	{
@@ -779,11 +763,11 @@ void ro_unroutecurrent(void)
 
 	/* convert requested nets */
 	us_clearhighlightcount();
-	found = 1;
-	while(found != 0)
+	found = TRUE;
+	while (found)
 	{
 		/* no net found yet */
-		found = 0;
+		found = FALSE;
 
 		/* find a net to be routed */
 		for(net = np->firstnetwork; net != NONETWORK;
@@ -793,7 +777,7 @@ void ro_unroutecurrent(void)
 			for(i=0; i<selectcount; i++)
 			{
 				if (list[i] == NOGEOM) continue;
-				if (list[i]->entrytype != OBJARCINST) continue;
+				if (list[i]->entryisnode) continue;
 				ai = list[i]->entryaddr.ai;
 				if (ai->network == net) break;
 			}
@@ -803,20 +787,20 @@ void ro_unroutecurrent(void)
 			for(i=0; i<selectcount; i++)
 			{
 				if (list[i] == NOGEOM) continue;
-				if (list[i]->entrytype != OBJARCINST) continue;
+				if (list[i]->entryisnode) continue;
 				ai = list[i]->entryaddr.ai;
 				if (ai->network == net) list[i] = NOGEOM;
 			}
 
 			/* now unroute the net */
-			if (ro_unroutenet(net) != 0) return;
-			found = 1;
+			if (ro_unroutenet(net)) return;
+			found = TRUE;
 			break;
 		}
 	}
 }
 
-INTSML ro_unroutenet(NETWORK *net)
+BOOLEAN ro_unroutenet(NETWORK *net)
 {
 	INTBIG *xlist, *ylist, count;
 	NODEINST **nilist;
@@ -825,7 +809,7 @@ INTSML ro_unroutenet(NETWORK *net)
 	REGISTER NODEINST *ni, *nextni;
 	REGISTER NODEPROTO *np;
 	REGISTER INTBIG bits, wid, i, j, dist, bestdist, first, found, besti, bestj;
-	REGISTER INTSML *covered;
+	REGISTER INTBIG *covered;
 
 	/* convert this net and mark arcs and nodes on it */
 	count = ro_findnetends(net, &nilist, &pplist, &xlist, &ylist);
@@ -840,7 +824,7 @@ INTSML ro_unroutenet(NETWORK *net)
 		if (killarcinst(ai))
 		{
 			ttyputerr(_("Error deleting arc"));
-			return(1);
+			return(TRUE);
 		}
 	}
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = nextni)
@@ -851,15 +835,15 @@ INTSML ro_unroutenet(NETWORK *net)
 		if (killnodeinst(ni))
 		{
 			ttyputerr(_("Error deleting intermediate node"));
-			return(1);
+			return(TRUE);
 		}
 	}
 
 	/* now create the new unrouted wires */
 	bits = us_makearcuserbits(gen_unroutedarc);
 	wid = defaultarcwidth(gen_unroutedarc);
-	covered = (INTSML *)emalloc(count * SIZEOFINTSML, el_tempcluster);
-	if (covered == 0) return(0);
+	covered = (INTBIG *)emalloc(count * SIZEOFINTBIG, el_tempcluster);
+	if (covered == 0) return(FALSE);
 	for(i=0; i<count; i++) covered[i] = 0;
 	for(first=0; ; first++)
 	{
@@ -891,12 +875,12 @@ INTSML ro_unroutenet(NETWORK *net)
 		if (ai == NOARCINST)
 		{
 			ttyputerr(_("Could not create unrouted arc"));
-			return(1);
+			return(TRUE);
 		}
 		endobjectchange((INTBIG)ai, VARCINST);
 		(void)asktool(us_tool, "show-object", (INTBIG)ai->geom);
 	}
-	return(0);
+	return(FALSE);
 }
 
 /*
@@ -912,7 +896,7 @@ INTBIG ro_findnetends(NETWORK *net, NODEINST ***nilist, PORTPROTO ***pplist,
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
 	REGISTER PORTARCINST *pi, *thispi;
-	REGISTER INTSML term;
+	REGISTER BOOLEAN term;
 	INTBIG listcount, newtotal, i, j;
 	NODEINST **newlistni;
 	PORTPROTO **newlistpp;
@@ -936,13 +920,13 @@ INTBIG ro_findnetends(NETWORK *net, NODEINST ***nilist, PORTPROTO ***pplist,
 		{
 			ni = ai->end[i].nodeinst;
 			thispi = ai->end[i].portarcinst;
-			term = 0;
+			term = FALSE;
 			for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 				if (pi != thispi && pi->conarcinst->network == net) break;
-			if (pi == NOPORTARCINST) term = 1;
-			if (ni->firstportexpinst != NOPORTEXPINST) term = 1;
-			if (ni->proto->primindex == 0) term = 1;
-			if (term != 0)
+			if (pi == NOPORTARCINST) term = TRUE;
+			if (ni->firstportexpinst != NOPORTEXPINST) term = TRUE;
+			if (ni->proto->primindex == 0) term = TRUE;
+			if (term)
 			{
 				/* valid network end: see if it is in the list */
 				for(j=0; j<listcount; j++)
@@ -1102,7 +1086,7 @@ void ro_pastetopology(NODEPROTO *tonp)
 		if (tocount != fromcount)
 		{
 			if (fromcount == 0) continue;
-			ttyputerr(_("Warning: %s has %ld of %s but facet %s has %d"),
+			ttyputerr(_("Warning: %s has %ld of %s but facet %s has %ld"),
 				describenodeproto(ro_copiedtopofacet), fromcount, describenodeproto(ni->proto),
 				describenodeproto(tonp), tocount);
 			return;
@@ -1141,12 +1125,12 @@ void ro_pastetopology(NODEPROTO *tonp)
 		/* look for name matches */
 		for(i=0; i<fromcount; i++)
 		{
-			var = getvalkey((INTBIG)fromlist[i], VNODEINST, VSTRING, el_node_name);
+			var = getvalkey((INTBIG)fromlist[i], VNODEINST, VSTRING, el_node_name_key);
 			if (var == NOVARIABLE) continue;
 			for(j=0; j<tocount; j++)
 			{
 				if (tolist[j] == NONODEINST) continue;
-				ovar = getvalkey((INTBIG)tolist[j], VNODEINST, VSTRING, el_node_name);
+				ovar = getvalkey((INTBIG)tolist[j], VNODEINST, VSTRING, el_node_name_key);
 				if (ovar == NOVARIABLE) continue;
 				if (namesame((char *)var->addr, (char *)ovar->addr) == 0) break;
 			}
@@ -1221,7 +1205,7 @@ void ro_pastetopology(NODEPROTO *tonp)
 			if (otpp == NOPORTPROTO) continue;
 
 			/* make the connection from "tni", port "tpp" to "otni" port "otpp" */
-			if (ro_makeunroutedconnection(tni, tpp, otni, otpp) != 0) return;
+			if (ro_makeunroutedconnection(tni, tpp, otni, otpp)) return;
 		}
 	}
 
@@ -1278,7 +1262,7 @@ void ro_pastetopology(NODEPROTO *tonp)
 			if (otpp == NOPORTPROTO) continue;
 
 			/* make the connection from "tni", port "tpp" to "otni" port "otpp" */
-			if (ro_makeunroutedconnection(tni, tpp, otni, otpp) != 0) return;
+			if (ro_makeunroutedconnection(tni, tpp, otni, otpp)) return;
 		}
 	}
 }
@@ -1286,9 +1270,9 @@ void ro_pastetopology(NODEPROTO *tonp)
 /*
  * Helper routine to run an unrouted wire between node "fni", port "fpp" and node "tni", port
  * "tpp".  If the connection is already there, the routine doesn't make another.
- * Returns nonzero on error.
+ * Returns true on error.
  */
-INTSML ro_makeunroutedconnection(NODEINST *fni, PORTPROTO *fpp, NODEINST *tni, PORTPROTO *tpp)
+BOOLEAN ro_makeunroutedconnection(NODEINST *fni, PORTPROTO *fpp, NODEINST *tni, PORTPROTO *tpp)
 {
 	REGISTER PORTARCINST *fpi, *tpi;
 	REGISTER ARCINST *fai, *tai, *ai;
@@ -1305,7 +1289,7 @@ INTSML ro_makeunroutedconnection(NODEINST *fni, PORTPROTO *fpp, NODEINST *tni, P
 	{
 		fai = fpi->conarcinst;
 		tai = tpi->conarcinst;
-		if (fai->network == tai->network) return(0);
+		if (fai->network == tai->network) return(FALSE);
 	}
 
 	/* make the connection from "tni", port "tpp" to "otni" port "otpp" */
@@ -1315,9 +1299,9 @@ INTSML ro_makeunroutedconnection(NODEINST *fni, PORTPROTO *fpp, NODEINST *tni, P
 	wid = defaultarcwidth(gen_unroutedarc);
 	np = fni->parent;
 	ai = newarcinst(gen_unroutedarc, wid, bits, fni, fpp, fx, fy, tni, tpp, tx, ty, np);
-	if (ai == NOARCINST) return(1);
+	if (ai == NOARCINST) return(TRUE);
 	endobjectchange((INTBIG)ai, VARCINST);
-	return(0);
+	return(FALSE);
 }
 
 /*
@@ -1395,7 +1379,7 @@ void ro_optionsdlog(void)
 	}
 
 	/* display the router arc dialog box */
-	if (DiaInitDialog(&ro_optionsdialog) != 0) return;
+	if (DiaInitDialog(&ro_optionsdialog)) return;
 	DiaSetPopup(DROO_ARCLIST, numarcnames, arcnames);
 	DiaSetPopupEntry(DROO_ARCLIST, initialindex);
 	efree((char *)arcnames);
@@ -1446,7 +1430,7 @@ void ro_optionsdlog(void)
 		{
 			if (ap == NOARCPROTO) paramstart[1] = "*"; else
 				paramstart[1] = ap->protoname;
-			(void)telltool(ro_tool, 2, paramstart);
+			telltool(ro_tool, 2, paramstart);
 		}
 	}
 	DiaDoneDialog();
