@@ -37,21 +37,23 @@
 #include "usr.h"
 #include <math.h>
 
+#define MENUDISPX 150			/* x displacement of confirm menu */
+#define MENUDISPY   0			/* y displacement of confirm menu */
+
 static ARCPROTO *ro_preferedarc;	/* the prefered arc */
 
 /* prototypes for local routines */
-static INTBIG ro_checkstitching(NODEINST*);
-static INTBIG ro_testpoly(NODEINST*, PORTPROTO*, ARCPROTO*, POLYGON*, NODEINST*);
-static INTBIG ro_comparepoly(NODEINST*, PORTPROTO*, POLYGON*, NODEINST*, PORTPROTO*, POLYGON*, ARCPROTO*);
-static INTSML ro_canconnect(ARCPROTO*, PORTPROTO*);
-static void ro_findsmallestlayer(ARCPROTO*);
-static void ro_substituteforpseudo(NODEINST *ni, POLYGON *poly);
-static INTBIG ro_didaccept(ARCINST*, ARCINST*, ARCINST*);
+static INTBIG  ro_checkstitching(NODEINST*);
+static INTBIG  ro_testpoly(NODEINST*, PORTPROTO*, ARCPROTO*, POLYGON*, NODEINST*);
+static INTBIG  ro_comparepoly(NODEINST*, PORTPROTO*, POLYGON*, NODEINST*, PORTPROTO*, POLYGON*, ARCPROTO*);
+static BOOLEAN ro_canconnect(ARCPROTO*, PORTPROTO*);
+static void    ro_findsmallestlayer(ARCPROTO*);
+static INTBIG  ro_didaccept(ARCINST*, ARCINST*, ARCINST*, NODEINST*, NODEINST*);
 
 void ro_autostitch(void)
 {
 	REGISTER RCHECK *r, *nextr;
-	REGISTER INTSML i, order, total;
+	REGISTER INTBIG i, order, total;
 	REGISTER INTBIG *bbarray, count;
 	INTBIG x1, x2, y1, y2;
 	XARRAY trans, localtran, temp;
@@ -67,7 +69,7 @@ void ro_autostitch(void)
 	if ((net_tool->toolstate&TOOLON) == 0)
 	{
 		ttyputerr(_("Network tool must be running...turning it on"));
-		toolturnon(net_tool, 0);
+		toolturnon(net_tool, FALSE);
 		return;
 	}
 
@@ -148,7 +150,7 @@ void ro_autostitch(void)
 	for(r = ro_firstrcheck; r != NORCHECK; r = nextr)
 	{
 		nextr = r->nextcheck;
-		if (stopping(STOPREASONROUTING) == 0)
+		if (!stopping(STOPREASONROUTING))
 		{
 			ni = r->entity;
 			if ((ni->parent->userbits&NLOCKED) != 0) continue;
@@ -183,8 +185,8 @@ void ro_autostitch(void)
  */
 INTBIG ro_checkstitching(NODEINST *ni)
 {
-	REGISTER INTBIG search, lx, hx, ly, hy, bestdist, dist, ox, oy, stitched, count;
-	REGISTER INTBIG tot, i, j, bbp;
+	REGISTER INTBIG search, lx, hx, ly, hy, bestdist, dist, ox, oy, stitched, count,
+		tot, i, j, bbp, useportpoly;
 	INTBIG x, y;
 	XARRAY trans, localtran, temp;
 	REGISTER GEOM *geom;
@@ -208,7 +210,7 @@ INTBIG ro_checkstitching(NODEINST *ni)
 
 		/* find another node in this area */
 		if ((geom = nextobject(search)) == NOGEOM) break;
-		if (geom->entrytype != OBJNODEINST) continue;
+		if (!geom->entryisnode) continue;
 		oni = geom->entryaddr.ni;
 
 		/* don't check newly created nodes */
@@ -263,22 +265,34 @@ INTBIG ro_checkstitching(NODEINST *ni)
 				}
 
 				/* look at all polygons on this nodeinst */
+				useportpoly = 0;
 				tot = nodeEpolys(rni, 0, NOWINDOWPART);
+				if (tot == 0)
+				{
+					useportpoly = 1;
+					tot = 1;
+				}
 				for(j=0; j<tot; j++)
 				{
-					shapeEnodepoly(rni, j, poly);
+					if (useportpoly != 0)
+					{
+						shapeportpoly(ni, pp, poly, FALSE);
+					} else
+					{
+						shapeEnodepoly(rni, j, poly);
 
-					/* only want electrically connected polygons */
-					if (poly->portproto == NOPORTPROTO) continue;
+						/* only want electrically connected polygons */
+						if (poly->portproto == NOPORTPROTO) continue;
 
-					/* only want polygons on correct part of this nodeinst */
-					if (poly->portproto->network != rpp->network) continue;
+						/* only want polygons on correct part of this nodeinst */
+						if (poly->portproto->network != rpp->network) continue;
 
-					/* transformed polygon */
-					xformpoly(poly, trans);
+						/* transformed polygon */
+						xformpoly(poly, trans);
 
-					/* if the polygon layer is pseudo, substitute real layer */
-					ro_substituteforpseudo(rni, poly);
+						/* if the polygon layer is pseudo, substitute real layer */
+						poly->layer = nonpseudolayer(poly->layer, poly->tech);
+					}
 
 					/* first see if the prefered arc is possible */
 					ap = ro_preferedarc;
@@ -291,7 +305,10 @@ INTBIG ro_checkstitching(NODEINST *ni)
 						if (ap->tech != rni->proto->tech) break;
 
 						/* this polygon must be the smallest arc layer */
-						if (ap->temp1 != poly->layer) break;
+						if (useportpoly == 0)
+						{
+							if (!samelayer(ap->tech, ap->temp1, poly->layer)) break;
+						}
 
 						/* pass it on to the next test */
 						stitched = ro_testpoly(ni, pp, ap, poly, oni);
@@ -311,7 +328,10 @@ INTBIG ro_checkstitching(NODEINST *ni)
 							if (ap->tech != rni->proto->tech) continue;
 
 							/* this polygon must be the smallest arc layer */
-							if (ap->temp1 != poly->layer) continue;
+							if (useportpoly == 0)
+							{
+								if (!samelayer(ap->tech, ap->temp1, poly->layer)) break;
+							}
 
 							/* pass it on to the next test */
 							stitched = ro_testpoly(ni, pp, ap, poly, oni);
@@ -332,34 +352,62 @@ INTBIG ro_checkstitching(NODEINST *ni)
 			oy = (oni->lowy + oni->highy) / 2;
 
 			/* look at all polygons on this nodeinst */
+			useportpoly = 0;
 			tot = nodeEpolys(ni, 0, NOWINDOWPART);
+			if (tot == 0)
+			{
+				useportpoly = 1;
+				tot = 1;
+			}
 			for(j=0; j<tot; j++)
 			{
-				shapeEnodepoly(ni, j, poly);
-
-				/* only want electrically connected polygons */
-				if (poly->portproto == NOPORTPROTO) continue;
-
-				/* if the polygon layer is pseudo, substitute real layer */
-				ro_substituteforpseudo(ni, poly);
-
-				/* get the correct port connected to this polygon */
-				rpp = NOPORTPROTO;
-
-				/* search all ports for the closest connected to this layer */
-				bestpp = NOPORTPROTO;
-				for(rpp = ni->proto->firstportproto; rpp != NOPORTPROTO; rpp = rpp->nextportproto)
-					if (rpp->network == poly->portproto->network)
+				if (useportpoly != 0)
 				{
-					/* compute best distance to the other node */
-					portposition(ni, rpp, &x, &y);
-					dist = abs(x-ox) + abs(y-oy);
-					if (bestpp == NOPORTPROTO) bestdist = dist;
-					if (dist > bestdist) continue;
-					bestpp = rpp;   bestdist = dist;
+					/* search all ports for the closest */
+					bestpp = NOPORTPROTO;
+					for(rpp = ni->proto->firstportproto; rpp != NOPORTPROTO; rpp = rpp->nextportproto)
+					{
+						/* compute best distance to the other node */
+						portposition(ni, rpp, &x, &y);
+						dist = abs(x-ox) + abs(y-oy);
+						if (bestpp == NOPORTPROTO) bestdist = dist;
+						if (dist > bestdist) continue;
+						bestpp = rpp;   bestdist = dist;
+					}
+					if (bestpp == NOPORTPROTO) continue;
+					rpp = bestpp;
+					shapeportpoly(ni, rpp, poly, FALSE);
+				} else
+				{
+					shapeEnodepoly(ni, j, poly);
+
+					/* only want electrically connected polygons */
+					if (poly->portproto == NOPORTPROTO) continue;
+
+					/* if the polygon layer is pseudo, substitute real layer */
+					poly->layer = nonpseudolayer(poly->layer, poly->tech);
+
+					/* get the correct port connected to this polygon */
+					rpp = NOPORTPROTO;
+
+					/* search all ports for the closest connected to this layer */
+					bestpp = NOPORTPROTO;
+					for(rpp = ni->proto->firstportproto; rpp != NOPORTPROTO; rpp = rpp->nextportproto)
+						if (rpp->network == poly->portproto->network)
+					{
+						/* compute best distance to the other node */
+						portposition(ni, rpp, &x, &y);
+						dist = abs(x-ox) + abs(y-oy);
+						if (bestpp == NOPORTPROTO) bestdist = dist;
+						if (dist > bestdist) continue;
+						bestpp = rpp;   bestdist = dist;
+					}
+					if (bestpp == NOPORTPROTO) continue;
+					rpp = bestpp;
+
+					/* transformed the polygon */
+					xformpoly(poly, trans);
 				}
-				if (bestpp == NOPORTPROTO) continue;
-				rpp = bestpp;
 
 				/* stop now if already an arc on this port to other node */
 				for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
@@ -368,9 +416,6 @@ INTBIG ro_checkstitching(NODEINST *ni)
 								pi->conarcinst->end[1].nodeinst == oni)) break;
 				if (pi != NOPORTARCINST) continue;
 
-				/* transformed the polygon */
-				xformpoly(poly, trans);
-
 				/* first see if the prefered arc is possible */
 				ap = ro_preferedarc;
 				stitched = 0;
@@ -383,7 +428,10 @@ INTBIG ro_checkstitching(NODEINST *ni)
 
 					/* this polygon must be the smallest arc layer */
 					ro_findsmallestlayer(ap);
-					if (ap->temp1 != poly->layer) break;
+					if (useportpoly == 0)
+					{
+						if (!samelayer(ap->tech, ap->temp1, poly->layer)) break;
+					}
 
 					/* pass it on to the next test */
 					stitched = ro_testpoly(ni, rpp, ap, poly, oni);
@@ -404,7 +452,10 @@ INTBIG ro_checkstitching(NODEINST *ni)
 
 						/* this polygon must be the smallest arc layer */
 						ro_findsmallestlayer(ap);
-						if (ap->temp1 != poly->layer) continue;
+						if (useportpoly == 0)
+						{
+							if (!samelayer(ap->tech, ap->temp1, poly->layer)) break;
+						}
 
 						/* pass it on to the next test */
 						stitched = ro_testpoly(ni, rpp, ap, poly, oni);
@@ -430,11 +481,10 @@ INTBIG ro_testpoly(NODEINST *ni, PORTPROTO *pp, ARCPROTO *ap, POLYGON *poly, NOD
 	REGISTER NODEINST *rni;
 	REGISTER PORTPROTO *rpp, *mpp, *bestpp;
 	XARRAY localtran, temp, trans;
-	INTBIG x, y, plx, phx, ply, phy;
+	INTBIG x, y, plx, phx, ply, phy, ox, oy;
 	static POLYGON *opoly = NOPOLYGON;
-	REGISTER INTBIG tot, j, stitched, bbp;
+	REGISTER INTBIG tot, j, bbp, dist, bestdist, lx, hx, ly, hy;
 	REGISTER NETWORK *net, *onet;
-	REGISTER INTBIG dist, ox, oy, bestdist, lx, hx, ly, hy;
 
 	/* get polygon */
 	if (opoly == NOPOLYGON) opoly = allocstaticpolygon(4, ro_tool->cluster);
@@ -443,10 +493,9 @@ INTBIG ro_testpoly(NODEINST *ni, PORTPROTO *pp, ARCPROTO *ap, POLYGON *poly, NOD
 	net = getnetonport(ni, pp);
 
 	/* now look at every layer in this node */
-	stitched = 0;
 	if (oni->proto->primindex == 0)
 	{
-		/* complex facet: look at all exportes */
+		/* complex facet: look at all exports */
 		if (oni->temp2 == 0 || oni->temp2 == -1) bbp = -1; else
 		{
 			getbbox(poly, &plx, &phx, &ply, &phy);
@@ -465,7 +514,7 @@ INTBIG ro_testpoly(NODEINST *ni, PORTPROTO *pp, ARCPROTO *ap, POLYGON *poly, NOD
 			}
 
 			/* port must be able to connect to the arc */
-			if (ro_canconnect(ap, mpp) == 0) continue;
+			if (!ro_canconnect(ap, mpp)) continue;
 
 			/* do not stitch where there is already an electrical connection */
 			onet = getnetonport(oni, mpp);
@@ -484,29 +533,35 @@ INTBIG ro_testpoly(NODEINST *ni, PORTPROTO *pp, ARCPROTO *ap, POLYGON *poly, NOD
 				transmult(localtran, temp, trans);
 			}
 
-			/* look at all polygons on this nodeinst */
+			/* see how much geometry is on this node */
 			tot = nodeEpolys(rni, 0, NOWINDOWPART);
-			for(j=0; j<tot; j++)
+			if (tot == 0)
 			{
-				shapeEnodepoly(rni, j, opoly);
-
-				/* only want electrically connected polygons */
-				if (opoly->portproto == NOPORTPROTO) continue;
-
-				/* only want polygons connected to correct part of nodeinst */
-				if (opoly->portproto->network != rpp->network) continue;
-
-				/* if the polygon layer is pseudo, substitute real layer */
-				ro_substituteforpseudo(rni, opoly);
-
-				if (ap->temp1 != opoly->layer) continue;
-
-				/* transformed the polygon and pass it on to the next test */
-				xformpoly(opoly, trans);
+				/* not a geometric primitive: look for ports that touch */
+				shapeportpoly(oni, mpp, opoly, FALSE);
 				if (ro_comparepoly(oni, mpp, opoly, ni, pp, poly, ap) != 0)
+					return(1);
+			} else
+			{
+				/* a geometric primitive: look for ports on layers that touch */
+				for(j=0; j<tot; j++)
 				{
-					stitched++;
-					break;
+					shapeEnodepoly(rni, j, opoly);
+
+					/* only want electrically connected polygons */
+					if (opoly->portproto == NOPORTPROTO) continue;
+
+					/* only want polygons connected to correct part of nodeinst */
+					if (opoly->portproto->network != rpp->network) continue;
+
+					/* if the polygon layer is pseudo, substitute real layer */
+					opoly->layer = nonpseudolayer(opoly->layer, opoly->tech);
+					if (!samelayer(ap->tech, ap->temp1, opoly->layer)) continue;
+
+					/* transform the polygon and pass it on to the next test */
+					xformpoly(opoly, trans);
+					if (ro_comparepoly(oni, mpp, opoly, ni, pp, poly, ap) != 0)
+						return(1);
 				}
 			}
 		}
@@ -515,33 +570,16 @@ INTBIG ro_testpoly(NODEINST *ni, PORTPROTO *pp, ARCPROTO *ap, POLYGON *poly, NOD
 		/* primitive node: check its layers */
 		makerot(oni, trans);
 
-		/* save information about the other node */
-		ox = (ni->lowx + ni->highx) / 2;
-		oy = (ni->lowy + ni->highy) / 2;
+		/* determine target point */
+		getcenter(poly, &ox, &oy);
 
 		/* look at all polygons on this nodeinst */
 		tot = nodeEpolys(oni, 0, NOWINDOWPART);
-		for(j=0; j<tot; j++)
+		if (tot == 0)
 		{
-			shapeEnodepoly(oni, j, opoly);
-
-			/* only want electrically connected polygons */
-			if (opoly->portproto == NOPORTPROTO) continue;
-
-			/* if the polygon layer is pseudo, substitute real layer */
-			ro_substituteforpseudo(oni, opoly);
-
-			/* this must be the smallest layer on the arc */
-			if (ap->temp1 != opoly->layer) continue;
-
-			/* do not stitch where there is already an electrical connection */
-			onet = getnetonport(oni, opoly->portproto);
-			if (net != NONETWORK && onet == net) continue;
-
-			/* search all ports for the closest connected to this layer */
+			/* not a geometric primitive: look for ports that touch */
 			bestpp = NOPORTPROTO;
 			for(rpp = oni->proto->firstportproto; rpp != NOPORTPROTO; rpp = rpp->nextportproto)
-				if (rpp->network == opoly->portproto->network)
 			{
 				/* compute best distance to the other node */
 				portposition(oni, rpp, &x, &y);
@@ -550,22 +588,65 @@ INTBIG ro_testpoly(NODEINST *ni, PORTPROTO *pp, ARCPROTO *ap, POLYGON *poly, NOD
 				if (dist > bestdist) continue;
 				bestpp = rpp;   bestdist = dist;
 			}
-			if (bestpp == NOPORTPROTO) continue;
-			rpp = bestpp;
-
-			/* port must be able to connect to the arc */
-			if (ro_canconnect(ap, rpp) == 0) continue;
-
-			/* transformed the polygon and pass it on to the next test */
-			xformpoly(opoly, trans);
-			if (ro_comparepoly(oni, rpp, opoly, ni, pp, poly, ap) != 0)
+			if (bestpp != NOPORTPROTO)
 			{
-				stitched++;
-				break;
+				rpp = bestpp;
+
+				/* port must be able to connect to the arc */
+				if (ro_canconnect(ap, rpp))
+				{
+					/* transformed the polygon and pass it on to the next test */
+					shapeportpoly(oni, rpp, opoly, FALSE);
+					if (ro_comparepoly(oni, rpp, opoly, ni, pp, poly, ap) != 0)
+						return(1);
+				}
+			}
+		} else
+		{
+			/* a geometric primitive: look for ports on layers that touch */
+			for(j=0; j<tot; j++)
+			{
+				shapeEnodepoly(oni, j, opoly);
+
+				/* only want electrically connected polygons */
+				if (opoly->portproto == NOPORTPROTO) continue;
+
+				/* if the polygon layer is pseudo, substitute real layer */
+				opoly->layer = nonpseudolayer(opoly->layer, opoly->tech);
+
+				/* this must be the smallest layer on the arc */
+				if (!samelayer(ap->tech, ap->temp1, opoly->layer)) continue;
+
+				/* do not stitch where there is already an electrical connection */
+				onet = getnetonport(oni, opoly->portproto);
+				if (net != NONETWORK && onet == net) continue;
+
+				/* search all ports for the closest connected to this layer */
+				bestpp = NOPORTPROTO;
+				for(rpp = oni->proto->firstportproto; rpp != NOPORTPROTO; rpp = rpp->nextportproto)
+					if (rpp->network == opoly->portproto->network)
+				{
+					/* compute best distance to the other node */
+					portposition(oni, rpp, &x, &y);
+					dist = abs(x-ox) + abs(y-oy);
+					if (bestpp == NOPORTPROTO) bestdist = dist;
+					if (dist > bestdist) continue;
+					bestpp = rpp;   bestdist = dist;
+				}
+				if (bestpp == NOPORTPROTO) continue;
+				rpp = bestpp;
+
+				/* port must be able to connect to the arc */
+				if (!ro_canconnect(ap, rpp)) continue;
+
+				/* transformed the polygon and pass it on to the next test */
+				xformpoly(opoly, trans);
+				if (ro_comparepoly(oni, rpp, opoly, ni, pp, poly, ap) != 0)
+					return(1);
 			}
 		}
 	}
-	return(stitched);
+	return(0);
 }
 
 /*
@@ -578,8 +659,10 @@ INTBIG ro_testpoly(NODEINST *ni, PORTPROTO *pp, ARCPROTO *ap, POLYGON *poly, NOD
 INTBIG ro_comparepoly(NODEINST *oni, PORTPROTO *opp, POLYGON *opoly, NODEINST *ni,
 	PORTPROTO *pp, POLYGON *poly, ARCPROTO *ap)
 {
-	INTBIG x, y, ox, oy, lx, hx, ly, hy, olx, oly, ohx, ohy, ret;
+	INTBIG x, y, ox, oy, lx, hx, ly, hy, olx, oly, ohx, ohy, ret, tx, ty, dist, tdist;
 	ARCINST *alt1, *alt2;
+	REGISTER PORTPROTO *tpp;
+	NODEINST *con1, *con2;
 	REGISTER ARCINST *newai;
 
 	/* find the bounding boxes of the polygons */
@@ -589,17 +672,39 @@ INTBIG ro_comparepoly(NODEINST *oni, PORTPROTO *opp, POLYGON *opoly, NODEINST *n
 	/* quit now if bounding boxes don't intersect */
 	if (lx > ohx || olx > hx || ly > ohy || oly > hy) return(0);
 
-	/* make sure there is more than a point of overlap */
-	if ((lx >= ohx || hx <= olx) && (ly >= ohy || hy <= oly)) return(0);
-
-	/* find some dummy position to help run the arc */
+	/* be sure the closest ports are being used */
 	portposition(ni, pp, &x, &y);
 	portposition(oni, opp, &ox, &oy);
+	dist = computedistance(x, y, ox, oy);
+	for(tpp = oni->proto->firstportproto; tpp != NOPORTPROTO; tpp = tpp->nextportproto)
+	{
+		if (tpp == opp) continue;
+		if (tpp->network != opp->network) continue;
+		portposition(oni, tpp, &tx, &ty);
+		tdist = computedistance(x, y, tx, ty);
+		if (tdist >= dist) continue;
+		dist = tdist;
+		opp = tpp;
+		ox = tx;   oy = ty;
+	}
+	for(tpp = ni->proto->firstportproto; tpp != NOPORTPROTO; tpp = tpp->nextportproto)
+	{
+		if (tpp == pp) continue;
+		if (tpp->network != pp->network) continue;
+		portposition(ni, tpp, &tx, &ty);
+		tdist = computedistance(ox, oy, tx, ty);
+		if (tdist >= dist) continue;
+		dist = tdist;
+		pp = tpp;
+		x = tx;   y = ty;
+	}
+
+	/* find some dummy position to help run the arc */
 	x = (ox+x) / 2;   y = (oy+y) / 2;
 
 	/* run the wire */
-	newai = aconnect(ni->geom, pp, oni->geom, opp, ap, x, y, &alt1, &alt2, 900, 1);
-	ret = ro_didaccept(newai, alt1, alt2);
+	newai = aconnect(ni->geom, pp, oni->geom, opp, ap, x, y, &alt1, &alt2, &con1, &con2, 900, TRUE);
+	ret = ro_didaccept(newai, alt1, alt2, con1, con2);
 	return(ret);
 }
 
@@ -607,15 +712,20 @@ INTBIG ro_comparepoly(NODEINST *oni, PORTPROTO *opp, POLYGON *opoly, NODEINST *n
  * routine to examine up to three arcs that were created and see if they
  * are acceptable to the user.  Returns zero if not, nonzero if so.
  */
-INTBIG ro_didaccept(ARCINST *ai, ARCINST *alt1, ARCINST *alt2)
+INTBIG ro_didaccept(ARCINST *ai, ARCINST *alt1, ARCINST *alt2, NODEINST *con1, NODEINST *con2)
 {
-	char ch;
 	REGISTER VARIABLE *var;
+	POPUPMENU *pm;
+	REGISTER POPUPMENUITEM *miret;
+	BOOLEAN butstate;
+	WINDOWPART *w;
+	INTBIG x, y, retval;
 
 	/* if main arc wasn't created, no update */
 	if (ai == NOARCINST) return(0);
 
 	/* see if user selection is to be done */
+	retval = 1;
 	if ((ro_state&(SELECT|SELSKIP)) == SELECT)
 	{
 		/* save highlighting on the first selection */
@@ -633,65 +743,108 @@ INTBIG ro_didaccept(ARCINST *ai, ARCINST *alt1, ARCINST *alt2)
 		endobjectchange((INTBIG)ai, VARCINST);
 		if (alt1 != NOARCINST) endobjectchange((INTBIG)alt1, VARCINST);
 		if (alt2 != NOARCINST) endobjectchange((INTBIG)alt2, VARCINST);
+		if (con1 != NONODEINST) endobjectchange((INTBIG)con1, VNODEINST);
+		if (con2 != NONODEINST) endobjectchange((INTBIG)con2, VNODEINST);
 
 		/* highlight the stitch */
 		(void)asktool(us_tool, "show-object", (INTBIG)ai->geom);
 		if (alt1 != NOARCINST) (void)asktool(us_tool, "show-object", (INTBIG)alt1->geom);
 		if (alt2 != NOARCINST) (void)asktool(us_tool, "show-object", (INTBIG)alt2->geom);
+		if (con1 != NONODEINST) (void)asktool(us_tool, "show-object", (INTBIG)con1->geom);
+		if (con2 != NONODEINST) (void)asktool(us_tool, "show-object", (INTBIG)con2->geom);
+		(void)asktool(us_tool, "flush-changes");
 
-		/* loop on user response */
-		for(;;)
+		/* prepare confirm menu */
+		pm = (POPUPMENU *)emalloc(sizeof(POPUPMENU), ro_tool->cluster);
+		if (pm == 0) return(0);
+		pm->name = "x";
+		pm->header = _("Confirm stitch");
+		pm->total = 3;
+		pm->list = (POPUPMENUITEM *)emalloc(pm->total * sizeof(POPUPMENUITEM), ro_tool->cluster);
+		if (pm->list == 0) return(0);
+		pm->list[0].attribute = _("&Accept");
+		pm->list[0].value = 0;
+		pm->list[0].response = NOUSERCOM;
+		pm->list[1].attribute = _("&Reject");
+		pm->list[1].value = 0;
+		pm->list[1].response = NOUSERCOM;
+		pm->list[2].attribute = _("Continue &silently");
+		pm->list[2].value = 0;
+		pm->list[2].response = NOUSERCOM;
+
+		/* show confirm menu near first arc */
+		butstate = TRUE;
+		if (el_curwindowpart != NOWINDOWPART)
 		{
-			ttyputmsg(_("Ok? "));
-			ch = (char)ttygetchar();
-			(void)asktool(us_tool, "clear");
-			if (ch == 's')
+			w = el_curwindowpart;
+			x = (ai->end[0].xpos + ai->end[1].xpos) / 2;
+			y = (ai->end[0].ypos + ai->end[1].ypos) / 2;
+			x = applyxscale(w, x-w->screenlx) + w->uselx + MENUDISPX;
+			y = applyyscale(w, y-w->screenly) + w->usely + MENUDISPY;
+		} else x = y = -1;
+		miret = us_popupmenu(&pm, &butstate, TRUE, x, y, 4);
+		(void)asktool(us_tool, "clear");
+		if (miret != NOPOPUPMENUITEM)
+		{
+			switch (miret - pm->list)
 			{
-				var = getvalkey((INTBIG)ro_tool, VTOOL, VINTEGER, ro_statekey);
-				if (var != NOVARIABLE)
-					(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_statekey,
-						var->addr & ~SELSKIP, VINTEGER|VDONTSAVE);
-				break;
+				case 0: /* accept */
+					break;	
+				case 1: /* reject */
+					startobjectchange((INTBIG)ai, VARCINST);
+					if (killarcinst(ai)) ttyputerr(_("Problem retracting arc"));
+					if (alt1 != NOARCINST)
+					{
+						startobjectchange((INTBIG)alt1, VARCINST);
+						if (killarcinst(alt1))
+							ttyputerr(_("Problem retracting arc"));
+					}
+					if (alt2 != NOARCINST)
+					{
+						startobjectchange((INTBIG)alt2, VARCINST);
+						if (killarcinst(alt2))
+							ttyputerr(_("Problem retracting arc"));
+					}
+					if (con1 != NONODEINST)
+					{
+						startobjectchange((INTBIG)con1, VNODEINST);
+						if (killnodeinst(con1))
+							ttyputerr(_("Problem retracting node"));
+					}
+					if (con2 != NONODEINST)
+					{
+						startobjectchange((INTBIG)con2, VNODEINST);
+						if (killnodeinst(con2))
+							ttyputerr(_("Problem retracting node"));
+					}
+					ttyputmsg(_("Stitch not made"));
+					retval = 0;
+					break;
+				case 2: /* continue silently */
+					var = getvalkey((INTBIG)ro_tool, VTOOL, VINTEGER, ro_statekey);
+					if (var != NOVARIABLE)
+						(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_statekey,
+							ro_state | SELSKIP, VINTEGER|VDONTSAVE);
+					break;
 			}
-			if (ch == ' ' || ch == '\r' || ch == 'y') break;
-			if (ch == 'n')
-			{
-				startobjectchange((INTBIG)ai, VARCINST);
-				if (killarcinst(ai) != 0) ttyputerr(_("Problem retracting arc"));
-				if (alt1 != NOARCINST)
-				{
-					startobjectchange((INTBIG)alt1, VARCINST);
-					if (killarcinst(alt1) != 0)
-						ttyputerr(_("Problem retracting arc"));
-				}
-				if (alt2 != NOARCINST)
-				{
-					startobjectchange((INTBIG)alt2, VARCINST);
-					if (killarcinst(alt2) != 0)
-						ttyputerr(_("Problem retracting arc"));
-				}
-				ttyputmsg(_("Stitch not made"));
-				return(0);
-			}
-			ttyputmsg(_("Type: y, SPACE, or CARRIAGE-RETURN to accept"));
-			ttyputmsg(_("      n to reject"));
-			ttyputmsg(_("      s to continue silently"));
 		}
+		efree((char *)pm->list);
+		efree((char *)pm);
 	}
-	return(1);
+	return(retval);
 }
 
 /*
  * routine to determine whether arcproto "ap" can connect to portproto
- * "pp".  Returns nonzero if it can connect.
+ * "pp".  Returns true if it can connect.
  */
-INTSML ro_canconnect(ARCPROTO *ap, PORTPROTO *pp)
+BOOLEAN ro_canconnect(ARCPROTO *ap, PORTPROTO *pp)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 
 	for(i=0; pp->connects[i] != NOARCPROTO; i++)
-		if (pp->connects[i] == ap) return(1);
-	return(0);
+		if (pp->connects[i] == ap) return(TRUE);
+	return(FALSE);
 }
 
 /*
@@ -735,62 +888,4 @@ void ro_findsmallestlayer(ARCPROTO *ap)
 	}
 }
 
-void ro_substituteforpseudo(NODEINST *ni, POLYGON *poly)
-{
-	REGISTER INTBIG fun, ofun, mask;
-	REGISTER INTSML i;
-	REGISTER TECHNOLOGY *tech;
-
-	tech = ni->proto->tech;
-	fun = layerfunction(tech, poly->layer);
-	if ((fun&LFPSEUDO) == 0) return;
-
-	/* these bits must match between pseudo and nonpseudo */
-	mask = LFTYPE | LFPTYPE | LFNTYPE | LFDEPLETION | LFENHANCEMENT |
-		LFLIGHT | LFHEAVY | LFNONELEC;
-
-#if 0
-	/* if this is a pin, try substituting the bounds of an attached arc */
-	nfun = (ni->userbits&NFUNCTION) >> NFUNCTIONSH;
-	if (nfun == NPPIN)
-	{
-		/* get polygon */
-		if (apoly == NOPOLYGON) apoly = allocstaticpolygon(4, ro_tool->cluster);
-		for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
-		{
-			ai = pi->conarcinst;
-			j = arcpolys(ai, NOWINDOWPART);
-			for(i=0; i<j; i++)
-			{
-				shapearcpoly(ai, i, apoly);
-				ofun = layerfunction(tech, apoly->layer);
-				if ((ofun&LFPSEUDO) != 0) continue;
-				if ((fun&mask) == (ofun&mask))
-				{
-					/* this layer on the arc is the true geometry of the pseudo-layer */
-					(void)extendpolygon(poly, apoly->count);
-					for(k=0; k<apoly->count; k++)
-					{
-						poly->xv[k] = apoly->xv[k];
-						poly->yv[k] = apoly->yv[k];
-					}
-					poly->count = apoly->count;
-					poly->layer = apoly->layer;
-					return;
-				}
-			}
-		}
-	}
-#endif
-
-	for(i=0; i<tech->layercount; i++)
-	{
-		ofun = layerfunction(tech, i);
-		if ((ofun&LFPSEUDO) != 0) continue;
-		if ((fun&mask) != (ofun&mask)) continue;
-		poly->layer = i;
-		break;
-	}
-}
-
 #endif  /* ROUTTOOL - at top */
