@@ -89,7 +89,7 @@ typedef enum
 typedef struct _srlayer
 {
 	char            *hused, *vused;
-	INTSML           index;				/* the layer index (sort order) */
+	INTBIG           index;				/* the layer index (sort order) */
 	UINTBIG          mask;				/* the layer mask */
 	INTBIG           transx, transy;	/* translation value for grid */
 	INTBIG           wid, hei;			/* the width and height of the grid */
@@ -114,7 +114,7 @@ typedef struct _srlayer
 
 typedef struct _srnet
 {
-	INTSML          routed;				/* route state flag */
+	BOOLEAN         routed;				/* route state flag */
 	SRREGION       *region;				/* the parent region */
 	struct _srport *ports;				/* the list of ports on the net */
 	struct _srpath *paths;				/* the list of paths */
@@ -131,7 +131,7 @@ typedef struct _srnet
 
 typedef struct _srport
 {
-	INTSML            index;			/* the port index */
+	INTBIG            index;			/* the port index */
 	UINTBIG           layers;			/* the layer mask */
 	INTBIG            lx, ly, hx, hy;	/* bounds of the port */
 	NODEINST         *ni;				/* node that this port comes from (may be NONODEINST) */
@@ -211,7 +211,7 @@ typedef enum {SR_MOR, SR_MAND, SR_MSET} SRMODE;
 		ro_mazeset_line(region,region->layers[SCH_VERTLAYER],SR_GSET,Mlx,Mly,Mhx,Mhy,SR_MSET);	\
 }
 
-static INTSML     ro_mazedebug = 0;
+static BOOLEAN    ro_mazedebug = FALSE;
 static ARCPROTO  *ro_mazevertwire, *ro_mazehoriwire;
 static NODEPROTO *ro_mazesteiner;
 static FILE      *ro_mazedebuggingout;
@@ -229,17 +229,17 @@ static SRWAVEPT  *ro_mazewavept_free_list = NOSRWAVEPT;
 /* prototypes for local routines */
 static INTBIG      ro_anglediff(INTBIG ang1, INTBIG ang2);
 static TECHNOLOGY *ro_findtech(NODEINST *ni, PORTPROTO *pp);
-static SRLAYER    *ro_mazeadd_layer(SRREGION *region, INTSML index,  SRDIRECTION direction, INTBIG gridx, INTBIG gridy, INTBIG alignx, INTBIG aligny);
+static SRLAYER    *ro_mazeadd_layer(SRREGION *region, INTBIG index,  SRDIRECTION direction, INTBIG gridx, INTBIG gridy, INTBIG alignx, INTBIG aligny);
 static SRNET      *ro_mazeadd_net(SRREGION *region);
 static SRPORT     *ro_mazeadd_port(SRNET *net, UINTBIG layers, INTBIG wx1, INTBIG wy1, INTBIG wx2, INTBIG wy2, NODEINST *ni, PORTPROTO *pp);
-static INTSML      ro_mazeadd_wavept(SRPORT *port, SRLAYER *layer, INTBIG x, INTBIG y, INTBIG code);
-static void        ro_mazeadjustpath(SRPATH *paths, SRPATH *thispath, INTSML end, INTBIG dx, INTBIG dy);
+static BOOLEAN     ro_mazeadd_wavept(SRPORT *port, SRLAYER *layer, INTBIG x, INTBIG y, INTBIG code);
+static void        ro_mazeadjustpath(SRPATH *paths, SRPATH *thispath, INTBIG end, INTBIG dx, INTBIG dy);
 static SRNET      *ro_mazealloc_net(void);
 static SRPATH     *ro_mazealloc_path(void);
 static SRPORT     *ro_mazealloc_port(void);
 static SRWAVEPT   *ro_mazealloc_wavept(void);
 static void        ro_mazeclear_maze(SRNET *net);
-static INTSML      ro_mazecreate_wavefront(SRPORT *port);
+static void        ro_mazecreate_wavefront(SRPORT *port);
 static SRREGION   *ro_mazedefine_region(NODEPROTO *np, INTBIG lx, INTBIG ly, INTBIG hx, INTBIG hy);
 static void        ro_mazedelete_net(SRNET *net);
 static void        ro_mazedelete_port(SRPORT *port);
@@ -248,28 +248,28 @@ static UINTBIG     ro_mazedetermine_dir(NODEINST *ni, INTBIG cx, INTBIG cy);
 static void        ro_mazedraw_arcinst(ARCINST *ai, XARRAY trans, NETWORK *net, SRREGION *region);
 static void        ro_mazedraw_facet(NODEINST *ni, XARRAY prevtrans, NETWORK *net, SRREGION *region);
 static void        ro_mazedraw_nodeinst(NODEINST *ni, XARRAY prevtrans, NETWORK *net, SRREGION *region);
-static void        ro_mazedraw_showpoly(POLYGON *obj, SRREGION *region, INTSML layer);
+static void        ro_mazedraw_showpoly(POLYGON *obj, SRREGION *region, INTBIG layer);
 static void        ro_mazedump_layer(char *message, SRREGION *region, UINTBIG layers);
-static INTSML      ro_mazeexamine_pt(SRPORT *port, SRLAYER *layer, INTBIG x, INTBIG y, INTBIG code);
-static INTSML      ro_mazeexpand_wavefront(SRPORT *port, INTBIG code);
-static INTSML      ro_mazeextract_paths(NODEPROTO *parent, SRNET *net);
-static INTSML      ro_mazefind_paths(SRWAVEPT *wavept, SRPATH *path);
-static INTBIG      ro_mazefindport(NODEPROTO*, INTBIG, INTBIG, ARCPROTO*, NODEINST *nis[], PORTPROTO *pps[], INTSML);
-static INTBIG      ro_mazefindport_geom(NODEPROTO *facet, INTBIG x, INTBIG y, ARCPROTO *ap, NODEINST *nis[], PORTPROTO *pps[], ARCINST **ai, INTSML forcefind);
+static INTBIG      ro_mazeexamine_pt(SRPORT *port, SRLAYER *layer, INTBIG x, INTBIG y, INTBIG code);
+static INTBIG      ro_mazeexpand_wavefront(SRPORT *port, INTBIG code);
+static BOOLEAN     ro_mazeextract_paths(NODEPROTO *parent, SRNET *net);
+static INTBIG      ro_mazefind_paths(SRWAVEPT *wavept, SRPATH *path);
+static INTBIG      ro_mazefindport(NODEPROTO*, INTBIG, INTBIG, ARCPROTO*, NODEINST *nis[], PORTPROTO *pps[], BOOLEAN);
+static INTBIG      ro_mazefindport_geom(NODEPROTO *facet, INTBIG x, INTBIG y, ARCPROTO *ap, NODEINST *nis[], PORTPROTO *pps[], ARCINST **ai, BOOLEAN forcefind);
 static void        ro_mazefree_net(SRNET *net);
 static void        ro_mazefree_path(SRPATH *path);
 static void        ro_mazefree_port(SRPORT *port);
 static void        ro_mazefree_wavept(SRWAVEPT *wavept);
 static SRPATH     *ro_mazeget_path(SRPORT *port, SRLAYER *layer, SREND e1, SREND e2, INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2);
 static SRREGION   *ro_mazeget_region(INTBIG wlx, INTBIG wly, INTBIG whx, INTBIG why, INTBIG gridx, INTBIG gridy, INTBIG offsetx, INTBIG offsety);
-static INTSML      ro_mazeinit_path(SRPORT *port, SRLAYER *layer, SRWAVEPT *wavept, INTBIG x, INTBIG y, INTBIG code);
-static INTSML      ro_mazeroute_net(SRNET *net);
-static INTSML      ro_mazeroutenet(NETWORK *net);
+static INTBIG      ro_mazeinit_path(SRPORT *port, SRLAYER *layer, SRWAVEPT *wavept, INTBIG x, INTBIG y, INTBIG code);
+static BOOLEAN     ro_mazeroute_net(SRNET *net);
+static BOOLEAN     ro_mazeroutenet(NETWORK *net);
 static SRWAVEPT   *ro_mazesearch_wavefront(SRPORT *port, SRLAYER *layer, INTBIG x, INTBIG y);
 static void        ro_mazeset_box(SRREGION *region, SRLAYER *layer, SRGPT type, INTBIG wx1, INTBIG wy1, INTBIG wx2, INTBIG wy2, SRMODE mode);
 static void        ro_mazeset_line(SRREGION *region, SRLAYER *layer, SRGPT type, INTBIG wx1, INTBIG wy1, INTBIG wx2, INTBIG wy2, SRMODE mode);
 static void        ro_mazeset_point(SRLAYER *layer, SRGPT type, INTBIG x, INTBIG y, SRMODE mode);
-static INTSML      ro_mazetest_pt(SRGPT pt, INTBIG code);
+static INTBIG      ro_mazetest_pt(SRGPT pt, INTBIG code);
 
 /*
  * Routine to free all memory associated with this module.
@@ -333,13 +333,13 @@ void ro_mazerouteselected(void)
 {
 	GEOM **list;
 	REGISTER NODEPROTO *np;
-	REGISTER INTSML found;
+	REGISTER BOOLEAN found;
 	REGISTER ARCINST *ai;
 	REGISTER INTBIG selectcount, i;
 	REGISTER NETWORK *net;
 
 	/* see what is selected */
-	list = us_gethighlighted(OBJARCINST, 0, 0);
+	list = us_gethighlighted(WANTARCINST, 0, 0);
 	for(selectcount=0; list[selectcount] != NOGEOM; selectcount++) ;
 	if (selectcount == 0)
 	{
@@ -349,10 +349,10 @@ void ro_mazerouteselected(void)
 	np = geomparent(list[0]);
 
 	/* loop while searching for networks to route */
-	found = 1;
-	while (found != 0)
+	found = TRUE;
+	while (found)
 	{
-		found = 0;
+		found = FALSE;
 		for(net = np->firstnetwork; net != NONETWORK; net = net->nextnetwork)
 		{
 			/* see if anything selected is on this net */
@@ -373,8 +373,8 @@ void ro_mazerouteselected(void)
 			}
 
 			/* now route the network */
-			if (ro_mazeroutenet(net) != 0) return;
-			found = 1;
+			if (ro_mazeroutenet(net)) return;
+			found = TRUE;
 			break;
 		}
 	}
@@ -400,17 +400,17 @@ void ro_mazeroutecell(void)
 		if (ai == NOARCINST) break;
 
 		/* now route the network */
-		if (ro_mazeroutenet(ai->network) != 0) return;
+		if (ro_mazeroutenet(ai->network)) return;
 	}
 }
 
 /*
- * Routine to reroute networks "net".  Returns nonzero on error.
+ * Routine to reroute networks "net".  Returns true on error.
  */
-INTSML ro_mazeroutenet(NETWORK *net)
+BOOLEAN ro_mazeroutenet(NETWORK *net)
 {
 	INTBIG lx, ly, hx, hy, lambda;
-	INTSML i, ret, first;
+	INTBIG i, first;
 	NODEPROTO *np;
 	NODEINST **nilist;
 	PORTPROTO **pplist;
@@ -433,7 +433,7 @@ INTSML ro_mazeroutenet(NETWORK *net)
 	if (count != 2)
 	{
 		ttyputerr(_("Can only route nets with 2 ends, this has %ld"), count);
-		return(1);
+		return(TRUE);
 	}
 
 	/* determine technology and grid size */
@@ -471,7 +471,7 @@ INTSML ro_mazeroutenet(NETWORK *net)
 	if (first != 0)
 	{
 		ttyputerr(_("Internal error: no bounding area for routing"));
-		return(1);
+		return(TRUE);
 	}
 
 	/* turn off highlighting */
@@ -486,7 +486,7 @@ INTSML ro_mazeroutenet(NETWORK *net)
 		if (killarcinst(ai))
 		{
 			ttyputerr(_("Error deleting original arc"));
-			return(1);
+			return(TRUE);
 		}
 	}
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = nextni)
@@ -497,20 +497,20 @@ INTSML ro_mazeroutenet(NETWORK *net)
 		if (killnodeinst(ni))
 		{
 			ttyputerr(_("Error deleting intermediate pin"));
-			return(1);
+			return(TRUE);
 		}
 	}
 
 	/* now create the routing region */
 	region = ro_mazedefine_region(np, lx, ly, hx, hy);
-	if (region == NOSRREGION) return(1);
+	if (region == NOSRREGION) return(TRUE);
 
 	/* create the net in the region */
 	srnet = ro_mazeadd_net(region);
 	if (srnet == NOSRNET)
 	{
 		ttyputerr(_("Could not allocate internal net"));
-		return(1);
+		return(TRUE);
 	}
 
 	/* add the ports to the net */
@@ -525,7 +525,7 @@ INTSML ro_mazeroutenet(NETWORK *net)
 		if (fsp == NOSRPORT)
 		{
 			ttyputerr(_("Port could not be defined"));
-			return(1);
+			return(TRUE);
 		}
 	}
 
@@ -533,14 +533,13 @@ INTSML ro_mazeroutenet(NETWORK *net)
 	if (ro_mazedebug)
 	{
 		ro_mazedebuggingout = xcreate("routing", el_filetypetext, 0, &dummy);
-		if (ro_mazedebuggingout == NULL) return(1);
+		if (ro_mazedebuggingout == NULL) return(TRUE);
 		ro_mazedump_layer(_("before"), region, (UINTBIG)3);
 	}
-	ret = ro_mazeroute_net(srnet);
-	if (ret != 0)
+	if (ro_mazeroute_net(srnet))
 	{
 		ttyputerr(_("Could not route net"));
-		return(1);
+		return(TRUE);
 	}
 	if (ro_mazedebug)
 	{
@@ -549,17 +548,16 @@ INTSML ro_mazeroutenet(NETWORK *net)
 	}
 
 	/* extract paths to create arcs */
-	ret = ro_mazeextract_paths(np, srnet);
-	if (ret != 0)
+	if (ro_mazeextract_paths(np, srnet))
 	{
 		ttyputerr(_("Could not create paths"));
-		return(1);
+		return(TRUE);
 	}
 
 	/* ensure that the facet is the proper size */
 	(*el_curconstraint->solve)(np);
 	setactivity(_("Maze routing"));
-	return(0);
+	return(FALSE);
 }
 
 /* internal helper routines */
@@ -592,11 +590,11 @@ SRREGION *ro_mazedefine_region(NODEPROTO *np, INTBIG lx, INTBIG ly, INTBIG hx, I
 	while ((look = nextobject(search)) != NOGEOM)
 	{
 		if (stopping(STOPREASONROUTING)) return(NOSRREGION);
-		if (look->entrytype == OBJNODEINST)
+		if (look->entryisnode)
 		{
 			/* draw this facet */
 			ro_mazedraw_facet(look->entryaddr.ni, trans, NONETWORK, region);
-		} else if (look->entrytype == OBJARCINST)
+		} else
 		{
 			/* draw this arc */
 			ro_mazedraw_arcinst(look->entryaddr.ai, trans, NONETWORK, region);
@@ -609,7 +607,7 @@ SRREGION *ro_mazedefine_region(NODEPROTO *np, INTBIG lx, INTBIG ly, INTBIG hx, I
  * Routine to recursively adjust paths to account for port positions that may not
  * be on the grid.
  */
-void ro_mazeadjustpath(SRPATH *paths, SRPATH *thispath, INTSML end, INTBIG dx, INTBIG dy)
+void ro_mazeadjustpath(SRPATH *paths, SRPATH *thispath, INTBIG end, INTBIG dx, INTBIG dy)
 {
 	SRPATH *opath;
 	INTBIG formerx, formery, formerthis, formerother;
@@ -668,7 +666,7 @@ void ro_mazeadjustpath(SRPATH *paths, SRPATH *thispath, INTSML end, INTBIG dx, I
 }
 
 /* routing grid database routines */
-INTSML ro_mazeextract_paths(NODEPROTO *parent, SRNET *net)
+BOOLEAN ro_mazeextract_paths(NODEPROTO *parent, SRNET *net)
 {
 	SRPATH *path;
 	SRPORT *port;
@@ -698,10 +696,10 @@ INTSML ro_mazeextract_paths(NODEPROTO *parent, SRNET *net)
 		} else
 		{
 			ap = path->layer->index ? ro_mazevertwire : ro_mazehoriwire;
-			fcnt = ro_mazefindport(parent, fx, fy, ap, fni, fpp, 1);
+			fcnt = ro_mazefindport(parent, fx, fy, ap, fni, fpp, TRUE);
 			if (fcnt > 0)
 			{
-				shapeportpoly(fni[0], fpp[0], poly, 0);
+				shapeportpoly(fni[0], fpp[0], poly, FALSE);
 				closestpoint(poly, &fx, &fy);
 				if (fx != ofx || fy != ofy)
 					ro_mazeadjustpath(net->paths, path, 0, fx-ofx, fy-ofy);
@@ -720,10 +718,10 @@ INTSML ro_mazeextract_paths(NODEPROTO *parent, SRNET *net)
 		} else
 		{
 			ap = path->layer->index ? ro_mazevertwire : ro_mazehoriwire;
-			fcnt = ro_mazefindport(parent, fx, fy, ap, fni, fpp, 1);
+			fcnt = ro_mazefindport(parent, fx, fy, ap, fni, fpp, TRUE);
 			if (fcnt > 0)
 			{
-				shapeportpoly(fni[0], fpp[0], poly, 0);
+				shapeportpoly(fni[0], fpp[0], poly, FALSE);
 				closestpoint(poly, &fx, &fy);
 				if (fx != ofx || fy != ofy)
 					ro_mazeadjustpath(net->paths, path, 1, fx-ofx, fy-ofy);
@@ -738,7 +736,7 @@ INTSML ro_mazeextract_paths(NODEPROTO *parent, SRNET *net)
 
 		/* create arc between the end points */
 		fx = path->wx[0];   fy = path->wy[0];
-		fcnt = ro_mazefindport(parent, fx, fy, ap, fni, fpp, 0);
+		fcnt = ro_mazefindport(parent, fx, fy, ap, fni, fpp, FALSE);
 		if (fcnt == 0)
 		{
 			/* create the from pin */
@@ -750,14 +748,14 @@ INTSML ro_mazeextract_paths(NODEPROTO *parent, SRNET *net)
 			if (fni[0] == NONODEINST)
 			{
 				ttyputerr(_("Could not create pin"));
-				return(1);
+				return(TRUE);
 			}
 			endobjectchange((INTBIG)fni[0], VNODEINST);
 			fpp[0] = ro_mazesteiner->firstportproto;
 		}
 
 		tx = path->wx[1];   ty = path->wy[1];
-		tcnt = ro_mazefindport(parent, tx, ty, ap, tni, tpp, 0);
+		tcnt = ro_mazefindport(parent, tx, ty, ap, tni, tpp, FALSE);
 		if (tcnt == 0)
 		{
 			/* create the from pin */
@@ -769,7 +767,7 @@ INTSML ro_mazeextract_paths(NODEPROTO *parent, SRNET *net)
 			if (tni[0] == NONODEINST)
 			{
 				ttyputerr(_("Could not create pin"));
-				return(1);
+				return(TRUE);
 			}
 			endobjectchange((INTBIG)tni[0], VNODEINST);
 			tpp[0] = ro_mazesteiner->firstportproto;
@@ -785,14 +783,14 @@ INTSML ro_mazeextract_paths(NODEPROTO *parent, SRNET *net)
 			if (ai == NOARCINST)
 			{
 				ttyputerr(_("Could not create path (arc)"));
-				return(1);
+				return(TRUE);
 			}
 			endobjectchange((INTBIG)ai, VARCINST);
 			if (ai->network != NONETWORK) ai->network->temp1 = 2;
 		}
 	}
 
-	return 0;
+	return(FALSE);
 }
 
 UINTBIG ro_mazedetermine_dir(NODEINST *ni, INTBIG cx, INTBIG cy)
@@ -828,7 +826,7 @@ UINTBIG ro_mazedetermine_dir(NODEINST *ni, INTBIG cx, INTBIG cy)
  * function: will write polys into EDIF syntax
  * inputs: poly
  */
-void ro_mazedraw_showpoly(POLYGON *obj, SRREGION *region, INTSML layer)
+void ro_mazedraw_showpoly(POLYGON *obj, SRREGION *region, INTBIG layer)
 {
 	INTBIG i, lx, ux, ly, uy, six, siy;
 	void io_compute_center(INTBIG xc, INTBIG yc, INTBIG x1, INTBIG y1,
@@ -837,7 +835,7 @@ void ro_mazedraw_showpoly(POLYGON *obj, SRREGION *region, INTSML layer)
 	/* now draw the polygon */
 	switch (obj->style)
 	{
-		case CIRCLE:
+		case CIRCLE: case THICKCIRCLE:
 		case DISC:						/* a circle */
 			i = computedistance(obj->xv[0], obj->yv[0], obj->xv[1], obj->yv[1]);
 			lx = obj->xv[0] - i; ly = obj->yv[0] - i;
@@ -845,7 +843,7 @@ void ro_mazedraw_showpoly(POLYGON *obj, SRREGION *region, INTSML layer)
 			DRAW_BOX(lx, ly, ux, uy, layer);
 			break;
 
-		case CIRCLEARC:
+		case CIRCLEARC: case THICKCIRCLEARC:
 			/* arcs at [i] points [1+i] [2+i] clockwise */
 			if (obj->count == 0) break;
 			if ((obj->count % 3) != 0) break;
@@ -1052,7 +1050,7 @@ void ro_mazedraw_facet(NODEINST *ni, XARRAY prevtrans, NETWORK *net, SRREGION *r
    pp = found pp proto.
  */
 INTBIG ro_mazefindport_geom(NODEPROTO *facet, INTBIG x, INTBIG y, ARCPROTO *ap,
-	NODEINST *nis[], PORTPROTO *pps[], ARCINST **ai, INTSML forcefind)
+	NODEINST *nis[], PORTPROTO *pps[], ARCINST **ai, BOOLEAN forcefind)
 {
 	REGISTER INTBIG j, cnt, sea, dist, bestdist;
 	REGISTER GEOM *geom;
@@ -1070,9 +1068,9 @@ INTBIG ro_mazefindport_geom(NODEPROTO *facet, INTBIG x, INTBIG y, ARCPROTO *ap,
 		geom = nextobject(sea);
 		if (geom == NOGEOM) break;
 
-		switch (geom->entrytype)
+		switch (geom->entryisnode)
 		{
-			case OBJNODEINST :
+			case TRUE:
 				ni = geom->entryaddr.ni;
 				if (ni->proto->primindex != 0 &&
 					(((ni->proto->userbits & NFUNCTION) >> NFUNCTIONSH) == NPPIN) &&
@@ -1083,8 +1081,8 @@ INTBIG ro_mazefindport_geom(NODEPROTO *facet, INTBIG x, INTBIG y, ARCPROTO *ap,
 				/* now locate a portproto */
 				for (pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 				{
-					shapeportpoly(ni, pp, poly, 0);
-					if (isinside(x, y, poly) != 0)
+					shapeportpoly(ni, pp, poly, FALSE);
+					if (isinside(x, y, poly))
 					{
 						/* check if port connects to arc ...*/
 						for (j = 0; pp->connects[j] != NOARCPROTO; j++)
@@ -1109,7 +1107,7 @@ INTBIG ro_mazefindport_geom(NODEPROTO *facet, INTBIG x, INTBIG y, ARCPROTO *ap,
 				}
 				break;
 
-			case OBJARCINST :
+			case FALSE:
 				if ((geom->entryaddr.ai->network != NONETWORK &&
 					geom->entryaddr.ai->network->temp1 != 2)) break;
 				*ai = geom->entryaddr.ai;
@@ -1117,7 +1115,7 @@ INTBIG ro_mazefindport_geom(NODEPROTO *facet, INTBIG x, INTBIG y, ARCPROTO *ap,
 		}
 	}
 
-	if (cnt == 0 && forcefind != 0 && closestni != NONODEINST && bestdist < ro_mazegridx)
+	if (cnt == 0 && forcefind && closestni != NONODEINST && bestdist < ro_mazegridx)
 	{
 		nis[cnt] = closestni;
 		pps[cnt] = closestpp;
@@ -1127,7 +1125,7 @@ INTBIG ro_mazefindport_geom(NODEPROTO *facet, INTBIG x, INTBIG y, ARCPROTO *ap,
 }
 
 INTBIG ro_mazefindport(NODEPROTO *facet, INTBIG x, INTBIG y, ARCPROTO *ap, NODEINST *nis[],
-	PORTPROTO *pps[], INTSML forcefind)
+	PORTPROTO *pps[], BOOLEAN forcefind)
 {
 	INTBIG cnt;
 	ARCINST *ai = NOARCINST, *ar1,*ar2;
@@ -1342,7 +1340,7 @@ void ro_mazefree_wavept(SRWAVEPT *wavept)
 SRREGION *ro_mazeget_region(INTBIG wlx, INTBIG wly, INTBIG whx, INTBIG why,
 	INTBIG gridx, INTBIG gridy, INTBIG offsetx, INTBIG offsety)
 {
-	INTSML index;
+	INTBIG index;
 	SRLAYER *vlayer, *hlayer;
 
 	if (wlx > whx || wly > why) return NOSRREGION;
@@ -1397,7 +1395,7 @@ void ro_mazecleanout_region(SRREGION *region)
 	}
 }
 
-SRLAYER *ro_mazeadd_layer(SRREGION *region, INTSML index, SRDIRECTION direction,
+SRLAYER *ro_mazeadd_layer(SRREGION *region, INTBIG index, SRDIRECTION direction,
 	INTBIG gridx, INTBIG gridy, INTBIG alignx, INTBIG aligny)
 {
 	SRLAYER *layer, *alayer;
@@ -1669,7 +1667,7 @@ SRNET *ro_mazeadd_net(SRREGION *region)
 	net = ro_mazealloc_net();
 	if (net == NOSRNET) return NOSRNET;
 
-	net->routed = 0;
+	net->routed = FALSE;
 	net->ports = NOSRPORT;
 	net->paths = NOSRPATH;
 	net->lastpath = NOSRPATH;
@@ -1717,7 +1715,7 @@ SRPORT *ro_mazeadd_port(SRNET *net, UINTBIG layers, INTBIG wx1, INTBIG wy1, INTB
 	NODEINST *ni, PORTPROTO *pp)
 {
 	SRPORT *port, *lport;
-	INTSML index;
+	INTBIG index;
 	INTBIG mask;
 
 	port = ro_mazealloc_port();
@@ -1765,12 +1763,12 @@ SRPORT *ro_mazeadd_port(SRNET *net, UINTBIG layers, INTBIG wx1, INTBIG wy1, INTB
 }
 
 /* routing commands */
-INTSML ro_mazeadd_wavept(SRPORT *port, SRLAYER *layer, INTBIG x, INTBIG y, INTBIG code)
+BOOLEAN ro_mazeadd_wavept(SRPORT *port, SRLAYER *layer, INTBIG x, INTBIG y, INTBIG code)
 {
 	SRWAVEPT *wavept;
 
 	wavept = ro_mazealloc_wavept();
-	if (wavept == NOSRWAVEPT) return 1;
+	if (wavept == NOSRWAVEPT) return TRUE;
 	wavept->x = x;
 	wavept->y = y;
 
@@ -1798,13 +1796,14 @@ INTSML ro_mazeadd_wavept(SRPORT *port, SRLAYER *layer, INTBIG x, INTBIG y, INTBI
 	}
 	if (wavept->next != NOSRWAVEPT)
 		wavept->next->prev = wavept;
-	return 0;
+	return FALSE;
 }
 
-INTSML ro_mazecreate_wavefront(SRPORT *port)
+void ro_mazecreate_wavefront(SRPORT *port)
 {
 	INTBIG x, y, dx, dy, lx, ly, hx, hy, cx, cy, ang, angrange, spread;
-	INTSML index, onedge;
+	INTBIG index;
+	BOOLEAN onedge;
 	UINTBIG mask;
 	SRLAYER *layer;
 	SRPATH *path;
@@ -1837,20 +1836,20 @@ INTSML ro_mazecreate_wavefront(SRPORT *port)
 			 */
 			if (ro_mazedebug)
 				xprintf(ro_mazedebuggingout, "Port %ld<=X<=%ld %ld<=Y<=%ld\n", lx, hx, ly, hy);
-			onedge = 0;
+			onedge = FALSE;
 			for (x = lx; x <= hx; x++)
 			{
 				for (y = ly; y <= hy; y++)
 				{
 					if (ro_mazeadd_wavept(master, layer, x, y, SR_GSTART))
-						return 1;
-					if (x < layer->wid-1 && layer->grids[x+1][y] == 0) onedge = 1;
-					if (x > 0 && layer->grids[x-1][y] == 0) onedge = 1;
-					if (y < layer->hei-1 && layer->grids[x][y+1] == 0) onedge = 1;
-					if (y > 0 && layer->grids[x][y-1] == 0) onedge = 1;
+						return;
+					if (x < layer->wid-1 && layer->grids[x+1][y] == 0) onedge = TRUE;
+					if (x > 0 && layer->grids[x-1][y] == 0) onedge = TRUE;
+					if (y < layer->hei-1 && layer->grids[x][y+1] == 0) onedge = TRUE;
+					if (y > 0 && layer->grids[x][y-1] == 0) onedge = TRUE;
 				}
 			}
-			if (onedge == 0)
+			if (!onedge)
 			{
 				/* port is inside of blocked area: search for opening */
 				cx = (lx + hx) / 2;
@@ -1865,7 +1864,7 @@ INTSML ro_mazecreate_wavefront(SRPORT *port)
 					for(spread=1; spread<BLOCKAGELIMIT; spread++)
 					{
 						if (hx+spread >= layer->wid) break;
-						if (layer->grids[hx+spread][cy] == 0) { onedge = 1;   break; }
+						if (layer->grids[hx+spread][cy] == 0) { onedge = TRUE;   break; }
 						layer->grids[hx+spread][cy] = 0;
 					}
 				}
@@ -1875,7 +1874,7 @@ INTSML ro_mazecreate_wavefront(SRPORT *port)
 					for(spread=1; spread<BLOCKAGELIMIT; spread++)
 					{
 						if (hy+spread >= layer->hei) break;
-						if (layer->grids[cx][hy+spread] == 0) { onedge = 1;   break; }
+						if (layer->grids[cx][hy+spread] == 0) { onedge = TRUE;   break; }
 						layer->grids[cx][hy+spread] = 0;
 					}
 				}
@@ -1885,7 +1884,7 @@ INTSML ro_mazecreate_wavefront(SRPORT *port)
 					for(spread=1; spread<BLOCKAGELIMIT; spread++)
 					{
 						if (lx-spread < 0) break;
-						if (layer->grids[lx-spread][cy] == 0) { onedge = 1;   break; }
+						if (layer->grids[lx-spread][cy] == 0) { onedge = TRUE;   break; }
 						layer->grids[lx-spread][cy] = 0;
 					}
 				}
@@ -1895,14 +1894,14 @@ INTSML ro_mazecreate_wavefront(SRPORT *port)
 					for(spread=1; spread<BLOCKAGELIMIT; spread++)
 					{
 						if (ly-spread < 0) break;
-						if (layer->grids[cx][ly-spread] == 0) { onedge = 1;   break; }
+						if (layer->grids[cx][ly-spread] == 0) { onedge = TRUE;   break; }
 						layer->grids[cx][ly-spread] = 0;
 					}
 				}
-				if (onedge == 0)
+				if (!onedge)
 				{
 					ttyputerr(_("Node %s is blocked"), describenodeinst(port->ni));
-					return 1;
+					return;
 				}
 			}
 		}
@@ -1920,7 +1919,7 @@ INTSML ro_mazecreate_wavefront(SRPORT *port)
 			for (x = path->x[0], y = path->y[0];
 				(dy < 0) ? y >= path->y[1] : y <= path->y[1]; y += dy)
 			{
-				if (ro_mazeadd_wavept(master, path->layer, x, y, SR_GSTART)) return 1;
+				if (ro_mazeadd_wavept(master, path->layer, x, y, SR_GSTART)) return;
 			}
 		} else if (path->y[0] == path->y[1])
 		{
@@ -1930,7 +1929,7 @@ INTSML ro_mazecreate_wavefront(SRPORT *port)
 			for (y = path->y[0], x = path->x[0];
 				(dx < 0) ? x >= path->x[1] : x <= path->x[1]; x += dx)
 			{
-				if (ro_mazeadd_wavept(master, path->layer, x, y, SR_GSTART)) return 1;
+				if (ro_mazeadd_wavept(master, path->layer, x, y, SR_GSTART)) return;
 			}
 		} else
 		{
@@ -1943,11 +1942,10 @@ INTSML ro_mazecreate_wavefront(SRPORT *port)
 			for (x = path->x[0], y = path->y[0];
 				(dx < 0) ? x >= path->x[1] : x <= path->x[1]; x += dx, y += dy)
 			{
-				if (ro_mazeadd_wavept(master, path->layer, x, y, SR_GSTART)) return 1;
+				if (ro_mazeadd_wavept(master, path->layer, x, y, SR_GSTART)) return;
 			}
 		}
 	}
-	return 0;
 }
 
 SRWAVEPT *ro_mazesearch_wavefront(SRPORT *port, SRLAYER *layer, INTBIG x, INTBIG y)
@@ -1962,7 +1960,7 @@ SRWAVEPT *ro_mazesearch_wavefront(SRPORT *port, SRLAYER *layer, INTBIG x, INTBIG
 	return NOSRWAVEPT;
 }
 
-INTSML ro_mazetest_pt(SRGPT pt, INTBIG code)
+INTBIG ro_mazetest_pt(SRGPT pt, INTBIG code)
 {
 	/* don't check other wavefront points */
 	if (!(pt & SR_GWAVE))
@@ -1986,10 +1984,10 @@ INTSML ro_mazetest_pt(SRGPT pt, INTBIG code)
  *	Will merge the starting point path with the first internal path
  *	if possible.
  */
-INTSML ro_mazefind_paths(SRWAVEPT *wavept, SRPATH *path)
+INTBIG ro_mazefind_paths(SRWAVEPT *wavept, SRPATH *path)
 {
 	INTBIG sx, sy, ex, ey, code, dx, dy, nx, ny;
-	INTSML status, pstart = 0;
+	INTBIG status, pstart = 0;
 	SRLAYER *layer;
 
 	/* Start scan from the first point */
@@ -2361,7 +2359,7 @@ INTSML ro_mazefind_paths(SRWAVEPT *wavept, SRPATH *path)
 	}
 }
 
-INTSML ro_mazeinit_path(SRPORT *port, SRLAYER *layer, SRWAVEPT *wavept, INTBIG x, INTBIG y, INTBIG code)
+INTBIG ro_mazeinit_path(SRPORT *port, SRLAYER *layer, SRWAVEPT *wavept, INTBIG x, INTBIG y, INTBIG code)
 {
 	SRPORT *target, *sport;
 	SRWAVEPT *twavept;
@@ -2401,9 +2399,9 @@ INTSML ro_mazeinit_path(SRPORT *port, SRLAYER *layer, SRWAVEPT *wavept, INTBIG x
 	} else path = NOSRPATH;
 
 	/* now create paths to each target point */
-	if (ro_mazefind_paths(wavept, path))
+	if (ro_mazefind_paths(wavept, path) != SRSUCCESS)
 		return SRERROR;
-	if (ro_mazefind_paths(twavept, path))
+	if (ro_mazefind_paths(twavept, path) != SRSUCCESS)
 		return SRERROR;
 
 	/* now set the target master */
@@ -2432,7 +2430,7 @@ INTSML ro_mazeinit_path(SRPORT *port, SRLAYER *layer, SRWAVEPT *wavept, INTBIG x
 	return SRROUTED;
 }
 
-INTSML ro_mazeexamine_pt(SRPORT *port, SRLAYER *layer, INTBIG x, INTBIG y, INTBIG code)
+INTBIG ro_mazeexamine_pt(SRPORT *port, SRLAYER *layer, INTBIG x, INTBIG y, INTBIG code)
 {
 	/* point is set */
 	if (layer->grids[x][y] & SR_GWAVE)
@@ -2451,13 +2449,13 @@ INTSML ro_mazeexamine_pt(SRPORT *port, SRLAYER *layer, INTBIG x, INTBIG y, INTBI
 	return SRBLOCKED;
 }
 
-INTSML ro_mazeexpand_wavefront(SRPORT *port, INTBIG code)
+INTBIG ro_mazeexpand_wavefront(SRPORT *port, INTBIG code)
 {
 	SRWAVEPT *wavept, *next;
 	SRWAVEPT bwavept;
 	SRLAYER *layer, *blayer;
-	INTBIG x, y, bx, by;
-	INTSML connected, status = SRSUCCESS, found = 0;
+	INTBIG x, y, bx, by, status = SRSUCCESS;
+	BOOLEAN connected, found = FALSE;
 
 	/* begin expansion of all wavepts */
 	/* disconnect wavepts from the port */
@@ -2466,7 +2464,7 @@ INTSML ro_mazeexpand_wavefront(SRPORT *port, INTBIG code)
 
 	for (wavept = port->wavefront; wavept != NOSRWAVEPT ; wavept = next)
 	{
-		connected = 0;
+		connected = FALSE;
 		layer = wavept->layer;
 		if (layer->dir == SRALL || layer->dir == SRHORIPREF)
 		{
@@ -2486,8 +2484,8 @@ INTSML ro_mazeexpand_wavefront(SRPORT *port, INTBIG code)
 						bx = x; by = wavept->y;
 						blayer = layer;
 					}
-					found = 1;
-					connected = 1;
+					found = TRUE;
+					connected = TRUE;
 				} else if (status == SRERROR) return SRERROR;
 			}
 			if (!connected && (x = wavept->x - 1) >= 0)
@@ -2504,8 +2502,8 @@ INTSML ro_mazeexpand_wavefront(SRPORT *port, INTBIG code)
 						bx = x; by = wavept->y;
 						blayer = layer;
 					}
-					found = 1;
-					connected = 1;
+					found = TRUE;
+					connected = TRUE;
 				} else if (status == SRERROR) return SRERROR;
 			}
 		}
@@ -2526,8 +2524,8 @@ INTSML ro_mazeexpand_wavefront(SRPORT *port, INTBIG code)
 						bx = wavept->x; by = y;
 						blayer = layer;
 					}
-					found = 1;
-					connected = 1;
+					found = TRUE;
+					connected = TRUE;
 				} else if (status == SRERROR) return SRERROR;
 			}
 			if (!connected && (y = wavept->y - 1) >= 0)
@@ -2544,8 +2542,8 @@ INTSML ro_mazeexpand_wavefront(SRPORT *port, INTBIG code)
 						bx = wavept->x; by = y;
 						blayer = layer;
 					}
-					found = 1;
-					connected = 1;
+					found = TRUE;
+					connected = TRUE;
 				} else if (status == SRERROR) return SRERROR;
 			}
 		}
@@ -2561,8 +2559,8 @@ INTSML ro_mazeexpand_wavefront(SRPORT *port, INTBIG code)
 					bx = wavept->x; by = wavept->y;
 					blayer = layer->up;
 				}
-				found = 1;
-				connected = 1;
+				found = TRUE;
+				connected = TRUE;
 			} else if (status == SRERROR) return SRERROR;
 		}
 		if (!connected && layer->down != NOSRLAYER)
@@ -2577,8 +2575,8 @@ INTSML ro_mazeexpand_wavefront(SRPORT *port, INTBIG code)
 					bx = wavept->x; by = wavept->y;
 					blayer = layer->down;
 				}
-				found = 1;
-				connected = 1;
+				found = TRUE;
+				connected = TRUE;
 			} else if (status == SRERROR) return SRERROR;
 		}
 		next = wavept->next;
@@ -2614,7 +2612,7 @@ void ro_mazeclear_maze(SRNET *net)
 	SRPORT *port;
 	SRWAVEPT *wavept;
 	INTBIG x, y;
-	INTSML index;
+	INTBIG index;
 
 	/* clear each region, and reset bounds */
 	for (index = 0; index < SRMAXLAYERS; index++)
@@ -2640,11 +2638,11 @@ void ro_mazeclear_maze(SRNET *net)
 	return;
 }
 
-INTSML ro_mazeroute_net(SRNET *net)
+BOOLEAN ro_mazeroute_net(SRNET *net)
 {
-	INTSML index, status;
+	INTBIG index, status;
 	INTBIG pcount, blocked, code, i, prio, x, y, count;
-	INTSML ret = 0;
+	BOOLEAN ret = FALSE;
 	SRLAYER *layer;
 	SRPORT *port;
 	ARCPROTO *ap, *routingarc;
@@ -2707,7 +2705,7 @@ INTSML ro_mazeroute_net(SRNET *net)
 	if (routingarc == NOARCPROTO)
 	{
 		ttyputerr(_("Cannot find wire to route"));
-		return(1);
+		return(TRUE);
 	}
 	ro_mazevertwire = routingarc;
 	ro_mazehoriwire = routingarc;
@@ -2782,7 +2780,7 @@ INTSML ro_mazeroute_net(SRNET *net)
 	do
 	{
 		if (++code > SR_GMAX) code = SR_GSTART;
-		if (stopping(STOPREASONROUTING)) return SRERROR;
+		if (stopping(STOPREASONROUTING)) return(TRUE);
 		for (blocked = 0, port = net->ports; port != NOSRPORT; port = port->next)
 		{
 			/* if part of other wavefront, get the next one */
@@ -2799,7 +2797,7 @@ INTSML ro_mazeroute_net(SRNET *net)
 					mstatus = "unknown";
 				ro_mazedump_layer(mstatus, net->region, (UINTBIG)3);
 			}
-			if (status == SRERROR) return SRERROR;
+			if (status == SRERROR) return(TRUE);
 			if (status == SRROUTED) break;
 			if (status == SRBLOCKED) blocked++;
 		}
@@ -2821,7 +2819,7 @@ INTSML ro_mazeroute_net(SRNET *net)
 			/* check for blocked net */
 			if (blocked == pcount)
 			{
-				ret = 1;
+				ret = TRUE;
 				ro_mazeclear_maze(net);
 				break;
 			}
@@ -2843,8 +2841,8 @@ INTSML ro_mazeroute_net(SRNET *net)
 		port->paths = NOSRPATH;
 		port->lastpath = NOSRPATH;
 	}
-	if (ret == 0) net->routed = 1;
-	return ret;
+	if (!ret) net->routed = TRUE;
+	return(ret);
 }
 
 INTBIG ro_anglediff(INTBIG ang1, INTBIG ang2)
@@ -2866,7 +2864,7 @@ void ro_mazedump_layer(char *message, SRREGION *region, UINTBIG layers)
 {
 	SRLAYER *layer;
 	INTBIG x, y, hei, wid;
-	INTSML index;
+	INTBIG index;
 	UINTBIG mask;
 	char gpt;
 
