@@ -42,11 +42,11 @@
 
 typedef struct Ipossiblearc
 {
-	ARCINST *ai;
-	NODEINST *ni1, *ni2;
-	PORTPROTO *pp1, *pp2;
-	INTBIG x1, y1, x2, y2;
-	INTBIG situation;
+	ARCINST             *ai;
+	NODEINST            *ni1, *ni2;
+	PORTPROTO           *pp1, *pp2;
+	INTBIG               x1, y1, x2, y2;
+	INTBIG               situation;
 	struct Ipossiblearc *nextpossiblearc;
 } POSSIBLEARC;
 
@@ -81,10 +81,10 @@ void ro_freemimicmemory(void)
 }
 
 /*
- * Entry point for mimic router.  Called each "slice".  If "forced" is nonzero,
+ * Entry point for mimic router.  Called each "slice".  If "forced" is true,
  * this mimic operation was explicitly requested.
  */
-void ro_mimicstitch(INTSML forced)
+void ro_mimicstitch(BOOLEAN forced)
 {
 	REGISTER ARCPROTO *ap;
 	REGISTER ARCINST *ai;
@@ -116,9 +116,11 @@ void ro_mimicstitch(INTSML forced)
 		if (ro_mimiccreate(ai) == 0)
 		{
 			/* nothing was wired */
-			if (forced != 0) ttyputmsg(_("No wires mimiced"));
+			if (forced) ttyputmsg(_("No wires mimiced"));
 		}
 		elapsed = endtimer();
+		if (elapsed > 60.0 && (us_useroptions&BEEPAFTERLONGJOB) != 0)
+			ttybeep(1);
 		if ((options&MIMICINTERACTIVE) == 0 && elapsed >= 2.0)
 			ttyputmsg(_("Mimicing took %s"), explainduration(elapsed));
 	}
@@ -177,7 +179,7 @@ void ro_mimicdelete(ARCPROTO *typ, NODEINST **nodes, PORTPROTO **ports)
 
 		/* the same! delete it */
 		startobjectchange((INTBIG)ai, VARCINST);
-		killarcinst(ai);
+		(void)killarcinst(ai);
 		deleted++;
 	}
 	if (deleted != 0)
@@ -196,7 +198,7 @@ INTBIG ro_mimiccreate(ARCINST *ai)
 	REGISTER ARCINST *newai, *oai;
 	REGISTER INTBIG dist, angle, options, count, i, wantx1, wanty1, end, end0offx, end0offy,
 		situation, total, node0wid, node0hei, node1wid, node1hei, wid, w, hei,
-		portpos, oportpos, stopcheck;
+		portpos, oportpos, stopcheck, ifignoreports, ifignorenodetype, ifignorenodesize;
 	INTBIG x0, y0, x1, y1, x0c, y0c, desiredangle, existingangle, thisend, lx, hx, ly, hy;
 	static POLYGON *poly = NOPOLYGON;
 	REGISTER POLYGON *thispoly, **newportpolys;
@@ -256,7 +258,7 @@ INTBIG ro_mimiccreate(ARCINST *ai)
 		for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		{
 			if (pp->temp1 == 0) continue;
-			shapeportpoly(ni, pp, ro_mimicportpolys[i], 0);
+			shapeportpoly(ni, pp, ro_mimicportpolys[i], FALSE);
 			i++;
 		}
 	}
@@ -319,8 +321,8 @@ INTBIG ro_mimiccreate(ARCINST *ai)
 					wantx1 = x0;   wanty1 = y0;
 				} else
 				{
-					wantx1 = x0 + mult(dist, cosine((INTSML)angle));
-					wanty1 = y0 + mult(dist, sine((INTSML)angle));
+					wantx1 = x0 + mult(dist, cosine(angle));
+					wanty1 = y0 + mult(dist, sine(angle));
 				}
 
 				/* now look for another node that matches the situation */
@@ -334,7 +336,12 @@ INTBIG ro_mimiccreate(ARCINST *ai)
 						thispoly = ro_mimicportpolys[oportpos];
 						oportpos++;
 
-						/* ensure that intra-node wirings stay that way */
+						/*
+						 * ensure that intra-node wirings stay that way
+						 *
+						 * it is tempting to move this code outside of the "opp" loop, but
+						 * that breaks the ordering of precached polygons in "ro_mimicportpolys"
+						 */
 						if (node0 == node1)
 						{
 							if (ni != oni) continue;
@@ -347,7 +354,7 @@ INTBIG ro_mimiccreate(ARCINST *ai)
 						if (ni == node0 && pp == port0 && oni == node1 && opp == port1) continue;
 
 						/* see if they are the same distance apart */
-						if (isinside(wantx1, wanty1, thispoly) == 0) continue;
+						if (!isinside(wantx1, wanty1, thispoly)) continue;
 
 						/* see if they are already wired */
 						if (x0 == wantx1 && y0 == wanty1) desiredangle = -1; else
@@ -446,29 +453,39 @@ INTBIG ro_mimiccreate(ARCINST *ai)
 	}
 
 	/* now create the mimiced arcs */
+	ifignoreports = ifignorenodetype = ifignorenodesize = 0;
 	for(i=0; i<NUMSITUATIONS; i++)
 	{
 		/* see if this situation is possible */
+		total = 0;
 		for(pa = firstpossiblearc; pa != NOPOSSIBLEARC; pa = pa->nextpossiblearc)
-			if (pa->situation == situations[i]) break;
-		if (pa == NOPOSSIBLEARC) continue;
+			if (pa->situation == situations[i]) total++;
+		if (total == 0) continue;
 
 		/* see if this situation is desired */
 		if ((options&MIMICINTERACTIVE) == 0)
 		{
 			/* make sure this situation is the desired one */
 			if ((options&MIMICIGNOREPORTS) == 0 && (situations[i]&LIKELYDIFFPORT) != 0)
+			{
+				ifignoreports += total;
 				continue;
+			}
 			if ((options&MIMICIGNORENODETYPE) == 0 && (situations[i]&LIKELYDIFFNODETYPE) != 0)
+			{
+				ifignorenodetype += total;
 				continue;
+			}
 			if ((options&MIMICIGNORENODESIZE) == 0 && (situations[i]&LIKELYDIFFNODESIZE) != 0)
+			{
+				ifignorenodesize += total;
 				continue;
+			}
 		} else
 		{
 			/* show the wires to be created */
 			(void)asktool(us_tool, "down-stack");
 			(void)asktool(us_tool, "clear");
-			total = 0;
 			for(pa = firstpossiblearc; pa != NOPOSSIBLEARC; pa = pa->nextpossiblearc)
 			{
 				if (pa->situation != situations[i]) continue;
@@ -481,7 +498,6 @@ INTBIG ro_mimiccreate(ARCINST *ai)
 				{
 					(void)asktool(us_tool, "show-line", pa->x1, pa->y1, pa->x2, pa->y2, (INTBIG)facet);
 				}
-				total++;
 			}
 			sprintf(question, _("Create %ld %s shown here?"), total, makeplural(_("wire"), total));
 			total = ttygetparam(question, &us_yesnop, 5, pars);
@@ -519,7 +535,18 @@ INTBIG ro_mimiccreate(ARCINST *ai)
 		ro_freepossiblearc(pa);
 	}
 	if (count != 0)
-		ttyputmsg(_("MIMIC ROUTING: added %ld %s"), count, makeplural(_("wire"), count));
+		ttyputmsg(_("MIMIC ROUTING: added %ld %s"), count, makeplural(_("wire"), count)); else
+	{
+		(void)initinfstr();
+		(void)addstringtoinfstr(_("No wires added"));
+		if (ifignoreports != 0)
+			(void)formatinfstr(_(", would add %ld wires if 'ports must match' is off"), ifignoreports);
+		if (ifignorenodetype != 0)
+			(void)formatinfstr(_(", would add %ld wires if 'node types must match' is off"), ifignorenodetype);
+		if (ifignorenodesize != 0)
+			(void)formatinfstr(_(", would add %ld wires if 'nodes sizes must match' is off"), ifignorenodesize);
+		ttyputmsg("%s", returninfstr());
+	}
 	return(count);
 }
 
