@@ -74,8 +74,6 @@
 #include "rout.h"
 #include "tecgen.h"
 
-#define YES           1
-#define NO            0
 #define ROUTEINX      1
 #define ROUTEINY      2
 #define ILLEGALROUTE -1
@@ -96,7 +94,7 @@
 
 typedef struct rivpoint
 {
-	INTSML           side;				/* the side this point is on */
+	INTBIG           side;				/* the side this point is on */
 	INTBIG           x, y;				/* points coordinates */
 	INTBIG           first, second;		/* nonrotated coordinates */
 	struct rivpoint *next;				/* next one in the list */
@@ -127,7 +125,7 @@ typedef struct rpath
 {
 	INTBIG           width;				/* the width of this path */
 	ARCPROTO        *pathtype;			/* the paty type for this wire */
-	INTSML           routetype;			/* how the wire needs to be routed - as above */
+	INTBIG           routetype;			/* how the wire needs to be routed - as above */
 	RPOINT          *pathdesc;			/* the path */
 	RPOINT          *lastp;				/* the last point on the path */
 	struct rpath    *next;
@@ -151,19 +149,16 @@ typedef struct itran
 typedef struct coord
 {
 	INTBIG        val;					/* the coordinate */
-	INTSML        total;				/* number of wires voting for this coordinate */
+	INTBIG        total;				/* number of wires voting for this coordinate */
 	struct coord *next;
 } RCOORD;
 
 /******** VARIABLES ********/
 
-#define CVALID   1
-#define CINVALID 0
-
 typedef struct
 {
 	NODEINST  *topfacet;
-	INTSML     facetvalid;
+	BOOLEAN    facetvalid;
 } MOVEFACET;
 
 static MOVEFACET ro_rrmovefacet;
@@ -178,13 +173,13 @@ typedef struct
 	INTBIG        startleft;			/* where to start wires on the left */
 	INTBIG        height;
 	INTBIG        llx, lly, urx, ury;
-	INTSML        xx;					/*  ROUTEINX route in X direction,
+	INTBIG        xx;					/*  ROUTEINX route in X direction,
 											ROUTEINY route in Y direction */
 	RCOORD       *xaxis, *yaxis;		/* linked list of possible routing coordinates */
 } ROUTEINFO;
 
 static ROUTEINFO ro_rrinfo;
-static INTSML    ro_initialized = 0;
+static BOOLEAN   ro_initialized = FALSE;
 
 static TRANSFORM ro_rrnorot     = { 1,  0,	/* X increasing, y2>y1                */
 									0,  1};
@@ -222,40 +217,40 @@ static COMCOMP ro_riverp = {ro_riveropt, NOTOPLIST, NONEXTLIST, NOPARAMS,
 
 /******** prototypes for local routines ********/
 
-static RPATH *ro_newrpath(INTBIG, ARCPROTO*, INTSML);
+static RPATH *ro_newrpath(INTBIG, ARCPROTO*, INTBIG);
 static void ro_freerpath(RPATH*);
 static RPOINT *ro_newrivpoint(RPATH*, INTBIG, INTBIG, RPOINT*);
-static RPOINT *ro_newrvpoint(INTBIG, INTBIG, INTSML);
+static RPOINT *ro_newrvpoint(INTBIG, INTBIG, INTBIG);
 static void ro_freerivpoint(RPOINT*);
 static RCOORD *ro_newcoord(INTBIG);
-static RDESC *ro_newroutedesc(INTBIG, INTBIG, INTSML, INTBIG, INTBIG, INTSML, ARCINST*, INTBIG, ARCINST*, INTBIG, RDESC*);
+static RDESC *ro_newroutedesc(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, ARCINST*, INTBIG, ARCINST*, INTBIG, RDESC*);
 static void ro_freeroutedesc(RDESC*);
-static RDESC **ro_newrdarray(INTSML);
+static RDESC **ro_newrdarray(INTBIG);
 static void ro_freerdarray(RDESC**);
 static void ro_initialize(void);
 static void ro_clipwire(RPOINT*, INTBIG, INTBIG);
-static INTSML ro_check_points(RDESC*, INTBIG, INTBIG);
+static BOOLEAN ro_check_points(RDESC*, INTBIG, INTBIG);
 static RDESC *ro_addright(RDESC*, RDESC*);
 static RDESC *ro_addleft(RDESC*, RDESC*);
 static void ro_structure_points(RDESC*);
-static INTSML ro_check_structured_points(RDESC*, RDESC*, INTBIG, INTBIG, INTBIG);
+static BOOLEAN ro_check_structured_points(RDESC*, RDESC*, INTBIG, INTBIG, INTBIG);
 static RDESC *ro_reverse(RDESC*);
 static void ro_cleanup(void);
-static INTSML ro_routepathtype(RPOINT*, RPOINT*);
+static INTBIG ro_routepathtype(RPOINT*, RPOINT*);
 static RPATH *ro_makeorigpath(INTBIG, ARCPROTO*, INTBIG, RPOINT*, RPOINT*);
 static RPATH *ro_addpath(RPATH*, INTBIG, ARCPROTO*, RPOINT*, RPOINT*, INTBIG, INTBIG, INTBIG);
 static RPATH *ro_makesideorigpath(INTBIG, ARCPROTO*, INTBIG, RPOINT*, RPOINT*);
 static RPATH *ro_sideaddpath(RPATH*, INTBIG, ARCPROTO*, RPOINT*, RPOINT*, INTBIG, INTBIG, INTBIG);
-static INTSML ro_process_right(INTBIG, ARCPROTO*, RDESC*, INTBIG, INTBIG, INTBIG);
-static INTSML ro_process_left(INTBIG, ARCPROTO*, RDESC*, INTBIG, INTBIG, INTBIG);
+static BOOLEAN ro_process_right(INTBIG, ARCPROTO*, RDESC*, INTBIG, INTBIG, INTBIG);
+static BOOLEAN ro_process_left(INTBIG, ARCPROTO*, RDESC*, INTBIG, INTBIG, INTBIG);
 static void ro_remap_points(RPOINT*, TRANSFORM*);
 static INTBIG ro_remap_second(INTBIG, TRANSFORM*);
 static INTBIG ro_height_coordinate(INTBIG);
-static INTSML ro_calculate_height_and_process(RDESC*, RDESC*, INTBIG, INTBIG, INTBIG, INTBIG*);
+static BOOLEAN ro_calculate_height_and_process(RDESC*, RDESC*, INTBIG, INTBIG, INTBIG, INTBIG*);
 static void ro_calculate_bb(INTBIG*, INTBIG*, INTBIG*, INTBIG*, RDESC*, RDESC*);
-static INTSML ro_sorted_rivrot(ARCPROTO*, RDESC*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+static BOOLEAN ro_sorted_rivrot(ARCPROTO*, RDESC*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 static RDESC *ro_quicksort(RDESC*);
-static INTSML ro_unsorted_rivrot(ARCPROTO*, RDESC*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+static BOOLEAN ro_unsorted_rivrot(ARCPROTO*, RDESC*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 static void ro_checkthefacet(NODEINST*);
 static void ro_pseudomake(RDESC*, NODEPROTO*);
 static void ro_makepseudogeometry(NODEPROTO*);
@@ -263,34 +258,34 @@ static NODEINST *ro_thenode(RDESC*, NODEPROTO*, RPOINT*, NODEPROTO*);
 static PORTPROTO *ro_theport(PORTPROTO*, RDESC*, RPOINT*);
 static void ro_makegeometry(RDESC*, NODEPROTO*);
 static void ro_clear_flags(NODEPROTO*);
-static INTSML ro_isunroutedpin(NODEINST*);
-static INTSML ro_is_interesting_arc(ARCINST*);
+static BOOLEAN ro_isunroutedpin(NODEINST*);
+static BOOLEAN ro_is_interesting_arc(ARCINST*);
 static void ro_set_flags(ARCINST*);
 static void ro_mark_tobedeleted(ARCINST*);
-static INTSML ro_delnodeinst(NODEINST*);
+static BOOLEAN ro_delnodeinst(NODEINST*);
 static void ro_kill_wires(NODEPROTO*);
 static void ro_makethegeometry(NODEPROTO*);
 static RCOORD *ro_tallyvote(RCOORD*, INTBIG);
 static void ro_vote(INTBIG, INTBIG, INTBIG, INTBIG);
-static INTSML ro_simplefigxx(RCOORD*, RCOORD*, RCOORD*, RCOORD*, INTSML, RCOORD**, RCOORD**);
+static INTBIG ro_simplefigxx(RCOORD*, RCOORD*, RCOORD*, RCOORD*, INTBIG, RCOORD**, RCOORD**);
 static RCOORD *ro_largest(RCOORD*);
 static RCOORD *ro_next_largest(RCOORD*, RCOORD*);
-static void ro_figureoutrails(INTSML);
-static INTBIG ro_point_val(RPOINT*, INTSML);
+static void ro_figureoutrails(INTBIG);
+static INTBIG ro_point_val(RPOINT*, INTBIG);
 static void ro_swap_points(RDESC*);
 static void ro_set_wires_to_rails(RDESC*);
-static RDESC *ro_addwire(RDESC*, ARCINST*, INTSML*);
-static RDESC *ro_findhighlightedwires(NODEPROTO*, INTSML*);
-static RDESC *ro_findnormalwires(NODEPROTO*, INTSML*);
-static INTSML ro_findwires(NODEPROTO*);
-static INTSML ro_move_instance(void);
-static INTSML ro_query_user(void);
+static RDESC *ro_addwire(RDESC*, ARCINST*, BOOLEAN*);
+static RDESC *ro_findhighlightedwires(NODEPROTO*, INTBIG*);
+static RDESC *ro_findnormalwires(NODEPROTO*, INTBIG*);
+static BOOLEAN ro_findwires(NODEPROTO*);
+static BOOLEAN ro_move_instance(void);
+static BOOLEAN ro_query_user(void);
 static void ro_sumup(PORTARCINST*);
 static int ro_rivpointascending(const void*, const void*);
 
 /******************** MEMORY MANAGEMENT ROUTINES ****************************/
 
-RPATH *ro_newrpath(INTBIG width, ARCPROTO *ptype, INTSML routetype)
+RPATH *ro_newrpath(INTBIG width, ARCPROTO *ptype, INTBIG routetype)
 {
 	RPATH *rp;
 
@@ -327,7 +322,7 @@ RPOINT *ro_newrivpoint(RPATH *rp, INTBIG first, INTBIG sec, RPOINT *next)
 }
 
 /* called to set up the route */
-RPOINT *ro_newrvpoint(INTBIG x, INTBIG y, INTSML side)
+RPOINT *ro_newrvpoint(INTBIG x, INTBIG y, INTBIG side)
 {
 	RPOINT *rvp;
 
@@ -355,8 +350,8 @@ RCOORD *ro_newcoord(INTBIG c)
 	return(cc);
 }
 
-RDESC *ro_newroutedesc(INTBIG fx, INTBIG fy, INTSML fside, INTBIG sx, INTBIG sy,
-	INTSML sside, ARCINST *ai1, INTBIG ae1, ARCINST *ai2, INTBIG ae2, RDESC *next)
+RDESC *ro_newroutedesc(INTBIG fx, INTBIG fy, INTBIG fside, INTBIG sx, INTBIG sy,
+	INTBIG sside, ARCINST *ai1, INTBIG ae1, ARCINST *ai2, INTBIG ae2, RDESC *next)
 {
 	RDESC *rd;
 
@@ -380,10 +375,10 @@ void ro_freeroutedesc(RDESC *rd)
 	efree((char *)rd);
 }
 
-RDESC **ro_newrdarray(INTSML size)
+RDESC **ro_newrdarray(INTBIG size)
 {
 	RDESC **r;
-	INTSML i;
+	INTBIG i;
 
 	r = (RDESC **)emalloc(((size+1)*sizeof(RDESC *)), ro_tool->cluster);
 	if (r == 0) return(0);
@@ -407,15 +402,15 @@ void ro_initialize(void)
 	ro_rrinfo.startright = -MAXINTBIG;   ro_rrinfo.startleft = -MAXINTBIG;
 	ro_rrinfo.height = -MAXINTBIG;   ro_rrinfo.xx = ILLEGALROUTE;
 
-	if (ro_initialized == 0)
+	if (!ro_initialized)
 	{
-		ro_initialized = 1;
+		ro_initialized = TRUE;
 		ro_rrinfo.xaxis = 0;
 		ro_rrinfo.yaxis = 0;
 	}
 	for(c = ro_rrinfo.xaxis; c; c = c->next) c->total = -1;
 	for(c = ro_rrinfo.yaxis; c; c = c->next) c->total = -1;
-	ro_rrmovefacet.topfacet = NONODEINST;   ro_rrmovefacet.facetvalid = CVALID;
+	ro_rrmovefacet.topfacet = NONODEINST;   ro_rrmovefacet.facetvalid = TRUE;
 }
 
 void ro_freerivermemory(void)
@@ -457,7 +452,7 @@ void ro_clipwire(RPOINT *p, INTBIG b1, INTBIG b2)
 	}
 }
 
-INTSML ro_check_points(RDESC *listp, INTBIG width, INTBIG space)
+BOOLEAN ro_check_points(RDESC *listp, INTBIG width, INTBIG space)
 {
 	RDESC *llist, *listlast;
 	RPOINT *lastfrom, *lastto;
@@ -471,7 +466,7 @@ INTSML ro_check_points(RDESC *listp, INTBIG width, INTBIG space)
 	{
 		/* need at least one point */
 		ttyputerr(_("River router: Not enought points"));
-		return(NO);
+		return(FALSE);
 	}
 
 	listlast = NULLRDESC;
@@ -479,7 +474,7 @@ INTSML ro_check_points(RDESC *listp, INTBIG width, INTBIG space)
 	if (!listlast->from || !listlast->to)
 	{
 		ttyputerr(_("River router: Not the same number of points"));
-		return(NO);	/* not the same number of points */
+		return(FALSE);	/* not the same number of points */
 	}
 
 	/*  decide route orientation */
@@ -518,7 +513,7 @@ INTSML ro_check_points(RDESC *listp, INTBIG width, INTBIG space)
 	} else
 	{
 		ttyputerr(_("River router: Not between two parallel lines"));
-		return(NO);		/* not on manhattan parallel lines */
+		return(FALSE);		/* not on manhattan parallel lines */
 	}
 
 	/* check ordering of coordinates */
@@ -534,7 +529,7 @@ INTSML ro_check_points(RDESC *listp, INTBIG width, INTBIG space)
 				(llist->from->x < llist->next->from->x && llist->to->x > llist->next->to->x))
 			{
 				ttyputerr(_("River router: Connections may not cross"));
-				return(NO);
+				return(FALSE);
 			}
 		} else
 		{
@@ -542,7 +537,7 @@ INTSML ro_check_points(RDESC *listp, INTBIG width, INTBIG space)
 				(llist->from->y < llist->next->from->y && llist->to->y > llist->next->to->y))
 			{
 				ttyputerr(_("River router: Connections may not cross"));
-				return(NO);
+				return(FALSE);
 			}
 		}
 	}
@@ -571,7 +566,7 @@ INTSML ro_check_points(RDESC *listp, INTBIG width, INTBIG space)
 			if (diff1 < width+space)
 			{
 				ttyputerr(_("River router: Ports not design rule distance apart"));
-				return(NO);
+				return(FALSE);
 			}
 		}
 		if (lastto && llist->to->side == SIDE3)
@@ -580,7 +575,7 @@ INTSML ro_check_points(RDESC *listp, INTBIG width, INTBIG space)
 			if (diff2 < width+space)
 			{
 				ttyputerr(_("River router: Ports not design rule distance apart"));
-				return(NO);
+				return(FALSE);
 			}
 		}		/* not far enough apart */
 		lastfrom = ((llist->from->side == SIDE1) ? llist->from : NULLRPOINT);
@@ -594,7 +589,7 @@ INTSML ro_check_points(RDESC *listp, INTBIG width, INTBIG space)
 								/* right now these last terms are not used */
 	ro_rrinfo.origmatrix = tmatrix;   ro_rrinfo.invmatrix = &ro_rrinverse;
 	ro_rrinfo.fromline = val1;   ro_rrinfo.toline = val2;
-	return(YES);
+	return(TRUE);
 }
 
 RDESC *ro_addright(RDESC *r, RDESC *npb)
@@ -626,13 +621,13 @@ void ro_structure_points(RDESC *listr)
 	if (llist) llist->next = NULLRDESC;
 }
 
-INTSML ro_check_structured_points(RDESC *right, RDESC *left, INTBIG co1, INTBIG width, INTBIG space)
+BOOLEAN ro_check_structured_points(RDESC *right, RDESC *left, INTBIG co1, INTBIG width, INTBIG space)
 {
 	RDESC *r, *l;
 	INTBIG fromside1, toside2, fromside2, toside3, toside4;
 	INTBIG botoffs2, botoffs4;
 
-	fromside1 = NO;   toside2 = NO;   botoffs2 = 0;
+	fromside1 = FALSE;   toside2 = FALSE;   botoffs2 = 0;
 
 	/* ensure ordering is correct */
 	for(r = right; r; r = r->next)
@@ -640,18 +635,18 @@ INTSML ro_check_structured_points(RDESC *right, RDESC *left, INTBIG co1, INTBIG
 		switch (r->from->side)
 		{
 			case SIDE1:
-				fromside1 = YES;
+				fromside1 = TRUE;
 				break;
 			default:
 			case SIDE2:
 			case SIDE3:
 				ttyputerr(_("River router: Improper sides for bottom right ports"));
-				return(NO);
+				return(FALSE);
 			case SIDE4:
 				if (fromside1)
 				{
 					ttyputerr(_("River router: Improper ordering of bottom right ports"));
-					return(NO);
+					return(FALSE);
 				}
 				break;
 		}
@@ -661,23 +656,23 @@ INTSML ro_check_structured_points(RDESC *right, RDESC *left, INTBIG co1, INTBIG
 			case SIDE4:
 			default:
 				ttyputerr(_("River router: Improper sides for top right ports"));
-				return(NO);
+				return(FALSE);
 			case SIDE2:
 				if (!toside2) botoffs2 = ro_rrinfo.fromline+co1+(width/2);
 					else botoffs2 += space+width;
-				toside2 = YES;
+				toside2 = TRUE;
 				break;
 			case SIDE3:
 				if (toside2)
 				{
 					ttyputerr(_("River router: Improper ordering of top right ports"));
-					return(NO);
+					return(FALSE);
 				}
 				break;
 		}
 	}
 
-	fromside2 = NO;   toside3 = NO;   toside4 = NO;   botoffs4 = 0;
+	fromside2 = FALSE;   toside3 = FALSE;   toside4 = FALSE;   botoffs4 = 0;
 	for(l = left; l; l = l->next)
 	{
 		switch (l->from->side)
@@ -686,17 +681,17 @@ INTSML ro_check_structured_points(RDESC *right, RDESC *left, INTBIG co1, INTBIG
 				if (fromside2)
 				{
 					ttyputerr(_("River router: Improper Ordering of Bottom Left Ports"));
-					return(NO);
+					return(FALSE);
 				}
 				break;
 			case SIDE2:
-				fromside2 = YES;
+				fromside2 = TRUE;
 				break;
 			case SIDE3:
 			case SIDE4:
 			default:
 				ttyputerr(_("River router: Improper sides for Bottom Left Ports"));
-				return(NO);
+				return(FALSE);
 		}
 		switch (l->to->side)
 		{
@@ -704,9 +699,9 @@ INTSML ro_check_structured_points(RDESC *right, RDESC *left, INTBIG co1, INTBIG
 			case SIDE2:
 			default:
 				ttyputerr(_("River router: Improper sides for Top Left Ports"));
-				return(NO);
+				return(FALSE);
 			case SIDE3:
-				toside3 = YES;
+				toside3 = TRUE;
 				break;
 			case SIDE4:
 				if (!toside3)
@@ -716,9 +711,9 @@ INTSML ro_check_structured_points(RDESC *right, RDESC *left, INTBIG co1, INTBIG
 				} else
 				{
 					ttyputerr(_("River router: Improper Ordering of Top Left Ports"));
-					return(NO);
+					return(FALSE);
 				}
-				toside4 = YES;
+				toside4 = TRUE;
 				break;
 		}
 	}
@@ -727,7 +722,7 @@ INTSML ro_check_structured_points(RDESC *right, RDESC *left, INTBIG co1, INTBIG
 
 	if (botoffs4 == 0) ro_rrinfo.startleft = ro_rrinfo.fromline+co1+(width/2);
 		else	       ro_rrinfo.startleft = botoffs4+space+width;
-	return(YES);
+	return(TRUE);
 }
 
 RDESC *ro_reverse(RDESC *p)
@@ -766,7 +761,7 @@ void ro_cleanup(void)
 /*
  * the type of route for this wire: side to top, bottom to side, bottom to top
  */
-INTSML ro_routepathtype(RPOINT *b, RPOINT *t)
+INTBIG ro_routepathtype(RPOINT *b, RPOINT *t)
 {
 	if (b && t)
 	{
@@ -882,15 +877,15 @@ RPATH *ro_sideaddpath(RPATH *path, INTBIG  width, ARCPROTO *ptype, RPOINT *b, RP
 	return(rp);
 }
 
-INTSML ro_process_right(INTBIG width, ARCPROTO *ptype, RDESC *rout, INTBIG co1, INTBIG space,
+BOOLEAN ro_process_right(INTBIG width, ARCPROTO *ptype, RDESC *rout, INTBIG co1, INTBIG space,
 	INTBIG dir)
 {
-	INTSML firsttime;
+	BOOLEAN firsttime;
 	RDESC *reversedrd, *rd;
 	RPATH *lastp;
 	INTBIG offset;
 
-	firsttime = YES;   lastp = NULLRPATH;   offset = ro_rrinfo.startleft;
+	firsttime = TRUE;   lastp = NULLRPATH;   offset = ro_rrinfo.startleft;
 
 	for(rd = reversedrd = ro_reverse(rout); rd; rd = rd->next)
 	{
@@ -900,39 +895,39 @@ INTSML ro_process_right(INTBIG width, ARCPROTO *ptype, RDESC *rout, INTBIG co1,
 			if (firsttime)
 			{
 				rd->path = ro_makeorigpath(width, ptype, co1, rd->from, rd->to);
-				if (rd->path == 0) return(1);
-				firsttime = NO;
+				if (rd->path == 0) return(TRUE);
+				firsttime = FALSE;
 			} else
 				rd->path = ro_addpath(lastp, width, ptype, rd->from, rd->to, space, co1, dir);
-			if (rd->path == 0) return(1);
+			if (rd->path == 0) return(TRUE);
 		} else
 		{
 			if (firsttime)
 			{
 				rd->path = ro_makesideorigpath(width, ptype, offset, rd->from, rd->to);
-				if (rd->path == 0) return(1);
-				firsttime = NO;
+				if (rd->path == 0) return(TRUE);
+				firsttime = FALSE;
 			} else
 			{
 				rd->path = ro_sideaddpath(lastp, width, ptype, rd->from, rd->to, space, offset, dir);
-				if (rd->path == 0) return(1);
+				if (rd->path == 0) return(TRUE);
 			}
 			offset += space+width;
 		}
 		lastp = rd->path;
 	}
 	(void)ro_reverse(reversedrd);  /* return to normal */
-	return(0);
+	return(FALSE);
 }
 
-INTSML ro_process_left(INTBIG width, ARCPROTO *ptype, RDESC *rout, INTBIG co1, INTBIG space,
+BOOLEAN ro_process_left(INTBIG width, ARCPROTO *ptype, RDESC *rout, INTBIG co1, INTBIG space,
 	INTBIG dir)
 {
-	INTSML firsttime;
+	BOOLEAN firsttime;
 	RPATH *lastp;
 	INTBIG offset;
 
-	firsttime = YES; lastp = NULLRPATH; offset = ro_rrinfo.startright;
+	firsttime = TRUE; lastp = NULLRPATH; offset = ro_rrinfo.startright;
 	for(; rout; rout = rout->next)
 	{
 		if (rout->from->side != SIDE2)
@@ -940,29 +935,29 @@ INTSML ro_process_left(INTBIG width, ARCPROTO *ptype, RDESC *rout, INTBIG co1, I
 			if (firsttime)
 			{
 				rout->path = ro_makeorigpath(width, ptype, co1, rout->from, rout->to);
-				if (rout->path == 0) return(1);
-				firsttime = NO;
+				if (rout->path == 0) return(TRUE);
+				firsttime = FALSE;
 			} else
 			rout->path = ro_addpath(lastp, width, ptype, rout->from, rout->to, space, co1, dir);
-			if (rout->path == 0) return(1);
+			if (rout->path == 0) return(TRUE);
 		} else
 		{
 			if (firsttime)
 			{
 				rout->path = ro_makesideorigpath(width, ptype, offset, rout->from, rout->to);
-				if (rout->path == 0) return(1);
-				firsttime = NO;
+				if (rout->path == 0) return(TRUE);
+				firsttime = FALSE;
 			} else
 			{
 				rout->path = ro_sideaddpath(lastp, width, ptype, rout->from, rout->to, space,
 					offset, dir);
-				if (rout->path == 0) return(1);
+				if (rout->path == 0) return(TRUE);
 			}
 			offset += space+width;
 		}
 		lastp = rout->path;
 	}
-	return(0);
+	return(FALSE);
 }
 
 /*
@@ -992,7 +987,7 @@ INTBIG ro_height_coordinate(INTBIG h)
 	return(h+ro_rrinfo.fromline);
 }
 
-INTSML ro_calculate_height_and_process(RDESC *right, RDESC *left, INTBIG width, INTBIG co2,
+BOOLEAN ro_calculate_height_and_process(RDESC *right, RDESC *left, INTBIG width, INTBIG co2,
 	INTBIG minheight, INTBIG *height)
 {
 	INTBIG maxheight;
@@ -1017,7 +1012,7 @@ INTSML ro_calculate_height_and_process(RDESC *right, RDESC *left, INTBIG width,
 		if (lastp->side != SIDE2)
 		{
 			lastp->next = ro_newrivpoint(rright->path, lastp->first, maxheight, NULLRPOINT);
-			if (lastp->next == 0) return(NO);
+			if (lastp->next == 0) return(FALSE);
 		}
 		ro_remap_points(rright->path->pathdesc, ro_rrinfo.invmatrix);
 	}
@@ -1027,14 +1022,14 @@ INTSML ro_calculate_height_and_process(RDESC *right, RDESC *left, INTBIG width,
 		if (lastp->side != SIDE4)
 		{
 			lastp->next = ro_newrivpoint(lleft->path, lastp->first, maxheight, NULLRPOINT);
-			if (lastp->next == 0) return(NO);
+			if (lastp->next == 0) return(FALSE);
 		}
 		ro_remap_points(lleft->path->pathdesc, ro_rrinfo.invmatrix);
 	}
 	ro_rrinfo.toline = ro_remap_second(ro_rrinfo.toline, ro_rrinfo.invmatrix);
 	ro_rrinfo.fromline = ro_remap_second(ro_rrinfo.fromline, ro_rrinfo.invmatrix);
 	*height = ro_remap_second(maxheight,ro_rrinfo.invmatrix);
-	return(YES);
+	return(TRUE);
 }
 
 void ro_calculate_bb(INTBIG *llx, INTBIG *lly, INTBIG *urx, INTBIG *ury, RDESC *right, RDESC *left)
@@ -1071,32 +1066,32 @@ void ro_calculate_bb(INTBIG *llx, INTBIG *lly, INTBIG *urx, INTBIG *ury, RDESC *
  * takes two sorted list of ports and routes between them
  * warning - if the width is not even, there will be round off problems
  */
-INTSML ro_sorted_rivrot(ARCPROTO *layerdesc, RDESC *listr, INTBIG width,
+BOOLEAN ro_sorted_rivrot(ARCPROTO *layerdesc, RDESC *listr, INTBIG width,
 	INTBIG space, INTBIG facetoff1, INTBIG facetoff2, INTBIG fixedheight)
 {
 	INTBIG height;
 
 	/* ports invalid */
-	if (!ro_check_points(listr, width, space)) return(NO);
+	if (!ro_check_points(listr, width, space)) return(FALSE);
 	ro_structure_points(listr);				/* put in left/right */
 	if (!ro_check_structured_points(ro_rrinfo.rightp, ro_rrinfo.leftp, facetoff1, width, space))
-		return(NO);
-	if (ro_process_right(width, layerdesc, ro_rrinfo.rightp, facetoff1, space, -1) != 0) return(NO);
-	if (ro_process_left(width, layerdesc, ro_rrinfo.leftp, facetoff1, space, 1) != 0) return(NO);
+		return(FALSE);
+	if (ro_process_right(width, layerdesc, ro_rrinfo.rightp, facetoff1, space, -1)) return(FALSE);
+	if (ro_process_left(width, layerdesc, ro_rrinfo.leftp, facetoff1, space, 1)) return(FALSE);
 	if (fixedheight != 0) fixedheight = ro_height_coordinate(fixedheight);
-	if (ro_calculate_height_and_process(ro_rrinfo.rightp, ro_rrinfo.leftp, width, facetoff2,
-		fixedheight, &height) == NO) return(NO);
+	if (!ro_calculate_height_and_process(ro_rrinfo.rightp, ro_rrinfo.leftp, width, facetoff2,
+		fixedheight, &height)) return(FALSE);
 	if (fixedheight > 0 && height > fixedheight)
 	{
 		/* can't make it in fixed height */
 		ttyputerr(_("River router: Unable to route in %s wide channel, need %s"), latoa(fixedheight),
 			latoa(height));
-		return(NO);
+		return(FALSE);
 	}
 	ro_calculate_bb(&ro_rrinfo.llx, &ro_rrinfo.lly, &ro_rrinfo.urx, &ro_rrinfo.ury,
 		ro_rrinfo.rightp, ro_rrinfo.leftp);
 	ro_rrinfo.height = height;
-	return(YES);
+	return(TRUE);
 }
 
 /*
@@ -1121,9 +1116,9 @@ RDESC *ro_quicksort(RDESC *rd)
 	for(len = 0, r = rd; r; len++, r = r->next)
 		;
 	if (len == 0) return(NULLRDESC);
-	thearray = ro_newrdarray((INTSML)len);
+	thearray = ro_newrdarray(len);
 	if (thearray == 0) return(NULLRDESC);
-	xdir = (ro_rrinfo.xx == ROUTEINX ? NO : YES);
+	xdir = (ro_rrinfo.xx == ROUTEINX ? FALSE : TRUE);
 
 	for(i=0; rd; i++, rd = rd->next)
 	{
@@ -1142,7 +1137,7 @@ RDESC *ro_quicksort(RDESC *rd)
  * takes two unsorted list of ports and routes between them
  * warning - if the width is not even, there will be round off problems
  */
-INTSML ro_unsorted_rivrot(ARCPROTO *layerdesc, RDESC *lists, INTBIG width,
+BOOLEAN ro_unsorted_rivrot(ARCPROTO *layerdesc, RDESC *lists, INTBIG width,
 	INTBIG space, INTBIG facetoff1, INTBIG facetoff2, INTBIG fixedheight)
 {
 	return(ro_sorted_rivrot(layerdesc, ro_quicksort(lists), width, space,
@@ -1157,10 +1152,10 @@ void ro_checkthefacet(NODEINST *ni)
 	if (ni->proto->primindex == 0)
 	{
 		/* the node is nonprimitive */
-		if (ro_rrmovefacet.facetvalid == CINVALID) return;
+		if (!ro_rrmovefacet.facetvalid) return;
 		if (ro_rrmovefacet.topfacet == NONODEINST)  /* first one */
 			ro_rrmovefacet.topfacet = ni;
-		else if (ro_rrmovefacet.topfacet != ni) ro_rrmovefacet.facetvalid = CINVALID;
+		else if (ro_rrmovefacet.topfacet != ni) ro_rrmovefacet.facetvalid = FALSE;
 	}
 }
 
@@ -1289,26 +1284,26 @@ void ro_clear_flags(NODEPROTO *np)
 }
 
 /*
- * routine to return nonzero if nodeinst "ni" is an unrouted pin
+ * routine to return true if nodeinst "ni" is an unrouted pin
  */
-INTSML ro_isunroutedpin(NODEINST *ni)
+BOOLEAN ro_isunroutedpin(NODEINST *ni)
 {
 	/* only want the unrouted pin */
-	if (ni->proto != gen_unroutedpinprim && ni->proto != gen_univpinprim) return(NO);
+	if (ni->proto != gen_unroutedpinprim && ni->proto != gen_univpinprim) return(FALSE);
 
 	/* found one */
-	return(YES);
+	return(TRUE);
 }
 
-INTSML ro_is_interesting_arc(ARCINST *ai)
+BOOLEAN ro_is_interesting_arc(ARCINST *ai)
 {
 	/* skip arcs already considered */
-	if (ai->temp1 != 0) return(NO);
+	if (ai->temp1 != 0) return(FALSE);
 
 	/* only want "unrouted" arc in generic technology */
-	if (ai->proto != gen_unroutedarc) return(NO);
+	if (ai->proto != gen_unroutedarc) return(FALSE);
 
-	return(YES);
+	return(TRUE);
 }
 
 void ro_set_flags(ARCINST *ai)
@@ -1322,7 +1317,7 @@ void ro_mark_tobedeleted(ARCINST *ai)
 {
 	PORTARCINST *pi;
 	ARCINST *oai, *ae;
-	INTSML e;
+	INTBIG e;
 
 	if (!ro_is_interesting_arc(ai)) return;
 
@@ -1357,18 +1352,18 @@ void ro_mark_tobedeleted(ARCINST *ai)
 	}
 }
 
-INTSML ro_delnodeinst(NODEINST *ni)
+BOOLEAN ro_delnodeinst(NODEINST *ni)
 {
 	REGISTER PORTARCINST *pi;
 
 	/* see if any arcs connect to this node */
 	for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 	{
-		if (pi->conarcinst != NOARCINST) return(NO);
+		if (pi->conarcinst != NOARCINST) return(FALSE);
 	}
 
 	/* see if this nodeinst is a portinst of the facet */
-	if (ni->firstportexpinst != NOPORTEXPINST) return(NO);
+	if (ni->firstportexpinst != NOPORTEXPINST) return(FALSE);
 
 	/* now erase the nodeinst */
 	startobjectchange((INTBIG)ni, VNODEINST);
@@ -1465,7 +1460,7 @@ void ro_vote(INTBIG ffx, INTBIG ffy, INTBIG ttx, INTBIG tty)
 	ro_rrinfo.yaxis = ro_tallyvote(ro_rrinfo.yaxis, tty);
 }
 
-INTSML ro_simplefigxx(RCOORD *x1, RCOORD *x2, RCOORD *y1, RCOORD *y2, INTSML total, RCOORD **from,
+INTBIG ro_simplefigxx(RCOORD *x1, RCOORD *x2, RCOORD *y1, RCOORD *y2, INTBIG total, RCOORD **from,
 	RCOORD **to)
 {
 	*from = NULLCOORD;   *to = NULLCOORD;
@@ -1515,7 +1510,7 @@ RCOORD *ro_next_largest(RCOORD *cc, RCOORD *largest)
 	return(nlargest);
 }
 
-void ro_figureoutrails(INTSML total)
+void ro_figureoutrails(INTBIG total)
 {
 	INTBIG fxx;
 	RCOORD *lx, *ly, *nlx, *nly, *from, *to, *tmp;
@@ -1551,11 +1546,11 @@ void ro_figureoutrails(INTSML total)
 		tmp = from;   from = to;   to = tmp;
 	}
 
-	ro_rrinfo.xx = (INTSML)fxx;
+	ro_rrinfo.xx = fxx;
 	ro_rrinfo.fromline = from->val;   ro_rrinfo.toline = to->val;
 }
 
-INTBIG ro_point_val(RPOINT *rp, INTSML xx)
+INTBIG ro_point_val(RPOINT *rp, INTBIG xx)
 {
 	return(xx == ROUTEINX ? rp->x : rp->y);
 }
@@ -1596,19 +1591,19 @@ void ro_set_wires_to_rails(RDESC *lists)
 /*
  * figure out the wires to route at all
  */
-RDESC *ro_addwire(RDESC *list, ARCINST *ai, INTSML *wireadded)
+RDESC *ro_addwire(RDESC *list, ARCINST *ai, BOOLEAN *wireadded)
 {
 	PORTARCINST *pi;
 	ARCINST *oai, *ae1, *ae2;
-	INTSML e1, e2;
+	INTBIG e1, e2;
 	INTBIG bx, by, ex, ey;
 
 	if (!ro_is_interesting_arc(ai))
 	{
-		*wireadded = NO;
+		*wireadded = FALSE;
 		return(list);
 	}
-	*wireadded = YES;
+	*wireadded = TRUE;
 
 	ai->temp1++;
 	ae1 = ai;   e1 = 0;
@@ -1650,12 +1645,13 @@ RDESC *ro_addwire(RDESC *list, ARCINST *ai, INTSML *wireadded)
 	return(list);
 }
 
-RDESC *ro_findhighlightedwires(NODEPROTO *np, INTSML *tot)
+RDESC *ro_findhighlightedwires(NODEPROTO *np, INTBIG *tot)
 {
 	RDESC *thelist;
 	GEOM **list;
 	ARCINST *ai;
-	INTSML i, total, wireadded;
+	INTBIG i, total;
+	BOOLEAN wireadded;
 
 	/* get list of all highlighted arcs */
 	list = (GEOM **)asktool(us_tool, "get-all-arcs");
@@ -1688,13 +1684,13 @@ RDESC *ro_findhighlightedwires(NODEPROTO *np, INTSML *tot)
 	return(thelist);
 }
 
-RDESC *ro_findnormalwires(NODEPROTO *np, INTSML *tot)
+RDESC *ro_findnormalwires(NODEPROTO *np, INTBIG *tot)
 {
 	REGISTER ARCINST *ai;
-	REGISTER INTSML total;
+	REGISTER INTBIG total;
 	RDESC *thelist;
 	INTBIG llx, lly, urx, ury;
-	INTSML wireadded;
+	BOOLEAN wireadded;
 
 	thelist = NULLRDESC;   llx = lly = MAXINTBIG;   urx = ury = -MAXINTBIG;
 	total = 0;
@@ -1719,14 +1715,14 @@ RDESC *ro_findnormalwires(NODEPROTO *np, INTSML *tot)
 	return(thelist);
 }
 
-INTSML ro_findwires(NODEPROTO *np)
+BOOLEAN ro_findwires(NODEPROTO *np)
 {
 	REGISTER ARCPROTO *ap, *wantap;
 	REGISTER TECHNOLOGY *tech, *curtech;
 	REGISTER INTBIG amt;
 	static POLYGON *poly = NOPOLYGON;
 	REGISTER ARCINST *ai;
-	INTSML total;
+	INTBIG total;
 	INTBIG edge;
 	RDESC *thelist;
 	REGISTER VARIABLE *var;
@@ -1735,7 +1731,7 @@ INTSML ro_findwires(NODEPROTO *np)
 	if (np->primindex != 0)
 	{
 		ttyputerr(_("River router cannot route primitives"));
-		return(NO);
+		return(FALSE);
 	}
 
 	curtech = np->tech;
@@ -1749,7 +1745,7 @@ INTSML ro_findwires(NODEPROTO *np)
 	if (!(thelist = ro_findhighlightedwires(np, &total)))
 		thelist = ro_findnormalwires(np, &total);
 
-	if (!thelist) return(NO);
+	if (!thelist) return(FALSE);
 
 	/* first look for the current arcproto */
 	wantap = NOARCPROTO;
@@ -1787,7 +1783,7 @@ INTSML ro_findwires(NODEPROTO *np)
 	if (wantap == NOARCPROTO)
 	{
 		ttyputerr(_("River router: Cannot find arc that will connect"));
-		return(NO);
+		return(FALSE);
 	}
 	ttyputmsg(_("River routing with %s arcs"), describearcproto(wantap));
 
@@ -1802,67 +1798,62 @@ INTSML ro_findwires(NODEPROTO *np)
 	(void)arcpolys(ai, NOWINDOWPART);
 	shapearcpoly(ai, 0, poly);
 	amt = drcmindistance(ai->proto->tech, np->cell->lib, poly->layer, ai->width,
-		poly->layer, ai->width, 0, 0, &edge, 0);
+		poly->layer, ai->width, FALSE, FALSE, &edge, 0);
 	if (amt < 0) amt = lambdaofarc(ai);
 	return(ro_unsorted_rivrot(wantap, thelist, ai->width, amt, amt, amt, 0));
 }
 
-INTSML ro_move_instance(void)
+BOOLEAN ro_move_instance(void)
 {
 	INTBIG lx, ly;
 	NODEINST *ni;
 
 	ni = ro_rrmovefacet.topfacet;
-	if (ro_rrmovefacet.facetvalid != CVALID || ni == NONODEINST)
+	if (!ro_rrmovefacet.facetvalid || ni == NONODEINST)
 	{
 		ttyputmsg(_("River router: Cannot determine facet to move"));
-		return(NO);
+		return(FALSE);
 	}
 
 	lx = (ro_rrinfo.xx == ROUTEINX ? ro_rrinfo.height + ni->lowx - ro_rrinfo.toline : ni->lowx);
 	ly = (ro_rrinfo.xx == ROUTEINY ? ro_rrinfo.height + ni->lowy - ro_rrinfo.toline : ni->lowy);
-	if (lx == ni->lowx && ly == ni->lowy) return(YES);
+	if (lx == ni->lowx && ly == ni->lowy) return(TRUE);
 	startobjectchange((INTBIG)ni, VNODEINST);
 	modifynodeinst(ni, lx - ni->lowx, ly - ni->lowy, lx - ni->lowx, ly - ni->lowy, 0, 0);
 	endobjectchange((INTBIG)ni, VNODEINST);
-	return(YES);
+	return(TRUE);
 }
 
-INTSML ro_query_user(void)
+BOOLEAN ro_query_user(void)
 {
 	char *par[MAXPARS];
-	INTSML count;
+	INTBIG count;
 
 	/* wait for user response */
 	for(;;)
 	{
 		count = ttygetparam(_("River-route option: "), &ro_riverp, MAXPARS, par);
 		if (count == 0) continue;
-		switch (par[0][0])
+		if (par[0][0] == 'r') break;
+		if (par[0][0] == 'm')
 		{
-			case 'r':
-				return(YES);
-			case 'm':
-				if (ro_move_instance()) return(YES);
-				continue;
-			case 'a':
-				return(NO);
-			default:
-				continue;
+			if (ro_move_instance()) return(TRUE);
 		}
+		if (par[0][0] == 'a') return(FALSE);
 	}
+	return(TRUE);
 }
 
-INTSML ro_river(NODEPROTO *np)
+BOOLEAN ro_river(NODEPROTO *np)
 {
-	INTSML valid_route;
+	BOOLEAN valid_route;
 	RDESC *q;
 
 	/* locate wires */
 	if (ro_findwires(np))
 	{
 		/* see if user selection is requested */
-		valid_route = YES;
+		valid_route = TRUE;
 		if ((ro_state&SELECT) == 0)
 		{
 			/* make wires */
@@ -1872,26 +1863,26 @@ INTSML ro_river(NODEPROTO *np)
 				ro_checkthefacet(q->unroutedwire2->end[q->unroutedend2].nodeinst);
 
 			/* if there is motion to be done, do it */
-			if (ro_rrmovefacet.facetvalid == CVALID && ro_rrmovefacet.topfacet != NONODEINST)
+			if (ro_rrmovefacet.facetvalid && ro_rrmovefacet.topfacet != NONODEINST)
 			{
 				if (ro_move_instance()) ro_makethegeometry(np); else
-					valid_route = NO;
+					valid_route = FALSE;
 			} else ro_makethegeometry(np);
 		} else
 		{
 			/* show where wires will go and allow user confirmation */
 			ro_makepseudogeometry(np);
 			if (ro_query_user()) ro_makethegeometry(np); else
-				valid_route = NO;
+				valid_route = FALSE;
 		}
-	} else valid_route = NO;
+	} else valid_route = FALSE;
 	ro_cleanup();
 	return(valid_route);
 }
 
 void ro_sumup(PORTARCINST *pi)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 
 	/*
 	 * for every layer (or arcproto) that this PORT allows to connect to it,
