@@ -29,7 +29,7 @@
  */
 
 #include "config.h"
-#if SCAID
+#if SCTOOL
 
 #include	"global.h"
 #include	"sc1.h"
@@ -43,19 +43,19 @@
 extern SCCELL	*sc_cells, *sc_curcell;
 
 /* prototypes for local routines */
-int Sc_free_cell(SCCELL*);
-int Sc_free_string(char*);
-int Sc_free_port(SCPORT*);
-int Sc_free_instance(SCNITREE*);
-int Sc_free_instance_port(SCNIPORT*);
-int Sc_free_extracted_node(SCEXTNODE*);
-int Sc_free_row(SCROWLIST*);
-int Sc_free_place(SCNBPLACE*);
-int Sc_free_route_channel(SCROUTECHANNEL*);
-int Sc_free_channel_node(SCROUTECHNODE*);
-int Sc_free_channel_track(SCROUTETRACK*);
-int Sc_free_route_row(SCROUTEROW*);
-int Sc_free_route_node(SCROUTENODE*);
+static int Sc_free_cell(SCCELL*);
+static int Sc_free_string(char*);
+static int Sc_free_port(SCPORT*);
+static int Sc_free_instance(SCNITREE*);
+static int Sc_free_instance_port(SCNIPORT*);
+static int Sc_free_extracted_node(SCEXTNODE*);
+static int Sc_free_row(SCROWLIST*);
+static int Sc_free_place(SCNBPLACE*);
+static int Sc_free_route_channel(SCROUTECHANNEL*);
+static int Sc_free_channel_node(SCROUTECHNODE*);
+static int Sc_free_channel_track(SCROUTETRACK*);
+static int Sc_free_route_row(SCROUTEROW*);
+static int Sc_free_route_node(SCROUTENODE*);
 
 /***********************************************************************
 Module:  Sc_delete
@@ -629,4 +629,4 @@ int Sc_free_route_node(SCROUTENODE *node)
 	return(SC_NOERROR);
 }
 
-#endif  /* SCAID - at top */
+#endif  /* SCTOOL - at top */
