@@ -35,6 +35,7 @@
 #include "efunction.h"
 #include "edialogs.h"
 #include "sc1.h"
+#include "usr.h"
 
 /***********************************************************************
 	Global Variables
@@ -90,8 +91,8 @@ void sc_init(INTBIG *argc, char *argv[], TOOL *thistool)
 	if ((sc_silkey = makekey("SC_silos")) == -1)
 		ttyputmsg("ERROR making SILOS key in SC Tool.");
 	DiaDeclareHook("silcomp", &sc_makep, sc_optionsdlog);
-	sc_filetypescsim = setupfiletype("", "*.*", MACFSTAG('TEXT'), 0, "scsim", _("QUISC simulation"));
-	sc_filetypesctab = setupfiletype("", "*.*", MACFSTAG('TEXT'), 0, "sctab", _("QUISC table"));
+	sc_filetypescsim = setupfiletype("", "*.*", MACFSTAG('TEXT'), FALSE, "scsim", _("QUISC simulation"));
+	sc_filetypesctab = setupfiletype("", "*.*", MACFSTAG('TEXT'), FALSE, "sctab", _("QUISC table"));
 }
 
 /***********************************************************************
@@ -107,7 +108,7 @@ void sc_slice(void)
 {
 	el_pleasestop = 0;
 	Sc_main();
-	toolturnoff(sc_tool, 0);
+	toolturnoff(sc_tool, FALSE);
 }
 
 /***********************************************************************
@@ -118,10 +119,9 @@ Description:
 ------------------------------------------------------------------------
 */
 
-INTSML sc_set(INTSML count, char *pars[])
+void sc_set(INTBIG count, char *pars[])
 {
 	Sc_one_command(count, pars);
-	return(1);
 }
 
 /***********************************************************************
@@ -888,8 +888,8 @@ type		int			Returned type.
 
 int Sc_leaf_port_type(char *leafport)
 {
-	if (portispower((PORTPROTO *)leafport) != 0) return(SCPWRPORT);
-	if (portisground((PORTPROTO *)leafport) != 0) return(SCGNDPORT);
+	if (portispower((PORTPROTO *)leafport)) return(SCPWRPORT);
+	if (portisground((PORTPROTO *)leafport)) return(SCGNDPORT);
 
 	switch (((PORTPROTO *)leafport)->userbits & STATEBITS)
 	{
@@ -1285,7 +1285,7 @@ char  *Sc_create_leaf_facet(char *name)
 		(void) strcat (layoutname, "{lay}");
 	}
 
-	bfacet = newnodeproto(layoutname, el_curlib);
+	bfacet = us_newnodeproto(layoutname, el_curlib);
 	if (bfacet == NONODEPROTO) return((char *)NULL);
 	return((char *)bfacet);
 }
@@ -1319,11 +1319,11 @@ char  *Sc_create_leaf_instance(char *name, char *type, int minx, int maxx, int m
 	NODEINST	*binst;
 	REGISTER VARIABLE *var;
 
-	binst = newnodeinst((NODEPROTO *)type, minx, maxx, miny, maxy, (INTSML)transpose,
-		(INTSML)rotation, (NODEPROTO *)parent);
+	binst = newnodeinst((NODEPROTO *)type, minx, maxx, miny, maxy, transpose,
+		rotation, (NODEPROTO *)parent);
 	if (binst == NONODEINST) return((char *)NULL);
 
-	var = setvalkey((INTBIG)binst, VNODEINST, el_node_name, (INTBIG)name, VSTRING|VDISPLAY);
+	var = setvalkey((INTBIG)binst, VNODEINST, el_node_name_key, (INTBIG)name, VSTRING|VDISPLAY);
 	if (var == NOVARIABLE)
 	{
 		ttyputmsg(_("ERROR creating name of instance '%s'."), name);
@@ -1845,7 +1845,7 @@ void sc_optionsdlog(void)
 	}
 
 	/* display the silicon compiler options dialog box */
-	if (DiaInitDialog(&sc_optionsdialog) != 0) return;
+	if (DiaInitDialog(&sc_optionsdialog)) return;
 	for(i=0; i<2; i++) transnames[i] = _(powerarcnames[i]);
 	DiaSetPopup(DSCO_MPOWERARC, 2, transnames);
 	DiaSetPopup(DSCO_VERTARCS, numarcnames, arcnames);
