@@ -29,7 +29,7 @@
  */
 
 #include "config.h"
-#if SCAID
+#if SCTOOL
 
 #define MAINPWRLAYER2 1
 
@@ -59,9 +59,9 @@ static char *sc_makerblerb[] =
 ------------------------------------------------------------------------
 */
 
-#define DEFAULT_VERBOSE				1		/* verbose default */
+#define DEFAULT_VERBOSE				0		/* verbose default */
 
-int sc_makerverbose = DEFAULT_VERBOSE;
+static int sc_makerverbose = DEFAULT_VERBOSE;
 
 /***********************************************************************
 	External Variables
@@ -71,12 +71,12 @@ int sc_makerverbose = DEFAULT_VERBOSE;
 extern SCCELL		*sc_curcell;
 
 /* prototypes for local routines */
-int  Sc_maker_set_control(int, char*[]);
-void Sc_maker_show_control(void);
-int  Sc_maker_create_info(SCCELL*);
-int  Sc_maker_set_up(SCCELL*, SCMAKERDATA**);
-int  Sc_maker_create_layout(SCMAKERDATA*);
-void Sc_free_maker_data(SCMAKERDATA*);
+static int  Sc_maker_set_control(int, char*[]);
+static void Sc_maker_show_control(void);
+static int  Sc_maker_create_info(SCCELL*);
+static int  Sc_maker_set_up(SCCELL*, SCMAKERDATA**);
+static int  Sc_maker_create_layout(SCMAKERDATA*);
+static void Sc_free_maker_data(SCMAKERDATA*);
 
 /***********************************************************************
 Module:  Sc_maker
@@ -113,6 +113,7 @@ int Sc_maker(int count, char *pars[])
 		}
 		if (namesamen(pars[0], "information", l) == 0)
 		{
+			/* EMPTY */ 
 		} else
 		{
 			return(Sc_seterrmsg(SC_MAKE_XCMD, pars[0]));
@@ -222,7 +223,12 @@ int Sc_maker_set_control(int count, char *pars[])
 			if (namesamen(pars[numcmd], "main-power-rail", n) == 0)
 			{
 				if (++numcmd < count)
-					ScSetParameter(SC_PARAM_MAKE_MAIN_PWR_RAIL, atoi(pars[numcmd]));
+				{
+					if (namesame(pars[numcmd], "horizontal") == 0)
+						ScSetParameter(SC_PARAM_MAKE_MAIN_PWR_RAIL, 0);
+					if (namesame(pars[numcmd], "vertical") == 0)
+						ScSetParameter(SC_PARAM_MAKE_MAIN_PWR_RAIL, 1);
+				}
 				continue;
 			}
 			if (namesamen(pars[numcmd], "via-size", n) == 0)
@@ -328,35 +334,35 @@ void Sc_maker_show_control(void)
 	char *str1;
 	static char *hv[3] = {N_("Horizontal"), N_("Vertical")};
 
-	ttyputverbose(M_("************ MAKER CONTROL STRUCTURE"));
+	ttyputmsg(M_("************ MAKER CONTROL STRUCTURE"));
 	if (sc_makerverbose) str1 = M_("TRUE"); else
 		str1 = M_("FALSE");
-	ttyputverbose(M_("Verbose output           =  %s"), str1);
-	ttyputverbose(M_("Minimum metal spacing    =  %d"),
+	ttyputmsg(M_("Verbose output           =  %s"), str1);
+	ttyputmsg(M_("Minimum metal spacing    =  %d"),
 		ScGetParameter(SC_PARAM_MAKE_MIN_SPACING));
-	ttyputverbose(M_("Via Size                 =  %d"),
+	ttyputmsg(M_("Via Size                 =  %d"),
 		ScGetParameter(SC_PARAM_MAKE_VIA_SIZE));
-	ttyputverbose(M_("Horizontal (layer 1) arc =  '%s'"),
+	ttyputmsg(M_("Horizontal (layer 1) arc =  '%s'"),
 		describearcproto((ARCPROTO *)ScGetParameter(SC_PARAM_MAKE_HORIZ_ARC)));
-	ttyputverbose(M_("Vertical (layer 2) arc   =  '%s'"),
+	ttyputmsg(M_("Vertical (layer 2) arc   =  '%s'"),
 		describearcproto((ARCPROTO *)ScGetParameter(SC_PARAM_MAKE_VERT_ARC)));
-	ttyputverbose(M_("Layer 1 Track width      =  %d"),
+	ttyputmsg(M_("Layer 1 Track width      =  %d"),
 		ScGetParameter(SC_PARAM_MAKE_L1_WIDTH));
-	ttyputverbose(M_("Layer 2 Track width      =  %d"),
+	ttyputmsg(M_("Layer 2 Track width      =  %d"),
 		ScGetParameter(SC_PARAM_MAKE_L2_WIDTH));
-	ttyputverbose(M_("Power Track width        =  %d"),
+	ttyputmsg(M_("Power Track width        =  %d"),
 		ScGetParameter(SC_PARAM_MAKE_PWR_WIDTH));
-	ttyputverbose(M_("Main Power Bus width     =  %d"),
+	ttyputmsg(M_("Main Power Bus width     =  %d"),
 		ScGetParameter(SC_PARAM_MAKE_MAIN_PWR_WIDTH));
-	ttyputverbose(M_("Main Power Bus rail      =  %s"),
+	ttyputmsg(M_("Main Power Bus rail      =  %s"),
 		hv[ScGetParameter(SC_PARAM_MAKE_MAIN_PWR_RAIL)]);
-	ttyputverbose(M_("P-well size (0 for none) =  %d"),
+	ttyputmsg(M_("P-well size (0 for none) =  %d"),
 		ScGetParameter(SC_PARAM_MAKE_PWELL_SIZE));
-	ttyputverbose(M_("P-well offset (bottom)   =  %d"),
+	ttyputmsg(M_("P-well offset (bottom)   =  %d"),
 		ScGetParameter(SC_PARAM_MAKE_PWELL_OFFSET));
-	ttyputverbose(M_("N-well size (0 for none) =  %d"),
+	ttyputmsg(M_("N-well size (0 for none) =  %d"),
 		ScGetParameter(SC_PARAM_MAKE_NWELL_SIZE));
-	ttyputverbose(M_("N-well offset (bottom)   =  %d"),
+	ttyputmsg(M_("N-well offset (bottom)   =  %d"),
 		ScGetParameter(SC_PARAM_MAKE_NWELL_OFFSET));
 }
 
@@ -390,7 +396,7 @@ int Sc_maker_create_info(SCCELL *cell)
 	int num_channels, num_tracks, track_length;
 
 	info = NULL;
-	info = (SCMAKERINFO *)emalloc(sizeof(SCMAKERINFO), sc_aid->cluster);
+	info = (SCMAKERINFO *)emalloc(sizeof(SCMAKERINFO), sc_tool->cluster);
 	if (info == 0)
 		return(Sc_seterrmsg(SC_NOMEMORY));
 
@@ -470,22 +476,19 @@ int Sc_maker_create_info(SCCELL *cell)
 	ttyputmsg(M_("    X size             = %10d  (microns)"), info->x_size / 2000);
 	ttyputmsg(M_("    Y size             = %10d  (microns)"), info->y_size / 2000);
 	ttyputmsg(M_("    Area               = %10d  (square microns)"), info->area);
-	if (sc_makerverbose)
-	{
-		ttyputmsg(M_("Limits (in microns):"));
-		ttyputmsg(M_("    Minimum X position =  %d"), info->min_x / 2000);
-		ttyputmsg(M_("    Maximim X position =  %d"), info->max_x / 2000);
-		ttyputmsg(M_("    Minimum Y position =  %d"), info->min_y / 2000);
-		ttyputmsg(M_("    Maximim Y position =  %d"), info->max_y / 2000);
-		ttyputmsg(M_("Numbers of Elements:"));
-		ttyputmsg(M_("    Base Cells         =  %d"), info->num_leaf_cells);
-		ttyputmsg(M_("    Feed Throughs      =  %d"), info->num_feeds);
-		ttyputmsg(M_("    Rows of cells      =  %d"), info->num_rows);
-		ttyputmsg(M_("    Routing Channels   =  %d"), info->num_channels);
-		ttyputmsg(M_("    Routing Tracks     =  %d"), info->num_tracks);
-		ttyputmsg(M_("    Total Track Length =  %d  (microns)"),
-			info->track_length / 2000);
-	}
+	ttyputmsg(M_("Limits (in microns):"));
+	ttyputmsg(M_("    Minimum X position =  %d"), info->min_x / 2000);
+	ttyputmsg(M_("    Maximim X position =  %d"), info->max_x / 2000);
+	ttyputmsg(M_("    Minimum Y position =  %d"), info->min_y / 2000);
+	ttyputmsg(M_("    Maximim Y position =  %d"), info->max_y / 2000);
+	ttyputmsg(M_("Numbers of Elements:"));
+	ttyputmsg(M_("    Base Cells         =  %d"), info->num_leaf_cells);
+	ttyputmsg(M_("    Feed Throughs      =  %d"), info->num_feeds);
+	ttyputmsg(M_("    Rows of cells      =  %d"), info->num_rows);
+	ttyputmsg(M_("    Routing Channels   =  %d"), info->num_channels);
+	ttyputmsg(M_("    Routing Tracks     =  %d"), info->num_tracks);
+	ttyputmsg(M_("    Total Track Length =  %d  (microns)"),
+		info->track_length / 2000);
 
 	efree((char *)info);
 	return(SC_NOERROR);
@@ -534,7 +537,7 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 	int			deltay;
 
 	/* create top level data structure */
-	data = (SCMAKERDATA *)emalloc(sizeof(SCMAKERDATA), sc_aid->cluster);
+	data = (SCMAKERDATA *)emalloc(sizeof(SCMAKERDATA), sc_tool->cluster);
 	if (data == 0)
 		return(Sc_seterrmsg(SC_NOMEMORY));
 	data->cell = cell;
@@ -559,7 +562,7 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 	{
 
 		/* create Maker Channel structute */
-		mchan = (SCMAKERCHANNEL *)emalloc(sizeof(SCMAKERCHANNEL), sc_aid->cluster);
+		mchan = (SCMAKERCHANNEL *)emalloc(sizeof(SCMAKERCHANNEL), sc_tool->cluster);
 		if (mchan == 0)
 			return(Sc_seterrmsg(SC_NOMEMORY));
 		mchan->number = chan->number;
@@ -583,7 +586,7 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 		ypos = 0;
 		for (track = chan->tracks; track; track = track->next)
 		{
-			mtrack = (SCMAKERTRACK *)emalloc(sizeof(SCMAKERTRACK), sc_aid->cluster);
+			mtrack = (SCMAKERTRACK *)emalloc(sizeof(SCMAKERTRACK), sc_tool->cluster);
 			if (mtrack == 0)
 				return(Sc_seterrmsg(SC_NOMEMORY));
 			mtrack->number = track->number;
@@ -626,7 +629,8 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 						tr1_port = tr1_port->next;
 						if (tr1_port == NULL)
 						{
-							if ((tr1_mem = tr1_mem->next))
+							tr1_mem = tr1_mem->next;
+							if (tr1_mem)
 								tr1_port = tr1_mem->node->firstport;
 						}
 					} else
@@ -634,7 +638,8 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 						tr2_port = tr2_port->next;
 						if (tr2_port == NULL)
 						{
-							if ((tr2_mem = tr2_mem->next))
+							tr2_mem = tr2_mem->next;
+							if (tr2_mem)
 								tr2_port = tr2_mem->node->firstport;
 						}
 					}
@@ -656,7 +661,7 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 	for (row = cell->placement->rows; row; row = row->next)
 	{
 		/* create maker row data structure */
-		mrow = (SCMAKERROW *)emalloc(sizeof(SCMAKERROW), sc_aid->cluster);
+		mrow = (SCMAKERROW *)emalloc(sizeof(SCMAKERROW), sc_tool->cluster);
 		if (mrow == 0)
 			return(Sc_seterrmsg(SC_NOMEMORY));
 		mrow->number = row->row_num;
@@ -697,7 +702,7 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 			if (place->cell->type != SCLEAFCELL &&
 				place->cell->type != SCFEEDCELL &&
 				place->cell->type != SCLATERALFEED) continue;
-			minst = (SCMAKERINST *)emalloc(sizeof(SCMAKERINST), sc_aid->cluster);
+			minst = (SCMAKERINST *)emalloc(sizeof(SCMAKERINST), sc_tool->cluster);
 			if (minst == 0)
 				return(Sc_seterrmsg(SC_NOMEMORY));
 			minst->place = place;
@@ -712,7 +717,7 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 				/* add power ports */
 				for (iport = place->cell->power; iport; iport = iport->next)
 				{
-					power_port = (SCMAKERPOWERPORT *)emalloc(sizeof(SCMAKERPOWERPORT), sc_aid->cluster);
+					power_port = (SCMAKERPOWERPORT *)emalloc(sizeof(SCMAKERPOWERPORT), sc_tool->cluster);
 					if (power_port == 0)
 						return(Sc_seterrmsg(SC_NOMEMORY));
 					power_port->inst = minst;
@@ -733,7 +738,7 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 						if (plist->ypos == port_ypos) break;
 					}
 					if (!plist) {
-						plist = (SCMAKERPOWER *)emalloc(sizeof(SCMAKERPOWER), sc_aid->cluster);
+						plist = (SCMAKERPOWER *)emalloc(sizeof(SCMAKERPOWER), sc_tool->cluster);
 						if (plist == 0)
 						{
 							return(Sc_seterrmsg(SC_NOMEMORY));
@@ -786,7 +791,7 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 				/* add ground ports */
 				for (iport = place->cell->ground; iport; iport = iport->next)
 				{
-					power_port = (SCMAKERPOWERPORT *)emalloc(sizeof(SCMAKERPOWERPORT), sc_aid->cluster);
+					power_port = (SCMAKERPOWERPORT *)emalloc(sizeof(SCMAKERPOWERPORT), sc_tool->cluster);
 					if (power_port == 0)
 						return(Sc_seterrmsg(SC_NOMEMORY));
 					power_port->inst = minst;
@@ -808,7 +813,7 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 					}
 					if (!plist)
 					{
-						plist = (SCMAKERPOWER *)emalloc(sizeof(SCMAKERPOWER), sc_aid->cluster);
+						plist = (SCMAKERPOWER *)emalloc(sizeof(SCMAKERPOWER), sc_tool->cluster);
 						if (plist == 0)
 							return(Sc_seterrmsg(SC_NOMEMORY));
 						plist->ports = NULL;
@@ -910,7 +915,7 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 			mtrack->ypos = ypos;
 			for (mem = mtrack->track->nodes; mem; mem = mem->next)
 			{
-				mnode = (SCMAKERNODE *)emalloc(sizeof(SCMAKERNODE), sc_aid->cluster);
+				mnode = (SCMAKERNODE *)emalloc(sizeof(SCMAKERNODE), sc_tool->cluster);
 				if (mnode == 0)
 					return(Sc_seterrmsg(SC_NOMEMORY));
 				mnode->vias = NULL;
@@ -920,7 +925,7 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 				for (chport = mem->node->firstport; chport;
 					chport = chport->next)
 				{
-					mvia = (SCMAKERVIA *)emalloc(sizeof(SCMAKERVIA), sc_aid->cluster);
+					mvia = (SCMAKERVIA *)emalloc(sizeof(SCMAKERVIA), sc_tool->cluster);
 					if (mvia == 0)
 						return(Sc_seterrmsg(SC_NOMEMORY));
 					mvia->xpos = chport->xpos;
@@ -1583,4 +1588,4 @@ void Sc_free_maker_data(SCMAKERDATA *data)
 	}
 }
 
-#endif  /* SCAID - at top */
+#endif  /* SCTOOL - at top */
