@@ -29,7 +29,7 @@
  */
 
 #include "config.h"
-#if SCAID
+#if SCTOOL
 
 #include "global.h"
 #include "sc1.h"
@@ -39,17 +39,17 @@ extern SCCELL	*sc_cells, *sc_curcell;
 int sc_sim_format = SC_SILOS_FORMAT;
 
 /* prototypes for local routines */
-int Sc_simformat(int, char*[]);
-int Sc_simset(int, char*[]);
-int Sc_simshow(int, char*[]);
-int Sc_simwrite(int, char*[]);
-void Sc_simwrite_clear_flags(void);
-int Sc_simwrite_model(SCCELL*, char*, FILE*);
-int Sc_simwrite_subelements(SCNITREE*, FILE*);
-int Sc_simwrite_cell_instances(SCCELL*, FILE*);
-char *Sc_sim_isaport(SCCELL*, char*);
-int Sc_simwrite_gate(char*, FILE*);
-void Sc_fprintf_80(FILE *fp, char *fstring, ...);
+static int   Sc_simformat(int, char*[]);
+static int   Sc_simset(int, char*[]);
+static int   Sc_simshow(int, char*[]);
+static int   Sc_simwrite(int, char*[]);
+static void  Sc_simwrite_clear_flags(void);
+static int   Sc_simwrite_model(SCCELL*, char*, FILE*);
+static int   Sc_simwrite_subelements(SCNITREE*, FILE*);
+static int   Sc_simwrite_cell_instances(SCCELL*, FILE*);
+static char *Sc_sim_isaport(SCCELL*, char*);
+static int   Sc_simwrite_gate(char*, FILE*);
+static void  Sc_fprintf_80(FILE *fp, char *fstring, ...);
 
 /***********************************************************************
 Module:  Sc_simulation
@@ -184,7 +184,7 @@ int Sc_simset(int count, char *pars[])
 		i = strlen(buffer);
 		if (buffer[i-1] == '\n') buffer[i-1] = '\0';
 		/* buffer[strlen(buffer) - 1] = NULL; */	/* strip off newline */
-		simline = (SCSIM *)emalloc(sizeof(SCSIM), sc_aid->cluster);
+		simline = (SCSIM *)emalloc(sizeof(SCSIM), sc_tool->cluster);
 		if (simline == 0)
 			return(Sc_seterrmsg(SC_NOMEMORY));
 		if (oldline)
@@ -194,7 +194,7 @@ int Sc_simset(int count, char *pars[])
 		{
 			startline = simline;
 		}
-		if (allocstring(&simline->model, buffer, sc_aid->cluster))
+		if (allocstring(&simline->model, buffer, sc_tool->cluster))
 			return(Sc_seterrmsg(SC_NOMEMORY));
 		simline->next = NULL;
 		oldline = simline;
@@ -786,7 +786,7 @@ void Sc_fprintf_80(FILE *fp, char *fstring, ...)
 	va_list		ap;
 
 	var_start(ap, fstring);
-	(void)vsprintf(buff, fstring, ap);
+	evsnprintf(buff, 256, fstring, ap);
 	va_end(ap);
 	length = strlen(buff);
 	sptr = buff;
@@ -831,4 +831,4 @@ void Sc_fprintf_80(FILE *fp, char *fstring, ...)
 	}
 }
 
-#endif  /* SCAID - at top */
+#endif  /* SCTOOL - at top */
