@@ -44,7 +44,6 @@ static void      simals_print_out_entry(ROWPTR);
 static void      simals_print_xref_entry(CONPTR, INTBIG);
 static char     *simals_strengthstring(INTSML);
 static void      simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib);
-static INTSML    simals_fgets(char *line, INTSML limit, FILE *file);
 static void      simals_sdfannotate(CONPTR cellhead);
 static NODEINST *simals_getcellinstance(char *celltype, char *instance);
 static void      simals_sdfportdelay(CONPTR cellhead, NODEINST *ni, char *path);
@@ -54,7 +53,7 @@ static void      simals_order_save(void);
 static void      simals_order_restore(char *list);
 static void      simals_update_netlist(void);
 static char     *simals_parent_level(char *child);
-static INTSML    simals_get_tdindex(char *name);
+static INTBIG    simals_get_tdindex(char *name);
 
 /* local variables */
 static DELAY_TYPES simals_sdfdelaytype;
@@ -69,7 +68,7 @@ typedef struct Iactelparam
 {
 	char               *paramname;
 	PARAMTYPE           paramtype;
-	INTSML              duplicate;
+	BOOLEAN             duplicate;
 	struct Iactelparam *next;
 } ACTELPARAM;
 
@@ -82,10 +81,10 @@ typedef struct Iactelparam
  *	This procedure reads an Actel table file and creates a library with
  * ALS-netlist facets.
  */
-void simals_build_actel_command(INTSML count, char *par[])
+void simals_build_actel_command(INTBIG count, char *par[])
 {
 	FILE *io;
-	INTSML len, i, filecount;
+	INTBIG len, i, filecount;
 	char *filename, line[MAXCHRS], **filelist;
 	REGISTER char *pt, *start;
 	static INTBIG filetypeacteltab = -1;
@@ -112,7 +111,7 @@ void simals_build_actel_command(INTSML count, char *par[])
 		(void)addstringtoinfstr(filelist[i]);
 		pt = returninfstr();
 		if (filetypeacteltab < 0)
-			filetypeacteltab = setupfiletype("tab", "*.tab", MACFSTAG('TEXT'), 0, "actel", M_("QuickPartTable"));
+			filetypeacteltab = setupfiletype("tab", "*.tab", MACFSTAG('TEXT'), FALSE, "actel", M_("QuickPartTable"));
 		io = xopen(pt, filetypeacteltab, "", &filename);
 		if (io == 0)
 		{
@@ -121,7 +120,7 @@ void simals_build_actel_command(INTSML count, char *par[])
 		}
 		for(;;)
 		{
-			if (simals_fgets(line, MAXCHRS, io) != 0) break;
+			if (xfgets(line, MAXCHRS, io) != 0) break;
 			pt = line;
 			while (*pt == ' ' || *pt == '\t') pt++;
 			if (*pt == 0 || *pt == '#') continue;
@@ -143,7 +142,8 @@ void simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib)
 	char line[MAXCHRS];
 	REGISTER char *pt, *start, save, *facetname;
 	REGISTER NODEPROTO *np;
-	INTSML statetablestate, doinginput, edgesense, fourstate;
+	INTBIG statetablestate;
+	BOOLEAN doinginput, edgesense, fourstate;
 	ACTELPARAM *ap, *lastap, *inputlist, *outputlist, *paramlist, *paramtail, *nextap, *newap;
 	void *sa;
 
@@ -160,7 +160,7 @@ void simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib)
 	statetablestate = 0;
 	for(;;)
 	{
-		if (simals_fgets(line, MAXCHRS, io) != 0) break;
+		if (xfgets(line, MAXCHRS, io) != 0) break;
 
 		/* find the first keyword */
 		pt = line;
@@ -178,7 +178,7 @@ void simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib)
 			{
 				/* get state table header */
 				statetablestate = 2;
-				doinginput = 1;
+				doinginput = TRUE;
 				paramtail = 0;
 				for(;;)
 				{
@@ -187,7 +187,7 @@ void simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib)
 					while (*pt != 0 && *pt != ' ' && *pt != '\t' && *pt != ',' && *pt != ';' &&
 						*pt != ':') pt++;
 					save = *pt;   *pt = 0;
-					if (doinginput != 0)
+					if (doinginput)
 					{
 						/* search input list for this one */
 						lastap = 0;
@@ -211,7 +211,7 @@ void simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib)
 							if (newap == 0) return;
 							(void)allocstring(&newap->paramname, ap->paramname, sim_tool->cluster);
 							newap->paramtype = ap->paramtype;
-							newap->duplicate = 1;
+							newap->duplicate = TRUE;
 							ap = newap;
 						} else
 						{
@@ -242,7 +242,7 @@ void simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib)
 							if (newap == 0) return;
 							(void)allocstring(&newap->paramname, ap->paramname, sim_tool->cluster);
 							newap->paramtype = ap->paramtype;
-							newap->duplicate = 1;
+							newap->duplicate = TRUE;
 							ap = newap;
 						} else
 						{
@@ -259,7 +259,7 @@ void simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib)
 					*pt = save;
 					while (*pt == ' ' || *pt == '\t') pt++;
 					if (*pt == ';') break;
-					if (*pt == ':') { pt += 2;   doinginput = 0;   continue; }
+					if (*pt == ':') { pt += 2;   doinginput = FALSE;   continue; }
 					if (*pt == ',') { pt++;   continue; }
 					ttyputerr(M_("In model %s, missing comma in Actel symbol list"), name);
 					return;
@@ -272,7 +272,7 @@ void simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib)
 				(void)addstringtoinfstr("(");
 				for(ap = paramlist; ap != 0; ap = ap->next)
 				{
-					if (ap->duplicate != 0) continue;
+					if (ap->duplicate) continue;
 					if (ap != paramlist) (void)addstringtoinfstr(", ");
 					(void)addstringtoinfstr(ap->paramname);
 				}
@@ -316,19 +316,19 @@ void simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib)
 		}
 
 		/* handle "edge_sense" prefix */
-		edgesense = 0;
+		edgesense = FALSE;
 		if (namesamen(pt, "edge_sense", 10) == 0)
 		{
-			edgesense = 1;
+			edgesense = TRUE;
 			pt += 10;
 			while (*pt == ' ' || *pt == '\t') pt++;
 		}
 
 		/* handle "four_state" prefix */
-		fourstate = 0;
+		fourstate = FALSE;
 		if (namesamen(pt, "four_state", 10) == 0)
 		{
-			fourstate = 1;
+			fourstate = TRUE;
 			pt += 10;
 			while (*pt == ' ' || *pt == '\t') pt++;
 		}
@@ -346,9 +346,9 @@ void simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib)
 				ap = (ACTELPARAM *)emalloc(sizeof (ACTELPARAM), sim_tool->cluster);
 				if (ap == 0) break;
 				(void)allocstring(&ap->paramname, start, sim_tool->cluster);
-				if (edgesense != 0) ap->paramtype = edgesenseinputparam; else
+				if (edgesense) ap->paramtype = edgesenseinputparam; else
 					ap->paramtype = inputparam;
-				ap->duplicate = 0;
+				ap->duplicate = FALSE;
 				ap->next = inputlist;
 				inputlist = ap;
 				*pt = save;
@@ -375,7 +375,7 @@ void simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib)
 				if (ap == 0) break;
 				(void)allocstring(&ap->paramname, start, sim_tool->cluster);
 				ap->paramtype = outputparam;
-				ap->duplicate = 0;
+				ap->duplicate = FALSE;
 				ap->next = outputlist;
 				outputlist = ap;
 				*pt = save;
@@ -401,9 +401,9 @@ void simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib)
 				ap = (ACTELPARAM *)emalloc(sizeof (ACTELPARAM), sim_tool->cluster);
 				if (ap == 0) break;
 				(void)allocstring(&ap->paramname, start, sim_tool->cluster);
-				if (fourstate != 0) ap->paramtype = fourstatebiputparam; else
+				if (fourstate) ap->paramtype = fourstatebiputparam; else
 					ap->paramtype = bidirparam;
-				ap->duplicate = 0;
+				ap->duplicate = FALSE;
 				ap->next = inputlist;
 				inputlist = ap;
 				*pt = save;
@@ -450,33 +450,11 @@ void simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib)
 		ttyputerr(M_("Cannot create facet %s"), facetname);
 		return;
 	}
-	stringarraytotextfacet(sa, np, 1);
+	stringarraytotextfacet(sa, np, TRUE);
 	killstringarray(sa);
 	ttyputmsg(M_("Created %s"), describenodeproto(np));
 }
 
-INTSML simals_fgets(char *line, INTSML limit, FILE *file)
-{
-	REGISTER char *pt;
-	REGISTER INTSML c, total;
-
-	pt = line;
-	total = 1;
-	for(;;)
-	{
-		c = xgetc(file);
-		if (c == EOF)
-		{
-			if (pt == line) return(1);
-			break;
-		}
-		if (c == '\n' || c == '\r') break;
-		*pt++ = (char)c;
-		if ((++total) >= limit) break;
-	}
-	return(*pt = 0);
-}
-
 /****************************** CLOCK ******************************/
 
 /*
@@ -487,18 +465,18 @@ INTSML simals_fgets(char *line, INTSML limit, FILE *file)
  * event list.  The user is polled for the node name and timing parameters
  * before any entry is made into the linklist.
  */
-void simals_clock_command(INTSML count, char *par[])
+void simals_clock_command(INTBIG count, char *par[])
 {
-	float    time;
+	double   time, totaltime;
 	NODEPTR  nodehead;
 	NODEPROTO *np;
 	LINKPTR  vectptr1, vectptr2, sethead;
 	ROWPTR   clokhead;
-	float    linear, totaltime;
+	float    linear;
 	LINKPTR  vectroot;
 	char     **vectptr;
-	INTSML    strength, l, i;
-	INTBIG    num;
+	INTSML    strength;
+	INTBIG    num, l, i;
 
 	if (sim_window_isactive(&np) == 0)
 	{
@@ -534,7 +512,7 @@ void simals_clock_command(INTSML count, char *par[])
 			ttyputusage("telltool simulation als clock NODENAME frequency/period PERIOD");
 			return;
 		}
-		time = (float)atof(par[2]);
+		time = atof(par[2]);
 		if (time <= 0.0)
 		{
 			ttyputerr(M_("Clock timing parameter must be greater than 0"));
@@ -567,7 +545,7 @@ void simals_clock_command(INTSML count, char *par[])
 		if (clokhead == 0) return;
 		clokhead->inptr = (IOPTR)vectptr1;
 		clokhead->outptr = 0;
-		clokhead->delta = time;
+		clokhead->delta = (float)time;
 		clokhead->linear = 0.0;
 		clokhead->exp = 0.0;
 		clokhead->abs = 0.0;
@@ -585,7 +563,7 @@ void simals_clock_command(INTSML count, char *par[])
 		sethead->right = 0;
 		simals_insert_set_list(sethead);
 
-		simals_initialize_simulator(0);
+		(void)simals_initialize_simulator(FALSE);
 		return;
 	}
 
@@ -618,7 +596,7 @@ void simals_clock_command(INTSML count, char *par[])
 		vectptr2->state = simals_trans_state_to_number(par[i]);
 		vectptr2->strength = strength;
 		vectptr2->priority = 1;
-		vectptr2->time = (float)atof(par[i+1]);
+		vectptr2->time = atof(par[i+1]);
 		totaltime += vectptr2->time;
 		vectptr2->right = 0;
 		*vectptr = (char*) vectptr2;
@@ -630,7 +608,7 @@ void simals_clock_command(INTSML count, char *par[])
 	if (clokhead == 0) return;
 	clokhead->inptr = (IOPTR) vectroot;
 	clokhead->outptr = 0;
-	clokhead->delta = totaltime;
+	clokhead->delta = (float)totaltime;
 	clokhead->linear = linear;
 	clokhead->exp = 0.0;
 	clokhead->abs = 0.0;
@@ -648,7 +626,7 @@ void simals_clock_command(INTSML count, char *par[])
 	sethead->right = 0;
 	simals_insert_set_list(sethead);
 
-	simals_initialize_simulator(0);
+	(void)simals_initialize_simulator(FALSE);
 }
 
 /****************************** ERASE ******************************/
@@ -670,7 +648,7 @@ void simals_erase_model(void)
 	simals_linkback = 0;
 
 	/* loop through all test vectors */
-	simals_clearallvectors(1);
+	simals_clearallvectors(TRUE);
 
 	/* loop throuth all cells in flattened network */
 	if (simals_cellroot != 0)
@@ -865,9 +843,9 @@ void simals_erase_model(void)
 
 /*
  * Routine to clear all test vectors (even the power and ground vectors if "pwrgnd"
- * is nonzero).
+ * is true).
  */
-void simals_clearallvectors(INTSML pwrgnd)
+void simals_clearallvectors(BOOLEAN pwrgnd)
 {
 	LINKPTR thisset, vecthead, nextvec, nextset, lastset;
 	ROWPTR clokhead;
@@ -876,7 +854,7 @@ void simals_clearallvectors(INTSML pwrgnd)
 	for(thisset = simals_setroot; thisset != 0; thisset = nextset)
 	{
 		nextset = thisset->right;
-		if (pwrgnd != 0 || thisset->strength != VDD_STRENGTH)
+		if (pwrgnd || thisset->strength != VDD_STRENGTH)
 		{
 			if (thisset->type == 'C')
 			{
@@ -935,9 +913,9 @@ void simals_erase_submod(CONPTR conhead)
  * keyboard.  The maximum execution time must also be specified for the
  * simulation run.
  */
-void simals_go_command(INTSML count, char *par[])
+void simals_go_command(INTBIG count, char *par[])
 {
-	float max;
+	double max;
 	NODEPROTO *np;
 
 	if (sim_window_isactive(&np) == 0)
@@ -950,7 +928,7 @@ void simals_go_command(INTSML count, char *par[])
 		ttyputerr(M_("Must specify simulation time"));
 		return;
 	}
-	max = (float)atof(par[0]);
+	max = atof(par[0]);
 	if (max <= 0.0)
 	{
 		ttyputerr(M_("Simulation time must be greater than 0 seconds"));
@@ -958,7 +936,7 @@ void simals_go_command(INTSML count, char *par[])
 	}
 	sim_window_settimerange(0.0, max);
 
-	simals_initialize_simulator(1);
+	(void)simals_initialize_simulator(TRUE);
 }
 
 /****************************** HELP ******************************/
@@ -977,65 +955,33 @@ void simals_help_command(void)
 /****************************** LEVEL ******************************/
 
 /*
- * Name: simals_level_command
+ * Name: simals_level_up_command
  *
  * Description:
- *	This procedure changes the level of hierarchy that is displayed by the
- * graphics routines.
+ *	This procedure changes the level of hierarchy up one level.
  */
-void simals_level_command(INTSML count, char *par[])
+void simals_level_up_command(void)
 {
 	CONPTR  cellptr;
-	INTSML   l;
-	float mintime, maxtime, maintime, exttime;
-	char    *pt;
+	INTBIG   l;
+	double mintime, maxtime, maintime, exttime;
 	NODEPROTO *np;
-	extern COMCOMP sim_alslevelsp;
 
 	if (sim_window_isactive(&np) == 0)
 	{
 		ttyputerr(_("No simulator active"));
 		return;
 	}
-	if (count < 1)
+
+	if (simals_levelptr == 0)
 	{
-		ttyputusage("telltool simulation als level OPTION");
+		ttyputerr(_("No simulation is running"));
 		return;
 	}
-
-	l = strlen(pt = par[0]);
-	if (namesamen(pt, "up", l) == 0)
+	cellptr = simals_levelptr->parent;
+	if (! cellptr)
 	{
-		if (simals_levelptr == 0)
-		{
-			ttyputerr(_("No simulation is running"));
-			return;
-		}
-		cellptr = simals_levelptr->parent;
-		if (! cellptr)
-		{
-			ttyputerr(_("ERROR: Currently at top level of hierarchy"));
-			return;
-		}
-	} else if (namesamen(pt, "set", l) == 0)
-	{
-		if (count < 2)
-		{
-			count = ttygetparam(M_("Instance to simulate: "), &sim_alslevelsp, 3, &par[1]) + 1;
-			if (count < 2) return;
-		}
-		for(pt = par[1]; *pt != 0; pt++) if (*pt == ' ') break;
-		*pt = 0;
-		simals_convert_to_upper(par[1]);
-		cellptr = simals_find_level(par[1]);
-		if (! cellptr)
-		{
-			ttyputerr(M_("ERROR: Unable to find level %s"), par[1]);
-			return;
-		}
-	} else
-	{
-		ttyputbadusage("telltool simulation als level");
+		ttyputerr(_("ERROR: Currently at top level of hierarchy"));
 		return;
 	}
 
@@ -1045,7 +991,7 @@ void simals_level_command(INTSML count, char *par[])
 	sim_window_gettimerange(&mintime, &maxtime);
 	maintime = sim_window_getmaincursor();
 	exttime = sim_window_getextensioncursor();
-	if (simals_set_current_level() != 0) return;
+	if (simals_set_current_level()) return;
 	sim_window_settimerange(mintime, maxtime);
 	sim_window_setmaincursor(maintime);
 	sim_window_setextensioncursor(exttime);
@@ -1053,7 +999,54 @@ void simals_level_command(INTSML count, char *par[])
 	l = simals_levelptr->num_chn;
 	sim_window_setlines(l);
 	sim_window_settopline(0);
-	simals_initialize_simulator(1);
+	(void)simals_initialize_simulator(TRUE);
+}
+
+/*
+ * Name: simals_level_set_command
+ *
+ * Description:
+ *	This procedure changes the level of hierarchy to a specified new (lower) level.
+ */
+void simals_level_set_command(char *instname)
+{
+	CONPTR  cellptr;
+	INTBIG   l;
+	double mintime, maxtime, maintime, exttime;
+	char    *pt;
+	NODEPROTO *np;
+
+	if (sim_window_isactive(&np) == 0)
+	{
+		ttyputerr(_("No simulator active"));
+		return;
+	}
+
+	for(pt = instname; *pt != 0; pt++) if (*pt == ' ') break;
+	*pt = 0;
+	simals_convert_to_upper(instname);
+	cellptr = simals_find_level(instname);
+	if (! cellptr)
+	{
+		ttyputerr(M_("ERROR: Unable to find level %s"), instname);
+		return;
+	}
+
+	simals_levelptr = cellptr;
+
+	/* reinitialize simulator while preserving time information */
+	sim_window_gettimerange(&mintime, &maxtime);
+	maintime = sim_window_getmaincursor();
+	exttime = sim_window_getextensioncursor();
+	if (simals_set_current_level()) return;
+	sim_window_settimerange(mintime, maxtime);
+	sim_window_setmaincursor(maintime);
+	sim_window_setextensioncursor(exttime);
+
+	l = simals_levelptr->num_chn;
+	sim_window_setlines(l);
+	sim_window_settopline(0);
+	(void)simals_initialize_simulator(TRUE);
 }
 
 /****************************** PRINT ******************************/
@@ -1061,9 +1054,9 @@ void simals_level_command(INTSML count, char *par[])
 /*
  * routine to print out the display screen status and information
  */
-void simals_print_command(INTSML count, char *par[])
+void simals_print_command(INTBIG count, char *par[])
 {
-	INTSML l;
+	INTBIG l;
 	char *pt, s1[256];
 	LINKPTR  linkhead;
 	NODEPTR  nodehead;
@@ -1404,7 +1397,7 @@ void simals_print_xref_entry(CONPTR cellhead, INTBIG tab)
  *	This procedure sets a flag which tells the simulator if it is necessary
  * to reseed the Random Number Generator each time a simulation is run.
  */
-void simals_seed_command(INTSML count, char *par[])
+void simals_seed_command(INTBIG count, char *par[])
 {
 	if (count < 1)
 	{
@@ -1412,7 +1405,7 @@ void simals_seed_command(INTSML count, char *par[])
 		return;
 	}
 	if (namesamen(par[0], "reset", strlen(par[0])) == 0)
-		simals_seed_flag = 0; else simals_seed_flag = 1;
+		simals_seed_flag = FALSE; else simals_seed_flag = TRUE;
 }
 
 /****************************** SET ******************************/
@@ -1424,11 +1417,11 @@ void simals_seed_command(INTSML count, char *par[])
  *	This procedure sets the specified node to the state that is indicated
  * in the command line.
 */
-void simals_set_command(INTSML count, char *par[])
+void simals_set_command(INTBIG count, char *par[])
 {
 	INTBIG	state;
 	INTSML	strength;
-	float    time;
+	double   time;
 	NODEPTR  nodehead;
 	LINKPTR  sethead;
 	NODEPROTO *np;
@@ -1453,7 +1446,7 @@ void simals_set_command(INTSML count, char *par[])
 
 	state = simals_trans_state_to_number(par[1]);
 	strength = (INTSML)simals_atoi(par[2])*2;
-	time = (float)atof(par[3]);
+	time = atof(par[3]);
 
 	sethead = simals_alloc_link_mem();
 	if (sethead == 0) return;
@@ -1468,7 +1461,7 @@ void simals_set_command(INTSML count, char *par[])
 
 	ttyputmsg(M_("Node '%s' scheduled, state = %s, strength = %s, time = %g"), par[0], par[1],
 		simals_strengthstring(strength), time);
-	simals_initialize_simulator(0);
+	(void)simals_initialize_simulator(FALSE);
 }
 
 /****************************** TRACE ******************************/
@@ -1480,9 +1473,9 @@ void simals_set_command(INTSML count, char *par[])
  *	This procedure turns on/off the trace buffer.  If it is turned off, no
  * timing diagram information will be stored in memory for plotting.
  */
-void simals_trace_command(INTSML count, char *par[])
+void simals_trace_command(INTBIG count, char *par[])
 {
-	INTSML l;
+	INTBIG l;
 	char *pt;
 
 	if (count < 1)
@@ -1493,12 +1486,12 @@ void simals_trace_command(INTSML count, char *par[])
 	l = strlen(pt = par[0]);
 	if (namesamen(pt, "on", l) == 0 && l >= 2)
 	{
-		(void)setvalkey((INTBIG)sim_tool, VTOOL, simals_no_update, 0, VINTEGER);
+		(void)setvalkey((INTBIG)sim_tool, VTOOL, simals_no_update_key, 0, VINTEGER);
 		return;
 	}
 	if (namesamen(pt, "off", l) == 0 && l >= 2)
 	{
-		(void)setvalkey((INTBIG)sim_tool, VTOOL, simals_no_update, 1, VINTEGER);
+		(void)setvalkey((INTBIG)sim_tool, VTOOL, simals_no_update_key, 1, VINTEGER);
 		return;
 	}
 	ttyputbadusage("telltool simulation als trace");
@@ -1506,17 +1499,17 @@ void simals_trace_command(INTSML count, char *par[])
 
 /****************************** VECTOR ******************************/
 
-void simals_vector_command(INTSML count, char *par[])
+void simals_vector_command(INTBIG count, char *par[])
 {
-	INTBIG	 i, flag;
-	INTSML   l, strength;
+	INTBIG	 l, flag;
+	INTSML   strength;
 	char     s1[256], s2[80], *pt, **vectptr1, **backptr;
 	char    *filename, *truename;
 	FILE    *vin, *vout;
 	LINKPTR  sethead, vecthead, vectptr2, nextvec;
 	ROWPTR   clokhead;
 	NODEPTR  nodehead;
-	float    time;
+	double   time;
 	NODEPROTO *np;
 
 	if (sim_window_isactive(&np) == 0)
@@ -1535,8 +1528,8 @@ void simals_vector_command(INTSML count, char *par[])
 	{
 		if (count < 2)
 		{
-			ttyputusage("telltool simulation als vector load FILENAME");
-			return;
+			par[1] = fileselect(_("ALS vector file"), sim_filetypealsvec, "");
+			if (par[1] == 0) return;
 		}
 		vin = xopen(par[1], sim_filetypealsvec, "", &filename);
 		if (! vin)
@@ -1568,15 +1561,14 @@ void simals_vector_command(INTSML count, char *par[])
 		{
 			if (flag)
 			{
-				i = xfgets(s1, 255, vin);
-				if (i != 0)
+				if (xfgets(s1, 255, vin))
 				{
 					xclose(vin);
-					simals_initialize_simulator(0);
+					(void)simals_initialize_simulator(FALSE);
 					break;
 				}
 				simals_convert_to_upper(s1);
-				if (simals_fragment_command(s1) != 0) break;
+				if (simals_fragment_command(s1)) break;
 			}
 
 			if (! strcmp(simals_instbuf, "CLOCK"))
@@ -1599,7 +1591,7 @@ void simals_vector_command(INTSML count, char *par[])
 				if (sethead->ptr == 0) return;
 				sethead->state = atoi(&(simals_instbuf[simals_instptr[13]]));
 				sethead->priority = 1;
-				sethead->time = (float)atof(&(simals_instbuf[simals_instptr[11]]));
+				sethead->time = atof(&(simals_instbuf[simals_instptr[11]]));
 				sethead->right = 0;
 				simals_insert_set_list(sethead);
 
@@ -1614,15 +1606,14 @@ void simals_vector_command(INTSML count, char *par[])
 				vectptr1 = (char**) &(clokhead->inptr);
 				for(;;)
 				{
-					i = xfgets(s1, 255, vin);
-					if (i != 0)
+					if (xfgets(s1, 255, vin))
 					{
 						xclose(vin);
-						simals_initialize_simulator(0);
+						(void)simals_initialize_simulator(FALSE);
 						return;
 					}
 					simals_convert_to_upper(s1);
-					if (simals_fragment_command(s1) != 0) return;
+					if (simals_fragment_command(s1)) return;
 					if (!strcmp(simals_instbuf, "CLOCK") || !strcmp(simals_instbuf, "SET"))
 					{
 						flag = 0;
@@ -1635,7 +1626,7 @@ void simals_vector_command(INTSML count, char *par[])
 					vectptr2->state = simals_trans_state_to_number(simals_instbuf);
 					vectptr2->strength = strength;
 					vectptr2->priority = 1;
-					vectptr2->time = (float)atof(&(simals_instbuf[simals_instptr[1]]));
+					vectptr2->time = atof(&(simals_instbuf[simals_instptr[1]]));
 					vectptr2->right = 0;
 					*vectptr1 = (char*) vectptr2;
 					vectptr1 = (char**) &(vectptr2->right);
@@ -1661,7 +1652,7 @@ void simals_vector_command(INTSML count, char *par[])
 				sethead->state = simals_trans_state_to_number(&(simals_instbuf[simals_instptr[2]]));
 				sethead->strength = atoi(&(simals_instbuf[simals_instptr[3]]))*2;
 				sethead->priority = 2;
-				sethead->time = (float)atof(&(simals_instbuf[simals_instptr[5]]));
+				sethead->time = atof(&(simals_instbuf[simals_instptr[5]]));
 				sethead->right = 0;
 				simals_insert_set_list(sethead);
 				flag = 1;
@@ -1673,8 +1664,8 @@ void simals_vector_command(INTSML count, char *par[])
 	if (namesamen(pt, "new", l) == 0)
 	{
 		/* clear all vectors */
-		simals_clearallvectors(0);
-		simals_initialize_simulator(0);
+		simals_clearallvectors(FALSE);
+		(void)simals_initialize_simulator(FALSE);
 		return;
 	}
 
@@ -1682,8 +1673,11 @@ void simals_vector_command(INTSML count, char *par[])
 	{
 		if (count < 2)
 		{
-			ttyputusage("telltool simulation als vector save FILENAME");
-			return;
+			(void)initinfstr();
+			(void)formatinfstr("%s.vec", el_curlib->libname);
+			par[1] = fileselect(_("ALS vector file"), sim_filetypealsvec|FILETYPEWRITE,
+				returninfstr());
+			if (par[1] == 0) return;
 		}
 		vout = xcreate(par[1], sim_filetypealsvec, 0, &truename);
 		if (vout == 0)
@@ -1774,7 +1768,7 @@ void simals_vector_command(INTSML count, char *par[])
 				backptr = (char**) &(sethead->right);
 				sethead = sethead->right;
 			}
-			simals_initialize_simulator(0);
+			(void)simals_initialize_simulator(FALSE);
 			return;
 		}
 
@@ -1783,7 +1777,7 @@ void simals_vector_command(INTSML count, char *par[])
 			ttyputusage("telltool simulation als vector delete time TIME");
 			return;
 		}
-		time = (float)atof(par[2]);
+		time = atof(par[2]);
 		while (sethead)
 		{
 			if (sethead->time == time)
@@ -1803,7 +1797,7 @@ void simals_vector_command(INTSML count, char *par[])
 							nextvec = vecthead->right;
 							simals_free_link_mem(vecthead);
 						}
-						simals_initialize_simulator(0);
+						(void)simals_initialize_simulator(FALSE);
 						return;
 					}
 				} else
@@ -1813,7 +1807,7 @@ void simals_vector_command(INTSML count, char *par[])
 						*backptr = (char *)sethead->right;
 						simals_free_link_mem(sethead);
 						sethead = (LINKPTR)*backptr;
-						simals_initialize_simulator(0);
+						(void)simals_initialize_simulator(FALSE);
 						return;
 					}
 				}
@@ -1836,7 +1830,7 @@ void simals_vector_command(INTSML count, char *par[])
  * Description:
  *   Annotate node information onto corresponding schematic.
  */
-void simals_annotate_command(INTSML count, char *par[])
+void simals_annotate_command(INTBIG count, char *par[])
 {
 	if (count < 1)
 	{
@@ -1897,7 +1891,7 @@ NODEINST *simals_getcellinstance(char *celltype, char *instance)
 	NODEPROTO *np;
 	VARIABLE *var;
 	char *pt, **instlist, *str, tmp[256];
-	INTSML i, j, count = 1;
+	INTBIG i, j, count = 1;
 
 	np = getcurfacet();
 	ni = NONODEINST;
@@ -1912,7 +1906,7 @@ NODEINST *simals_getcellinstance(char *celltype, char *instance)
 	for (i=0, j=0; i<count; i++)
 	{
 		str = getkeyword(&pt, ".");
-		if (i >= 2) if (allocstring(&instlist[j++], str, el_tempcluster) != 0)
+		if (i >= 2) if (allocstring(&instlist[j++], str, el_tempcluster))
 			return(NONODEINST);
 		(void)tonextchar(&pt);
 	}
@@ -1925,7 +1919,7 @@ NODEINST *simals_getcellinstance(char *celltype, char *instance)
 	{
 		for (ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		{
-			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name);
+			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
 			if (var == NOVARIABLE) continue;
 			if (namesame((char *)var->addr, instlist[i]) != 0) continue;
 			np = ni->proto;
@@ -1983,7 +1977,7 @@ void simals_sdfportdelay(CONPTR cellhead, NODEINST *ni, char *path)
 INTBIG simals_getportdelayvalue(char *datastring, char *transition, DELAY_TYPES delaytype)
 {
 	char *pt, *ts, **instlist, *str, tmp[256];
-	INTSML i, count = 1;
+	INTBIG i, count = 1;
 
 	/* count number of parts in data string */
 	(void)sprintf(tmp, "%s", datastring);
@@ -1995,7 +1989,7 @@ INTBIG simals_getportdelayvalue(char *datastring, char *transition, DELAY_TYPES
 	for (i=0; i<count; i++)
 	{
 		str = getkeyword(&pt, " ");
-		if (allocstring(&instlist[i], str, el_tempcluster) != 0) return(-1);
+		if (allocstring(&instlist[i], str, el_tempcluster)) return(-1);
 	}
 
 	/* get piece that corresponds to specified transition */
@@ -2003,7 +1997,7 @@ INTBIG simals_getportdelayvalue(char *datastring, char *transition, DELAY_TYPES
 	{
 		if (namesamen(instlist[i], transition, strlen(transition)) == 0)
 		{
-			if (allocstring(&ts, instlist[i], el_tempcluster) != 0) return(-1);
+			if (allocstring(&ts, instlist[i], el_tempcluster)) return(-1);
 			return(simals_getdval(ts, delaytype));
 		}
 	}
@@ -2018,7 +2012,7 @@ INTBIG simals_getportdelayvalue(char *datastring, char *transition, DELAY_TYPES
 INTBIG simals_getdval(char *tstring, DELAY_TYPES delaytype)
 {
 	char *pt, *str, *bs, ts[256], *t1, *t2, *t3;
-	INTSML i, start = 0, stop = 0;
+	INTBIG i, start = 0, stop = 0;
 
 	bs = str = (char *)emalloc(strlen(tstring), el_tempcluster);
 	for (pt = tstring; *pt != 0; pt++)
@@ -2042,9 +2036,9 @@ INTBIG simals_getdval(char *tstring, DELAY_TYPES delaytype)
 	for (i=0; i<3; i++)
 	{
 		str = getkeyword(&pt, ":");
-		if (i == 0) if (allocstring(&t1, str, el_tempcluster) != 0) return(-1);
-		if (i == 1) if (allocstring(&t2, str, el_tempcluster) != 0) return(-1);
-		if (i == 2) if (allocstring(&t3, str, el_tempcluster) != 0) return(-1);
+		if (i == 0) if (allocstring(&t1, str, el_tempcluster)) return(-1);
+		if (i == 1) if (allocstring(&t2, str, el_tempcluster)) return(-1);
+		if (i == 2) if (allocstring(&t3, str, el_tempcluster)) return(-1);
 		(void)tonextchar(&pt);
 	}
 
@@ -2069,7 +2063,7 @@ INTBIG simals_getdval(char *tstring, DELAY_TYPES delaytype)
  * Description:
  *   Save/restore signal trace order for waveform display.
  */
-void simals_order_command(INTSML count, char *par[])
+void simals_order_command(INTBIG count, char *par[])
 {
 	if (count < 1)
 	{
@@ -2096,7 +2090,7 @@ void simals_order_command(INTSML count, char *par[])
 void simals_order_save(void)
 {
 	INTBIG tr;
-	INTSML first = 0;
+	BOOLEAN first = FALSE;
 	char str[256], *ts;
 	NODEPROTO *curfacet;
 
@@ -2106,7 +2100,7 @@ void simals_order_save(void)
 		if (!first) (void)initinfstr();
 		(void)sprintf(str, "%s:", sim_window_gettracename(tr));
 		(void)addstringtoinfstr(str);
-		first++;
+		first = TRUE;
 	}
 
 	if (first)
@@ -2272,9 +2266,9 @@ void simals_update_netlist(void)
 /*
  * Return index for transition delays given text name.
  */
-INTSML simals_get_tdindex(char *name)
+INTBIG simals_get_tdindex(char *name)
 {
-	INTSML i;
+	INTBIG i;
 
 	for (i=0; i<12; i++)
 	{
@@ -2290,7 +2284,7 @@ INTSML simals_get_tdindex(char *name)
 char *simals_parent_level(char *child)
 {
 	char tmp[256], *pt, *str, **instlist;
-	INTSML i, count = 1;
+	INTBIG i, count = 1;
 
 	(void)sprintf(tmp, "%s", child);
 	for (pt = tmp; *pt != 0; pt++) if (*pt == '.') count++;
