@@ -39,23 +39,23 @@
 #include "network.h"
 #include "edialogs.h"
 
-static INTSML sim_window_iter;
-static INTSML sim_als_wantweak = 0, sim_als_wantstrong = 0, sim_als_wantfull = 0;
+static INTBIG sim_window_iter;
+static BOOLEAN sim_als_wantweak = FALSE, sim_als_wantstrong = FALSE, sim_als_wantfull = FALSE;
 
 /* prototypes for local routines */
-static INTSML  sim_window_topofdsignals(char**);
-static char   *sim_window_nextdsignals(void);
-static INTBIG  simals_count_channels(CONPTR);
-static void    simals_helpwindow(INTSML waveform);
-static INTSML  simals_getwidevalue(INTBIG *value);
+static BOOLEAN  simals_topofsignals(char**);
+static char    *simals_nextsignals(void);
+static INTBIG   simals_count_channels(CONPTR);
+static void     simals_helpwindow(BOOLEAN waveform);
+static int      simals_sortbusnames(const void *e1, const void *e2);
 
-INTSML sim_window_topofdsignals(char **c)
+BOOLEAN simals_topofsignals(char **c)
 {
 	sim_window_iter = 0;
-	return(1);
+	return(TRUE);
 }
 
-char *sim_window_nextdsignals(void)
+char *simals_nextsignals(void)
 {
 	char *nextname;
 
@@ -70,88 +70,91 @@ char *sim_window_nextdsignals(void)
 	return(nextname);
 }
 
-static COMCOMP sim_window_pickdtrace = {NOKEYWORD, sim_window_topofdsignals,
-	sim_window_nextdsignals, NOPARAMS, NOBACKUP, 0, " \t", N_("pick a signal to display"), ""};
+static COMCOMP sim_window_pickalstrace = {NOKEYWORD, simals_topofsignals,
+	simals_nextsignals, NOPARAMS, NOBACKUP, 0, " \t", N_("pick a signal to display"), ""};
 
 /*
  * Routine to start ALS simulation of facet "np".
  */
-INTSML simals_startsimulation(NODEPROTO *np)
+BOOLEAN simals_startsimulation(NODEPROTO *np)
 {
 	extern TOOL *vhdl_tool;
+	REGISTER INTBIG error;
 
 	/* initialize memory */
 	simals_init();
 
 	/* demand an ALS netlist */
-	(void)asktool(vhdl_tool, "want-netlist-input", (INTBIG)np, sim_filetypeals);
+	error = asktool(vhdl_tool, "want-netlist-input", (INTBIG)np, sim_filetypeals);
+	if (error != 0) return(TRUE);
 
 	/* read netlist */
 	simals_erase_model();
-	if (simals_read_net_desc(np) != 0) return(1);
-	if (simals_flatten_network() != 0) return(1);
+	if (simals_read_net_desc(np)) return(TRUE);
+	if (simals_flatten_network()) return(TRUE);
 
 	/* initialize display */
 	simals_init_display();
-	return(0);
+	return(FALSE);
 }
 
 /*
  * The character handler for the waveform window of ALS simulation
  */
-INTSML simals_charhandlerwave(WINDOWPART *w, INTSML chr)
+BOOLEAN simals_charhandlerwave(WINDOWPART *w, INTSML chr, INTBIG special)
 {
 	REGISTER INTBIG i, j, traces, pos, thispos, lines, strength, *tracelist,
-		tr, trl, nexttr, prevtr, highsig, *highsigs, windowstate, bit;
-	INTBIG state;
-	REGISTER VARIABLE *var;
+		tr, trl, nexttr, prevtr, highsig, *highsigs, numbits, bitoffset;
+	INTBIG state, *theBits;
 	char *par[30], *name;
 	NODEPTR node, nodehead;
 	NODEPROTO *np;
-	float endtime;
+	double endtime;
 	LINKPTR sethead;
 
 	ttynewcommand();
 
+	/* special characters are not handled here */
+	if (special != 0)
+		return(us_charhandler(w, chr, special));
+
 	/* can always preserve snapshot */
 	if (chr == 'p')
 	{
 		sim_window_savegraph();
-		sim_als_wantweak = sim_als_wantstrong = sim_als_wantfull = 0;
-		return(0);
+		sim_als_wantweak = sim_als_wantstrong = sim_als_wantfull = FALSE;
+		return(FALSE);
 	}
 
 	/* can always do help */
 	if (chr == '?')
 	{
-		simals_helpwindow(1);
-		sim_als_wantweak = sim_als_wantstrong = sim_als_wantfull = 0;
-		return(0);
+		simals_helpwindow(TRUE);
+		sim_als_wantweak = sim_als_wantstrong = sim_als_wantfull = FALSE;
+		return(FALSE);
 	}
 
 	/* if not simulating, don't handle any simulation commands */
 	if (sim_window_isactive(&np) == 0)
-		return(us_charhandler(w, chr));
+		return(us_charhandler(w, chr, special));
 
 	switch (chr)
 	{
 		/* update display */
 		case 'u':
-			endtime = simals_initialize_simulator(1);
-			var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_window_state);
-			if (var == NOVARIABLE) windowstate = 0; else windowstate = var->addr;
-			if ((windowstate&ADVANCETIME) != 0) sim_window_setmaincursor(endtime);
-			return(0);
+			endtime = simals_initialize_simulator(TRUE);
+			if ((sim_window_state&ADVANCETIME) != 0) sim_window_setmaincursor(endtime);
+			return(FALSE);
 
 		/* convert busses */
 		case 'b':
 			(void)sim_window_buscommand();
-			return(0);
+			return(FALSE);
 
 		/* add trace */
 		case 'a':
-			i = ttygetparam(_("Signal to add"), &sim_window_pickdtrace, 3, par);
-			if (i == 0) return(0);
+			i = ttygetparam(_("Signal to add"), &sim_window_pickalstrace, 3, par);
+			if (i == 0) return(FALSE);
 
 			/* find the signal */
 			for(i=0; i<simals_levelptr->num_chn; i++)
@@ -162,7 +165,7 @@ INTSML simals_charhandlerwave(WINDOWPART *w, INTSML chr)
 				name = simals_levelptr->display_page[i+1].name;
 				if (namesame(name, par[0]) == 0) break;
 			}
-			if (i >= simals_levelptr->num_chn) return(0);
+			if (i >= simals_levelptr->num_chn) return(FALSE);
 
 			/* ready to add: remove highlighting */
 			sim_window_cleartracehighlight();
@@ -186,76 +189,77 @@ INTSML simals_charhandlerwave(WINDOWPART *w, INTSML chr)
 			simals_fill_display_arrays();
 			sim_window_redraw();
 			sim_window_addhighlighttrace(tr);
-			sim_als_wantweak = sim_als_wantstrong = sim_als_wantfull = 0;
-			return(0);
+			sim_als_wantweak = sim_als_wantstrong = sim_als_wantfull = FALSE;
+			return(FALSE);
 
 		/* handle weak and strong prefixes */
 		case 'w':
-			if (sim_als_wantweak != 0 || sim_als_wantstrong != 0) ttybeep();
-			sim_als_wantweak = 1;
-			return(0);
+			if (sim_als_wantweak || sim_als_wantstrong) ttybeep(0);
+			sim_als_wantweak = TRUE;
+			return(FALSE);
 		case 's':
-			if (sim_als_wantweak != 0 || sim_als_wantstrong != 0) ttybeep();
-			sim_als_wantstrong = 1;
-			return(0);
+			if (sim_als_wantweak || sim_als_wantstrong) ttybeep(0);
+			sim_als_wantstrong = TRUE;
+			return(FALSE);
 		case 'f':
-			if (sim_als_wantfull != 0) ttybeep();
-			sim_als_wantfull = 1;
-			return(0);
+			if (sim_als_wantfull) ttybeep(0);
+			sim_als_wantfull = TRUE;
+			return(FALSE);
 
 		/* different flavors of low values */
 		case '0':
 		case 'l':
 			state = LOGIC_LOW;    strength = GATE_STRENGTH;
-			if (sim_als_wantweak != 0) strength = NODE_STRENGTH; else
-				if (sim_als_wantstrong != 0) strength = VDD_STRENGTH;
+			if (sim_als_wantweak) strength = NODE_STRENGTH; else
+				if (sim_als_wantstrong) strength = VDD_STRENGTH;
 			break;
 
 		/* different flavors of high values */
 		case '1':
 		case 'h':
 			state = LOGIC_HIGH;   strength = GATE_STRENGTH;
-			if (sim_als_wantweak != 0) strength = NODE_STRENGTH; else
-				if (sim_als_wantstrong != 0) strength = VDD_STRENGTH;
+			if (sim_als_wantweak) strength = NODE_STRENGTH; else
+				if (sim_als_wantstrong) strength = VDD_STRENGTH;
 			break;
 
 		/* different flavors of undefined values */
 		case 'x':
 			state = LOGIC_X;      strength = GATE_STRENGTH;
-			if (sim_als_wantweak != 0) strength = NODE_STRENGTH; else
-				if (sim_als_wantstrong != 0) strength = VDD_STRENGTH;
+			if (sim_als_wantweak) strength = NODE_STRENGTH; else
+				if (sim_als_wantstrong) strength = VDD_STRENGTH;
 			break;
 
 		/* different flavors of wide numeric values */
 		case 'v':
-			if (simals_getwidevalue(&state) != 0) return(0);
+			numbits = sim_window_getwidevalue(&theBits);
+			if (numbits < 0) return(FALSE);
 			strength = GATE_STRENGTH;
-			if (sim_als_wantweak != 0) strength = NODE_STRENGTH; else
-				if (sim_als_wantstrong != 0) strength = VDD_STRENGTH;
+			if (sim_als_wantweak) strength = NODE_STRENGTH; else
+				if (sim_als_wantstrong) strength = VDD_STRENGTH;
 			break;
 
 		/* signal tracing */
 		case 't':
-			if (sim_als_wantfull != 0)
+			if (sim_als_wantfull)
 			{
-				simals_trace_all_nodes = 1;
-				(void)simals_initialize_simulator(1);
-				simals_trace_all_nodes = 0;
+				simals_trace_all_nodes = TRUE;
+				(void)simals_initialize_simulator(TRUE);
+				simals_trace_all_nodes = FALSE;
 			} else
 			{
 				highsigs = sim_window_gethighlighttraces();
 				if (highsigs[0] == 0)
 				{
 					ttyputerr(_("Select signal names first"));
-					return(0);
+					return(FALSE);
 				}
 				for(i=0; highsigs[i] != 0; i++)
-					((NODEPTR)sim_window_gettracedata(highsigs[i]))->tracenode = 1;
-				(void)simals_initialize_simulator(1);
+					((NODEPTR)sim_window_gettracedata(highsigs[i]))->tracenode = TRUE;
+				(void)simals_initialize_simulator(TRUE);
 				for(i=0; highsigs[i] != 0; i++)
-					((NODEPTR)sim_window_gettracedata(highsigs[i]))->tracenode = 0;
+					((NODEPTR)sim_window_gettracedata(highsigs[i]))->tracenode = FALSE;
 			}
-			return(0);
+			return(FALSE);
 
 		/* signal clock setting, info, erasing, removing (all handled later) */
 		case 'c':
@@ -265,22 +269,22 @@ INTSML simals_charhandlerwave(WINDOWPART *w, INTSML chr)
 			break;
 
 		default:
-			sim_als_wantweak = sim_als_wantstrong = sim_als_wantfull = 0;
-			return(us_charhandler(w, chr));
+			sim_als_wantweak = sim_als_wantstrong = sim_als_wantfull = FALSE;
+			return(us_charhandler(w, chr, special));
 	}
-	sim_als_wantweak = sim_als_wantstrong = sim_als_wantfull = 0;
+	sim_als_wantweak = sim_als_wantstrong = sim_als_wantfull = FALSE;
 
 	/* the following commands demand a current trace...get it */
 	highsigs = sim_window_gethighlighttraces();
 	if (highsigs[0] == 0)
 	{
 		ttyputerr(_("Select a signal name first"));
-		return(0);
+		return(FALSE);
 	}
 	if (highsigs[1] != 0)
 	{
 		ttyputerr(_("Select just one signal name first"));
-		return(0);
+		return(FALSE);
 	}
 	highsig = highsigs[0];
 
@@ -290,18 +294,18 @@ INTSML simals_charhandlerwave(WINDOWPART *w, INTSML chr)
 		if (tracelist != 0 && tracelist[0] != 0)
 		{
 			ttyputerr(_("Cannot set clock waveform on a bus signal"));
-			return(0);
+			return(FALSE);
 		}
 		par[0] = sim_window_gettracename(highsig);
 		simals_clock_command(1, par);
-		return(0);
+		return(FALSE);
 	}
 	if (chr == 'i')		/* print signal info */
 	{
 		par[0] = "state";
 		par[1] = sim_window_gettracename(highsig);
 		simals_print_command(2, par);
-		return(0);
+		return(FALSE);
 	}
 	if (chr == 'e')		/* clear signal vectors */
 	{
@@ -322,7 +326,7 @@ INTSML simals_charhandlerwave(WINDOWPART *w, INTSML chr)
 			par[2] = "all";
 			simals_vector_command(3, par);
 		}
-		return(0);
+		return(FALSE);
 	}
 	if (chr == 'r')		/* remove trace */
 	{
@@ -364,7 +368,7 @@ INTSML simals_charhandlerwave(WINDOWPART *w, INTSML chr)
 		if (nexttr != 0) sim_window_addhighlighttrace(nexttr); else
 			if (prevtr != 0) sim_window_addhighlighttrace(prevtr);
 		sim_window_redraw();
-		return(0);
+		return(FALSE);
 	}
 
 	/* handle setting of values on signals */
@@ -374,21 +378,20 @@ INTSML simals_charhandlerwave(WINDOWPART *w, INTSML chr)
 		if (tracelist == 0 || tracelist[0] == 0)
 		{
 			ttyputerr(_("Select a bus signal before setting numeric values on it"));
-			return(0);
+			return(FALSE);
 		}
 		for(i=0; tracelist[i] != 0; i++) ;
-		bit = 1 << (i-1);
+		bitoffset = numbits - i;
 		for(i=0; tracelist[i] != 0; i++)
 		{
 			nodehead = simals_find_node(sim_window_gettracename(tracelist[i]));
-			if (! nodehead) return(0);
+			if (! nodehead) return(FALSE);
 			sethead = simals_alloc_link_mem();
-			if (sethead == 0) return(0);
+			if (sethead == 0) return(FALSE);
 			sethead->type = 'N';
 			sethead->ptr = (char *)nodehead;
-			if ((state & bit) == 0) sethead->state = LOGIC_LOW; else
+			if (i+bitoffset < 0 || theBits[i+bitoffset] == 0) sethead->state = LOGIC_LOW; else
 				sethead->state = LOGIC_HIGH;
-			bit >>= 1;
 			sethead->strength = (INTSML)strength;
 			sethead->priority = 2;
 			sethead->time = sim_window_getmaincursor();
@@ -398,9 +401,9 @@ INTSML simals_charhandlerwave(WINDOWPART *w, INTSML chr)
 	} else
 	{
 		nodehead = simals_find_node(sim_window_gettracename(highsig));
-		if (! nodehead) return(0);
+		if (! nodehead) return(FALSE);
 		sethead = simals_alloc_link_mem();
-		if (sethead == 0) return(0);
+		if (sethead == 0) return(FALSE);
 		sethead->type = 'N';
 		sethead->ptr = (char *)nodehead;
 		sethead->state = state;
@@ -411,64 +414,64 @@ INTSML simals_charhandlerwave(WINDOWPART *w, INTSML chr)
 		simals_insert_set_list(sethead);
 	}
 
-	endtime = simals_initialize_simulator(0);
-	var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_window_state);
-	if (var == NOVARIABLE) windowstate = 0; else windowstate = var->addr;
-	if ((windowstate&ADVANCETIME) != 0) sim_window_setmaincursor(endtime);
-	return(0);
+	endtime = simals_initialize_simulator(FALSE);
+	if ((sim_window_state&ADVANCETIME) != 0) sim_window_setmaincursor(endtime);
+	return(FALSE);
 }
 
 /*
  * The character handler for the schematic/layout window of ALS simulation
  */
-INTSML simals_charhandlerschem(WINDOWPART *w, INTSML chr)
+BOOLEAN simals_charhandlerschem(WINDOWPART *w, INTSML chr, INTBIG special)
 {
-	INTBIG state, highsig, windowstate;
-	REGISTER VARIABLE *var;
+	INTBIG state, highsig;
 	REGISTER INTSML strength;
 	REGISTER NETWORK *net;
 	char *par[30], *pt;
-	float endtime;
+	double endtime;
 	NODEPTR nodehead;
 	LINKPTR sethead;
 
 	ttynewcommand();
+
+	/* special characters are not handled here */
+	if (special != 0)
+		return(us_charhandler(w, chr, special));
+
 	switch (chr)
 	{
 		case '?':
-			simals_helpwindow(0);
-			sim_als_wantweak = sim_als_wantstrong = 0;
-			return(0);
+			simals_helpwindow(FALSE);
+			sim_als_wantweak = sim_als_wantstrong = FALSE;
+			return(FALSE);
 		case 'u':
-			endtime = simals_initialize_simulator(1);
-			var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_window_state);
-			if (var == NOVARIABLE) windowstate = 0; else windowstate = var->addr;
-			if ((windowstate&ADVANCETIME) != 0) sim_window_setmaincursor(endtime);
-			return(0);
+			endtime = simals_initialize_simulator(TRUE);
+			if ((sim_window_state&ADVANCETIME) != 0) sim_window_setmaincursor(endtime);
+			return(FALSE);
 		case 'w':
-			if (sim_als_wantweak != 0 || sim_als_wantstrong != 0) ttybeep();
-			sim_als_wantweak = 1;
-			return(0);
+			if (sim_als_wantweak || sim_als_wantstrong) ttybeep(0);
+			sim_als_wantweak = TRUE;
+			return(FALSE);
 		case 's':
-			if (sim_als_wantweak != 0 || sim_als_wantstrong != 0) ttybeep();
-			sim_als_wantstrong = 1;
-			return(0);
+			if (sim_als_wantweak || sim_als_wantstrong) ttybeep(0);
+			sim_als_wantstrong = TRUE;
+			return(FALSE);
 		case '0':
 		case 'l':
 			state = LOGIC_LOW;    strength = GATE_STRENGTH;
-			if (sim_als_wantweak != 0) strength = NODE_STRENGTH; else
-				if (sim_als_wantstrong != 0) strength = VDD_STRENGTH;
+			if (sim_als_wantweak) strength = NODE_STRENGTH; else
+				if (sim_als_wantstrong) strength = VDD_STRENGTH;
 			break;
 		case '1':
 		case 'h':
 			state = LOGIC_HIGH;   strength = GATE_STRENGTH;
-			if (sim_als_wantweak != 0) strength = NODE_STRENGTH; else
-				if (sim_als_wantstrong != 0) strength = VDD_STRENGTH;
+			if (sim_als_wantweak) strength = NODE_STRENGTH; else
+				if (sim_als_wantstrong) strength = VDD_STRENGTH;
 			break;
 		case 'x':
 			state = LOGIC_X;      strength = GATE_STRENGTH;
-			if (sim_als_wantweak != 0) strength = NODE_STRENGTH; else
-				if (sim_als_wantstrong != 0) strength = VDD_STRENGTH;
+			if (sim_als_wantweak) strength = NODE_STRENGTH; else
+				if (sim_als_wantstrong) strength = VDD_STRENGTH;
 			break;
 		case 'c':
 		case 'i':
@@ -476,21 +479,21 @@ INTSML simals_charhandlerschem(WINDOWPART *w, INTSML chr)
 		case 'e':
 			break;
 		default:
-			sim_als_wantweak = sim_als_wantstrong = 0;
-			return(us_charhandler(w, chr));
+			sim_als_wantweak = sim_als_wantstrong = FALSE;
+			return(us_charhandler(w, chr, special));
 	}
-	sim_als_wantweak = sim_als_wantstrong = 0;
+	sim_als_wantweak = sim_als_wantstrong = FALSE;
 
 	/* find the net in the waveform window */
-	net = net_gethighlightednet(0, 0);
-	if (net == NONETWORK) return(0);
+	net = net_gethighlightednet(FALSE, FALSE);
+	if (net == NONETWORK) return(FALSE);
 	if (net->namecount > 0) pt = net->netname; else
 		pt = describenetwork(net);
 	highsig = sim_window_findtrace(pt);
 	if (highsig == 0)
 	{
 		ttyputerr(_("Cannot find network %s in simulation"), pt);
-		return(0);
+		return(FALSE);
 	}
 	sim_window_cleartracehighlight();
 	sim_window_addhighlighttrace(highsig);
@@ -499,22 +502,22 @@ INTSML simals_charhandlerschem(WINDOWPART *w, INTSML chr)
 	{
 		par[0] = sim_window_gettracename(highsig);
 		simals_clock_command(1, par);
-		return(0);
+		return(FALSE);
 	}
 	if (chr == 'i')
 	{
 		par[0] = "state";
 		par[1] = sim_window_gettracename(highsig);
 		simals_print_command(2, par);
-		return(0);
+		return(FALSE);
 	}
 	if (chr == 't')
 	{
 		nodehead = (NODEPTR)sim_window_gettracedata(highsig);
-		nodehead->tracenode = 1;
-		(void)simals_initialize_simulator(1);
-		nodehead->tracenode = 0;
-		return(0);
+		nodehead->tracenode = TRUE;
+		(void)simals_initialize_simulator(TRUE);
+		nodehead->tracenode = FALSE;
+		return(FALSE);
 	}
 	if (chr == 'e')
 	{
@@ -524,14 +527,14 @@ INTSML simals_charhandlerschem(WINDOWPART *w, INTSML chr)
 		simals_vector_command(3, par);
 		simals_fill_display_arrays();
 		sim_window_redraw();
-		return(0);
+		return(FALSE);
 	}
 
 	nodehead = simals_find_node(sim_window_gettracename(highsig));
-	if (nodehead == 0) return(0);
+	if (nodehead == 0) return(FALSE);
 
 	sethead = simals_alloc_link_mem();
-	if (sethead == 0) return(0);
+	if (sethead == 0) return(FALSE);
 	sethead->type = 'N';
 	sethead->ptr = (char *)nodehead;
 	sethead->state = state;
@@ -540,49 +543,13 @@ INTSML simals_charhandlerschem(WINDOWPART *w, INTSML chr)
 	sethead->time = sim_window_getmaincursor();
 	sethead->right = 0;
 	simals_insert_set_list(sethead);
-	endtime = simals_initialize_simulator(0);
+	endtime = simals_initialize_simulator(FALSE);
 
-	var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_window_state);
-	if (var == NOVARIABLE) windowstate = 0; else windowstate = var->addr;
-	if ((windowstate&ADVANCETIME) != 0) sim_window_setmaincursor(endtime);
-	return(0);
+	if ((sim_window_state&ADVANCETIME) != 0) sim_window_setmaincursor(endtime);
+	return(FALSE);
 }
 
-/* Simulation: Wide Value */
-static DIALOGITEM sim_widedialogitems[] =
-{
- /*  1 */ {0, {36,148,60,228}, BUTTON, N_("OK")},
- /*  2 */ {0, {36,16,60,96}, BUTTON, N_("Cancel")},
- /*  3 */ {0, {4,4,20,148}, MESSAGE, N_("Value to set on bus:")},
- /*  4 */ {0, {4,152,20,240}, EDITTEXT, ""}
-};
-static DIALOG sim_widedialog = {{75,75,144,324}, N_("Set Wide Value"), 0, 4, sim_widedialogitems};
-
-/* special items for the "wide value" dialog: */
-#define DSWV_VALUE     4		/* Width (edit text) */
-
-/*
- * Routine to prompt for a wide value and return it in "value".
- * Returns nonzero on abort/error.
- */
-INTSML simals_getwidevalue(INTBIG *value)
-{
-	INTBIG itemHit;
-
-	if (DiaInitDialog(&sim_widedialog) != 0) return(1);
-	DiaSetText(-DSWV_VALUE, "0");
-	for(;;)
-	{
-		itemHit = DiaNextHit();
-		if (itemHit == OK || itemHit == CANCEL) break;
-	}
-	*value = myatoi(DiaGetText(DSWV_VALUE));
-	DiaDoneDialog();
-	if (itemHit == OK) return(0);
-	return(1);
-}
-
-void simals_helpwindow(INTSML waveform)
+void simals_helpwindow(BOOLEAN waveform)
 {
 	REGISTER INTBIG active;
 	NODEPROTO *np;
@@ -594,7 +561,7 @@ void simals_helpwindow(INTSML waveform)
 		return;
 	}
 
-	if (waveform != 0)
+	if (waveform)
 		ttyputmsg(_("These keys may be typed in the ALS Waveform window:")); else
 			ttyputmsg(_("These keys may be typed in the ALS Schematic window:"));
 	ttyputinstruction("L,0", 4, _("Set signal low (normal strength)"));
@@ -606,7 +573,7 @@ void simals_helpwindow(INTSML waveform)
 	ttyputinstruction(" X",  4, _("Set signal undefined (normal strength)"));
 	ttyputinstruction("WX",  4, _("Set signal undefined (weak strength)"));
 	ttyputinstruction("SX",  4, _("Set signal undefined (strong strength)"));
-	if (waveform != 0)
+	if (waveform)
 	{
 		ttyputinstruction(" V",  4, _("Set bus to wide value (normal strength)"));
 		ttyputinstruction("WV",  4, _("Set bus to wide value (weak strength)"));
@@ -618,7 +585,7 @@ void simals_helpwindow(INTSML waveform)
 	ttyputinstruction(" T",  4, _("Trace events on signal(s)"));
 	ttyputinstruction(" U",  4, _("Update display (resimulate)"));
 
-	if (waveform != 0)
+	if (waveform)
 	{
 		ttyputinstruction(" A", 4, _("Add signal to simulation window"));
 		ttyputinstruction(" R", 4, _("Remove signal from the window"));
@@ -651,17 +618,18 @@ INTBIG simals_count_channels(CONPTR level_pointer)
  *
  * Description:
  *	This procedure is used to initialize the display channels to the current
- * level of the database hierarchy.  Returns nonzero on error.
+ * level of the database hierarchy.  Returns true on error.
  */
-INTSML simals_set_current_level(void)
+BOOLEAN simals_set_current_level(void)
 {
-	INTBIG i, j, buscount, oldsigcount, chn, windowstate, bussignals[32];
+	INTBIG i, j, k, buscount, oldsigcount, chn, bussignals[MAXSIMWINDOWBUSWIDTH],
+		len, olen;
 	char **oldsignames;
 	REGISTER VARIABLE *var;
 	NODEPTR nodehead;
-	NODE *node;
+	NODE *node, *subnode;
 	EXPTR exhead;
-	char *name, *pt, *start, save;
+	char *name, *subname, *pt, *start, save;
 	void *sa;
 	NODEPROTO *np;
 
@@ -681,10 +649,10 @@ INTSML simals_set_current_level(void)
 		}
 	} else
 	{
-		simals_levelptr->num_chn = (INTSML)simals_count_channels(simals_levelptr);
+		simals_levelptr->num_chn = simals_count_channels(simals_levelptr);
 		chn = simals_levelptr->num_chn + 1;
 		simals_levelptr->display_page = (CHNPTR)simals_alloc_mem((INTBIG)(chn * sizeof(CHANNEL)));
-		if (simals_levelptr->display_page == 0) return(1);
+		if (simals_levelptr->display_page == 0) return(TRUE);
 
 		exhead = simals_levelptr->exptr;
 		for (i = 1; i < chn; i++)
@@ -701,6 +669,21 @@ INTSML simals_set_current_level(void)
 				simals_levelptr->display_page[i].nodeptr = 0;
 			}
 			(void)allocstring(&simals_levelptr->display_page[i].name, name, sim_tool->cluster);
+
+			/* convert names to proper bracketed form */
+			name = simals_levelptr->display_page[i].name;
+			len = strlen(name) - 1;
+			if (name[len] == '_')
+			{
+				olen = len;
+				while (len > 0 && isdigit(name[len-1])) len--;
+				if (len != olen && name[len-1] == '_')
+				{
+					/* found the form "name_INDEX_" */
+					name[len-1] = '[';
+					name[olen] = ']';
+				}
+			}
 		}
 	}
 
@@ -709,11 +692,10 @@ INTSML simals_set_current_level(void)
 	if (sim_window_isactive(&np) == 0)
 	{
 		/* no simulation running: start it up */
-		if (simals_levelptr->num_chn <= 0) return(1);
+		if (simals_levelptr->num_chn <= 0) return(TRUE);
 
-		var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_window_state);
-		if (var == NOVARIABLE) windowstate = 0; else windowstate = var->addr;
-		var = getvalkey((INTBIG)simals_mainproto, VNODEPROTO, VSTRING|VISARRAY, sim_window_signal_order);
+		var = getvalkey((INTBIG)simals_mainproto, VNODEPROTO, VSTRING|VISARRAY,
+			sim_window_signalorder_key);
 		if (var != NOVARIABLE)
 		{
 			oldsigcount = getlength(var);
@@ -726,16 +708,16 @@ INTSML simals_set_current_level(void)
 			}
 		}
 		if (sim_window_create(simals_levelptr->num_chn, simals_mainproto,
-			((windowstate&SHOWWAVEFORM) != 0 ? simals_charhandlerwave : 0),
-				simals_charhandlerschem) != 0)
+			((sim_window_state&SHOWWAVEFORM) != 0 ? simals_charhandlerwave : 0),
+				simals_charhandlerschem, ALS))
 		{
 			if (oldsigcount > 0) killstringarray(sa);
-			return(1);
+			return(TRUE);
 		}
 	}
 
 	/* load the traces */
-	sim_window_killalltraces();
+	sim_window_killalltraces(TRUE);
 	for(i=0; i<simals_levelptr->num_chn; i++)
 		simals_levelptr->display_page[i+1].displayptr = 0;
 
@@ -768,7 +750,13 @@ INTSML simals_set_current_level(void)
 			}
 
 			/* create the bus */
-			(void)sim_window_makebus(buscount, bussignals);
+			(void)initinfstr();
+			for(pt = oldsignames[j]; *pt != 0; pt++)
+			{
+				if (*pt == '\t') break;
+				(void)addtoinfstr(*pt);
+			}
+			(void)sim_window_makebus(buscount, bussignals, returninfstr());
 		} else
 		{
 			/* a single signal */
@@ -790,33 +778,83 @@ INTSML simals_set_current_level(void)
 		node = simals_levelptr->display_page[i+1].nodeptr;
 		if (node == 0) continue;
 		name = simals_levelptr->display_page[i+1].name;
-		simals_levelptr->display_page[i+1].displayptr = sim_window_newtrace(-1, name,
-			(INTBIG)node);
+		for(k=0; name[k] != 0; k++) if (name[k] == '[') break;
+		if (name[k] == '[')
+		{
+			/* found an arrayed signal: gather it into a bus */
+			buscount = 0;
+			for(j=0; j<simals_levelptr->num_chn; j++)
+			{
+				if (simals_levelptr->display_page[j+1].displayptr != 0) continue;
+				if (simals_levelptr->display_page[j+1].nodeptr == 0) continue;
+				subname = simals_levelptr->display_page[j+1].name;
+				if (namesamen(subname, name, k) != 0) continue;
+				if (buscount >= MAXSIMWINDOWBUSWIDTH) break;
+				bussignals[buscount++] = j;
+			}
+			esort(bussignals, buscount, SIZEOFINTBIG, simals_sortbusnames);
+			for(j=0; j<buscount; j++)
+			{
+				k = bussignals[j];
+				subnode = simals_levelptr->display_page[k+1].nodeptr;
+				subname = simals_levelptr->display_page[k+1].name;
+				bussignals[j] = sim_window_newtrace(-1, subname, (INTBIG)subnode);
+				simals_levelptr->display_page[k+1].displayptr = bussignals[j];
+			}
+
+			/* create the bus */
+			if (buscount > 1)
+			{
+				(void)sim_window_makebus(buscount, bussignals, 0);
+			}
+		} else
+		{
+			simals_levelptr->display_page[i+1].displayptr = sim_window_newtrace(-1, name,
+				(INTBIG)node);
+		}
 	}
 	sim_window_cleartracehighlight();
 	sim_window_settimerange(0.0, 0.0000005f);
 	sim_window_setmaincursor(0.0000002f);
 	sim_window_setextensioncursor(0.0000003f);
 	if (oldsigcount > 0) killstringarray(sa);
-	return(0);
+	return(FALSE);
+}
+
+/*
+ * Helper routine for "esort" that makes bus signals be numerically ordered
+ */
+int simals_sortbusnames(const void *e1, const void *e2)
+{
+	REGISTER char *n1, *n2;
+	REGISTER INTBIG i1, i2;
+
+	i1 = *((INTBIG *)e1);
+	i2 = *((INTBIG *)e2);
+	n1 = simals_levelptr->display_page[i1+1].name;
+	n2 = simals_levelptr->display_page[i2+1].name;
+	if ((net_options&NETDEFBUSBASEDESC) != 0)
+		return(namesamenumeric(n2, n1));
+	return(namesamenumeric(n1, n2));
 }
 
 void simals_fill_display_arrays(void)
 {
-	INTSML i, j, pos, num_chan, *numsteps, **statearrays;
+	INTBIG *numsteps, i, j, pos, num_chan;
+	INTSML **statearrays;
 	INTBIG *nodelist, displayobj;
 	TRAKPTR trakhead;
-	float min, max, **timearrays;
+	double min, max, **timearrays;
 
 	/* determine size needed for waveform arrays */
 	num_chan = simals_levelptr->num_chn;
-	numsteps = (INTSML *)emalloc(num_chan * SIZEOFINTSML, el_tempcluster);
+	numsteps = (INTBIG *)emalloc(num_chan * SIZEOFINTBIG, el_tempcluster);
 	if (numsteps == 0) return;
 	nodelist = (INTBIG *)emalloc(num_chan * SIZEOFINTBIG, el_tempcluster);
 	if (nodelist == 0) return;
-	timearrays = (float **)emalloc(num_chan * (sizeof (float *)), el_tempcluster);
+	timearrays = (double **)emalloc(num_chan * (sizeof (double *)), el_tempcluster);
 	if (timearrays == 0) return;
-	statearrays = (INTSML **)emalloc(num_chan * (sizeof (INTSML*)), el_tempcluster);
+	statearrays = (INTSML **)emalloc(num_chan * (sizeof (INTSML *)), el_tempcluster);
 	if (statearrays == 0) return;
 	for(i=0; i<num_chan; i++)
 	{
@@ -827,7 +865,7 @@ void simals_fill_display_arrays(void)
 	}
 
 	sim_window_gettimerange(&min, &max);
-	if (simals_trakfull == 0) i = 0; else i = (INTSML)simals_trakptr;
+	if (simals_trakfull == 0) i = 0; else i = simals_trakptr;
 	for( ; i < simals_trakptr && i < simals_trace_size; i++)
 	{
 		trakhead = &(simals_trakroot[i]);
@@ -844,7 +882,7 @@ void simals_fill_display_arrays(void)
 	for (j=0; j<num_chan; j++)
 	{
 		if (nodelist[j] == 0) continue;
-		timearrays[j] = (float *)emalloc(numsteps[j] * (sizeof (float)), sim_tool->cluster);
+		timearrays[j] = (double *)emalloc(numsteps[j] * (sizeof (double)), sim_tool->cluster);
 		statearrays[j] = (INTSML *)emalloc(numsteps[j] * SIZEOFINTSML, sim_tool->cluster);
 		if (timearrays[j] == 0 || statearrays[j] == 0) return;
 	}
@@ -857,7 +895,7 @@ void simals_fill_display_arrays(void)
 		timearrays[i][0] = min;
 		statearrays[i][0] = (LOGIC_LOW << 8) | OFF_STRENGTH;
 	}
-	if (simals_trakfull == 0) i = 0; else i = (INTSML)simals_trakptr;
+	if (simals_trakfull == 0) i = 0; else i = simals_trakptr;
 	for( ; i < simals_trakptr && i < simals_trace_size; i++)
 	{
 		trakhead = &(simals_trakroot[i]);
