@@ -37,17 +37,17 @@
 #include "simals.h"
 
 static LINKPTR simals_freelink = 0;
-INTSML  simals_tracing = 0;
+BOOLEAN  simals_tracing = FALSE;
 static char *simals_statedesc[] = {N_("High"), N_("Undefined"), N_("Low")};
 static char *simals_strengthdesc[] = {N_("Off-"), N_("Weak-"), N_("Weak-"), "", "",
 	N_("Strong-"), N_("Strong-")};
 
 /* prototypes for local routines */
-static INTSML simals_fire_event(void);
-static void   simals_create_check_list(NODEPTR, LINKPTR);
-static INTSML simals_schedule_new_events(void);
-static void   simals_calculate_clock_time(LINKPTR, ROWPTR);
-static INTSML simals_calculate_event_time(MODPTR, ROWPTR);
+static BOOLEAN simals_fire_event(void);
+static void    simals_create_check_list(NODEPTR, LINKPTR);
+static BOOLEAN simals_schedule_new_events(void);
+static void    simals_calculate_clock_time(LINKPTR, ROWPTR);
+static BOOLEAN simals_calculate_event_time(MODPTR, ROWPTR);
 
 /*
  * Routine to free all memory associated with this module.
@@ -74,13 +74,13 @@ void simals_freesimmemory(void)
  * tasks are completed the simulator is ready to start the actual simulation.
  * Returns the time where the simulation quiesces.
  */
-float simals_initialize_simulator(INTSML force)
+double simals_initialize_simulator(BOOLEAN force)
 {
 	LINKPTR linkptr2, linkhead, link;
 	NODEPTR nodehead;
 	STATPTR stathead;
 	char s1[40];
-	float tmin, tmax;
+	double tmin, tmax;
 	REGISTER VARIABLE *var;
 
 	simals_time_abs = 0.0;
@@ -137,8 +137,8 @@ float simals_initialize_simulator(INTSML force)
 	if (simals_seed_flag) (void)srand(3);
 
 	/* now run the simulation */
-	if (force != 0) var = NOVARIABLE; else
-		var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, simals_no_update);
+	if (force) var = NOVARIABLE; else
+		var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, simals_no_update_key);
 	if (var == NOVARIABLE || var->addr == 0)
 	{
 		/* fire events until end of time or quiesced */
@@ -146,15 +146,15 @@ float simals_initialize_simulator(INTSML force)
 		while (simals_linkfront && (simals_linkfront->time <= tmax))
 		{
 			if (stopping(STOPREASONSIMULATE)) break;
-			if (simals_fire_event() != 0) break;
+			if (simals_fire_event()) break;
 			if (simals_chekroot)
 			{
-				if (simals_schedule_new_events() != 0) break;
+				if (simals_schedule_new_events()) break;
 			}
 		}
 
 		/* redisplay results */
-		simals_fill_display_arrays();
+		if (simals_levelptr != 0) simals_fill_display_arrays();
 		sim_window_redraw();
 		sim_window_updatelayoutwindow();
 		sim_windowconvertengineeringnotation(simals_time_abs, s1);
@@ -172,13 +172,13 @@ float simals_initialize_simulator(INTSML force)
  * link list and updates the database accordingly.  If a node is updated by a
  * user defined vector the node value is changed as specified in the linklist
  * entry.  If a transition fired, all the output nodes are updated as specified
- * in the truth table for the transtion.  Returns nonzero on error.
+ * in the truth table for the transtion.  Returns true on error.
  */
-INTSML simals_fire_event(void)
+BOOLEAN simals_fire_event(void)
 {
 	INTBIG operand, state;
 	unsigned char operatr;
-	float time;
+	double time;
 	LINKPTR	linkhead, linkptr2, vecthead;
 	NODEPTR	nodehead;
 	ROWPTR rowhead;
@@ -212,17 +212,17 @@ INTSML simals_fire_event(void)
 		}
 	}
 
-	simals_tracing = 0;
+	simals_tracing = FALSE;
 	switch (linkhead->type)
 	{
 		case 'G':
 			stathead = (STATPTR)linkhead->ptr;
-			if (simals_trace_all_nodes != 0 || stathead->nodeptr->tracenode != 0)
+			if (simals_trace_all_nodes || stathead->nodeptr->tracenode)
 			{
 				sim_windowconvertengineeringnotation(simals_time_abs, s1);
 				simals_compute_node_name(stathead->nodeptr, s2);
 				ttyputmsg("%s: Firing gate %s%s, net %s", s1, stathead->primptr->name, stathead->primptr->level, s2);
-				simals_tracing = 1;
+				simals_tracing = TRUE;
 			}
 			if (stathead->sched_state != linkhead->state ||
 				stathead->sched_op != linkhead->operatr ||
@@ -265,7 +265,7 @@ INTSML simals_fire_event(void)
 					break;
 				default:
 					ttyputerr(_("Invalid arithmetic operator: %c"), operatr);
-					return(1);
+					return(TRUE);
 			}
 
 			if (state == stathead->new_state &&
@@ -280,12 +280,12 @@ INTSML simals_fire_event(void)
 
 		case 'N':
 			nodehead = (NODEPTR)linkhead->ptr;
-			if (simals_trace_all_nodes != 0 || nodehead->tracenode != 0)
+			if (simals_trace_all_nodes || nodehead->tracenode)
 			{
 				sim_windowconvertengineeringnotation(simals_time_abs, s1);
 				simals_compute_node_name(nodehead, s2);
 				ttyputmsg("%s: Changed state of net %s", s1, s2);
-				simals_tracing = 1;
+				simals_tracing = TRUE;
 			}
 			if (linkhead->state == nodehead->new_state &&
 				linkhead->strength == nodehead->new_strength)
@@ -302,7 +302,7 @@ INTSML simals_fire_event(void)
 			for (vecthead = (LINKPTR)rowhead->inptr; vecthead; vecthead = vecthead->right)
 			{
 				linkptr2 = simals_alloc_link_mem();
-				if (linkptr2 == 0) return(1);
+				if (linkptr2 == 0) return(TRUE);
 				linkptr2->type = 'N';
 				linkptr2->ptr = vecthead->ptr;
 				linkptr2->state = vecthead->state;
@@ -316,18 +316,18 @@ INTSML simals_fire_event(void)
 			if (linkhead->state == 0)
 			{
 				simals_calculate_clock_time(linkhead, rowhead);
-				return(0);
+				return(FALSE);
 			}
 			--(linkhead->state);
 			if (linkhead->state)
 			{
 				simals_calculate_clock_time(linkhead, rowhead);
-				return(0);
+				return(FALSE);
 			}
 	}
 
 	simals_free_link_mem(linkhead);
-	return(0);
+	return(FALSE);
 }
 
 /*
@@ -354,7 +354,7 @@ void simals_create_check_list(NODEPTR nodehead, LINKPTR linkhead)
 	strength = nodehead->new_strength;
 
 	/* print state of signal if this signal is being traced */
-	if (simals_tracing != 0)
+	if (simals_tracing)
 	{
 		ttyputmsg("  Formerly %s%s, starts at %s%s",
 			_(simals_strengthdesc[nodehead->sum_strength]), _(simals_statedesc[nodehead->sum_state+3]),
@@ -366,7 +366,7 @@ void simals_create_check_list(NODEPTR nodehead, LINKPTR linkhead)
 	{
 		thisstate = stathead->new_state;
 		thisstrength = stathead->new_strength;
-		if (simals_tracing != 0)
+		if (simals_tracing)
 			ttyputmsg("    %s%s from %s%s", _(simals_strengthdesc[thisstrength]),
 			_(simals_statedesc[thisstate+3]), stathead->primptr->name, stathead->primptr->level);
 
@@ -396,7 +396,7 @@ void simals_create_check_list(NODEPTR nodehead, LINKPTR linkhead)
 	/* stop now if node state did not change */
 	if (nodehead->sum_state == state && nodehead->sum_strength == strength)
 	{
-		if (simals_tracing != 0) ttyputmsg("    NO CHANGE");
+		if (simals_tracing) ttyputmsg("    NO CHANGE");
 		return;
 	}
 
@@ -411,7 +411,7 @@ void simals_create_check_list(NODEPTR nodehead, LINKPTR linkhead)
 		if (! simals_trakptr)
 			simals_trakfull = 1;
 	}
-	if (simals_tracing != 0)
+	if (simals_tracing)
 		ttyputmsg("    BECOMES %s%s", _(simals_strengthdesc[strength]), _(simals_statedesc[state+3]));
 
 	nodehead->sum_state = state;
@@ -429,9 +429,9 @@ void simals_create_check_list(NODEPTR nodehead, LINKPTR linkhead)
  *	This procedure examines the truth tables for the transitions that are
  * specified in the checking list.  If there is a match between a truth table
  * entry and the state of the logic network the transition is scheduled
- * for firing.  Returns nonzero on error.
+ * for firing.  Returns true on error.
  */
-INTSML simals_schedule_new_events(void)
+BOOLEAN simals_schedule_new_events(void)
 {
 	INTBIG operand;
 	unsigned char flag, operatr;
@@ -485,7 +485,7 @@ INTSML simals_schedule_new_events(void)
 						break;
 					default:
 						ttyputerr(_("Invalid logical operator: %c"), operatr);
-						return(1);
+						return(TRUE);
 				}
 
 				if (! flag) break;
@@ -493,13 +493,13 @@ INTSML simals_schedule_new_events(void)
 
 			if (flag)
 			{
-				if (simals_calculate_event_time(primhead, rowhead) != 0) return(1);
+				if (simals_calculate_event_time(primhead, rowhead)) return(TRUE);
 				break;
 			}
 		}
 	}
 	simals_chekroot = 0;
-	return(0);
+	return(FALSE);
 }
 
 /*
@@ -515,15 +515,15 @@ INTSML simals_schedule_new_events(void)
  */
 void simals_calculate_clock_time(LINKPTR linkhead, ROWPTR rowhead)
 {
-	float time, prob;
+	double time, prob;
 
 	time = simals_time_abs;
 
 	if (rowhead->delta) time += rowhead->delta;
 	if (rowhead->linear)
 	{
-		prob = (float)(rand() / MAXINTBIG);
-		time += 2.0f * prob * rowhead->linear;
+		prob = rand() / MAXINTBIG;
+		time += 2.0 * prob * rowhead->linear;
 	}
 
 	/*
@@ -546,16 +546,16 @@ void simals_calculate_clock_time(LINKPTR linkhead, ROWPTR rowhead)
  * Description:
  *	This procedure calculates the time of occurance of an event and then
  * places an entry into the event scheduling linklist for later execution.
- * Returns nonzero on error.
+ * Returns true on error.
  *
  * Calling Arguments:
  *	primhead  = pointer to the primitive to be scheduled for firing
  *	rowhead  = pointer to the row containing the event to be scheduled
  */
-INTSML simals_calculate_event_time(MODPTR primhead, ROWPTR rowhead)
+BOOLEAN simals_calculate_event_time(MODPTR primhead, ROWPTR rowhead)
 {
 	INTSML priority;
-	float time, prob;
+	double time, prob;
 	STATPTR	stathead;
 	IOPTR iohead;
 	LINKPTR	linkptr2;
@@ -568,8 +568,8 @@ INTSML simals_calculate_event_time(MODPTR primhead, ROWPTR rowhead)
 	if (rowhead->abs) time += rowhead->abs;
 	if (rowhead->linear)
 	{
-		prob = (float)(rand() / MAXINTBIG);
-		time += 2.0f * prob * rowhead->linear;
+		prob = rand() / MAXINTBIG;
+		time += 2.0 * prob * rowhead->linear;
 	}
 
 	/*
@@ -582,7 +582,7 @@ INTSML simals_calculate_event_time(MODPTR primhead, ROWPTR rowhead)
 
 	if (rowhead->random)
 	{
-		prob = (float)(rand() / MAXINTBIG);
+		prob = rand() / MAXINTBIG;
 		if (prob <= rowhead->random)
 		{
 			priority = -1;
@@ -607,7 +607,7 @@ INTSML simals_calculate_event_time(MODPTR primhead, ROWPTR rowhead)
 		}
 
 		linkptr2 = simals_alloc_link_mem();
-		if (linkptr2 == 0) return(1);
+		if (linkptr2 == 0) return(TRUE);
 		linkptr2->type = 'G';
 		linkptr2->ptr = (char *)stathead;
 		linkptr2->operatr = stathead->sched_op = iohead->operatr;
@@ -616,7 +616,7 @@ INTSML simals_calculate_event_time(MODPTR primhead, ROWPTR rowhead)
 		linkptr2->time = time;
 		linkptr2->priority = priority;
 		linkptr2->primhead = primhead;
-		if (simals_tracing != 0)
+		if (simals_tracing)
 		{
 			sim_windowconvertengineeringnotation(time, s1);
 			ttyputmsg(_("      Schedule(G): %s%s at %s"), stathead->primptr->name,
@@ -624,7 +624,7 @@ INTSML simals_calculate_event_time(MODPTR primhead, ROWPTR rowhead)
 		}
 		simals_insert_link_list(linkptr2);
 	}
-	return(0);
+	return(FALSE);
 }
 
 /*
