@@ -38,29 +38,29 @@
 
 
 /* keys to cached variables */
-INTBIG sim_fasthenrystatekey = 0;			/* cached key for "SIM_fasthenry_state" */
-INTBIG sim_fasthenryfreqstartkey = 0;		/* cached key for "SIM_fasthenry_freqstart" */
-INTBIG sim_fasthenryfreqendkey = 0;			/* cached key for "SIM_fasthenry_freqend" */
-INTBIG sim_fasthenryrunsperdecadekey = 0;	/* cached key for "SIM_fasthenry_runsperdecade" */
-INTBIG sim_fasthenrynumpoleskey = 0;		/* cached key for "SIM_fasthenry_numpoles" */
-INTBIG sim_fasthenryseglimitkey = 0;		/* cached key for "SIM_fasthenry_seglimit" */
-INTBIG sim_fasthenrythicknesskey = 0;		/* cached key for "SIM_fasthenry_thickness" */
-INTBIG sim_fasthenrywidthsubdivkey = 0;		/* cached key for "SIM_fasthenry_width_subdivs" */
-INTBIG sim_fasthenryheightsubdivkey = 0;	/* cached key for "SIM_fasthenry_height_subdivs" */
+INTBIG sim_fasthenrystatekey = 0;			/* variable key for "SIM_fasthenry_state" */
+INTBIG sim_fasthenryfreqstartkey = 0;		/* variable key for "SIM_fasthenry_freqstart" */
+INTBIG sim_fasthenryfreqendkey = 0;			/* variable key for "SIM_fasthenry_freqend" */
+INTBIG sim_fasthenryrunsperdecadekey = 0;	/* variable key for "SIM_fasthenry_runsperdecade" */
+INTBIG sim_fasthenrynumpoleskey = 0;		/* variable key for "SIM_fasthenry_numpoles" */
+INTBIG sim_fasthenryseglimitkey = 0;		/* variable key for "SIM_fasthenry_seglimit" */
+INTBIG sim_fasthenrythicknesskey = 0;		/* variable key for "SIM_fasthenry_thickness" */
+INTBIG sim_fasthenrywidthsubdivkey = 0;		/* variable key for "SIM_fasthenry_width_subdivs" */
+INTBIG sim_fasthenryheightsubdivkey = 0;	/* variable key for "SIM_fasthenry_height_subdivs" */
 
-INTBIG sim_fasthenryzheadkey = 0;			/* cached key for "SIM_fasthenry_z_head" */
-INTBIG sim_fasthenryztailkey = 0;			/* cached key for "SIM_fasthenry_z_tail" */
-INTBIG sim_fasthenrygroupnamekey = 0;		/* cached key for "SIM_fasthenry_group_name" */
+INTBIG sim_fasthenryzheadkey = 0;			/* variable key for "SIM_fasthenry_z_head" */
+INTBIG sim_fasthenryztailkey = 0;			/* variable key for "SIM_fasthenry_z_tail" */
+INTBIG sim_fasthenrygroupnamekey = 0;		/* variable key for "SIM_fasthenry_group_name" */
 
 /* prototypes for local routines */
-static INTSML sim_writefhfacet(NODEPROTO *np, FILE *io);
-static void   sim_fasthenryarcdlog(void);
-static void   sim_fasthenrydlog(void);
-static void   sim_fasthenrygetoptions(INTBIG *options, float *startfreq, float *endfreq,
+static BOOLEAN sim_writefhfacet(NODEPROTO *np, FILE *io);
+static void    sim_fasthenryarcdlog(void);
+static void    sim_fasthenrydlog(void);
+static void    sim_fasthenrygetoptions(INTBIG *options, float *startfreq, float *endfreq,
 				INTBIG *runsperdecade, INTBIG *numpoles, INTBIG *seglenlimit, INTBIG *thickness,
 				INTBIG *widsubdiv, INTBIG *heisubdiv);
-static char  *sim_fasthenrygetarcoptions(ARCINST *ai, INTBIG *thickness, INTBIG *widsubdiv,
-				INTBIG *heisubdiv, INTBIG *z_head, INTBIG *z_tail, INTSML *zhover, INTSML *ztover,
+static char   *sim_fasthenrygetarcoptions(ARCINST *ai, INTBIG *thickness, INTBIG *widsubdiv,
+				INTBIG *heisubdiv, INTBIG *z_head, INTBIG *z_tail, BOOLEAN *zhover, BOOLEAN *ztover,
 				INTBIG *defz);
 static PORTPROTO *sim_fasthenryfindotherport(ARCINST *ai, INTBIG end);
 
@@ -82,7 +82,6 @@ void sim_writefasthenrynetlist(NODEPROTO *np)
 {
 	char name[100], *truename, *args[30], txtpoles[20], *path;
 	FILE *io;
-	UINTBIG cdate, rdate;
 	float startfreq, endfreq;
 	INTBIG options, runsperdecade, numpoles, seglenlimit, thickness, widsubdiv, heisubdiv;
 	REGISTER INTBIG argc, i;
@@ -91,7 +90,7 @@ void sim_writefasthenrynetlist(NODEPROTO *np)
 	if ((net_tool->toolstate&TOOLON) == 0)
 	{
 		ttyputerr(_("Network tool must be running...turning it on"));
-		toolturnon(net_tool, 0);
+		toolturnon(net_tool, FALSE);
 		ttyputerr(_("...now reissue the simulation command"));
 		return;
 	}
@@ -111,16 +110,18 @@ void sim_writefasthenrynetlist(NODEPROTO *np)
 	}
 	xprintf(io, "* FastHenry for facet %s\n", describenodeproto(np));
 
-	cdate = np->creationdate;
-	rdate = np->revisiondate;
-	if (cdate != 0 && rdate != 0)
+	if ((us_useroptions&NODATEORVERSION) == 0)
 	{
-		xprintf(io, "* Facet created on %s\n", timetostring(cdate));
-		xprintf(io, "* Facet last modified on %s\n", timetostring(rdate));
+		if (np->creationdate != 0)
+			xprintf(io, "* Facet created on %s\n", timetostring(np->creationdate));
+		if (np->revisiondate != 0)
+			xprintf(io, "* Facet last modified on %s\n", timetostring(np->revisiondate));
+		xprintf(io, "* Netlist written on %s\n", timetostring(getcurrenttime()));
+		xprintf(io, "* Written by Electric VLSI Design System, version %s\n", el_version);
+	} else
+	{
+		xprintf(io, "* Written by Electric VLSI Design System\n");
 	}
-	cdate = getcurrenttime();
-	xprintf(io, "* Netlist written on %s\n", timetostring(cdate));
-	xprintf(io, "* Written by Electric VLSI Design System, version %s\n", el_version);
 
 	xprintf(io, "\n* Units are microns\n");
 	xprintf(io, ".units um\n");
@@ -130,7 +131,7 @@ void sim_writefasthenrynetlist(NODEPROTO *np)
 	xprintf(io, ".Default nwinc=%ld nhinc=%ld h=%s\n", widsubdiv, heisubdiv, latoa(thickness));
 
 	/* reset flags for facets that have been written */
-	if (sim_writefhfacet(np, io) != 0)
+	if (sim_writefhfacet(np, io))
 		ttyputmsg("Back-annotation information has been added (library must be saved)");
 
 	/* write frequency range */
@@ -192,9 +193,9 @@ void sim_writefasthenrynetlist(NODEPROTO *np)
  * The description is treated as the top-level facet if "top" is nonzero
  * np is the current nodeproto
  */
-INTSML sim_writefhfacet(NODEPROTO *np, FILE *io)
+BOOLEAN sim_writefhfacet(NODEPROTO *np, FILE *io)
 {
-	REGISTER INTSML backannotate, found;
+	REGISTER BOOLEAN backannotate, found;
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
 	REGISTER PORTARCINST *pi;
@@ -207,7 +208,7 @@ INTSML sim_writefhfacet(NODEPROTO *np, FILE *io)
 	float startfreq, endfreq;
 	INTBIG options, runsperdecade, numpoles, seglenlimit, thickness, defthickness,
 		widsubdiv, defwidsubdiv, heisubdiv, defheisubdiv, z_head, z_tail, defz;
-	INTSML zhover, ztover;
+	BOOLEAN zhover, ztover;
 
 	/* get polygon */
 	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, sim_tool->cluster);
@@ -216,7 +217,7 @@ INTSML sim_writefhfacet(NODEPROTO *np, FILE *io)
 	if (el_pleasestop != 0)
 	{
 		stopping(STOPREASONDECK);
-		return(0);
+		return(FALSE);
 	}
 
 	/* get overriding defaults */
@@ -224,15 +225,15 @@ INTSML sim_writefhfacet(NODEPROTO *np, FILE *io)
 		&seglenlimit, &defthickness, &defwidsubdiv, &defheisubdiv);
 
 	/* make sure that all nodes have names on them */
-	backannotate = 0;
-	if (asktool(net_tool, "name-all-nodes", (INTBIG)np) != 0) backannotate++;
+	backannotate = FALSE;
+	if (asktool(net_tool, "name-all-nodes", (INTBIG)np) != 0) backannotate = TRUE;
 
 	/* look at every node in the facet */
 	xprintf(io, "\n* Traces\n");
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		/* see if this node has a FastHenry arc on it */
-		found = 0;
+		found = FALSE;
 		for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 		{
 			ai = pi->conarcinst;
@@ -240,9 +241,9 @@ INTSML sim_writefhfacet(NODEPROTO *np, FILE *io)
 				&z_head, &z_tail, &zhover, &ztover, &defz);
 			if (groupname == 0) continue;
 			zval = defz;
-			if (ai->end[0].portarcinst == pi && zhover != 0) zval = z_head;
-			if (ai->end[1].portarcinst == pi && ztover != 0) zval = z_tail;
-			if (found != 0)
+			if (ai->end[0].portarcinst == pi && zhover) zval = z_head;
+			if (ai->end[1].portarcinst == pi && ztover) zval = z_tail;
+			if (found)
 			{
 				/* LINTED "nodezval" used in proper order */
 				if (zval != nodezval)
@@ -250,9 +251,9 @@ INTSML sim_writefhfacet(NODEPROTO *np, FILE *io)
 						describenodeinst(ni));
 			}
 			nodezval = zval;
-			found++;
+			found = TRUE;
 		}
-		if (found == 0) continue;
+		if (!found) continue;
 
 		/* node is an end point: get its name */
 		if (ni->firstportexpinst != NOPORTEXPINST)
@@ -260,7 +261,7 @@ INTSML sim_writefhfacet(NODEPROTO *np, FILE *io)
 			nname = ni->firstportexpinst->exportproto->protoname;
 		} else
 		{
-			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name);
+			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
 			if (var == NOVARIABLE) nname = ""; else nname = (char *)var->addr;
 		}
 
@@ -288,7 +289,7 @@ INTSML sim_writefhfacet(NODEPROTO *np, FILE *io)
 			n1name = ai->end[0].nodeinst->firstportexpinst->exportproto->protoname;
 		} else
 		{
-			var = getvalkey((INTBIG)ai->end[0].nodeinst, VNODEINST, VSTRING, el_node_name);
+			var = getvalkey((INTBIG)ai->end[0].nodeinst, VNODEINST, VSTRING, el_node_name_key);
 			if (var == NOVARIABLE) n1name = ""; else n1name = (char *)var->addr;
 		}
 		if (ai->end[1].nodeinst->firstportexpinst != NOPORTEXPINST)
@@ -296,7 +297,7 @@ INTSML sim_writefhfacet(NODEPROTO *np, FILE *io)
 			n2name = ai->end[1].nodeinst->firstportexpinst->exportproto->protoname;
 		} else
 		{
-			var = getvalkey((INTBIG)ai->end[1].nodeinst, VNODEINST, VSTRING, el_node_name);
+			var = getvalkey((INTBIG)ai->end[1].nodeinst, VNODEINST, VSTRING, el_node_name_key);
 			if (var == NOVARIABLE) n2name = ""; else n2name = (char *)var->addr;
 		}
 
@@ -412,7 +413,7 @@ void sim_fasthenrygetoptions(INTBIG *options, float *startfreq, float *endfreq,
 }
 
 char *sim_fasthenrygetarcoptions(ARCINST *ai, INTBIG *thickness, INTBIG *widsubdiv,
-	INTBIG *heisubdiv, INTBIG *z_head, INTBIG *z_tail, INTSML *zhover, INTSML *ztover,
+	INTBIG *heisubdiv, INTBIG *z_head, INTBIG *z_tail, BOOLEAN *zhover, BOOLEAN *ztover,
 	INTBIG *defz)
 {
 	REGISTER VARIABLE *var;
@@ -436,22 +437,22 @@ char *sim_fasthenrygetarcoptions(ARCINST *ai, INTBIG *thickness, INTBIG *widsubd
 	for(i=0; i<total; i++)
 	{
 		shapearcpoly(ai, i, poly);
-		if (get3dfactors(ai->proto->tech, poly->layer, &lheight, &lthickness) != 0)
+		if (get3dfactors(ai->proto->tech, poly->layer, &lheight, &lthickness))
 			continue;
 		*defz = lheight * lambdaofarc(ai);
 		break;
 	}
 	var = getvalkey((INTBIG)ai, VARCINST, VINTEGER, sim_fasthenryzheadkey);
-	if (var == NOVARIABLE) *zhover = 0; else
+	if (var == NOVARIABLE) *zhover = FALSE; else
 	{
 		*z_head = var->addr;
-		*zhover = 1;
+		*zhover = TRUE;
 	}
 	var = getvalkey((INTBIG)ai, VARCINST, VINTEGER, sim_fasthenryztailkey);
-	if (var == NOVARIABLE) *ztover = 0; else
+	if (var == NOVARIABLE) *ztover = FALSE; else
 	{
 		*z_tail = var->addr;
-		*ztover = 1;
+		*ztover = TRUE;
 	}		
 
 	/* get the group name */
@@ -478,15 +479,15 @@ static DIALOGITEM sim_fasthenrydialogitems[] =
  /* 11 */ {0, {128,144,144,200}, EDITTEXT, ""},
  /* 12 */ {0, {104,8,120,200}, CHECK, N_("Make multipole subcircuit")},
  /* 13 */ {0, {104,232,120,420}, CHECK, N_("Make PostScript view")},
- /* 14 */ {0, {76,232,92,420}, MESSAGE, N_("Maximum segment length:")},
- /* 15 */ {0, {76,424,92,480}, EDITTEXT, ""},
- /* 16 */ {0, {28,232,44,420}, MESSAGE, N_("Default width subdivisions:")},
- /* 17 */ {0, {28,424,44,480}, EDITTEXT, ""},
- /* 18 */ {0, {52,232,68,420}, MESSAGE, N_("Default height subdivisions:")},
- /* 19 */ {0, {52,424,68,480}, EDITTEXT, ""},
+ /* 14 */ {0, {80,232,96,420}, MESSAGE, N_("Maximum segment length:")},
+ /* 15 */ {0, {80,424,96,480}, EDITTEXT, ""},
+ /* 16 */ {0, {32,232,48,420}, MESSAGE, N_("Default width subdivisions:")},
+ /* 17 */ {0, {32,424,48,480}, EDITTEXT, ""},
+ /* 18 */ {0, {56,232,72,420}, MESSAGE, N_("Default height subdivisions:")},
+ /* 19 */ {0, {56,424,72,480}, EDITTEXT, ""},
  /* 20 */ {0, {128,232,144,420}, CHECK, N_("Make SPICE subcircuit")},
- /* 21 */ {0, {4,232,20,420}, MESSAGE, N_("Default thickness:")},
- /* 22 */ {0, {4,424,20,480}, EDITTEXT, ""},
+ /* 21 */ {0, {8,232,24,420}, MESSAGE, N_("Default thickness:")},
+ /* 22 */ {0, {8,424,24,480}, EDITTEXT, ""},
  /* 23 */ {0, {176,140,192,344}, POPUP, ""},
  /* 24 */ {0, {156,176,172,320}, MESSAGE, N_("After writing deck:")}
 };
@@ -512,7 +513,8 @@ static DIALOG sim_fasthenrydialog = {{75,75,276,564}, N_("FastHenry Options"), 0
 
 void sim_fasthenrydlog(void)
 {
-	REGISTER INTBIG itemHit, value, canexecute, i;
+	REGISTER INTBIG itemHit, value, i;
+	REGISTER BOOLEAN canexecute;
 	float fvalue;
 	char line[30], *newlang[5];
 	static char *exechoices[] = {N_("Nothing run"), N_("Run FastHenry"),
@@ -526,13 +528,13 @@ void sim_fasthenrydlog(void)
 		&seglenlimit, &thickness, &widsubdiv, &heisubdiv);
 
 	/* Display the FastHenry options dialog box */
-	if (DiaInitDialog(&sim_fasthenrydialog) != 0) return;
+	if (DiaInitDialog(&sim_fasthenrydialog)) return;
 
 	/* set popup */
 	for(i=0; i<3; i++) newlang[i] = _(exechoices[i]);
 	DiaSetPopup(DFHO_AFTERWRITE, 3, newlang);
 	canexecute = graphicshas(CANRUNPROCESS);
-	if (canexecute != 0)
+	if (canexecute)
 	{
 		if ((options&FHEXECUTETYPE) == FHEXECUTERUNFH)
 		{
@@ -745,7 +747,7 @@ void sim_fasthenryarcdlog(void)
 	float startfreq, endfreq;
 	INTBIG options, runsperdecade, numpoles, seglenlimit, thickness, defthickness,
 		widsubdiv, defwidsubdiv, heisubdiv, defheisubdiv, z_head, z_tail, defz;
-	INTSML zhover, ztover;
+	BOOLEAN zhover, ztover;
 
 	/* get currently selected arc */
 	ai = (ARCINST *)asktool(us_tool, "get-arc");
@@ -762,7 +764,7 @@ void sim_fasthenryarcdlog(void)
 		&z_head, &z_tail, &zhover, &ztover, &defz);
 
 	/* display the FastHenry arc dialog box */
-	if (DiaInitDialog(&sim_fasthenryarcdialog) != 0) return;
+	if (DiaInitDialog(&sim_fasthenryarcdialog)) return;
 
 	/* make a list of all group names */
 	groupnamesize = 0;
@@ -833,10 +835,10 @@ void sim_fasthenryarcdlog(void)
 	DiaSetText(DFHA_DEFZ, latoa(defz));
 	DiaSetText(DFHA_ARCHEADX, latoa(ai->end[0].xpos));
 	DiaSetText(DFHA_ARCHEADY, latoa(ai->end[0].ypos));
-	if (zhover != 0) DiaSetText(DFHA_ARCHEADZ, latoa(z_head));
+	if (zhover) DiaSetText(DFHA_ARCHEADZ, latoa(z_head));
 	DiaSetText(DFHA_ARCTAILX, latoa(ai->end[1].xpos));
 	DiaSetText(DFHA_ARCTAILY, latoa(ai->end[1].ypos));
-	if (ztover != 0) DiaSetText(DFHA_ARCTAILZ, latoa(z_tail));
+	if (ztover) DiaSetText(DFHA_ARCTAILZ, latoa(z_tail));
 
 	if (groupname != 0)
 	{
@@ -950,7 +952,7 @@ void sim_fasthenryarcdlog(void)
 		} else
 		{
 			if (var != NOVARIABLE)
-				delvalkey((INTBIG)ai, VARCINST, sim_fasthenrygroupnamekey);
+				(void)delvalkey((INTBIG)ai, VARCINST, sim_fasthenrygroupnamekey);
 		}
 
 		/* save thickness */
@@ -964,7 +966,7 @@ void sim_fasthenryarcdlog(void)
 		} else
 		{
 			if (var != NOVARIABLE)
-				delvalkey((INTBIG)ai, VARCINST, sim_fasthenrythicknesskey);
+				(void)delvalkey((INTBIG)ai, VARCINST, sim_fasthenrythicknesskey);
 		}
 
 		/* save width and height subdivisions */
@@ -978,7 +980,7 @@ void sim_fasthenryarcdlog(void)
 		} else
 		{
 			if (var != NOVARIABLE)
-				delvalkey((INTBIG)ai, VARCINST, sim_fasthenrywidthsubdivkey);
+				(void)delvalkey((INTBIG)ai, VARCINST, sim_fasthenrywidthsubdivkey);
 		}
 		pt = DiaGetText(DFHA_HEIGHTSUBDIV);
 		var = getvalkey((INTBIG)ai, VARCINST, VINTEGER, sim_fasthenryheightsubdivkey);
@@ -990,7 +992,7 @@ void sim_fasthenryarcdlog(void)
 		} else
 		{
 			if (var != NOVARIABLE)
-				delvalkey((INTBIG)ai, VARCINST, sim_fasthenryheightsubdivkey);
+				(void)delvalkey((INTBIG)ai, VARCINST, sim_fasthenryheightsubdivkey);
 		}
 
 		/* save z overrides */
@@ -1004,7 +1006,7 @@ void sim_fasthenryarcdlog(void)
 		} else
 		{
 			if (var != NOVARIABLE)
-				delvalkey((INTBIG)ai, VARCINST, sim_fasthenryzheadkey);
+				(void)delvalkey((INTBIG)ai, VARCINST, sim_fasthenryzheadkey);
 		}
 		pt = DiaGetText(DFHA_ARCTAILZ);
 		var = getvalkey((INTBIG)ai, VARCINST, VINTEGER, sim_fasthenryztailkey);
@@ -1016,7 +1018,7 @@ void sim_fasthenryarcdlog(void)
 		} else
 		{
 			if (var != NOVARIABLE)
-				delvalkey((INTBIG)ai, VARCINST, sim_fasthenryztailkey);
+				(void)delvalkey((INTBIG)ai, VARCINST, sim_fasthenryztailkey);
 		}
 		endobjectchange((INTBIG)ai, VARCINST);
 	}
