@@ -35,6 +35,7 @@
 #include "global.h"
 #include "efunction.h"
 #include "sim.h"
+#include "usr.h"
 #include "tecschem.h"
 
 #define MAXSTR  79		/* split lines into 80 characters */
@@ -66,27 +67,27 @@
 
 static FILE  *sim_silfile;
 extern INTBIG sim_pseudonet;		/* for internal networks */
-static INTBIG sim_silos_global_name = 0;
+static INTBIG sim_silos_global_name_key = 0;
 static INTBIG sim_silos_model_key = 0;		/* for model on cell */
 
 /* ************************************************************* */
 
 /* prototypes for local routines */
-static INTBIG  sim_writesilfacet(NODEPROTO*, INTSML);
-static void    sim_writesilinstances(NODEPROTO*, INTSML);
-static char   *sim_silportname(INTSML, NODEINST*, PORTPROTO*, NODEPROTO*);
+static INTBIG  sim_writesilfacet(NODEPROTO*, BOOLEAN);
+static void    sim_writesilinstances(NODEPROTO*, BOOLEAN);
+static char   *sim_silportname(BOOLEAN, NODEINST*, PORTPROTO*, NODEPROTO*);
 static char   *sim_silname(NODEINST*);
-static char   *sim_silproto(NODEINST*, INTSML);
+static char   *sim_silproto(NODEINST*, BOOLEAN);
 static char   *sim_siltext(char*);
 static void    sim_sendtosil(char*);
 static char   *sim_silarcname(ARCINST*);
-static INTSML  sim_silnegated(PORTARCINST*);
+static BOOLEAN sim_silnegated(PORTARCINST*);
 static char   *sim_silspecials(char*);
-static INTSML  sim_silostype(NODEINST*);
+static INTBIG  sim_silostype(NODEINST*);
 static char   *sim_silrisetime(NODEINST*);
 static char   *sim_silfalltime(NODEINST*);
 static INTBIG  sim_silgetcapacitance(NODEINST*);
-static void    sim_silwriteflipflop(INTSML, NODEINST*, NODEPROTO*, INTSML);
+static void    sim_silwriteflipflop(BOOLEAN, NODEINST*, NODEPROTO*, INTBIG);
 static char   *sim_sil_isaport(NODEPROTO*, char*);
 static char   *sim_convertsub(char*);
 
@@ -98,14 +99,12 @@ void sim_writesilnetlist(NODEPROTO *np)
 	char name[100], numberstring[100], *truename;
 	REGISTER NODEPROTO *lnp;
 	REGISTER LIBRARY *lib;
-	UINTBIG cdate, rdate;
-	INTBIG rnum;
 
 	/* make sure network tool is on */
 	if ((net_tool->toolstate&TOOLON) == 0)
 	{
 		ttyputerr(_("Network tool must be running...turning it on"));
-		toolturnon(net_tool, 0);
+		toolturnon(net_tool, FALSE);
 		ttyputerr(_("...now reissue the simulation command"));
 		return;
 	}
@@ -125,46 +124,50 @@ void sim_writesilnetlist(NODEPROTO *np)
 	sim_sendtosil(" FROM LIBRARY:");
 	sim_sendtosil(np->cell->lib->libname);
 	sim_sendtosil("\n");
-	cdate = np->creationdate;
-	if (cdate)
+	if ((us_useroptions&NODATEORVERSION) == 0)
 	{
-		(void)sprintf(numberstring,"$ FACET CREATED ON %s", timetostring(cdate));
+		if (np->creationdate)
+		{
+			(void)sprintf(numberstring,"$ FACET CREATED ON %s", timetostring(np->creationdate));
+			sim_sendtosil(numberstring);
+			sim_sendtosil("\n");
+		}
+		if (np->version)
+		{
+			(void)sprintf(numberstring,"$ VERSION %ld", np->version);
+			sim_sendtosil(numberstring);
+			sim_sendtosil("\n");
+		}
+		if (np->revisiondate)
+		{
+			(void)sprintf(numberstring,"$ LAST REVISED %s", timetostring(np->revisiondate));
+			sim_sendtosil(numberstring);
+			sim_sendtosil("\n");
+		}
+		(void)sprintf(numberstring, "$ SILOS netlist written by Electric Design System; Version %s",
+			el_version);
 		sim_sendtosil(numberstring);
 		sim_sendtosil("\n");
-	}
-	rnum = np->version;
-	if (rnum)
-	{
-		(void)sprintf(numberstring,"$ VERSION %ld",rnum);
-		sim_sendtosil(numberstring);
-		sim_sendtosil("\n");
-	}
-	rdate = np->revisiondate;
-	if (rdate)
-	{
-		(void)sprintf(numberstring,"$ LAST REVISED %s", timetostring(rdate));
-		sim_sendtosil(numberstring);
-		sim_sendtosil("\n");
-	}
-	(void)sprintf(numberstring, "$ SILOS netlist written by Electric Design System; Version %s",
-		el_version);
-	sim_sendtosil(numberstring);
-	sim_sendtosil("\n");
-	cdate = getcurrenttime();
-	(void)sprintf(numberstring, "%s", timetostring(cdate));
 
-	sim_sendtosil("$ WRITTEN ON ");
-	sim_sendtosil(numberstring);
-	sim_sendtosil("\n");
+		(void)sprintf(numberstring, "%s", timetostring(getcurrenttime()));
+		sim_sendtosil("$ WRITTEN ON ");
+		sim_sendtosil(numberstring);
+		sim_sendtosil("\n");
+	} else
+	{
+		sim_sendtosil("$ SILOS netlist written by Electric Design System\n");
+	}
 
-	if (sim_silos_global_name == 0) sim_silos_global_name = makekey("SIM_silos_global_name");
-	if (sim_silos_model_key == 0) sim_silos_model_key = makekey("SC_silos");
+	if (sim_silos_global_name_key == 0)
+		sim_silos_global_name_key = makekey("SIM_silos_global_name");
+	if (sim_silos_model_key == 0)
+		sim_silos_model_key = makekey("SC_silos");
 
 	/* reset flags for facets that have been written */
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 		for(lnp = lib->firstnodeproto; lnp != NONODEPROTO; lnp = lnp->nextnodeproto)
 			lnp->temp1 = 0;
-	if (sim_writesilfacet(np, 1) != 0)
+	if (sim_writesilfacet(np, TRUE) != 0)
 		ttyputmsg(_("Back-annotation information has been added (library must be saved)"));
 	sim_sendtosil("\n");
 
@@ -176,10 +179,10 @@ void sim_writesilnetlist(NODEPROTO *np)
 
 /*
  * recursively called routine to print the SILOS description of facet "np".
- * The description is treated as the top-level facet if "top" is nonzero
+ * The description is treated as the top-level facet if "top" is true
  * np is the current nodeproto
  */
-INTBIG sim_writesilfacet(NODEPROTO *np, INTSML top)
+INTBIG sim_writesilfacet(NODEPROTO *np, BOOLEAN top)
 {
 	char buf[256];
 	REGISTER INTBIG i, j, nodetype, clktype, count, backannotate;
@@ -201,7 +204,7 @@ INTBIG sim_writesilfacet(NODEPROTO *np, INTSML top)
 	backannotate = 0;
 
 	/* First look for any global sources */
-	if (top != 0)
+	if (top)
 	{
 		for (ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		{
@@ -210,7 +213,7 @@ INTBIG sim_writesilfacet(NODEPROTO *np, INTSML top)
 			nodetype = nodefunction(ni);
 			if (nodetype != NPSOURCE) continue;
 
-			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, sim_silos_global_name);
+			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, sim_silos_global_name_key);
 			if (var != NOVARIABLE)	/* is this a global source ? */
 			{
 				name = (char *)var->addr;
@@ -266,7 +269,7 @@ INTBIG sim_writesilfacet(NODEPROTO *np, INTSML top)
 				/* copy the file */
 				for(;;)
 				{
-					count = (INTSML)xfread(buf, 1, 256, f);
+					count = xfread(buf, 1, 256, f);
 					if (count <= 0) break;
 					if (xfwrite(buf, 1, count, sim_silfile) != count)
 						ttyputerr(_("Error copying file"));
@@ -291,7 +294,7 @@ INTBIG sim_writesilfacet(NODEPROTO *np, INTSML top)
 		if (var != NOVARIABLE)
 		{
 			model = (char **)var->addr;
-			j = (INTSML)getlength(var);
+			j = getlength(var);
 			for(i = 0; i < j; i++)
 				xprintf(sim_silfile, "%s\n", model[i]);
 			sim_sendtosil("\n");
@@ -322,7 +325,7 @@ INTBIG sim_writesilfacet(NODEPROTO *np, INTSML top)
 		/* write the subfacet */
 		if (onp->temp1 == 0)
 		{
-			if (sim_writesilfacet(onp, 0) != 0) backannotate = 1;
+			if (sim_writesilfacet(onp, FALSE) != 0) backannotate = 1;
 		}
 	}
 
@@ -333,7 +336,7 @@ INTBIG sim_writesilfacet(NODEPROTO *np, INTSML top)
 	np->temp1++;
 
 	/* write the header if this not the top level */
-	if (top == 0)
+	if (!top)
 	{
 		sim_sendtosil("\n");
 		sim_sendtosil(".MACRO");
@@ -381,10 +384,10 @@ INTBIG sim_writesilfacet(NODEPROTO *np, INTSML top)
 /* Function to write the instances contained in 'np'
  * This was part of sim_writesilfacet before...
  */
-void sim_writesilinstances(NODEPROTO *np, INTSML top)
+void sim_writesilinstances(NODEPROTO *np, BOOLEAN top)
 {
 	REGISTER INTBIG j, schem_ref;
-	REGISTER INTSML nodetype;
+	REGISTER INTBIG nodetype;
 	REGISTER NODEINST *ni;
 	REGISTER PORTPROTO *pp, *lastpp, *outpp;
 	REGISTER PORTARCINST *pi;
@@ -419,7 +422,7 @@ void sim_writesilinstances(NODEPROTO *np, INTSML top)
 				sim_sendtosil("(");
 				sim_sendtosil(sim_silname(ni));
 				sim_sendtosil(" ");
-				sim_sendtosil(sim_silproto(ni, 0));	/* write the type */
+				sim_sendtosil(sim_silproto(ni, FALSE));	/* write the type */
 
 				/* write the rest of the port(s), connected or not */
 				for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
@@ -435,7 +438,7 @@ void sim_writesilinstances(NODEPROTO *np, INTSML top)
 				/* Transistors and flip-flops need a part number */
 				sim_sendtosil(sim_silname(ni));
 				sim_sendtosil(" ");
-				sim_sendtosil(sim_silproto(ni, 0));
+				sim_sendtosil(sim_silproto(ni, FALSE));
 
 				/* write the names of the port(s) */
 				if (nodetype == SILOSTFF || nodetype == SILOSDFF ||
@@ -451,7 +454,7 @@ void sim_writesilinstances(NODEPROTO *np, INTSML top)
 
 			case SILOSCLOCK:
 			case SILOSSOURCE:
-				if (top ==0) ttyputerr(_("WARNING: Global Clock in a sub-facet"));
+				if (!top) ttyputerr(_("WARNING: Global Clock in a sub-facet"));
 				break;
 
 			case SILOSAND:	/* only need positive logic here */
@@ -479,7 +482,7 @@ void sim_writesilinstances(NODEPROTO *np, INTSML top)
 							if (pi->proto == pp) break;
 
 						/* sim_silnegated handles NOPORTARCINST */
-						sim_sendtosil(sim_silproto(ni,sim_silnegated(pi)));
+						sim_sendtosil(sim_silproto(ni, sim_silnegated(pi)));
 					}
 					if (outpp != NOPORTPROTO)	/* found the output name */
 						break;
@@ -525,7 +528,7 @@ void sim_writesilinstances(NODEPROTO *np, INTSML top)
 					sim_sendtosil(sim_silportname(top, ni, pp, np));
 
 					sim_sendtosil(" ");
-					sim_sendtosil(sim_silproto(ni, 0));
+					sim_sendtosil(sim_silproto(ni, FALSE));
 
 					j = sim_silgetcapacitance(ni);
 					if (j >= 0)
@@ -555,20 +558,20 @@ void sim_writesilinstances(NODEPROTO *np, INTSML top)
  * If the port is a power or ground port, ignore it
  * If this is not the top level facet (ie. a .macro) remove [] notation.
  */
-char *sim_silportname(INTSML top, NODEINST *ni, PORTPROTO *pp, NODEPROTO *np)
+char *sim_silportname(BOOLEAN top, NODEINST *ni, PORTPROTO *pp, NODEPROTO *np)
 {
 	REGISTER PORTPROTO *epp;
 	REGISTER PORTARCINST *pi;
 	REGISTER PORTEXPINST *pe;
 	REGISTER ARCINST *ai = NOARCINST;
 	char *portname;
-	INTSML noarcs;	/* boolean flag */
+	BOOLEAN noarcs;
 
-	if (portispower(pp) || portisground (pp)) return("");
+	if (portispower(pp) || portisground(pp)) return("");
 
 	(void)initinfstr();
 
-	noarcs = 1;
+	noarcs = TRUE;
 
 	/* find all portarcinsts that are connected to this pp */
 	for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
@@ -576,12 +579,12 @@ char *sim_silportname(INTSML top, NODEINST *ni, PORTPROTO *pp, NODEPROTO *np)
 		if (pi->proto == pp)	/* if this pi is connected */
 		{
 			/* found an arc */
-			noarcs = 0;
+			noarcs = FALSE;
 
 			/* if an input connection has a bubble, negate the signal */
 			if (sim_silnegated(pi) && ((pp->userbits&STATEBITS) == INPORT))
-				addstringtoinfstr(" -"); else
-					addtoinfstr(' ');
+				(void)addstringtoinfstr(" -"); else
+					(void)addtoinfstr(' ');
 
 			/* find the arc connected to this pi */
 			ai = pi->conarcinst;
@@ -592,11 +595,11 @@ char *sim_silportname(INTSML top, NODEINST *ni, PORTPROTO *pp, NODEPROTO *np)
 				 * this is either the network name, or of the form NETn
 				 */
 				if (top)
-					addstringtoinfstr(sim_silspecials(sim_silarcname(ai))); else
-						addstringtoinfstr(sim_sil_isaport(np, sim_silspecials(sim_silarcname(ai))));
+					(void)addstringtoinfstr(sim_silspecials(sim_silarcname(ai))); else
+						(void)addstringtoinfstr(sim_sil_isaport(np, sim_silspecials(sim_silarcname(ai))));
 			} else /* this is a database error, and won't ever occur */
 			{
-				ttyputerr(_("Uh Oh! there is a PORTARCINST without a CONARCINST"));
+				ttyputerr(_("Error: there is a PORTARCINST without a CONARCINST"));
 				return("");
 			}
 
@@ -621,11 +624,11 @@ char *sim_silportname(INTSML top, NODEINST *ni, PORTPROTO *pp, NODEPROTO *np)
 				epp = pe->exportproto;
 				if (epp->network->namecount > 0)
 				{
-					if (top) addstringtoinfstr(sim_silspecials(epp->network->netname)); else
-						addstringtoinfstr(sim_sil_isaport(np, sim_silspecials(epp->network->netname)));
+					if (top) (void)addstringtoinfstr(sim_silspecials(epp->network->netname)); else
+						(void)addstringtoinfstr(sim_sil_isaport(np, sim_silspecials(epp->network->netname)));
 				} else	/* this would be a database error - won't happen */
 				{
-					ttyputerr(_("Uh Oh! there is a net on an export, but no net name"));
+					ttyputerr(_("Error: there is a net on an export, but no net name"));
 					return("");
 				}
 				break;	/* out of "for (pe..." */
@@ -649,12 +652,13 @@ char *sim_silname(NODEINST *ni)
 {
 	static char name[100];
 	REGISTER VARIABLE *var;
-	static INTBIG SIM_silos_node_name = 0;
+	static INTBIG SIM_silos_node_name_key = 0;
 
-	if (SIM_silos_node_name == 0) SIM_silos_node_name = makekey("SIM_silos_node_name");
-	var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, SIM_silos_node_name);
+	if (SIM_silos_node_name_key == 0)
+		SIM_silos_node_name_key = makekey("SIM_silos_node_name");
+	var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, SIM_silos_node_name_key);
 	if (var != NOVARIABLE) return((char *)var->addr);
-	var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name);
+	var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
 	if (var != NOVARIABLE)
 	{
 		strcpy(name, (char *)var->addr);
@@ -667,11 +671,11 @@ char *sim_silname(NODEINST *ni)
 
 /*
  * routine to return a string describing the SILOS type of nodeinst "ni"
- * if 'neg' is non-zero, then the negated version is needed
+ * if 'neg' is true, then the negated version is needed
  */
-char *sim_silproto(NODEINST *ni,INTSML neg)
+char *sim_silproto(NODEINST *ni, BOOLEAN neg)
 {
-	REGISTER INTSML f;
+	REGISTER INTBIG f;
 	static char name[100];
 
 	/* facets use their real name */
@@ -747,8 +751,8 @@ char *sim_siltext(char *p)
 
 void sim_sendtosil(char *str)
 {
-	static INTSML count = 0;
-	INTSML i;
+	static INTBIG count = 0;
+	INTBIG i;
 
 	if (*str == '\n') count = 0;
 	if ((count + (i = strlen(str))) > MAXSTR)
@@ -783,22 +787,22 @@ char *sim_silarcname(ARCINST *ai)
 }
 
 /* Function to determine if this end of the connecting arc is negated */
-INTSML sim_silnegated(PORTARCINST *pi)
+BOOLEAN sim_silnegated(PORTARCINST *pi)
 {
 	REGISTER ARCINST *ai;
-	INTSML thisend;
+	INTBIG thisend;
 
-	if (pi == NOPORTARCINST) return(0);
+	if (pi == NOPORTARCINST) return(FALSE);
 
 	ai = pi->conarcinst;
-	if (ai == NOARCINST) return(0);
-	if ((ai->userbits&ISNEGATED) == 0) return(0);
+	if (ai == NOARCINST) return(FALSE);
+	if ((ai->userbits&ISNEGATED) == 0) return(FALSE);
 
 	if (ai->end[0].portarcinst == pi) thisend = 0; else
 		thisend = 1;
 	if ((thisend == 0 && (ai->userbits&REVERSEEND) == 0) ||
-		(thisend == 1 && (ai->userbits&REVERSEEND) != 0)) return(1);
-	return(0);
+		(thisend == 1 && (ai->userbits&REVERSEEND) != 0)) return(TRUE);
+	return(FALSE);
 }
 
 /*
@@ -821,7 +825,7 @@ char *sim_silspecials(char *str)
  * Read the contents of the added string, make it available to
  * the caller
  */
-INTSML sim_silostype(NODEINST *ni)
+INTBIG sim_silostype(NODEINST *ni)
 {
 	INTBIG func;
 
@@ -877,11 +881,12 @@ INTSML sim_silostype(NODEINST *ni)
 char *sim_silrisetime(NODEINST *ni)
 {
 	REGISTER VARIABLE *var;
-	INTBIG SIM_sil_risetime;
+	static INTBIG SIM_sil_risetime_key = 0;
 	static char s[80];
 
-	SIM_sil_risetime = makekey("SIM_rise_delay");
-	var = getvalkey((INTBIG)ni, VNODEINST, -1, SIM_sil_risetime);
+	if (SIM_sil_risetime_key == 0)
+		SIM_sil_risetime_key = makekey("SIM_rise_delay");
+	var = getvalkey((INTBIG)ni, VNODEINST, -1, SIM_sil_risetime_key);
 	if (var != NOVARIABLE)
 	{
 		if ((var->type&VTYPE) == VINTEGER)
@@ -910,11 +915,12 @@ char *sim_silrisetime(NODEINST *ni)
 char *sim_silfalltime(NODEINST *ni)
 {
 	REGISTER VARIABLE *var;
-	INTBIG SIM_sil_falltime;
+	static INTBIG SIM_sil_falltime_key = 0;
 	static char s[80];
 
-	SIM_sil_falltime = makekey("SIM_fall_delay");
-	var = getvalkey((INTBIG)ni, VNODEINST, -1, SIM_sil_falltime);
+	if (SIM_sil_falltime_key == 0)
+		SIM_sil_falltime_key = makekey("SIM_fall_delay");
+	var = getvalkey((INTBIG)ni, VNODEINST, -1, SIM_sil_falltime_key);
 	if (var != NOVARIABLE)
 	{
 		if ((var->type&VTYPE) == VINTEGER)
@@ -957,11 +963,11 @@ INTBIG sim_silgetcapacitance(NODEINST *ni)
 #define CK	 4
 #define PRE  5
 #define CLR  6
-void sim_silwriteflipflop(INTSML top, NODEINST *ni, NODEPROTO *np, INTSML type)
+void sim_silwriteflipflop(BOOLEAN top, NODEINST *ni, NODEPROTO *np, INTBIG type)
 {
 	REGISTER PORTPROTO *pp;
 	char line[8][50], out[100];
-	INTSML i;
+	INTBIG i;
 
 	for(pp = ni->proto->firstportproto, i=0; pp != NOPORTPROTO && i < 7; pp = pp->nextportproto, i++)
 	{
