@@ -38,24 +38,24 @@
 #include "tecschem.h"
 #include <setjmp.h>
 
-static INTBIG sim_cosmos_attribute = 0;
+static INTBIG sim_cosmos_attribute_key = 0;
 static jmp_buf sim_userdone;		/* for when simulator command is done */
 static INTBIG sim_index, sim_vdd, sim_gnd, sim_namethresh,
 		 sim_phi1h, sim_phi1l, sim_phi2h, sim_phi2l, count_unconn;
 static char *sim_name, *sim_prompt, *sim_inputfile = 0;
 
 /* prototypes for local routines */
-static INTSML  sim_simsearch(INTSML, NODEPROTO*, INTSML);
+static BOOLEAN sim_simsearch(INTBIG, NODEPROTO*, INTBIG);
 static void    sim_simtell(void);
-static void    sim_simprint(NODEPROTO*, FILE*, INTSML);
-static void    sim_simprintcosmos(NODEPROTO*, FILE*, INTSML);
-static char   *sim_makenodename(INTBIG, INTSML);
+static void    sim_simprint(NODEPROTO*, FILE*, INTBIG);
+static void    sim_simprintcosmos(NODEPROTO*, FILE*, INTBIG);
+static char   *sim_makenodename(INTBIG, INTBIG);
 static void    sim_prop(ARCINST*, INTBIG, INTBIG*, INTBIG*, INTBIG*, INTBIG*, INTBIG*, INTBIG*);
 
-void sim_writesim(NODEPROTO *simnt, INTSML format)
+void sim_writesim(NODEPROTO *simnt, INTBIG format)
 {
 	REGISTER INTBIG save0, save1, save2, filetype;
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 	REGISTER VARIABLE *var;
 	REGISTER FILE *f;
 	REGISTER PORTPROTO *pp, *spt, *shpt;
@@ -66,7 +66,7 @@ void sim_writesim(NODEPROTO *simnt, INTSML format)
 	if ((net_tool->toolstate&TOOLON) == 0)
 	{
 		ttyputerr(_("Network tool must be running...turning it on"));
-		toolturnon(net_tool, 0);
+		toolturnon(net_tool, FALSE);
 		ttyputerr(_("...now reissue the simulation command"));
 		return;
 	}
@@ -74,21 +74,22 @@ void sim_writesim(NODEPROTO *simnt, INTSML format)
 	if (format == COSMOS)
 	{
 		/* get variable names (only once) */
-		if (sim_cosmos_attribute == 0) sim_cosmos_attribute = makekey("SIM_cosmos_attribute");
+		if (sim_cosmos_attribute_key == 0)
+			sim_cosmos_attribute_key = makekey("SIM_cosmos_attribute");
 	}
 
 	count_unconn = 0;
 	sim_simnt = simnt;
 
 	/* initialize for the particular simulator */
-	var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_format);
-	if (var == NOVARIABLE) format = -1; else format = (INTSML)var->addr;
+	var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_formatkey);
+	if (var == NOVARIABLE) format = -1; else format = var->addr;
 
 	/* construct the simulation description file name from the facet */
 	(void)initinfstr();
 	(void)addstringtoinfstr(simnt->cell->cellname);
 	(void)addstringtoinfstr(".sim");
-	var = setvalkey((INTBIG)sim_tool, VTOOL, sim_netfile, (INTBIG)returninfstr(), VSTRING|VDONTSAVE);
+	var = setvalkey((INTBIG)sim_tool, VTOOL, sim_netfilekey, (INTBIG)returninfstr(), VSTRING|VDONTSAVE);
 	if (var != NOVARIABLE) netfile = (char *)var->addr; else netfile = "";
 
 	/* also record the actual input file to the simulator */
@@ -105,11 +106,14 @@ void sim_writesim(NODEPROTO *simnt, INTSML format)
 		return;
 	}
 	xprintf(f,"| %s\n", netfile);
-	if (simnt->creationdate != 0)
-		xprintf(f, "| Facet created %s\n", timetostring(simnt->creationdate));
-	xprintf(f, "| Version %d", simnt->version);
-	if (simnt->revisiondate != 0)
-		xprintf(f, " last revised %s\n", timetostring(simnt->revisiondate));
+	if ((us_useroptions&NODATEORVERSION) == 0)
+	{
+		if (simnt->creationdate != 0)
+			xprintf(f, "| Facet created %s\n", timetostring(simnt->creationdate));
+		xprintf(f, "| Version %ld", simnt->version);
+		if (simnt->revisiondate != 0)
+			xprintf(f, " last revised %s\n", timetostring(simnt->revisiondate));
+	}
 	if (format == COSMOS)
 	{
 		xprintf(f,"| [e | d | p | n] gate source drain length width xpos ypos {[gsd]=attrs}\n");
@@ -239,7 +243,7 @@ void sim_writesim(NODEPROTO *simnt, INTSML format)
 	xclose(f);
 
 	/* if execution is not desired, quit now */
-	var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_dontrun);
+	var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_dontrunkey);
 	if (format == COSMOS || (var != NOVARIABLE && var->addr == SIMRUNNO))
 	{
 		if (count_unconn != 0)
@@ -366,18 +370,18 @@ void sim_writesim(NODEPROTO *simnt, INTSML format)
 	setinteractivemode(sim_fromsim[0]);
 
 	/* now communicate with the simulator */
-	sim_resumesim(1);
+	sim_resumesim(TRUE);
 }
 
-INTSML sim_simpointout(char *nonum, INTSML format)
+void sim_simpointout(char *nonum, INTBIG format)
 {
-	REGISTER INTSML want;
+	REGISTER INTBIG want;
 	REGISTER PORTPROTO *pp, *spt;
 
 	if (sim_simnt == NONODEPROTO)
 	{
 		ttyputerr(_("No simulation done"));
-		return(1);
+		return;
 	}
 
 	/* make sure user is still in the same facet */
@@ -385,7 +389,7 @@ INTSML sim_simpointout(char *nonum, INTSML format)
 	{
 		ttyputerr(_("Simulation was done on facet %s; please edit that facet"),
 			describenodeproto(sim_simnt));
-		return(1);
+		return;
 	}
 
 	/* figure out the desired nodeinst number */
@@ -396,9 +400,9 @@ INTSML sim_simpointout(char *nonum, INTSML format)
 		if (pp == NOPORTPROTO)
 		{
 			ttyputerr(_("Cannot find a port called '%s'"), nonum);
-			return(1);
+			return;
 		}
-		want = (INTSML)pp->temp1;
+		want = pp->temp1;
 	}
 
 	/* re-assign net-list values, starting at each portinst of the top facet */
@@ -419,12 +423,12 @@ INTSML sim_simpointout(char *nonum, INTSML format)
 		if (format == COSMOS)
 		{
 			/* see if the port is special */
-			if (portispower(pp) != 0)
+			if (portispower(pp))
 			{
 				if (sim_vdd == 0) sim_vdd = sim_index++;
 				pp->temp1 = sim_vdd;   continue;
 			}
-			if (portisground(pp) != 0)
+			if (portisground(pp))
 			{
 				if (sim_gnd == 0) sim_gnd = sim_index++;
 				pp->temp1 = sim_gnd;   continue;
@@ -457,19 +461,18 @@ INTSML sim_simpointout(char *nonum, INTSML format)
 	}
 
 	/* look for node number */
-	if (sim_simsearch(want, sim_simnt, format) != 0)
+	if (sim_simsearch(want, sim_simnt, format))
 	{
 		ttyputerr(_("Cannot find node '%s'"), nonum);
-		return(1);
+		return;
 	}
-	return(0);
 }
 
-INTSML sim_simsearch(INTSML want, NODEPROTO *facet, INTSML format)
+BOOLEAN sim_simsearch(INTBIG want, NODEPROTO *facet, INTBIG format)
 {
 	char *newpar[2];
 	INTBIG darea, dperim, parea, pperim, marea, mperim;
-	REGISTER INTSML i;
+	REGISTER BOOLEAN i;
 	REGISTER ARCINST *ai;
 	REGISTER PORTPROTO *pp, *spt;
 	REGISTER PORTARCINST *pi;
@@ -496,8 +499,8 @@ INTSML sim_simsearch(INTSML want, NODEPROTO *facet, INTSML format)
 				(void)asktool(us_tool, "clear");
 				(void)asktool(us_tool, "show-object", (INTBIG)ai->geom);
 				newpar[0] = "highlight";
-				(void)telltool(net_tool, 1, newpar);
-				return(0);
+				telltool(net_tool, 1, newpar);
+				return(FALSE);
 			}
 			darea = dperim = parea = pperim = marea = mperim = 0;
 			sim_prop(ai, (INTBIG)pp->temp1, &darea, &dperim, &parea, &pperim, &marea, &mperim);
@@ -512,8 +515,8 @@ INTSML sim_simsearch(INTSML want, NODEPROTO *facet, INTSML format)
 				(void)asktool(us_tool, "clear");
 				(void)asktool(us_tool, "show-object", (INTBIG)ai->geom);
 				newpar[0] = "highlight";
-				(void)telltool(net_tool, 1, newpar);
-				return(0);
+				telltool(net_tool, 1, newpar);
+				return(FALSE);
 			}
 			darea = dperim = parea = pperim = marea = mperim = 0;
 			sim_prop(ai, sim_index, &darea, &dperim, &parea, &pperim, &marea, &mperim);
@@ -527,7 +530,7 @@ INTSML sim_simsearch(INTSML want, NODEPROTO *facet, INTSML format)
 	{
 		(void)asktool(us_tool, "clear");
 		(void)asktool(us_tool, "show-port", (INTBIG)pp->subnodeinst->geom, (INTBIG)pp->subportproto);
-		return(0);
+		return(FALSE);
 	}
 
 	/* look at every nodeinst in the facet */
@@ -602,13 +605,13 @@ INTSML sim_simsearch(INTSML want, NODEPROTO *facet, INTSML format)
 		if (np->primindex == 0)
 		{
 			i = sim_simsearch(want, ni->proto, format);
-			if (i == 0) return(0);
+			if (!i) return(FALSE);
 		}
 	}
-	return(1);
+	return(TRUE);
 }
 
-void sim_resumesim(INTSML firsttime)
+void sim_resumesim(BOOLEAN firsttime)
 {
 	REGISTER INTBIG i, format;
 	char line[200], *ptr;
@@ -624,7 +627,7 @@ void sim_resumesim(INTSML firsttime)
 	if (firsttime)
 	{
 		ttyputmsg(_("Type 'help' if you need it"));
-		var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_format);
+		var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_formatkey);
 		if (var == NOVARIABLE) format = -1; else format = var->addr;
 		if (format == RNL)
 		{
@@ -650,7 +653,7 @@ void sim_resumesim(INTSML firsttime)
 				ekill(sim_process);
 				ewait(sim_process);
 				sim_process = -1;
-				var = getvalkey((INTBIG)sim_tool, VTOOL, VSTRING, sim_netfile);
+				var = getvalkey((INTBIG)sim_tool, VTOOL, VSTRING, sim_netfilekey);
 				if (var != NOVARIABLE)
 					ttyputmsg(_("Net list saved in '%s'"), (char *)var->addr);
 				return;
@@ -680,7 +683,9 @@ void sim_resumesim(INTSML firsttime)
 				sim_simtell();
 			}
 		}
-		if (ttydataready() != 0) sim_simtell();
+#ifndef USEQT
+		if (ttydataready()) sim_simtell();
+#endif
 
 		ttyputmsg(_("Abnormal simulator termination"));
 		longjmp(sim_userdone, 2);
@@ -691,7 +696,7 @@ void sim_simtell(void)
 {
 	char *newpar[2];
 	REGISTER char *pp;
-	REGISTER INTSML len;
+	REGISTER INTBIG len;
 	REGISTER VARIABLE *var;
 
 	for(;;)
@@ -709,14 +714,14 @@ void sim_simtell(void)
 		if (len > 1 && namesamen(pp, "help", len) == 0)
 		{
 			newpar[0] = "help";   newpar[1] = sim_name;
-			(void)telltool(us_tool, 2, newpar);
+			telltool(us_tool, 2, newpar);
 		} else break;
 	}
 
 	/* send user command to simulator */
 	if (*pp == 'q')
 	{
-		var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_format);
+		var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_formatkey);
 		if (var != NOVARIABLE && var->addr == RNL) *pp = CTRLDKEY;
 	}
 	len = strlen(pp);
@@ -726,7 +731,7 @@ void sim_simtell(void)
 	longjmp(sim_userdone, 1);
 }
 
-void sim_simprint(NODEPROTO *facet, FILE *f, INTSML format)
+void sim_simprint(NODEPROTO *facet, FILE *f, INTBIG format)
 {
 	REGISTER INTBIG gate, source, drain, type;
 	INTBIG darea, dperim, parea, pperim, marea, mperim, length, width;
@@ -921,7 +926,7 @@ void sim_simprint(NODEPROTO *facet, FILE *f, INTSML format)
 	}
 }
 
-void sim_simprintcosmos(NODEPROTO *facet, FILE *f, INTSML format)
+void sim_simprintcosmos(NODEPROTO *facet, FILE *f, INTBIG format)
 {
 	REGISTER PORTPROTO *gate, *source, *drain;
 	REGISTER INTBIG type;
@@ -982,7 +987,7 @@ void sim_simprintcosmos(NODEPROTO *facet, FILE *f, INTSML format)
 	/* Test each arc for attributes */
 	for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 	{
-		var = getvalkey((INTBIG)ai, VARCINST, -1, sim_cosmos_attribute);
+		var = getvalkey((INTBIG)ai, VARCINST, -1, sim_cosmos_attribute_key);
 		if (var != NOVARIABLE)
 		{
 			if (var->type == VINTEGER)
@@ -1115,7 +1120,7 @@ void sim_simprintcosmos(NODEPROTO *facet, FILE *f, INTSML format)
 			/* see if there is a strength mentioned on this node */
 			for (pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 			{
-				var = getvalkey((INTBIG)pi, VPORTARCINST, -1, sim_cosmos_attribute);
+				var = getvalkey((INTBIG)pi, VPORTARCINST, -1, sim_cosmos_attribute_key);
 				if (var != NOVARIABLE)
 				{
 					if (pi->proto->network == source->network) xprintf(f, " s="); else
@@ -1128,7 +1133,7 @@ void sim_simprintcosmos(NODEPROTO *facet, FILE *f, INTSML format)
 							ttyputerr(_("Bad cosmos attribute type"));
 				}
 			}
-			var = getvalkey((INTBIG)ni, VNODEINST, -1, sim_cosmos_attribute);
+			var = getvalkey((INTBIG)ni, VNODEINST, -1, sim_cosmos_attribute_key);
 			if (var != NOVARIABLE)
 			{
 				if (var->type == VINTEGER) xprintf(f, " g=Sim:%ld", var->addr);
@@ -1158,7 +1163,7 @@ void sim_simprintcosmos(NODEPROTO *facet, FILE *f, INTSML format)
  * name if at the top level, or "power", "ground", etc. if special).  The
  * "format" is the particular simuator being used
  */
-char *sim_makenodename(INTBIG node, INTSML format)
+char *sim_makenodename(INTBIG node, INTBIG format)
 {
 	static char line[50];
 	REGISTER PORTPROTO *pp;
@@ -1202,7 +1207,7 @@ void sim_prop(ARCINST *ai, INTBIG indx, INTBIG *darea, INTBIG *dperim, INTBIG *p
 	REGISTER NODEINST *ni;
 	REGISTER PORTARCINST *pi;
 	REGISTER PORTPROTO *pp;
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 	INTBIG length, width;
 
 	/* see if this arcinst is already on a path */
