@@ -38,8 +38,6 @@
 
 #define MAXLENGTH 80
 #define MAXNAMECHARS 12
-#define TRUE 1
-#define FALSE 0
 #define NPGATENOR -NPGATEOR
 #define NPGATENXOR -NPGATEXOR
 #define NPGATENAND -NPGATEAND
@@ -52,7 +50,7 @@ static FILE *sim_texfile, *reservefile;
 /* prototypes for local routines */
 static void         sim_writetexcell(NODEPROTO*, INTBIG);
 static char        *sim_textdlpower(NODEINST*, INTBIG, INTBIG*, INTBIG*, INTBIG*);
-static INTSML       sim_texcountwires(NODEINST*);
+static INTBIG       sim_texcountwires(NODEINST*);
 static char        *sim_texsrcname(NODEINST*, PORTARCINST*);
 static char        *sim_texwritesignals(NODEINST*, INTBIG, INTBIG*);
 static char        *sim_texwriteffsignals(NODEINST*, INTBIG*);
@@ -65,11 +63,11 @@ static char        *sim_texname(char*);
 static char        *sim_texproto(NODEINST*, INTBIG, INTBIG*);
 static char        *sim_texffname(NODEINST*, INTBIG*);
 static char        *sim_texgetdelay(NODEINST*, INTBIG);
-static INTSML       sim_texnegatedoutput(NODEINST*);
+static BOOLEAN      sim_texnegatedoutput(NODEINST*);
 static char        *sim_texlibname(NODEPROTO*);
 static PORTARCINST *sim_oppendpai(PORTARCINST*);
 static NODEINST    *sim_oppendni(PORTARCINST*);
-static INTSML       sim_texcheckname(char*);
+static BOOLEAN      sim_texcheckname(char*);
 static INTBIG       sim_strcspn(char *str, char *set);
 
 void sim_writetexnetlist(NODEPROTO *np)
@@ -171,41 +169,41 @@ void sim_writetexcell(NODEPROTO *np, INTBIG top)
 	if (np->firstportproto != NOPORTPROTO)
 	{
 		(void)initinfstr();
-		addstringtoinfstr("INPUTS:\n");
+		(void)addstringtoinfstr("INPUTS:\n");
 
 		for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		{
-			if (sim_texcheckname(sim_texname(pp->protoname)) == 0)
+			if (!sim_texcheckname(sim_texname(pp->protoname)))
 				sim_texerror(11, &module_err, sim_texname(pp->protoname));
 
 			pp->temp1 = pp->temp2 = 0;
 			if ((pp->userbits&STATEBITS) == INPORT)
 			{
-				addstringtoinfstr("   ");
-				addstringtoinfstr(sim_texname(pp->protoname));
-				addstringtoinfstr("\n");
+				(void)addstringtoinfstr("   ");
+				(void)addstringtoinfstr(sim_texname(pp->protoname));
+				(void)addstringtoinfstr("\n");
 				pp->temp1 = 1;
 			}
 		}
-		addstringtoinfstr(";\n\n");
+		(void)addstringtoinfstr(";\n\n");
 		sim_texstrprint(returninfstr());
 
 		/* OUTPUTS */
 		(void)initinfstr();
-		addstringtoinfstr("OUTPUTS:\n");
+		(void)addstringtoinfstr("OUTPUTS:\n");
 
 		for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		{
 			if ((pp->userbits&STATEBITS) == OUTPORT)
 			{
-				addstringtoinfstr("   ");
-				addstringtoinfstr(sim_texname(pp->protoname));
-				addstringtoinfstr("\n");
+				(void)addstringtoinfstr("   ");
+				(void)addstringtoinfstr(sim_texname(pp->protoname));
+				(void)addstringtoinfstr("\n");
 				pp->temp1 = 1;
 			}
 			if (pp->temp1 == 0) sim_texerror(2, &module_err, pp->protoname);
 		}
-		addstringtoinfstr(";\n\n");
+		(void)addstringtoinfstr(";\n\n");
 		sim_texstrprint(returninfstr());
 	}
 
@@ -283,16 +281,6 @@ void sim_writetexcell(NODEPROTO *np, INTBIG top)
 				break; /* end of switch option */
 
 			case NPSOURCE:
-			case NPSOURCEV:
-			case NPSOURCEC:
-			case NPSOURCECM:
-			case NPSOURCET:
-			case NPSOURCEDC:
-			case NPSOURCEAC:
-			case NPSOURCEN:
-			case NPSOURCEX:
-			case NPSOURCEB:
-			case NPSOURCES:
 			case NPRESIST:
 			case NPCAPAC:
 			case NPDIODE:
@@ -465,9 +453,9 @@ char *sim_textdlpower(NODEINST *ni, INTBIG f, INTBIG *pwr, INTBIG *gnd, INTBIG *
 }
 
 /* routine to count the wires on a primitive with only one inport */
-INTSML sim_texcountwires(NODEINST *ni)
+INTBIG sim_texcountwires(NODEINST *ni)
 {
-	INTSML inputs;
+	INTBIG inputs;
 	PORTARCINST *pai;
 	PORTEXPINST *pei;
 
@@ -979,24 +967,24 @@ char *sim_texgetdelay(NODEINST *ni, INTBIG f)
 {
 	VARIABLE *var;
 	static char str1[30], str2[30];
-	static INTBIG SIM_rise_delay = 0, SIM_fall_delay = 0;
+	static INTBIG SIM_rise_delay_key = 0, SIM_fall_delay_key = 0;
 
 	/* user defined modules are not allowed delays */
 	if (f == NPUNKNOWN) return("");
 
 	/* initialise variable for signal source names to be held on portarcinsts */
 	/* and TEX rise and fall time delays */
-	if (SIM_rise_delay == 0) SIM_rise_delay = makekey("SIM_rise_delay");
-	if (SIM_fall_delay == 0) SIM_fall_delay = makekey("SIM_fall_delay");
+	if (SIM_rise_delay_key == 0) SIM_rise_delay_key = makekey("SIM_rise_delay");
+	if (SIM_fall_delay_key == 0) SIM_fall_delay_key = makekey("SIM_fall_delay");
 
-	var = getvalkey((INTBIG)ni, VNODEINST, -1, SIM_rise_delay);
+	var = getvalkey((INTBIG)ni, VNODEINST, -1, SIM_rise_delay_key);
 	if (var == NOVARIABLE) sprintf(str1, "/1,"); else
 	{
 		if ((var->type&VTYPE) == VINTEGER) sprintf(str1, "/%1ld,", var->addr);
 		if ((var->type&VTYPE) == VSTRING) sprintf(str1, "/%s,", (char *)var->addr);
 	}
 
-	var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, SIM_fall_delay);
+	var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, SIM_fall_delay_key);
 	if (var == NOVARIABLE) sprintf(str2, "1/"); else
 	{
 		if ((var->type&VTYPE) == VINTEGER) sprintf(str2, "%1ld/", var->addr);
@@ -1008,16 +996,16 @@ char *sim_texgetdelay(NODEINST *ni, INTBIG f)
 }
 
 /* determines whether a nodeinst has an output arc that is negated */
-INTSML sim_texnegatedoutput(NODEINST *ni)
+BOOLEAN sim_texnegatedoutput(NODEINST *ni)
 {
 	PORTARCINST *pai;
 
 	for(pai = ni->firstportarcinst; pai != NOPORTARCINST; pai = pai->nextportarcinst)
 	{
 		if ((pai->conarcinst->userbits&ISNEGATED) == 0) continue;
-		if ((pai->proto->userbits&STATEBITS) == OUTPORT) return(1);
+		if ((pai->proto->userbits&STATEBITS) == OUTPORT) return(TRUE);
 	}
-	return(0);
+	return(FALSE);
 }
 
 /* routine to remove the path specification from the electric library name */
@@ -1058,7 +1046,7 @@ NODEINST *sim_oppendni(PORTARCINST *pai)
  * routine that takes a string of max. length 12 and checks to see if it is a
  * reserved word
  */
-INTSML sim_texcheckname(char *str)
+BOOLEAN sim_texcheckname(char *str)
 {
 	char name[MAXNAMECHARS], *p, fileline[MAXLENGTH];
 	INTBIG i=0, x=0;
@@ -1067,7 +1055,7 @@ INTSML sim_texcheckname(char *str)
 	{
 		xseek(reservefile, 0, 0);
 		p = fileline;
-		while (xfgets(fileline, MAXLENGTH, reservefile) == 0)
+		while (!xfgets(fileline, MAXLENGTH, reservefile))
 		{
 			for(i=0; i != MAXNAMECHARS-1; i++) name[i]= 0;
 			i = 0;
@@ -1075,11 +1063,11 @@ INTSML sim_texcheckname(char *str)
 
 			p = fileline;
 			if ((x = strlen(str)) < 2) x = 2;  /* minimum abbrev. is 2 chars */
-			if (namesamen(name, str, x) == 0) return(0);
+			if (namesamen(name, str, x) == 0) return(FALSE);
 		}
-		return(1);
+		return(TRUE);
 	}
-	return(1);
+	return(TRUE);
 }
 
 /* private version of library function (may not be on all systems) */
