@@ -60,6 +60,7 @@ NODEPROTO  *art_boxprim;
 NODEPROTO  *art_crossedboxprim;
 NODEPROTO  *art_filledboxprim;
 NODEPROTO  *art_circleprim;
+NODEPROTO  *art_thickcircleprim;
 NODEPROTO  *art_filledcircleprim;
 NODEPROTO  *art_splineprim;
 NODEPROTO  *art_triangleprim;
@@ -78,7 +79,7 @@ ARCPROTO   *art_thickerarc;
 /* prototypes for local routines */
 static void art_getgraphics(INTBIG, INTBIG);
 static void art_fillellipse(INTBIG, INTBIG, INTBIG, INTBIG, double, double, POLYGON*);
-static void art_fillspline(INTBIG *points, INTBIG count, INTBIG cx, INTBIG cy, POLYGON *poly, INTSML steps);
+static void art_fillspline(INTBIG *points, INTBIG count, INTBIG cx, INTBIG cy, POLYGON *poly, INTBIG steps);
 static void art_setstate(INTBIG newstate);
 static void art_fillnodebox(NODEINST *ni, INTBIG box, POLYGON *poly);
 
@@ -113,30 +114,30 @@ static INTBIG art_gds_layers[MAXLAYERS] = {1};
 /* solid arc */
 static TECH_ARCLAY art_al_s[] = {{LOPAQUE, 0, FILLED}};
 static TECH_ARCS art_a_s = {
-	"Solid",0,ASOLID,												/* name */
+	"Solid",0,ASOLID,NOARCPROTO,									/* name */
 	1,art_al_s,														/* layers */
-	(APUNKNOWN<<AFUNCTIONSH)|CANWIPE|CANCURVE|(0<<AANGLEINCSH)};	/* userbits */
+	(APNONELEC<<AFUNCTIONSH)|CANWIPE|CANCURVE|(0<<AANGLEINCSH)};	/* userbits */
 
 /* dotted arc */
 static TECH_ARCLAY art_al_d1[] = {{LOPAQUE, 0, FILLED}};
 static TECH_ARCS art_a_d1 = {
-	"Dotted",0,ADOTTED,												/* name */
+	"Dotted",0,ADOTTED,NOARCPROTO,									/* name */
 	1,art_al_d1,													/* layers */
-	(APUNKNOWN<<AFUNCTIONSH)|CANWIPE|CANCURVE|(0<<AANGLEINCSH)};	/* userbits */
+	(APNONELEC<<AFUNCTIONSH)|CANWIPE|CANCURVE|(0<<AANGLEINCSH)};	/* userbits */
 
 /* dashed arc */
 static TECH_ARCLAY art_al_d2[] = {{LOPAQUE, 0, FILLED}};
 static TECH_ARCS art_a_d2 = {
-	"Dashed",0,ADASHED,												/* name */
+	"Dashed",0,ADASHED,NOARCPROTO,									/* name */
 	1,art_al_d2,													/* layers */
-	(APUNKNOWN<<AFUNCTIONSH)|CANWIPE|CANCURVE|(0<<AANGLEINCSH)};	/* userbits */
+	(APNONELEC<<AFUNCTIONSH)|CANWIPE|CANCURVE|(0<<AANGLEINCSH)};	/* userbits */
 
 /* thicker arc */
 static TECH_ARCLAY art_al_d3[] = {{LOPAQUE, 0, FILLED}};
 static TECH_ARCS art_a_d3 = {
-	"Thicker",0,ATHICKER,											/* name */
+	"Thicker",0,ATHICKER,NOARCPROTO,								/* name */
 	1,art_al_d3,													/* layers */
-	(APUNKNOWN<<AFUNCTIONSH)|CANWIPE|CANCURVE|(0<<AANGLEINCSH)};	/* userbits */
+	(APNONELEC<<AFUNCTIONSH)|CANWIPE|CANCURVE|(0<<AANGLEINCSH)};	/* userbits */
 
 TECH_ARCS *art_arcprotos[ARCPROTOCOUNT+1] = {&art_a_s, &art_a_d1,
 	&art_a_d2, &art_a_d3, ((TECH_ARCS *)-1)};
@@ -148,7 +149,7 @@ static INTBIG art_pc_d[] = {-1, ASOLID, ADOTTED, ADASHED, ATHICKER, ALLGEN, -1};
 
 /******************** NODES ********************/
 
-#define NODEPROTOCOUNT 16
+#define NODEPROTOCOUNT 17
 #define NPIN            1		/* point */
 #define NBOX            2		/* rectangular box */
 #define NCBOX           3		/* crossed rectangular box */
@@ -165,6 +166,7 @@ static INTBIG art_pc_d[] = {-1, ASOLID, ADOTTED, ADASHED, ATHICKER, ALLGEN, -1};
 #define NOPENEDT3      14		/* opened thicker polygon */
 #define NCLOSED        15		/* closed polygon */
 #define NFILLED        16		/* filled polygon */
+#define NTCIRCLE       17		/* thick circle */
 
 #define SX   (WHOLE/6)
 static INTBIG art_fullbox[8]  = {LEFTEDGE, LEFTEDGE, RIGHTEDGE, TOPEDGE};
@@ -407,10 +409,24 @@ static TECH_NODES art_polygon = {
 	(NPART<<NFUNCTIONSH)|HOLDSTRACE|NEDGESELECT,	/* userbits */
 	0,0,0,0,0,0,0,0,0};								/* characteristics */
 
+/* Thick Circle (or Arc or Ellipse) */
+static TECH_PORTS art_tcircle_p[] = {				/* ports */
+	{art_pc_d, "site", NOPORTPROTO, (180<<PORTARANGESH),
+		CENTER, CENTER, CENTER, CENTER}};
+static TECH_POLYGON art_tcircle_l[] = {				/* layers */
+	{LOPAQUE, -1, 2, THICKCIRCLE, POINTS, art_circ}};
+static TECH_NODES art_tcircle = {
+	"Thick-Circle",NTCIRCLE,NONODEPROTO,			/* name */
+	K4,K4,											/* size */
+	1,art_tcircle_p,								/* ports */
+	1,art_tcircle_l,								/* layers */
+	(NPART<<NFUNCTIONSH)|NEDGESELECT,				/* userbits */
+	0,0,0,0,0,0,0,0,0};								/* characteristics */
+
 TECH_NODES *art_nodeprotos[NODEPROTOCOUNT+1] = {&art_pin,
 	&art_box, &art_cbox, &art_fbox, &art_circle, &art_fcircle, &art_spline,
 	&art_triangle, &art_ftriangle, &art_arrow, &art_freeform, &art_freeformdot,
-	&art_freeformdash, &art_freeformfdot, &art_closed, &art_polygon,
+	&art_freeformdash, &art_freeformfdot, &art_closed, &art_polygon, &art_tcircle,
 	((TECH_NODES *)-1)};
 
 /******************** VARIABLE AGGREGATION ********************/
@@ -440,7 +456,7 @@ TECH_VARIABLES art_variables[] =
 static INTBIG art_col, art_bits;
 static VARIABLE *art_colorvar, *art_patternvar;
 
-INTSML art_initprocess(TECHNOLOGY *tech, INTSML pass)
+BOOLEAN art_initprocess(TECHNOLOGY *tech, INTBIG pass)
 {
 	if (pass == 0)
 	{
@@ -453,6 +469,7 @@ INTSML art_initprocess(TECHNOLOGY *tech, INTSML pass)
 		art_crossedboxprim = getnodeproto("artwork:Crossed-Box");
 		art_filledboxprim = getnodeproto("artwork:Filled-Box");
 		art_circleprim = getnodeproto("artwork:Circle");
+		art_thickcircleprim = getnodeproto("artwork:Thick-Circle");
 		art_filledcircleprim = getnodeproto("artwork:Filled-Circle");
 		art_splineprim = getnodeproto("artwork:Spline");
 		art_triangleprim = getnodeproto("artwork:Triangle");
@@ -475,13 +492,16 @@ INTSML art_initprocess(TECHNOLOGY *tech, INTSML pass)
 		art_degreeskey = makekey("ART_degrees");
 		art_patternkey = makekey("ART_pattern");
 		art_state = 0;
+		nextchangequiet();
+		setvalkey((INTBIG)art_tech, VTECHNOLOGY, el_techstate_key, art_state,
+			VINTEGER|VDONTSAVE);
 	}
-	return(0);
+	return(FALSE);
 }
 
-void art_setmode(INTSML count, char *par[])
+void art_setmode(INTBIG count, char *par[])
 {
-	REGISTER INTSML l;
+	REGISTER INTBIG l;
 	REGISTER char *pp;
 
 	if (count == 0)
@@ -577,25 +597,25 @@ void art_shapenodepoly(NODEINST *ni, INTBIG box, POLYGON *poly)
 	if (box >= tech_realpolys)
 	{
 		(void)tech_filldisplayablenvar(ni, poly, tech_curwindowpart, 0);
-	} else
-	{
-		art_fillnodebox(ni, box, poly);
+		return;
 	}
 
+	art_fillnodebox(ni, box, poly);
+
 	/* use stipple pattern if specified */
 	if (art_patternvar == NOVARIABLE) poly->desc = &art_o_lay; else
 		poly->desc = &art_st_lay;
 
-	poly->desc->col = (INTSML)art_col;
-	poly->desc->bits = (INTSML)art_bits;
+	poly->desc->col = art_col;
+	poly->desc->bits = art_bits;
 }
 
 void art_shapeEnodepoly(NODEINST *ni, INTBIG box, POLYGON *poly) {}
 
 void art_shapeportpoly(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans,
-	INTSML purpose)
+	BOOLEAN purpose)
 {
-	REGISTER INTSML pindex;
+	REGISTER INTBIG pindex;
 
 	pindex = ni->proto->primindex;
 	if (pindex == NPIN || pindex == NARROW)
@@ -640,7 +660,7 @@ void art_shapearcpoly(ARCINST *ai, INTBIG box, POLYGON *poly)
 	aindex = ai->proto->arcindex;
 	thista = &art_arcprotos[aindex]->list[0];
 	realwid = ai->width - thista->off*lambdaofarc(ai)/WHOLE;
-	if (tech_curvedarcpiece(ai, box, poly, art_arcprotos) != 0)
+	if (tech_curvedarcpiece(ai, box, poly, art_arcprotos))
 	{
 		/* standard arc: compute polygon in normal way */
 		makearcpoly(ai->length, realwid, ai, poly, thista->style);
@@ -659,8 +679,8 @@ void art_shapearcpoly(ARCINST *ai, INTBIG box, POLYGON *poly)
 		}
 	} else poly->desc = &art_st_lay;
 
-	poly->desc->col = (INTSML)art_col;
-	poly->desc->bits = (INTSML)art_bits;
+	poly->desc->col = art_col;
+	poly->desc->bits = art_bits;
 }
 
 /*
@@ -668,14 +688,14 @@ void art_shapearcpoly(ARCINST *ai, INTBIG box, POLYGON *poly)
  */
 void art_fillnodebox(NODEINST *ni, INTBIG box, POLYGON *poly)
 {
-	REGISTER INTSML sty;
+	REGISTER INTBIG sty;
 	REGISTER INTBIG pindex, dist, cx, cy, sx, sy, count;
 	REGISTER VARIABLE *var;
 	double startoffset, endangle;
 	INTBIG dummypoints[8];
 
 	pindex = ni->proto->primindex;
-	if (pindex == NCIRCLE)
+	if (pindex == NCIRCLE || pindex == NTCIRCLE)
 	{
 		/* handle ellipses */
 		getarcdegrees(ni, &startoffset, &endangle);
@@ -699,7 +719,8 @@ void art_fillnodebox(NODEINST *ni, INTBIG box, POLYGON *poly)
 				poly->xv[1] = poly->xv[0] + rounddouble(cos(startoffset+endangle) * (double)dist);
 				poly->yv[1] = poly->yv[0] + rounddouble(sin(startoffset+endangle) * (double)dist);
 				poly->count = 3;
-				poly->style = CIRCLEARC;
+				if (pindex == NCIRCLE) poly->style = CIRCLEARC; else
+					poly->style = THICKCIRCLEARC;
 			}
 		}
 	} else if (pindex == NSPLINE)
@@ -739,7 +760,7 @@ void art_fillnodebox(NODEINST *ni, INTBIG box, POLYGON *poly)
 
 void art_getgraphics(INTBIG addr, INTBIG type)
 {
-	REGISTER INTSML i, sty;
+	REGISTER INTBIG i, sty;
 
 	/* get the color information */
 	art_colorvar = getvalkey(addr, type, VINTEGER, art_colorkey);
@@ -789,7 +810,7 @@ void art_getgraphics(INTBIG addr, INTBIG type)
 		}
 
 		/* set the outline style (outlined if SHORT used) */
-		art_st_lay.colstyle = art_st_lay.bwstyle = sty;
+		art_st_lay.colstyle = art_st_lay.bwstyle = (INTSML)sty;
 	}
 }
 
@@ -803,7 +824,7 @@ void art_fillellipse(INTBIG lx, INTBIG ly, INTBIG hx, INTBIG hy, double startoff
 	double endangle, POLYGON *poly)
 {
 	double cx, cy, a, b, p, s2, s3, c2, c3, t1;
-	REGISTER INTSML m, pts;
+	REGISTER INTBIG m, pts;
 
 	/* ensure that the polygon can hold the vectors */
 	if (startoffset == 0.0 && endangle == 0.0)
@@ -816,7 +837,7 @@ void art_fillellipse(INTBIG lx, INTBIG ly, INTBIG hx, INTBIG hy, double startoff
 		/* partial ellipse */
 		poly->style = OPENED;
 	}
-	pts = (INTSML)(endangle * ELLIPSEPOINTS / (EPI * 2.0));
+	pts = (INTBIG)(endangle * ELLIPSEPOINTS / (EPI * 2.0));
 	if (poly->limit < pts) (void)extendpolygon(poly, pts);
 	poly->count = pts;
 
@@ -862,13 +883,13 @@ void art_fillellipse(INTBIG lx, INTBIG ly, INTBIG hx, INTBIG hy, double startoff
  * Routine to convert the "count" spline control points in "points" that are centered at (cx,cy)
  * to a line approximation in "poly".  Uses "steps" lines per spline segment.
  */
-void art_fillspline(INTBIG *points, INTBIG count, INTBIG cx, INTBIG cy, POLYGON *poly, INTSML steps)
+void art_fillspline(INTBIG *points, INTBIG count, INTBIG cx, INTBIG cy, POLYGON *poly, INTBIG steps)
 {
 	REGISTER INTBIG i, k, out, outpoints;
 	double t, t1, t2, t3, t4, x1, y1, x2, y2, x3, y3, x4, y4, x, y, tsq, splinestep;
 
 	outpoints = (count - 1) * steps + 1;
-	if (poly->limit < outpoints) (void)extendpolygon(poly, (INTSML)outpoints);
+	if (poly->limit < outpoints) (void)extendpolygon(poly, outpoints);
 	out = 0;
 
 	splinestep = 1.0 / (double)steps;
@@ -911,5 +932,5 @@ void art_fillspline(INTBIG *points, INTBIG count, INTBIG cx, INTBIG cy, POLYGON
 	poly->xv[out] = SPLINEPOLYX(count-1);
 	poly->yv[out++] = SPLINEPOLYY(count-1);
 	poly->style = OPENED;
-	poly->count = (INTSML)out;
+	poly->count = out;
 }
