@@ -36,7 +36,7 @@
 #include "tech.h"
 #include "efunction.h"
 
-INTSML bipolar_initprocess(TECHNOLOGY *tech, INTSML pass);
+BOOLEAN bipolar_initprocess(TECHNOLOGY *tech, INTBIG pass);
 
 /******************** LAYERS ********************/
 
@@ -313,25 +313,25 @@ static INTBIG bipolar_unconnectedtable[] = {
 
 static TECH_ARCLAY bipolar_al_0[] = {{LM,0,FILLED}};
 static TECH_ARCS bipolar_a_0 = {
-	"Metal_1", K3, AMETAL_1,
+	"Metal_1", K3, AMETAL_1, NOARCPROTO,
 	1, bipolar_al_0,
 	(APMETAL1<<AFUNCTIONSH)|WANTFIXANG|CANWIPE|(90<<AANGLEINCSH)};
 
 static TECH_ARCLAY bipolar_al_1[] = {{LM0,0,FILLED}};
 static TECH_ARCS bipolar_a_1 = {
-	"Metal_2", K4, AMETAL_2,
+	"Metal_2", K4, AMETAL_2, NOARCPROTO,
 	1, bipolar_al_1,
 	(APMETAL2<<AFUNCTIONSH)|WANTFIXANG|CANWIPE|(90<<AANGLEINCSH)};
 
 static TECH_ARCLAY bipolar_al_2[] = {{LPD,K2,FILLED}, {LN,0,FILLED}};
 static TECH_ARCS bipolar_a_2 = {
-	"NPPoly", K4, ANPPOLY,
+	"NPPoly", K4, ANPPOLY, NOARCPROTO,
 	2, bipolar_al_2,
 	(APPOLY1<<AFUNCTIONSH)|WANTFIXANG|WANTNOEXTEND|(90<<AANGLEINCSH)};
 
 static TECH_ARCLAY bipolar_al_3[] = {{LPD,K2,FILLED}, {LP,0,FILLED}};
 static TECH_ARCS bipolar_a_3 = {
-	"PPPoly", K4, APPPOLY,
+	"PPPoly", K4, APPPOLY, NOARCPROTO,
 	2, bipolar_al_3,
 	(APPOLY2<<AFUNCTIONSH)|WANTFIXANG|WANTNOEXTEND|(90<<AANGLEINCSH)};
 
@@ -852,9 +852,9 @@ TECH_VARIABLES bipolar_variables[] =
 
 /******************** ROUTINES ********************/
 
-INTSML bipolar_initprocess(TECHNOLOGY *tech, INTSML pass)
+BOOLEAN bipolar_initprocess(TECHNOLOGY *tech, INTBIG pass)
 {
-	return(0);
+	return(FALSE);
 }
 
 #endif  /* TECBIPOLAR - at top */
