@@ -37,7 +37,7 @@
 #include "tech.h"
 #include "efunction.h"
 
-INTSML cmos_initprocess(TECHNOLOGY*, INTSML);
+BOOLEAN cmos_initprocess(TECHNOLOGY*, INTBIG);
 
 /******************** LAYERS ********************/
 
@@ -268,28 +268,28 @@ static INTBIG cmos_unconnectedtable[] = {
 /* metal arc */
 static TECH_ARCLAY cmos_al_m[] = {{ LMETAL,0,FILLED }};
 static TECH_ARCS cmos_a_m = {
-	"Metal",K3,AMETAL,												/* name */
+	"Metal",K3,AMETAL,NOARCPROTO,									/* name */
 	1,cmos_al_m,													/* layers */
 	(APMETAL1<<AFUNCTIONSH)|WANTFIXANG|CANWIPE|(90<<AANGLEINCSH)};	/* userbits */
 
 /* polysilicon arc */
 static TECH_ARCLAY cmos_al_p[] = {{ LPOLY,0,FILLED }};
 static TECH_ARCS cmos_a_p = {
-	"Polysilicon",K2,APOLY,											/* name */
+	"Polysilicon",K2,APOLY,NOARCPROTO,								/* name */
 	1,cmos_al_p,													/* layers */
 	(APPOLY1<<AFUNCTIONSH)|WANTFIXANG|CANWIPE|(90<<AANGLEINCSH)};	/* userbits */
 
 /* diffusion-p arc */
 static TECH_ARCLAY cmos_al_dp[] = {{ LDIFF,K4,FILLED}, {LP,0,FILLED }};
 static TECH_ARCS cmos_a_dp = {
-	"Diffusion-p",K6,ADIFP,											/* name */
+	"Diffusion-p",K6,ADIFP,NOARCPROTO,								/* name */
 	2,cmos_al_dp,													/* layers */
 	(APDIFFP<<AFUNCTIONSH)|WANTFIXANG|CANWIPE|(90<<AANGLEINCSH)};	/* userbits */
 
 /* diffusion-well arc */
 static TECH_ARCLAY cmos_al_dw[] = {{ LDIFF,K6,FILLED}, {LWELL,0,FILLED }};
 static TECH_ARCS cmos_a_dw = {
-	"Diffusion-well",K8,ADIFW,										/* name */
+	"Diffusion-well",K8,ADIFW,NOARCPROTO,							/* name */
 	2,cmos_al_dw,													/* layers */
 	(APDIFFN<<AFUNCTIONSH)|WANTFIXANG|CANWIPE|(90<<AANGLEINCSH)};	/* userbits */
 
@@ -715,9 +715,9 @@ TECH_VARIABLES cmos_variables[] =
 
 /******************** ROUTINES ********************/
 
-INTSML cmos_initprocess(TECHNOLOGY *tech, INTSML pass)
+BOOLEAN cmos_initprocess(TECHNOLOGY *tech, INTBIG pass)
 {
-	return(0);
+	return(FALSE);
 }
 
 #endif  /* TECCMOS - at top */
