@@ -42,7 +42,7 @@
 #define D3	(WHOLE/20 * 3)	/* 0.15 */
 #define D4	(WHOLE/5)		/* 0.20 */
 
-INTSML efido_initprocess(TECHNOLOGY*, INTSML);
+BOOLEAN efido_initprocess(TECHNOLOGY*, INTBIG);
 
 /******************** LAYERS ********************/
 
@@ -112,14 +112,14 @@ static TECH_COLORMAP efido_colmap[32] =
 /* wire arc */
 static TECH_ARCLAY efido_al_w[] = {{ LARC,0,FILLED }};
 static TECH_ARCS efido_a_w = {
-	"wire",0,AWIRE,													/* name */
+	"wire",0,AWIRE,NOARCPROTO,										/* name */
 	1,efido_al_w,													/* layers */
 	(APMETAL1<<AFUNCTIONSH)|WANTFIXANG|(45<<AANGLEINCSH)};			/* userbits */
 
 /* bus arc */
 static TECH_ARCLAY efido_al_b[] = {{ LARC,0,CLOSED }};
 static TECH_ARCS efido_a_b = {
-	"bus",K2,ABUS,													/* name */
+	"bus",K2,ABUS,NOARCPROTO,										/* name */
 	1,efido_al_b,													/* layers */
 	(APBUS<<AFUNCTIONSH)|WANTFIXANG|(45<<AANGLEINCSH)};				/* userbits */
 
@@ -436,9 +436,9 @@ TECH_VARIABLES efido_variables[] =
 
 /******************** ROUTINES ********************/
 
-INTSML efido_initprocess(TECHNOLOGY *tech, INTSML pass)
+BOOLEAN efido_initprocess(TECHNOLOGY *tech, INTBIG pass)
 {
-	return(0);
+	return(FALSE);
 }
 
 #endif  /* TECEFIDO - at top */
