@@ -38,10 +38,10 @@
 #include "efunction.h"
 
 /* prototypes for local routines */
-static void gem_addtailplus(POLYGON*, INTSML, INTBIG*, INTBIG*, INTBIG);
-static void gem_addheadplus(POLYGON*, INTSML, INTBIG*, INTBIG*, INTBIG);
+static void gem_addtailplus(POLYGON*, INTBIG, INTBIG*, INTBIG*, INTBIG);
+static void gem_addheadplus(POLYGON*, INTBIG, INTBIG*, INTBIG*, INTBIG);
 static void gem_add1linebody(POLYGON*, INTBIG, INTBIG, INTBIG, INTBIG);
-static void gem_addzigzagbody(POLYGON*, INTSML, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
+static void gem_addzigzagbody(POLYGON*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 
 static TECHNOLOGY *gem_tech;
 
@@ -95,42 +95,42 @@ static char *gem_layer_letters[MAXLAYERS] = {"e", "g", "t", "c", "p", "n", "f"};
 /* General arc */
 static TECH_ARCLAY gem_gw[] = {{LGENARC,0,VECTORS}};
 static TECH_ARCS gem_a_g = {
-	"General",0,AGENERAL,								/* name */
+	"General",0,AGENERAL,NOARCPROTO,					/* name */
 	1,gem_gw,											/* layers */
 	(APNONELEC<<AFUNCTIONSH)|CANWIPE|(0<<AANGLEINCSH)};	/* userbits */
 
 /* Temporal arc */
 static TECH_ARCLAY gem_tw[] = {{LTEMPARC,0,VECTORS}};
 static TECH_ARCS gem_a_t = {
-	"Temporal",0,ATEMP,									/* name */
+	"Temporal",0,ATEMP,NOARCPROTO,						/* name */
 	1,gem_tw,											/* layers */
 	(APNONELEC<<AFUNCTIONSH)|CANWIPE|(0<<AANGLEINCSH)};	/* userbits */
 
 /* Causal arc */
 static TECH_ARCLAY gem_cw[] = {{LCAUSEARC,0,VECTORS}};
 static TECH_ARCS gem_a_c = {
-	"Causal",0,ACAUSE,									/* name */
+	"Causal",0,ACAUSE,NOARCPROTO,						/* name */
 	1,gem_cw,											/* layers */
 	(APNONELEC<<AFUNCTIONSH)|CANWIPE|(0<<AANGLEINCSH)};	/* userbits */
 
 /* Prereq arc */
 static TECH_ARCLAY gem_pw[] = {{LPREARC,0,VECTORS}};
 static TECH_ARCS gem_a_p = {
-	"Prerequisite",0,APREREQ,							/* name */
+	"Prerequisite",0,APREREQ,NOARCPROTO,				/* name */
 	1,gem_pw,											/* layers */
 	(APNONELEC<<AFUNCTIONSH)|CANWIPE|(0<<AANGLEINCSH)};	/* userbits */
 
 /* Nondeterministic arc */
 static TECH_ARCLAY gem_nw[] = {{LNONARC,0,VECTORS}};
 static TECH_ARCS gem_a_n = {
-	"Nondeterministic",0,ANONDET,						/* name */
+	"Nondeterministic",0,ANONDET,NOARCPROTO,			/* name */
 	1,gem_nw,											/* layers */
 	(APNONELEC<<AFUNCTIONSH)|CANWIPE|(0<<AANGLEINCSH)};	/* userbits */
 
 /* Nondeterministic-fork arc */
 static TECH_ARCLAY gem_fw[] = {{LFORKARC,0,VECTORS}};
 static TECH_ARCS gem_a_f = {
-	"Nondeterministic-fork",0,AFORK,					/* name */
+	"Nondeterministic-fork",0,AFORK,NOARCPROTO,			/* name */
 	1,gem_fw,											/* layers */
 	(APNONELEC<<AFUNCTIONSH)|CANWIPE|(0<<AANGLEINCSH)};	/* userbits */
 
@@ -321,11 +321,11 @@ TECH_VARIABLES gem_variables[] =
 
 /******************** ROUTINES ********************/
 
-INTSML gem_initprocess(TECHNOLOGY *tech, INTSML pass)
+BOOLEAN gem_initprocess(TECHNOLOGY *tech, INTBIG pass)
 {
 	/* initialize the technology variable */
 	if (pass == 0) gem_tech = tech;
-	return(0);
+	return(FALSE);
 }
 
 void gem_shapenodepoly(NODEINST *ni, INTBIG box, POLYGON *poly)
@@ -333,7 +333,7 @@ void gem_shapenodepoly(NODEINST *ni, INTBIG box, POLYGON *poly)
 	REGISTER TECH_POLYGON *lay;
 	REGISTER VARIABLE *var;
 	REGISTER INTBIG pindex;
-	static INTBIG element = 0, event1 = 0, event2 = 0, event3 = 0, event4 = 0;
+	static INTBIG elementkey = 0, event1key = 0, event2key = 0, event3key = 0, event4key = 0;
 
 	/* handle displayable variables */
 	if (box >= tech_realpolys)
@@ -356,26 +356,26 @@ void gem_shapenodepoly(NODEINST *ni, INTBIG box, POLYGON *poly)
 	switch (box)
 	{
 		case 1:
-			if (element == 0) element = makekey("GEM_element");
-			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, element);
+			if (elementkey == 0) elementkey = makekey("GEM_element");
+			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, elementkey);
 			TDCLEAR(poly->textdescript);
 			TDSETSIZE(poly->textdescript, TXTSETQLAMBDA(12));
 			break;
 		case 2:
-			if (event1 == 0) event1 = makekey("GEM_event1");
-			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, event1);
+			if (event1key == 0) event1key = makekey("GEM_event1");
+			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, event1key);
 			break;
 		case 3:
-			if (event2 == 0) event2 = makekey("GEM_event2");
-			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, event2);
+			if (event2key == 0) event2key = makekey("GEM_event2");
+			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, event2key);
 			break;
 		case 4:
-			if (event3 == 0) event3 = makekey("GEM_event3");
-			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, event3);
+			if (event3key == 0) event3key = makekey("GEM_event3");
+			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, event3key);
 			break;
 		case 5:
-			if (event4 == 0) event4 = makekey("GEM_event4");
-			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, event4);
+			if (event4key == 0) event4key = makekey("GEM_event4");
+			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, event4key);
 			break;
 	}
 	if (var != NOVARIABLE) poly->string = (char *)var->addr;
@@ -383,7 +383,7 @@ void gem_shapenodepoly(NODEINST *ni, INTBIG box, POLYGON *poly)
 
 void gem_shapearcpoly(ARCINST *ai, INTBIG box, POLYGON *poly)
 {
-	REGISTER INTSML angle;
+	REGISTER INTBIG angle;
 	REGISTER INTBIG aindex, i, dist, lambda;
 	INTBIG x1, y1, x2, y2;
 	REGISTER TECH_ARCLAY *thista;
@@ -404,7 +404,7 @@ void gem_shapearcpoly(ARCINST *ai, INTBIG box, POLYGON *poly)
 	lambda = lambdaofarc(ai);
 	x1 = ai->end[0].xpos;   y1 = ai->end[0].ypos;
 	x2 = ai->end[1].xpos;   y2 = ai->end[1].ypos;
-	angle = (INTSML)(((ai->userbits&AANGLE) >> AANGLESH) * 10);
+	angle = ((ai->userbits&AANGLE) >> AANGLESH) * 10;
 	if ((ai->userbits&REVERSEEND) != 0)
 	{
 		i = x1;   x1 = x2;   x2 = i;
@@ -464,13 +464,13 @@ void gem_shapearcpoly(ARCINST *ai, INTBIG box, POLYGON *poly)
  * helper routine to add a "+" to the tail of the arc in "poly", given that
  * the arc runs to (x,y) and is at an angle of "angle" tenth-degrees
  */
-void gem_addtailplus(POLYGON *poly, INTSML angle, INTBIG *x, INTBIG *y, INTBIG lambda)
+void gem_addtailplus(POLYGON *poly, INTBIG angle, INTBIG *x, INTBIG *y, INTBIG lambda)
 {
 	REGISTER INTBIG sin, cos, dist, threehalfdist, twicedist;
-	REGISTER INTSML c;
+	REGISTER INTBIG c;
 
 	c = poly->count;
-	if (poly->limit < c+4) (void)extendpolygon(poly, (INTSML)(c+4));
+	if (poly->limit < c+4) (void)extendpolygon(poly, c+4);
 	dist = K1 * lambda / WHOLE;
 	threehalfdist = dist + dist / 2;
 	twicedist = dist * 2;
@@ -479,10 +479,10 @@ void gem_addtailplus(POLYGON *poly, INTSML angle, INTBIG *x, INTBIG *y, INTBIG l
 	poly->xv[c] = *x;   poly->yv[c] = *y;   c++;
 	poly->xv[c] = *x + mult(cos, threehalfdist);
 	poly->yv[c] = *y + mult(sin, threehalfdist);   c++;
-	poly->xv[c] = *x + mult(cosine((INTSML)((angle+450) % 3600)), dist);
-	poly->yv[c] = *y + mult(sine((INTSML)((angle+450) % 3600)), dist);   c++;
-	poly->xv[c] = *x + mult(cosine((INTSML)((angle+3150) % 3600)), dist);
-	poly->yv[c] = *y + mult(sine((INTSML)((angle+3150) % 3600)), dist);   c++;
+	poly->xv[c] = *x + mult(cosine((angle+450) % 3600), dist);
+	poly->yv[c] = *y + mult(sine((angle+450) % 3600), dist);   c++;
+	poly->xv[c] = *x + mult(cosine((angle+3150) % 3600), dist);
+	poly->yv[c] = *y + mult(sine((angle+3150) % 3600), dist);   c++;
 	*x += mult(cos, twicedist);   *y += mult(sin, twicedist);
 	poly->count = c;
 }
@@ -491,25 +491,25 @@ void gem_addtailplus(POLYGON *poly, INTSML angle, INTBIG *x, INTBIG *y, INTBIG l
  * helper routine to add a "+" to the head of the arc in "poly", given that
  * the arc runs from (x,y) and is at an angle of "angle" tenth-degrees
  */
-void gem_addheadplus(POLYGON *poly, INTSML angle, INTBIG *x, INTBIG *y, INTBIG lambda)
+void gem_addheadplus(POLYGON *poly, INTBIG angle, INTBIG *x, INTBIG *y, INTBIG lambda)
 {
-	REGISTER INTSML c;
+	REGISTER INTBIG c;
 	REGISTER INTBIG sin, cos, dist, threehalfdist, twicedist;
 
 	c = poly->count;
-	if (poly->limit < c+4) (void)extendpolygon(poly, (INTSML)(c+4));
+	if (poly->limit < c+4) (void)extendpolygon(poly, c+4);
 	dist = K1 * lambda / WHOLE;
 	threehalfdist = dist + dist / 2;
 	twicedist = dist * 2;
-	sin = sine((INTSML)((angle+1800) % 3600));
-	cos = cosine((INTSML)((angle+1800) % 3600));
+	sin = sine((angle+1800) % 3600);
+	cos = cosine((angle+1800) % 3600);
 	poly->xv[c] = *x;   poly->yv[c] = *y;   c++;
 	poly->xv[c] = *x + mult(cos, threehalfdist);
 	poly->yv[c] = *y + mult(sin, threehalfdist);   c++;
-	poly->xv[c] = *x + mult(cosine((INTSML)((angle+1350) % 3600)), dist);
-	poly->yv[c] = *y + mult(sine((INTSML)((angle+1350) % 3600)), dist);   c++;
-	poly->xv[c] = *x + mult(cosine((INTSML)((angle+2250) % 3600)), dist);
-	poly->yv[c] = *y + mult(sine((INTSML)((angle+2250) % 3600)), dist);   c++;
+	poly->xv[c] = *x + mult(cosine((angle+1350) % 3600), dist);
+	poly->yv[c] = *y + mult(sine((angle+1350) % 3600), dist);   c++;
+	poly->xv[c] = *x + mult(cosine((angle+2250) % 3600), dist);
+	poly->yv[c] = *y + mult(sine((angle+2250) % 3600), dist);   c++;
 	*x += mult(cos, twicedist);   *y += mult(sin, twicedist);
 	poly->count = c;
 }
@@ -520,10 +520,10 @@ void gem_addheadplus(POLYGON *poly, INTSML angle, INTBIG *x, INTBIG *y, INTBIG l
  */
 void gem_add1linebody(POLYGON *poly, INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2)
 {
-	REGISTER INTSML c;
+	REGISTER INTBIG c;
 
 	c = poly->count;
-	if (poly->limit < c+2) (void)extendpolygon(poly, (INTSML)(c+2));
+	if (poly->limit < c+2) (void)extendpolygon(poly, c+2);
 	poly->xv[c] = x1;    poly->yv[c] = y1;   c++;
 	poly->xv[c] = x2;    poly->yv[c] = y2;   c++;
 	poly->count = c;
@@ -533,24 +533,24 @@ void gem_add1linebody(POLYGON *poly, INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2)
  * helper routine to add a zig-zag body to the arc in "poly", given that
  * the arc runs from (x1,y1) to (x2,y2) and is at an angle of "angle" tenth-degrees.
  */
-void gem_addzigzagbody(POLYGON *poly, INTSML angle, INTBIG x1, INTBIG y1,
+void gem_addzigzagbody(POLYGON *poly, INTBIG angle, INTBIG x1, INTBIG y1,
 	INTBIG x2, INTBIG y2, INTBIG lambda)
 {
 	REGISTER INTBIG xc, yc, dist;
-	REGISTER INTSML c;
+	REGISTER INTBIG c;
 
 	/* get the center of the zig-zag */
 	xc = (x1 + x2) / 2;  yc = (y1 + y2) / 2;
 
 	c = poly->count;
-	if (poly->limit < c+6) (void)extendpolygon(poly, (INTSML)(c+6));
+	if (poly->limit < c+6) (void)extendpolygon(poly, c+6);
 	dist = K1 * lambda / WHOLE;
 	poly->xv[c] = x1;   poly->yv[c] = y1;   c++;
-	poly->xv[c] = poly->xv[c+1] = xc + mult(cosine((INTSML)((angle+900) % 3600)), dist);
-	poly->yv[c] = poly->yv[c+1] = yc + mult(sine((INTSML)((angle+900) % 3600)), dist);
+	poly->xv[c] = poly->xv[c+1] = xc + mult(cosine((angle+900) % 3600), dist);
+	poly->yv[c] = poly->yv[c+1] = yc + mult(sine((angle+900) % 3600), dist);
 	c += 2;
-	poly->xv[c] = poly->xv[c+1] = xc + mult(cosine((INTSML)((angle+2700) % 3600)),dist);
-	poly->yv[c] = poly->yv[c+1] = yc + mult(sine((INTSML)((angle+2700) % 3600)), dist);
+	poly->xv[c] = poly->xv[c+1] = xc + mult(cosine((angle+2700) % 3600),dist);
+	poly->yv[c] = poly->yv[c+1] = yc + mult(sine((angle+2700) % 3600), dist);
 	c += 2;
 	poly->xv[c] = x2;   poly->yv[c] = y2;   c++;
 	poly->count = c;
