@@ -86,21 +86,21 @@ static char *gen_layer_letters[MAXLAYERS] = {"u", "i", "r", "g", "d"};
 /* universal arc */
 static TECH_ARCLAY gen_al_u[] = {{LUNIV,0,FILLED}};
 static TECH_ARCS gen_a_u = {
-	"Universal",0,GENAUNIV,									/* name */
+	"Universal",0,GENAUNIV,NOARCPROTO,						/* name */
 	1,gen_al_u,												/* layers */
 	(APUNKNOWN<<AFUNCTIONSH)|WANTFIXANG|(45<<AANGLEINCSH)};	/* userbits */
 
 /* invisible arc */
 static TECH_ARCLAY gen_al_i[] = {{LINVIS,0,FILLED}};
 static TECH_ARCS gen_a_i = {
-	"Invisible",0,GENAINVIS,								/* name */
+	"Invisible",0,GENAINVIS,NOARCPROTO,						/* name */
 	1,gen_al_i,												/* layers */
 	(APNONELEC<<AFUNCTIONSH)|WANTFIXANG|(45<<AANGLEINCSH)};	/* userbits */
 
 /* unrouted arc */
 static TECH_ARCLAY gen_al_r[] = {{LUNROUTED,0,FILLED}};
 static TECH_ARCS gen_a_r = {
-	"Unrouted",0,GENAUNROUTED,								/* name */
+	"Unrouted",0,GENAUNROUTED,NOARCPROTO,					/* name */
 	1,gen_al_r,												/* layers */
 	(APUNROUTED<<AFUNCTIONSH)|(0<<AANGLEINCSH)};			/* userbits */
 
@@ -246,7 +246,7 @@ TECH_VARIABLES gen_variables[] =
 
 /******************** ROUTINES ********************/
 
-INTSML gen_initprocess(TECHNOLOGY *tech, INTSML pass)
+BOOLEAN gen_initprocess(TECHNOLOGY *tech, INTBIG pass)
 {
 	switch (pass)
 	{
@@ -276,7 +276,7 @@ INTSML gen_initprocess(TECHNOLOGY *tech, INTSML pass)
 			gen_gl_lay.col = el_colmengly;
 			break;
 	}
-	return(0);
+	return(FALSE);
 }
 
 void gen_termprocess(void)
@@ -291,10 +291,10 @@ void gen_termprocess(void)
  */
 void gen_makeunivlist(void)
 {
-	REGISTER INTSML tot;
+	REGISTER INTBIG tot;
 	REGISTER ARCPROTO *ap;
 	REGISTER TECHNOLOGY *t;
-	static INTBIG first = 1;
+	static BOOLEAN first = TRUE;
 
 	/* count the number of arcs in all technologies */
 	tot = 0;
@@ -310,7 +310,7 @@ void gen_makeunivlist(void)
 
 	/* fill the array */
 	tot = 0;
-	if (first != 0)
+	if (first)
 		gen_upconn[tot++] = (ARCPROTO *)0;
 	for(t = el_technologies; t != NOTECHNOLOGY; t = t->nexttechnology)
 	{
@@ -320,7 +320,7 @@ void gen_makeunivlist(void)
 	gen_upconn[tot] = NOARCPROTO;
 
 	/* store the array in this technology */
-	if (first != 0)
+	if (first)
 	{
 		/* on first entry, load the local descriptor */
 		gen_u_p[0].portarcs = (INTBIG *)gen_upconn;
@@ -331,22 +331,22 @@ void gen_makeunivlist(void)
 		gen_univpinprim->firstportproto->connects = gen_upconn;
 		gen_invispinprim->firstportproto->connects = gen_upconn;
 	}
-	first = 0;
+	first = FALSE;
 }
 
 INTBIG gen_nodepolys(NODEINST *ni, INTBIG *reasonable, WINDOWPART *win)
 {
 	REGISTER INTBIG pindex, count;
-	REGISTER INTSML start, end;
+	REGISTER INTBIG start, end;
 	REGISTER INTBIG lambda;
-	static INTBIG portangle = 0, portrange = 0;
+	static INTBIG portanglekey = 0, portrangekey = 0;
 	REGISTER VARIABLE *var, *var2;
 
 	pindex = ni->proto->primindex;
 	count = gen_nodeprotos[pindex-1]->layercount;
 	if (pindex == NUNIV || pindex == NINVIS || pindex == NUNROUTED)
 	{
-		if (tech_pinusecount(ni, NOARCPROTO) != 0) count = 0;
+		if (tech_pinusecount(ni, win)) count = 0;
 		if (pindex == NINVIS)
 		{
 			gen_in_lay.bits = LAYERO;
@@ -367,7 +367,7 @@ INTBIG gen_nodepolys(NODEINST *ni, INTBIG *reasonable, WINDOWPART *win)
 						if ((var->addr&(LAYERG|LAYERH|LAYEROE)) == LAYEROE)
 							gen_in_lay.bits = LAYERO; else
 								gen_in_lay.bits = LAYERA;
-						gen_in_lay.col = (INTSML)var->addr;
+						gen_in_lay.col = var->addr;
 						break;
 				}
 				gen_int_lay.bits = gen_in_lay.bits;
@@ -376,16 +376,16 @@ INTBIG gen_nodepolys(NODEINST *ni, INTBIG *reasonable, WINDOWPART *win)
 		}
 	} else if (pindex == NPORT)
 	{
-		if (portangle == 0) portangle = makekey("EDTEC_portangle");
-		if (portrange == 0) portrange = makekey("EDTEC_portrange");
+		if (portanglekey == 0) portanglekey = makekey("EDTEC_portangle");
+		if (portrangekey == 0) portrangekey = makekey("EDTEC_portrange");
 
 		/* port node becomes a cross when it is 1x1 */
 		lambda = lambdaofnode(ni);
 		if (ni->highx-ni->lowx == lambda*2 && ni->highy-ni->lowy == lambda*2)
 			gen_p_l[0].style = CROSS; else gen_p_l[0].style = CLOSED;
 
-		var = getvalkey((INTBIG)ni, VNODEINST, VINTEGER, portangle);
-		var2 = getvalkey((INTBIG)ni, VNODEINST, VINTEGER, portrange);
+		var = getvalkey((INTBIG)ni, VNODEINST, VINTEGER, portanglekey);
+		var2 = getvalkey((INTBIG)ni, VNODEINST, VINTEGER, portrangekey);
 		if (var == NOVARIABLE || var2 == NOVARIABLE) count--; else
 		{
 			start = (var->addr - var2->addr) * 10;
@@ -432,13 +432,13 @@ void gen_shapenodepoly(NODEINST *ni, INTBIG box, POLYGON *poly)
 	/* universal pins may have trace information */
 	if (pindex == NUNIV)
 	{
-		var = getvalkey((INTBIG)ni, VNODEINST, VINTEGER|VISARRAY, el_trace);
+		var = getvalkey((INTBIG)ni, VNODEINST, VINTEGER|VISARRAY, el_trace_key);
 		if (var != NOVARIABLE)
 		{
 			/* make sure polygon can hold this description */
 			count = getlength(var) / 2;
 			j = count*4 + (count-1)*2;
-			if (poly->limit < j) (void)extendpolygon(poly, (INTSML)j);
+			if (poly->limit < j) (void)extendpolygon(poly, j);
 
 			/* fill the polygon */
 			xoff = (ni->highx + ni->lowx) / 2;
@@ -469,7 +469,7 @@ void gen_shapenodepoly(NODEINST *ni, INTBIG box, POLYGON *poly)
 			/* add in peripheral information */
 			poly->layer = lay->layernum;
 			poly->style = VECTORS;
-			poly->count = (INTSML)j;
+			poly->count = j;
 			poly->desc = gen_layers[poly->layer];
 			return;
 		}
@@ -481,9 +481,9 @@ void gen_shapenodepoly(NODEINST *ni, INTBIG box, POLYGON *poly)
 }
 
 void gen_shapeportpoly(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans,
-	INTSML purpose)
+	BOOLEAN purpose)
 {
-	REGISTER INTSML pindex;
+	REGISTER INTBIG pindex;
 
 	pindex = ni->proto->primindex;
 	tech_fillportpoly(ni, pp, poly, trans, gen_nodeprotos[pindex-1], OPENED);
