@@ -87,7 +87,7 @@ COMCOMP mocmosold_parse = {mocmosopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
 #define EITHER    1		/* set for either, cleared for general */
 #define OUTLINE   2		/* set to outline layers, clear for stipple */
 #define NWELL     4		/* set for n-well, clear for p-well */
-static INTSML mocmosold_state = 0;
+static INTBIG mocmosold_state = 0;
 static TECHNOLOGY *mocmosold_tech;
 static char *mocmosold_stipplelayers = "Select and Passivation";
 
@@ -387,7 +387,7 @@ static GRAPHICS *mocmosold_layerstipple[] =
 	&mocmosold_m2_lay,
 	&mocmosold_pm2_lay
 };
-static INTSML mocmosold_layerstipplesize = 5;
+static INTBIG mocmosold_layerstipplesize = 5;
 
 /* The low 5 bits map Metal-1, Poly, Active, Metal-2}, and well */
 static TECH_COLORMAP mocmosold_colmap[32] =
@@ -518,21 +518,21 @@ static INTBIG mocmosold_connectedtable[] = {
 /* metal 1 arc */
 static TECH_ARCLAY mocmosold_al_m1[] = {{LMETAL1,0,FILLED }};
 static TECH_ARCS mocmosold_a_m1 = {
-	"Metal-1",K3,AMETAL1,											/* name */
+	"Metal-1",K3,AMETAL1,NOARCPROTO,								/* name */
 	1,mocmosold_al_m1,												/* layers */
 	(APMETAL1<<AFUNCTIONSH)|WANTFIXANG|CANWIPE|(90<<AANGLEINCSH)};	/* userbits */
 
 /* metal 2 arc */
 static TECH_ARCLAY mocmosold_al_m2[] = {{LMETAL2,0,FILLED }};
 static TECH_ARCS mocmosold_a_m2 = {
-	"Metal-2",K3,AMETAL2,											/* name */
+	"Metal-2",K3,AMETAL2,NOARCPROTO,								/* name */
 	1,mocmosold_al_m2,												/* layers */
 	(APMETAL2<<AFUNCTIONSH)|WANTFIXANG|CANWIPE|(90<<AANGLEINCSH)};	/* userbits */
 
 /* polysilicon arc */
 static TECH_ARCLAY mocmosold_al_p[] = {{LPOLY,0,FILLED }};
 static TECH_ARCS mocmosold_a_po = {
-	"Polysilicon",K2,APOLY,											/* name */
+	"Polysilicon",K2,APOLY,NOARCPROTO,								/* name */
 	1,mocmosold_al_p,												/* layers */
 	(APPOLY1<<AFUNCTIONSH)|WANTFIXANG|CANWIPE|(90<<AANGLEINCSH)};	/* userbits */
 
@@ -540,7 +540,7 @@ static TECH_ARCS mocmosold_a_po = {
 static TECH_ARCLAY mocmosold_al_pa[] = {{LSACT,K8,FILLED}, {LWELLNP,0,FILLED},
 	{LSELECTP,K4,FILLED}};
 static TECH_ARCS mocmosold_a_pa = {
-	"S-Active",K10,ASACT,											/* name */
+	"S-Active",K10,ASACT,NOARCPROTO,								/* name */
 	3,mocmosold_al_pa,												/* layers */
 	(APDIFFP<<AFUNCTIONSH)|WANTFIXANG|CANWIPE|(90<<AANGLEINCSH)};	/* userbits */
 
@@ -548,14 +548,14 @@ static TECH_ARCS mocmosold_a_pa = {
 static TECH_ARCLAY mocmosold_al_na[] = {{LDACT,K8,FILLED}, {LWELLP,0,FILLED},
 	{LSELECTNP,K4,FILLED}};
 static TECH_ARCS mocmosold_a_na = {
-	"D-Active",K10,ADACT,											/* name */
+	"D-Active",K10,ADACT,NOARCPROTO,								/* name */
 	3,mocmosold_al_na,												/* layers */
 	(APDIFFN<<AFUNCTIONSH)|WANTFIXANG|CANWIPE|(90<<AANGLEINCSH)};	/* userbits */
 
 /* General active arc */
 static TECH_ARCLAY mocmosold_al_a[] = {{LDACT,0,FILLED}, {LSACT,0,FILLED}};
 static TECH_ARCS mocmosold_a_a = {
-	"Active",K2,AACT,												/* name */
+	"Active",K2,AACT,NOARCPROTO,									/* name */
 	2,mocmosold_al_a,												/* layers */
 	(APDIFF<<AFUNCTIONSH)|WANTFIXANG|CANWIPE|(90<<AANGLEINCSH)};	/* userbits */
 
@@ -571,7 +571,7 @@ static INTBIG mocmosold_arc_widoff[ARCPROTOCOUNT] = {0,0,0,K8,K8,0};
 typedef struct
 {
 	TECH_ARCLAY *str;
-	INTSML        layer;
+	INTBIG        layer;
 } STIPARC;
 static STIPARC mocmosold_arcstipple[] =
 {
@@ -581,7 +581,7 @@ static STIPARC mocmosold_arcstipple[] =
 	{mocmosold_al_na, 1},		/* well-p */
 	{mocmosold_al_m2, 0}		/* metal-2 */
 };
-static INTSML mocmosold_arcstipplesize = 2;
+static INTBIG mocmosold_arcstipplesize = 2;
 
 /******************** PORTINST CONNECTIONS ********************/
 
@@ -1142,7 +1142,7 @@ static INTBIG mocmosold_node_widoff[NODEPROTOCOUNT*4] = {
 typedef struct
 {
 	TECH_POLYGON *str;
-	INTSML         layer;
+	INTBIG        layer;
 } STIPPCONV;
 
 static STIPPCONV mocmosold_nodepstipple[] =
@@ -1163,12 +1163,12 @@ static STIPPCONV mocmosold_nodepstipple[] =
 	{mocmosold_mm_l, 1},	/* metal-2 */
 	{mocmosold_m2_l, 0}		/* metal-2 */
 };
-static INTSML mocmosold_nodepstipplesize = 7;
+static INTBIG mocmosold_nodepstipplesize = 7;
 
 typedef struct
 {
 	TECH_SERPENT *str;
-	INTSML         layer;
+	INTBIG        layer;
 } STIPSCONV;
 
 static STIPSCONV mocmosold_nodesstipple[] =
@@ -1178,7 +1178,7 @@ static STIPSCONV mocmosold_nodesstipple[] =
 	{mocmosold_tpa_l, 2},	/* well-n */
 	{mocmosold_tna_l, 2},	/* well-p */
 };
-static INTSML mocmosold_nodesstipplesize = 2;
+static INTBIG mocmosold_nodesstipplesize = 2;
 
 /******************** SIMULATION VARIABLES ********************/
 
@@ -1488,16 +1488,16 @@ TECH_VARIABLES mocmosold_variables[] =
 
 /******************** ROUTINES ********************/
 
-INTSML mocmosold_initprocess(TECHNOLOGY *tech, INTSML pass)
+BOOLEAN mocmosold_initprocess(TECHNOLOGY *tech, INTBIG pass)
 {
 	/* initialize the technology variable */
 	if (pass == 0) mocmosold_tech = tech;
-	return(0);
+	return(FALSE);
 }
 
-void mocmosold_setmode(INTSML count, char *par[])
+void mocmosold_setmode(INTBIG count, char *par[])
 {
-	REGISTER INTSML l, i, aindex;
+	REGISTER INTBIG l, i, aindex;
 	REGISTER char *pp;
 	REGISTER ARCPROTO *ap;
 	REGISTER VARIABLE *var;
@@ -1840,10 +1840,10 @@ static VARIABLE *mocmosold_shrinkvar;
 INTBIG mocmosold_arcpolys(ARCINST *ai, WINDOWPART *win)
 {
 	REGISTER INTBIG total;
-	static INTBIG arc_shrinkback = 0;
+	static INTBIG arc_shrinkback_key = 0;
 
-	if (arc_shrinkback == 0) arc_shrinkback = makekey("ARC_shrinkback");
-	mocmosold_shrinkvar = getvalkey((INTBIG)ai, VARCINST, VINTEGER, arc_shrinkback);
+	if (arc_shrinkback_key == 0) arc_shrinkback_key = makekey("ARC_shrinkback");
+	mocmosold_shrinkvar = getvalkey((INTBIG)ai, VARCINST, VINTEGER, arc_shrinkback_key);
 
 	if ((ai->userbits&ISNEGATED) != 0) tech_resetnegated(ai);
 	total = mocmosold_arcprotos[ai->proto->arcindex]->laycount;
@@ -1857,7 +1857,7 @@ INTBIG mocmosold_arcpolys(ARCINST *ai, WINDOWPART *win)
 
 void mocmosold_shapearcpoly(ARCINST *ai, INTBIG box, POLYGON *poly)
 {
-	REGISTER INTSML aindex, i;
+	REGISTER INTBIG aindex, i;
 	REGISTER INTBIG shrinkback, len, oldbits, thisend, lambda;
 	REGISTER TECH_ARCLAY *thista;
 	INTBIG oldx[2], oldy[2];
