@@ -36,7 +36,7 @@
 #include "tech.h"
 #include "efunction.h"
 
-INTSML nmos_initprocess(TECHNOLOGY*, INTSML);
+BOOLEAN nmos_initprocess(TECHNOLOGY*, INTBIG);
 
 /******************** LAYERS ********************/
 
@@ -434,21 +434,21 @@ static INTBIG nmos_connectedtable[] = {
 /* metal arc */
 static TECH_ARCLAY nmos_al_m[] = {{ LMETAL,0,FILLED }};
 static TECH_ARCS nmos_a_m = {
-	"Metal",K3,AMETAL,												/* name */
+	"Metal",K3,AMETAL,NOARCPROTO,									/* name */
 	1,nmos_al_m,													/* layers */
 	(APMETAL1<<AFUNCTIONSH)|WANTFIXANG|CANWIPE|(90<<AANGLEINCSH)};	/* userbits */
 
 /* polysilicon arc */
 static TECH_ARCLAY nmos_al_p[] = {{ LPOLY,0,FILLED }};
 static TECH_ARCS nmos_a_p = {
-	"Polysilicon",K2,APOLY,											/* name */
+	"Polysilicon",K2,APOLY,NOARCPROTO,								/* name */
 	1,nmos_al_p,													/* layers */
 	(APPOLY1<<AFUNCTIONSH)|WANTFIXANG|CANWIPE|(90<<AANGLEINCSH)};	/* userbits */
 
 /* diffusion arc */
 static TECH_ARCLAY nmos_al_d[] = {{ LDIFF,0,FILLED }};
 static TECH_ARCS nmos_a_d = {
-	"Diffusion",K2,ADIFF,											/* name */
+	"Diffusion",K2,ADIFF,NOARCPROTO,								/* name */
 	1,nmos_al_d,													/* layers */
 	(APDIFF<<AFUNCTIONSH)|WANTFIXANG|CANWIPE|(90<<AANGLEINCSH)};	/* userbits */
 
@@ -1071,9 +1071,9 @@ TECH_VARIABLES nmos_variables[] =
 
 /******************** ROUTINES ********************/
 
-INTSML nmos_initprocess(TECHNOLOGY *tech, INTSML pass)
+BOOLEAN nmos_initprocess(TECHNOLOGY *tech, INTBIG pass)
 {
-	return(0);
+	return(FALSE);
 }
 
 #endif  /* TECNMOS - at top */
