@@ -299,42 +299,42 @@ static TECH_COLORMAP rcmos_colmap[32] =
 /* metal 1 arc */
 static TECH_ARCLAY rcmos_al_m1[] = {{LMETAL1,0,FILLED }};
 static TECH_ARCS rcmos_a_m1 = {
-	"Metal-1",K3,AMETAL1,												/* name */
+	"Metal-1",K3,AMETAL1,NOARCPROTO,									/* name */
 	1,rcmos_al_m1,														/* layers */
 	(APMETAL1<<AFUNCTIONSH)|WANTNOEXTEND|CANCURVE|(0<<AANGLEINCSH)};	/* userbits */
 
 /* metal 2 arc */
 static TECH_ARCLAY rcmos_al_m2[] = {{LMETAL2,0,FILLED }};
 static TECH_ARCS rcmos_a_m2 = {
-	"Metal-2",K3,AMETAL2,												/* name */
+	"Metal-2",K3,AMETAL2,NOARCPROTO,									/* name */
 	1,rcmos_al_m2,														/* layers */
 	(APMETAL2<<AFUNCTIONSH)|WANTNOEXTEND|CANCURVE|(0<<AANGLEINCSH)};	/* userbits */
 
 /* polysilicon arc */
 static TECH_ARCLAY rcmos_al_p[] = {{LPOLY,0,FILLED }};
 static TECH_ARCS rcmos_a_po = {
-	"Polysilicon",K2,APOLY,												/* name */
+	"Polysilicon",K2,APOLY,NOARCPROTO,									/* name */
 	1,rcmos_al_p,														/* layers */
 	(APPOLY1<<AFUNCTIONSH)|WANTNOEXTEND|CANCURVE|(0<<AANGLEINCSH)};		/* userbits */
 
 /* S-active arc */
 static TECH_ARCLAY rcmos_al_sa[] = {{LSACT,K4,FILLED}, {LSELECT,0,FILLED}};
 static TECH_ARCS rcmos_a_sa = {
-	"S-Active",K6,ASACT,												/* name */
+	"S-Active",K6,ASACT,NOARCPROTO,										/* name */
 	2,rcmos_al_sa,														/* layers */
 	(APDIFFN<<AFUNCTIONSH)|WANTNOEXTEND|CANCURVE|(0<<AANGLEINCSH)};		/* userbits */
 
 /* D-active arc */
 static TECH_ARCLAY rcmos_al_da[] = {{LDACT,K8,FILLED}, {LWELL,0,FILLED}};
 static TECH_ARCS rcmos_a_da = {
-	"D-Active",K10,ADACT,												/* name */
+	"D-Active",K10,ADACT,NOARCPROTO,									/* name */
 	2,rcmos_al_da,														/* layers */
 	(APDIFFP<<AFUNCTIONSH)|WANTNOEXTEND|CANCURVE|(0<<AANGLEINCSH)};		/* userbits */
 
 /* Substrate active arc */
 static TECH_ARCLAY rcmos_al_sua[] = {{LDACT,0,FILLED}, {LSACT,0,FILLED}};
 static TECH_ARCS rcmos_a_sua = {
-	"Substrate-Active",K2,ASUACT,										/* name */
+	"Substrate-Active",K2,ASUACT,NOARCPROTO,							/* name */
 	2,rcmos_al_sua,														/* layers */
 	(APDIFFS<<AFUNCTIONSH)|WANTNOEXTEND|CANCURVE|(0<<AANGLEINCSH)};		/* userbits */
 
@@ -342,7 +342,7 @@ static TECH_ARCS rcmos_a_sua = {
 static TECH_ARCLAY rcmos_al_wea[] = {{LDACT,K4,FILLED}, {LSACT,K4,FILLED},
 	{LWELL,0,FILLED}, {LSELECT,K2,FILLED}};
 static TECH_ARCS rcmos_a_wea = {
-	"Well-Active",K6,AWEACT,											/* name */
+	"Well-Active",K6,AWEACT,NOARCPROTO,									/* name */
 	4,rcmos_al_wea,														/* layers */
 	(APDIFFW<<AFUNCTIONSH)|WANTNOEXTEND|CANCURVE|(0<<AANGLEINCSH)};		/* userbits */
 
@@ -350,7 +350,7 @@ static TECH_ARCS rcmos_a_wea = {
 static TECH_ARCLAY rcmos_al_st[] = {{LDACT,K4,FILLED}, {LPOLY,K4,FILLED},
 	{LSELECT,0,FILLED}};
 static TECH_ARCS rcmos_a_st = {
-	"S-Transistor",K6,ASTRANS,											/* name */
+	"S-Transistor",K6,ASTRANS,NOARCPROTO,								/* name */
 	3,rcmos_al_st,														/* layers */
 	(APDIFFN<<AFUNCTIONSH)|WANTNOEXTEND|CANCURVE|(0<<AANGLEINCSH)};		/* userbits */
 
@@ -358,7 +358,7 @@ static TECH_ARCS rcmos_a_st = {
 static TECH_ARCLAY rcmos_al_dt[] = {{LDACT,K8,FILLED}, {LPOLY,K8,FILLED},
 	{LWELL,0,FILLED}};
 static TECH_ARCS rcmos_a_dt = {
-	"D-Transistor",K10,ADTRANS,											/* name */
+	"D-Transistor",K10,ADTRANS,NOARCPROTO,								/* name */
 	3,rcmos_al_dt,														/* layers */
 	(APDIFFP<<AFUNCTIONSH)|WANTNOEXTEND|CANCURVE|(0<<AANGLEINCSH)};		/* userbits */
 
@@ -931,10 +931,10 @@ TECH_VARIABLES rcmos_variables[] =
 
 /******************** ROUTINES ********************/
 
-INTSML rcmos_initprocess(TECHNOLOGY *tech, INTSML pass)
+BOOLEAN rcmos_initprocess(TECHNOLOGY *tech, INTBIG pass)
 {
 	if (pass == 0) rcmos_tech = tech;
-	return(0);
+	return(FALSE);
 }
 
 INTBIG rcmos_arcpolys(ARCINST *ai, WINDOWPART *win)
@@ -983,7 +983,7 @@ INTBIG rcmos_arcpolys(ARCINST *ai, WINDOWPART *win)
 		rcmos_arcprotos[aindex]->list[1].off = (ai->width - widestp) * WHOLE / lambda;
 		rcmos_arcprotos[aindex]->list[2].off = rcmos_arcprotos[aindex]->list[0].off - amt;
 	}
-	total = tech_initcurvedarc(ai, (INTSML)total);
+	total = tech_initcurvedarc(ai, total);
 
 	/* add in displayable variables */
 	tech_realpolys = total;
@@ -1004,7 +1004,7 @@ void rcmos_shapearcpoly(ARCINST *ai, INTBIG box, POLYGON *poly)
 	}
 
 	/* now handle curved arcs */
-	if (tech_curvedarcpiece(ai, box, poly, rcmos_arcprotos) == 0)
+	if (!tech_curvedarcpiece(ai, box, poly, rcmos_arcprotos))
 	{
 		poly->desc = rcmos_layers[poly->layer];
 		return;
