@@ -40,15 +40,11 @@
  * "BBOX"       uses "SCHEM_function"        for function
  * "SOURCE"     uses "SIM_spice_model"       for the SPICE card
  * "METER"      uses "SCHEM_meter_type"      for SPICE range
- * "TWOPORT"    uses "SCHEM_twoport_type"    which is:
- *    siemens for transconductance (VCCS)
- *    ohms for transresistance (CCVS)
- *    value for voltage gain (VCVS)
- *    value for current gain (CCCS)
- *    impedance for transmission line
+ * "TWOPORT"    uses "SIM_spice_model"       for the SPICE card
  */
 
 #include "global.h"
+#include "database.h"
 #include "egraphics.h"
 #include "tech.h"
 #include "tecschem.h"
@@ -219,31 +215,32 @@ static KEYWORD schopt[] =
 COMCOMP sch_parse = {schopt, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP,
 	0, " \t", M_("Schematic option"), M_("show current options")};
 
-TECHNOLOGY    *sch_tech;
-INTBIG         sch_meterkey;			/* key for "SCHEM_meter_type" */
-INTBIG         sch_diodekey;			/* key for "SCHEM_diode" */
-INTBIG         sch_capacitancekey;		/* key for "SCHEM_capacitance" */
-INTBIG         sch_resistancekey;		/* key for "SCHEM_resistance" */
-INTBIG         sch_inductancekey;		/* key for "SCHEM_inductance" */
-INTBIG         sch_twoportkey;			/* key for "SCHEM_twoport_type" */
-INTBIG         sch_functionkey;			/* key for "SCHEM_function" */
-INTBIG         sch_spicemodelkey;		/* key for "SIM_spice_model" */
-NODEPROTO     *sch_wirepinprim, *sch_buspinprim, *sch_wireconprim, *sch_bufprim,
-              *sch_andprim, *sch_orprim, *sch_xorprim, *sch_ffprim, *sch_muxprim,
-              *sch_bboxprim, *sch_switchprim, *sch_offpageprim, *sch_pwrprim,
-              *sch_gndprim, *sch_sourceprim, *sch_transistorprim, *sch_resistorprim,
-              *sch_capacitorprim, *sch_diodeprim, *sch_inductorprim, *sch_meterprim,
-			  *sch_wellprim, *sch_substrateprim, *sch_twoportprim, *sch_transistor4prim;
-ARCPROTO      *sch_wirearc, *sch_busarc;
-static INTBIG  sch_bubblediameter = K1+D4;
-static INTBIG  sch_bubblebox, sch_arrowbox;
-static PORTPROTO     *sch_anddiffports, *sch_ordiffports, *sch_xordiffports;
-INTBIG         sch_wirepinsizex;		/* X size if wire-pin primitives */
-INTBIG         sch_wirepinsizey;		/* Y size if wire-pin primitives */
+TECHNOLOGY       *sch_tech;
+INTBIG            sch_meterkey;			/* key for "SCHEM_meter_type" */
+INTBIG            sch_diodekey;			/* key for "SCHEM_diode" */
+INTBIG            sch_capacitancekey;	/* key for "SCHEM_capacitance" */
+INTBIG            sch_resistancekey;	/* key for "SCHEM_resistance" */
+INTBIG            sch_inductancekey;	/* key for "SCHEM_inductance" */
+INTBIG            sch_functionkey;		/* key for "SCHEM_function" */
+INTBIG            sch_spicemodelkey;	/* key for "SIM_spice_model" */
+INTBIG            sch_globalnamekey;	/* key for "SCHEM_global_name" */
+NODEPROTO        *sch_wirepinprim, *sch_buspinprim, *sch_wireconprim, *sch_bufprim,
+                 *sch_andprim, *sch_orprim, *sch_xorprim, *sch_ffprim, *sch_muxprim,
+                 *sch_bboxprim, *sch_switchprim, *sch_offpageprim, *sch_pwrprim,
+                 *sch_gndprim, *sch_sourceprim, *sch_transistorprim, *sch_resistorprim,
+                 *sch_capacitorprim, *sch_diodeprim, *sch_inductorprim, *sch_meterprim,
+			     *sch_wellprim, *sch_substrateprim, *sch_twoportprim, *sch_transistor4prim,
+			     *sch_globalprim;
+ARCPROTO         *sch_wirearc, *sch_busarc;
+static INTBIG     sch_bubblediameter = K1+D4;
+static INTBIG     sch_bubblebox, sch_arrowbox;
+static PORTPROTO *sch_anddiffports, *sch_ordiffports, *sch_xordiffports;
+INTBIG            sch_wirepinsizex;		/* X size if wire-pin primitives */
+INTBIG            sch_wirepinsizey;		/* Y size if wire-pin primitives */
 
 #ifdef SCALABLEGATES
 void sch_fillpoly(POLYGON *poly, TECH_POLYGON *lay, NODEINST *ni, INTBIG lambda,
-	INTSML sty);
+	INTBIG sty);
 INTBIG sch_getrange(INTBIG low, INTBIG high, INTBIG mul,INTBIG sum, INTBIG lambda, float scale);
 #endif
 
@@ -290,14 +287,14 @@ static char *sch_layer_letters[MAXLAYERS] = {"a", "b", "n", "t"};
 /* wire arc */
 static TECH_ARCLAY sch_al_w[] = { {LARC,0,FILLED}, {LARC,0,CIRCLE}, {LARC,0,VECTORS}};
 static TECH_ARCS sch_a_w = {
-	"wire",0,AWIRE,																	/* name */
+	"wire",0,AWIRE,NOARCPROTO,														/* name */
 	1,sch_al_w,																		/* layers */
 	(APMETAL1<<AFUNCTIONSH)|WANTFIXANG|WANTCANTSLIDE|(45<<AANGLEINCSH)};			/* userbits */
 
 /* bus arc */
 static TECH_ARCLAY sch_al_b[] = { {LBUS,0,FILLED}, {LBUS,0,CIRCLE}, {LARC,0,VECTORS}};
 static TECH_ARCS sch_a_b = {
-	"bus",K1,ABUS,																	/* name */
+	"bus",K1,ABUS,NOARCPROTO,														/* name */
 	1,sch_al_b,																		/* layers */
 	(APBUS<<AFUNCTIONSH)|WANTFIXANG|WANTCANTSLIDE|WANTNOEXTEND|(45<<AANGLEINCSH)};	/* userbits */
 
@@ -312,7 +309,7 @@ static INTBIG sch_pc_either[] = {-1, AWIRE, ABUS, ALLGEN, -1};
 
 /******************** NODES ********************/
 
-#define NODEPROTOCOUNT    25
+#define NODEPROTOCOUNT    26
 
 #define NWIREPIN      1		/* wire pin */
 #define NBUSPIN       2		/* bus pin */
@@ -339,6 +336,7 @@ static INTBIG sch_pc_either[] = {-1, AWIRE, ABUS, ALLGEN, -1};
 #define NSUBSTRATE   23		/* substrate connection */
 #define NTWOPORT     24		/* generic two-port block */
 #define NTRANSISTOR4 25		/* four-port transistor */
+#define NGLOBALSIG   26		/* global signal */
 
 /******************** POLYGONS ********************/
 
@@ -436,23 +434,9 @@ static INTBIG sch_g_capac[]      = {LEFTEDGE,  TOPBYP2,   RIGHTEDGE, TOPBYP2,
 								    CENTER,    BOTBYP2,   CENTER,    BOTEDGE};
 static INTBIG sch_g_capace[]     = {RIGHTBYP2, BOTBYP6,   RIGHTBYP6, BOTBYP6,
 								    RIGHTBYP4, BOTBYP4,   RIGHTBYP4, BOTBYP8};
-
-static char *sch_g_sourcet[]    = {0,  0,    (char *)-D4,0,   0 /* "TRAN ANAL." */};
-static char *sch_g_sourced[]    = {0,  0,    (char *)-D4,0,   0 /* "DC ANAL." */};
-static char *sch_g_sourcea[]    = {0,  0,    (char *)-D4,0,   0 /* "AC ANAL." */};
-static char *sch_g_sourceb[]    = {0,  0,    (char *)-D4,0,   0 /* "BULK" */};
-static char *sch_g_sourcem[]    = {0,  0,    (char *)-D4,0,   0 /* "METER" */};
-static char *sch_g_sourcen[]    = {0,  0,    (char *)-D4,0,   0 /* "NODE SET" */};
-static char *sch_g_sourcex[]    = {0,  0,    (char *)-D4,0,   0 /* "EXTENSION" */};
-static char *sch_g_sources[]    = {0,  0,    (char *)-D4,0,   0 /* "SPECIAL" */};
 static INTBIG sch_g_source[]     = {CENTER,    CENTER,    RIGHTEDGE, CENTER};
-static INTBIG sch_g_sourcec[]    = {CENTER,    TOPBYP9,   CENTER,    BOTBYP9,
-								    CENTER,    BOTBYP9,   RIGHTBYP3, BOTBYP6,
-								    CENTER,    BOTBYP9,   LEFTBYP3,  BOTBYP6};
 static INTBIG sch_g_sourcepl[]   = {LEFTBYP3,  TOPBYP6,   RIGHTBYP3, TOPBYP6,
 								    CENTER,    TOPBYP3,   CENTER,    TOPBYP9};
-static INTBIG sch_g_sourcemi[]   = {LEFTBYP3,  BOTBYP7,   RIGHTBYP3, BOTBYP7};
-
 static INTBIG sch_g_mos[]        = {LEFTEDGE,  BOTEDGE,   LEFTBYP75, BOTEDGE,
 								    LEFTBYP75, BOTBYP5,   RIGHTBYP75,BOTBYP5,
 								    RIGHTBYP75,BOTEDGE,   RIGHTEDGE, BOTEDGE};
@@ -517,6 +501,10 @@ static INTBIG sch_g_induct4[]    = {LEFTBYP5,  BOTBYP33,  CENTER,    BOTBYP33};
 static INTBIG sch_g_meter[]      = {CENTER,    CENTER,    RIGHTEDGE, CENTER};
 static INTBIG sch_g_well[]       = {LEFTEDGE,  BOTEDGE,   RIGHTEDGE, BOTEDGE,
 								    CENTER,    TOPEDGE,   CENTER,    BOTEDGE};
+static INTBIG sch_g_global1[]    = {LEFTEDGE,  CENTER,    CENTER,    TOPEDGE,
+								    RIGHTEDGE, CENTER,    CENTER,    BOTEDGE};
+static INTBIG sch_g_global2[]    = {LEFTBYP9,  CENTER,    CENTER,    TOPBYP9,
+								    RIGHTBYP9, CENTER,    CENTER,    BOTBYP9};
 static INTBIG sch_g_substrate[]  = {CENTER,    CENTER,    CENTER,    TOPEDGE,
 								    LEFTEDGE,  CENTER,    RIGHTEDGE, CENTER,
 								    LEFTEDGE,  CENTER,    CENTER,    BOTEDGE,
@@ -571,7 +559,7 @@ static TECH_POLYGON sch_wirepin_l[] = {				/* layers */
 	{LARC, 0, 2, DISC, POINTS, sch_g_pindisc}};
 static TECH_NODES sch_wirepin = {
 	"Wire_Pin",NWIREPIN,NONODEPROTO,				/* name */
-	K1,K1,											/* size */
+	H0,H0,											/* size */
 	1,sch_wirepin_p,								/* ports */
 	1,sch_wirepin_l,								/* layers */
 	(NPPIN<<NFUNCTIONSH)|NSQUARE|WIPEON1OR2,		/* userbits */
@@ -856,28 +844,7 @@ static TECH_PORTS sch_source_p[] = {				/* ports */
 		(1<<PORTNETSH), CENTER, BOTEDGE, CENTER, BOTEDGE}};
 static TECH_POLYGON sch_sourcev_l[] = {				/* layers */
 	{LNODE, 0,                2, CIRCLE,   POINTS, sch_g_source},
-	{LNODE, 0,                4, VECTORS,  POINTS, sch_g_sourcepl},
-	{LNODE, 0,                2, VECTORS,  POINTS, sch_g_sourcemi},
-	{LTEXT, TXTSETQLAMBDA(4), 1, TEXTCENT, POINTS, (INTBIG *)sch_g_sourced}};
-static TECH_POLYGON sch_sourcec_l[] = {				/* layers */
-	{LNODE, 0,                2, CIRCLE,   POINTS, sch_g_source},
-	{LNODE, 0,                6, VECTORS,  POINTS, sch_g_sourcec},
-	{LTEXT, TXTSETQLAMBDA(4), 1, TEXTCENT, POINTS, (INTBIG *)sch_g_sourced}};
-static TECH_POLYGON sch_sourcet_l[] = {				/* layers */
-	{LNODE, 0,                2, CIRCLE,   POINTS, sch_g_source},
-	{LTEXT, TXTSETQLAMBDA(4), 1, TEXTCENT, POINTS, (INTBIG *)sch_g_sourcet}};
-static TECH_POLYGON sch_sourcen_l[] = {				/* layers */
-	{LNODE, 0,                2, CIRCLE,   POINTS, sch_g_source},
-	{LNODE, 0,                4, VECTORS,  POINTS, sch_g_sourcepl},
-	{LTEXT, TXTSETQLAMBDA(4), 1, TEXTCENT, POINTS, (INTBIG *)sch_g_sourcen}};
-static TECH_POLYGON sch_sourcex_l[] = {				/* layers */
-	{LNODE, 0,                2, CIRCLE,   POINTS, sch_g_source},
-	{LNODE, 0,                4, VECTORS,  POINTS, sch_g_sourcepl},
-	{LTEXT, TXTSETQLAMBDA(4), 1, TEXTCENT, POINTS, (INTBIG *)sch_g_sourcex}};
-static TECH_POLYGON sch_sources_l[] = {				/* layers */
-	{LNODE, 0,                2, CIRCLE,   POINTS, sch_g_source},
-	{LNODE, 0,                4, VECTORS,  POINTS, sch_g_sourcepl},
-	{LTEXT, TXTSETQLAMBDA(4), 1, TEXTCENT, POINTS, (INTBIG *)sch_g_sources}};
+	{LNODE, 0,                4, VECTORS,  POINTS, sch_g_sourcepl}};
 static TECH_NODES sch_source = {
 	"Source", NSOURCE, NONODEPROTO,					/* name */
 	K6,K6,											/* size */
@@ -1182,6 +1149,21 @@ static TECH_NODES sch_trans4 = {
 	(NPTRANS4<<NFUNCTIONSH),						/* userbits */
 	0,0,0,0,0,0,0,0,0};								/* characteristics */
 
+/* global signal */
+static TECH_PORTS sch_globalsig_p[] = {				/* ports */
+	{sch_pc_wire, "global", NOPORTPROTO, (270<<PORTANGLESH)|(90<<PORTARANGESH),
+		CENTER, BOTEDGE, CENTER, BOTEDGE}};
+static TECH_POLYGON sch_globalsig_l[] = {			/* layers */
+	{LNODE, 0, 4, CLOSED, POINTS, sch_g_global1},
+	{LNODE, 0, 4, CLOSED, POINTS, sch_g_global2}};
+static TECH_NODES sch_globalsig = {
+	"Global-Signal", NGLOBALSIG, NONODEPROTO,		/* name */
+	K3,K3,											/* size */
+	1,sch_globalsig_p,								/* ports */
+	2,sch_globalsig_l,								/* layers */
+	(NPCONNECT<<NFUNCTIONSH),						/* userbits */
+	0,0,0,0,0,0,0,0,0};								/* characteristics */
+
 TECH_NODES *sch_nodeprotos[NODEPROTOCOUNT+1] = {
 	&sch_wirepin,  &sch_buspin,   &sch_wirecon,					/* pins */
 	&sch_buf,      &sch_and,      &sch_or,       &sch_xor,		/* gates */
@@ -1193,7 +1175,7 @@ TECH_NODES *sch_nodeprotos[NODEPROTOCOUNT+1] = {
 	&sch_diode,    &sch_induct,									/* diode/inductor */
 	&sch_meter,													/* meter */
 	&sch_well,     &sch_substrate,								/* well/substrate */
-	&sch_twoport,  &sch_trans4,									/* twoport/4-port */
+	&sch_twoport,  &sch_trans4,  &sch_globalsig,				/* twoport/4-port/global */
 	((TECH_NODES *)-1)
 };
 
@@ -1208,13 +1190,13 @@ static INTBIG sch_node_widoff[NODEPROTOCOUNT*4] = {
 	  0, 0, 0, 0,    0, 0, 0, 0,								/* diode/inductor */
 	  0, 0, 0, 0,												/* meter */
 	  0, 0, 0, 0,    0, 0, 0, 0,								/* well/substrate */
-	  0, 0, 0, 0,    0, 0, 0,K1									/* twoport/4-por */
+	  0, 0, 0, 0,    0, 0, 0,K1,    0, 0, 0, 0					/* twoport/4-port/global */
 };
 
 static char *sch_node_vhdlstring[NODEPROTOCOUNT] = {
 	"", "", "",													/* pins */
-	"buffer/inverter", "and%d/nand%d", "or%d/nor%d", "xor%d/xnor%d",	/* gates */
-	"ff", "mux%d",												/* flipflop, mux */
+	"buffer/inverter", "and%ld/nand%ld", "or%ld/nor%ld", "xor%ld/xnor%ld",	/* gates */
+	"ff", "mux%ld",												/* flipflop, mux */
 	"", "",														/* box/switch */
 	"",															/* offpage */
 	"", "", "",													/* pwr/gnd/source */
@@ -1222,7 +1204,7 @@ static char *sch_node_vhdlstring[NODEPROTOCOUNT] = {
 	"", "",														/* diode/inductor */
 	"",															/* meter */
 	"", "",														/* well/substrate */
-	"", ""														/* twoport/4-port */
+	"", "", ""													/* twoport/4-port/global */
 };
 
 /******************** VARIABLE AGGREGATION ********************/
@@ -1247,7 +1229,7 @@ TECH_VARIABLES sch_variables[] =
 
 /******************** ROUTINES ********************/
 
-INTSML sch_initprocess(TECHNOLOGY *tech, INTSML pass)
+BOOLEAN sch_initprocess(TECHNOLOGY *tech, INTBIG pass)
 {
 	/* initialize the technology variable */
 	if (pass == 0) sch_tech = tech; else
@@ -1278,6 +1260,7 @@ INTSML sch_initprocess(TECHNOLOGY *tech, INTSML pass)
 		sch_substrateprim = getnodeproto("schematic:Substrate");
 		sch_twoportprim = getnodeproto("schematic:Two-Port");
 		sch_transistor4prim = getnodeproto("schematic:4-Port-Transistor");
+		sch_globalprim = getnodeproto("schematic:Global-Signal");
 
 		sch_wirearc = getarcproto("schematic:wire");
 		sch_busarc = getarcproto("schematic:bus");
@@ -1287,27 +1270,19 @@ INTSML sch_initprocess(TECHNOLOGY *tech, INTSML pass)
 		sch_capacitancekey = makekey("SCHEM_capacitance");
 		sch_resistancekey = makekey("SCHEM_resistance");
 		sch_inductancekey = makekey("SCHEM_inductance");
-		sch_twoportkey = makekey("SCHEM_twoport_type");
 		sch_functionkey = makekey("SCHEM_function");
 		sch_spicemodelkey = makekey("SIM_spice_model");
+		sch_globalnamekey = makekey("SCHEM_global_name");
 
 		/* differential ports are enabled */
 		sch_anddiffports = sch_ordiffports = sch_xordiffports = NOPORTPROTO;
 
 		/* translate strings on schematic nodes */
-		sch_g_sourcea[4] = _("AC ANAL.");
-		sch_g_sourced[4] = _("DC ANAL.");
 		sch_g_fftextclr[16] = _("CLR");
-		sch_g_sourcet[4] = _("TRAN ANAL.");
-		sch_g_sourceb[4] = _("BULK");
-		sch_g_sourcem[4] = _("METER");
-		sch_g_sourcen[4] = _("NODE SET");
-		sch_g_sourcex[4] = _("EXTENSION");
-		sch_g_sources[4] = _("SPECIAL");
 		sch_wirepinsizex = sch_wirepinprim->highx - sch_wirepinprim->lowx;
 		sch_wirepinsizey = sch_wirepinprim->highy - sch_wirepinprim->lowy;
 	}
-	return(0);
+	return(FALSE);
 }
 
 void sch_termprocess(void)
@@ -1320,10 +1295,10 @@ void sch_termprocess(void)
 	sch_anddiffports = sch_ordiffports = sch_xordiffports = NOPORTPROTO;
 }
 
-void sch_setmode(INTSML count, char *par[])
+void sch_setmode(INTBIG count, char *par[])
 {
 	REGISTER char *pp;
-	REGISTER INTSML l;
+	REGISTER INTBIG l;
 
 	if (count == 0)
 	{
@@ -1341,7 +1316,7 @@ void sch_setmode(INTSML count, char *par[])
 			ttyputmsg(M_("Diameter of negating bubbles is %s"), frtoa(sch_bubblediameter));
 			return;
 		}
-		l = (INTSML)atofr(par[1]);
+		l = atofr(par[1]);
 		if (l > 0) sch_bubblediameter = l; else
 			ttyputerr(M_("Bubble diameter must be positive and nonzero"));
 		return;
@@ -1400,7 +1375,10 @@ static TECH_PORTS *sch_extrasteinerport[10];
 INTBIG sch_nodepolys(NODEINST *ni, INTBIG *reasonable, WINDOWPART *win)
 {
 	REGISTER INTBIG total, pindex, buscon, nonbuscon, hei, arcs, i;
+	INTBIG depth;
+	NODEINST **nilist, *upni;
 	REGISTER PORTARCINST *pi;
+	REGISTER PORTEXPINST *pe;
 	REGISTER PORTPROTO *pp;
 
 	/* get the default number of polygons and list of layers */
@@ -1412,7 +1390,7 @@ INTBIG sch_nodepolys(NODEINST *ni, INTBIG *reasonable, WINDOWPART *win)
 	switch (pindex)
 	{
 		case NWIREPIN:	/* wire pins disappear with one or two wires */
-			if (tech_pinusecount(ni, NOARCPROTO) != 0) total = 0;
+			if (tech_pinusecount(ni, win)) total = 0;
 			break;
 
 		case NBUSPIN:	/* bus pins get bigger in "T" configurations, disappear when alone and exported */
@@ -1423,9 +1401,33 @@ INTBIG sch_nodepolys(NODEINST *ni, INTBIG *reasonable, WINDOWPART *win)
 					nonbuscon++;
 			}
 
+			/* if the next level up the hierarchy is visible, consider arcs connected there */
+			if (win != NOWINDOWPART && ni->firstportexpinst != NOPORTEXPINST)
+			{
+				db_gettraversalpath(&nilist, &depth);
+				if (depth == 1)
+				{
+					upni = nilist[0];
+					if (upni->proto == ni->parent && upni->parent == win->curnodeproto)
+					{
+						for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
+						{
+							for (pi = upni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
+							{
+								if (pi->proto != pe->exportproto) continue;
+								if (pi->conarcinst->proto == sch_busarc) buscon++; else
+									nonbuscon++;
+							}
+						}
+					}
+				}
+			}
+
 			/* bus pins don't show wire pin in center if not tapped */
 			if (nonbuscon == 0) total--;
 
+			sch_buspin_l[0].layernum = LBUS;
+			sch_buspin_l[0].points = sch_g_buspindisc;
 			if (buscon > 2)
 			{
 				/* larger pin because it is connected to 3 or more bus arcs */
@@ -1434,8 +1436,19 @@ INTBIG sch_nodepolys(NODEINST *ni, INTBIG *reasonable, WINDOWPART *win)
 			{
 				/* smaller pin because it has 0, 1, or 2 connections */
 				sch_g_buspindisc[4] = Q0;
-				if (buscon == 0 && nonbuscon == 0 && ni->firstportexpinst != NOPORTEXPINST)
-					total = 0;
+				if (buscon == 0)
+				{
+					if (nonbuscon > 2)
+					{
+						sch_buspin_l[0].layernum = LARC;
+						sch_buspin_l[0].points = sch_g_bustapdisc;
+						total--;
+					} else
+					{
+						if (ni->firstportexpinst != NOPORTEXPINST)
+							total = 0;
+					}
+				}
 			}
 			break;
 
@@ -1480,51 +1493,6 @@ INTBIG sch_nodepolys(NODEINST *ni, INTBIG *reasonable, WINDOWPART *win)
 				sch_g_switchbar[7] = K1;
 			break;
 
-		case NSOURCE:	/* determine graphics to use for sources */
-			switch (ni->userbits&NTECHBITS)
-			{
-				case SOURCEVS:				/* Source is Voltage */
-					total = 3;
-					break;
-				case SOURCEAC:				/* Source is AC analysis */
-					sch_layerlist[3].points = (INTBIG *)sch_g_sourcea;
-					total = 4;
-					break;
-				case SOURCEBULK:			/* Source is Bulk */
-					sch_layerlist[3].points = (INTBIG *)sch_g_sourceb;
-					total = 4;
-					break;
-				case SOURCECURSRC:			/* Source is Current source */
-					sch_layerlist = sch_sourcec_l;
-					break;
-				case SOURCECURMTR:			/* Source is Current meter */
-					sch_layerlist = sch_sourcec_l;
-					sch_layerlist[2].points = (INTBIG *)sch_g_sourcem;
-					total = 3;
-					break;
-				case SOURCENODE:			/* Source is Nodeset */
-					sch_layerlist = sch_sourcen_l;
-					total = 3;
-					break;
-				case SOURCESPEC:			/* Source is Special */
-					sch_layerlist = sch_sources_l;
-					total = 3;
-					break;
-				case SOURCETRAN:			/* Source is Transient Analysis */
-					sch_layerlist = sch_sourcet_l;
-					total = 2;
-					break;
-				case SOURCEDCAN:			/* Source is DC Analysis */
-					sch_layerlist[3].points = (INTBIG *)sch_g_sourced;
-					total = 4;
-					break;
-				case SOURCEEXT:				/* Source is Extension */
-					sch_layerlist = sch_sourcex_l;
-					total = 3;
-					break;
-			}
-			break;
-
 		case NTRANSISTOR:	/* determine graphics to use for transistors */
 			switch (ni->userbits&NTECHBITS)
 			{
@@ -1766,9 +1734,9 @@ void sch_shapenodepoly(NODEINST *ni, INTBIG box, POLYGON *poly)
 #ifdef SCALABLEGATES
 /* scalable version of polygon filling for AND, OR, and XOR gates */
 void sch_fillpoly(POLYGON *poly, TECH_POLYGON *lay, NODEINST *ni, INTBIG lambda,
-	INTSML sty)
+	INTBIG sty)
 {
-	REGISTER INTSML i, lastpoint;
+	REGISTER INTBIG i, lastpoint;
 	REGISTER INTBIG *pt, xm, xs, ym, ys;
 	INTBIG minlx, minhx, minly, minhy;
 	float scale;
@@ -1866,9 +1834,9 @@ INTBIG sch_getrange(INTBIG low, INTBIG high, INTBIG mul,INTBIG sum, INTBIG lambd
 #endif
 
 void sch_shapeportpoly(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans,
-	INTSML purpose)
+	BOOLEAN purpose)
 {
-	REGISTER INTSML pindex, i, e, total, besti;
+	REGISTER INTBIG pindex, i, e, total, besti;
 	REGISTER INTBIG xposition, yposition, x, y, lambda, wantx, wanty, bestdist,
 		bestx, besty, dist;
 	REGISTER PORTARCINST *pi;
@@ -1878,7 +1846,7 @@ void sch_shapeportpoly(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans,
 	pindex = ni->proto->primindex;
 
 	/* special case for extendible primitives */
-	if (purpose != 0 && sch_nodeprotos[pindex-1]->portlist[0].addr == pp)
+	if (purpose && sch_nodeprotos[pindex-1]->portlist[0].addr == pp)
 	{
 		/* initialize */
 		wantx = poly->xv[0];   wanty = poly->yv[0];
@@ -1895,7 +1863,7 @@ void sch_shapeportpoly(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans,
 				if (pi->proto == pp) total++;
 
 			/* cycle through the arc positions */
-			total = (INTSML)maxi(total+2, 3);
+			total = maxi(total+2, 3);
 			for(i=0; i<total; i++)
 			{
 				/* compute the position along the left edge */
@@ -2003,7 +1971,7 @@ INTBIG sch_arcpolys(ARCINST *ai, WINDOWPART *win)
 void sch_shapearcpoly(ARCINST *ai, INTBIG box, POLYGON *poly)
 {
 	REGISTER INTBIG aindex, bubbleend;
-	REGISTER INTSML angle;
+	REGISTER INTBIG angle;
 	REGISTER INTBIG x1,y1, cosdist, sindist, x2,y2, lambda, i,
 		saveendx, saveendy, bubblesize;
 	REGISTER TECH_ARCLAY *thista;
@@ -2033,7 +2001,7 @@ void sch_shapearcpoly(ARCINST *ai, INTBIG box, POLYGON *poly)
 	bubbleend = 0;
 	x1 = ai->end[0].xpos;   y1 = ai->end[0].ypos;
 	x2 = ai->end[1].xpos;   y2 = ai->end[1].ypos;
-	angle = (INTSML)(((ai->userbits&AANGLE) >> AANGLESH) * 10);
+	angle = ((ai->userbits&AANGLE) >> AANGLESH) * 10;
 	if ((ai->userbits&REVERSEEND) != 0)
 	{
 		i = x1;   x1 = x2;   x2 = i;
