@@ -31,11 +31,12 @@
 #include "global.h"
 #include "egraphics.h"
 #include "usr.h"
+#include "usrtrack.h"
 
-void us_arc(INTSML count, char *par[])
+void us_arc(INTBIG count, char *par[])
 {
-	REGISTER INTBIG negate, ang, toggle, acx, acy, r, j, i, l;
-	INTBIG ix, iy, x1, y1, x2, y2, xcur, ycur, dx[2], dy[2];
+	REGISTER INTBIG negate, toggle, r, j, i, l, interactive;
+	INTBIG ix, iy, xcur, ycur, dx[2], dy[2];
 	REGISTER ARCINST *ai;
 	REGISTER NODEPROTO *np;
 	REGISTER char *pp;
@@ -90,7 +91,7 @@ void us_arc(INTSML count, char *par[])
 	}
 
 	/* get the list of all highlighted arcs */
-	list = us_gethighlighted(OBJARCINST, 0, 0);
+	list = us_gethighlighted(WANTARCINST, 0, 0);
 	if (list[0] == NOGEOM)
 	{
 		us_abortcommand(_("No arcs are selected"));
@@ -99,7 +100,7 @@ void us_arc(INTSML count, char *par[])
 
 	/* disallow arraying if lock is on */
 	np = geomparent(list[0]);
-	if (us_canedit(np, NONODEPROTO, 1) != 0) return;
+	if (us_cantedit(np, NONODEPROTO, TRUE)) return;
 
 	/* save and erase highlighting */
 	us_pushhighlight();
@@ -110,11 +111,11 @@ void us_arc(INTSML count, char *par[])
 		if (namesame(el_curconstraint->conname, "layout") != 0)
 		{
 			us_abortcommand(_("Use the layout constraint system for rigid arcs"));
-			(void)us_pophighlight(0);
+			us_pophighlight(FALSE);
 			return;
 		}
-		i = us_modarcbits((INTSML)((toggle != 0 ? 23 : (negate != 0 ? 1 : 0))), 0, "", list);
-		if (i >= 0) ttyputverbose("%d %s %s", i, makeplural(_("arc"), i),
+		i = us_modarcbits((toggle != 0 ? 23 : (negate != 0 ? 1 : 0)), FALSE, "", list);
+		if (i >= 0) ttyputverbose("%ld %s %s", i, makeplural(_("arc"), i),
 			(toggle != 0 ? _("toggle rigidity") : (negate != 0 ? _("made un-rigid") : _("made rigid"))));
 	} else if ((namesamen(pp, "manhattan", l) == 0 ||
 		namesamen(pp, "fixed-angle", l) == 0) && l >= 1)
@@ -122,94 +123,94 @@ void us_arc(INTSML count, char *par[])
 		if (namesame(el_curconstraint->conname, "layout") != 0)
 		{
 			us_abortcommand(_("Use the layout constraint system for fixed-angle arcs"));
-			(void)us_pophighlight(0);
+			us_pophighlight(FALSE);
 			return;
 		}
 		if (namesamen(pp, "manhattan", l) == 0)
 			ttyputmsg(_("It is now proper to use 'arc fixed-angle' instead of 'arc manhattan'"));
-		i = us_modarcbits((INTSML)((toggle != 0 ? 24 : (negate != 0 ? 3 : 2))), 0, "", list);
+		i = us_modarcbits((toggle != 0 ? 24 : (negate != 0 ? 3 : 2)), FALSE, "", list);
 		if (i >= 0)
-			ttyputverbose("%d %s %s", i, makeplural(_("arc"), i), (toggle != 0 ? _("toggle fixed-angle") :
+			ttyputverbose("%ld %s %s", i, makeplural(_("arc"), i), (toggle != 0 ? _("toggle fixed-angle") :
 				(negate != 0 ? _("made not fixed-angle") : _("made fixed-angle"))));
 	} else if (namesamen(pp, "slide", l) == 0 && l >= 2)
 	{
 		if (namesame(el_curconstraint->conname, "layout") != 0)
 		{
 			us_abortcommand(_("Use the layout constraint system for slidable arcs"));
-			(void)us_pophighlight(0);
+			us_pophighlight(FALSE);
 			return;
 		}
-		i = us_modarcbits((INTSML)((toggle != 0 ? 25 : (negate != 0 ? 5 : 4))), 0, "", list);
+		i = us_modarcbits((toggle != 0 ? 25 : (negate != 0 ? 5 : 4)), FALSE, "", list);
 		if (i >= 0)
-			ttyputverbose("%d %s %s", i, makeplural(_("arc"), i), (toggle != 0 ? _("toggle slidability") :
+			ttyputverbose("%ld %s %s", i, makeplural(_("arc"), i), (toggle != 0 ? _("toggle slidability") :
 				(negate != 0 ? _("can not slide in ports") : _("can slide in ports"))));
 	} else if (namesamen(pp, "temp-rigid", l) == 0 && l >= 1)
 	{
 		if (namesame(el_curconstraint->conname, "layout") != 0)
 		{
 			us_abortcommand(_("Use the layout constraint system for rigid arcs"));
-			(void)us_pophighlight(0);
+			us_pophighlight(FALSE);
 			return;
 		}
-		i = us_modarcbits((INTSML)((negate != 0 ? 7 : 6)), 0, "", list);
-		if (i >= 0) ttyputverbose(M_("%d %s made temporarily %srigid"), i, makeplural(_("arc"), i),
+		i = us_modarcbits((negate != 0 ? 7 : 6), FALSE, "", list);
+		if (i >= 0) ttyputverbose(M_("%ld %s made temporarily %srigid"), i, makeplural(_("arc"), i),
 			(negate!=0 ? _("un-") : ""));
 	} else if (namesamen(pp, "ends-extend", l) == 0 && l >= 1)
 	{
-		i = us_modarcbits((INTSML)((toggle != 0 ? 26 : (negate != 0 ? 9 : 8))), 1, "", list);
-		if (i >= 0) ttyputverbose("%d %s %s", i, makeplural(_("arc"), i),
+		i = us_modarcbits((toggle != 0 ? 26 : (negate != 0 ? 9 : 8)), TRUE, "", list);
+		if (i >= 0) ttyputverbose("%ld %s %s", i, makeplural(_("arc"), i),
 			(toggle != 0 ? _("toggle end extension") :
 				(negate != 0 ? _("given no end extension") : _("given full end extension"))));
 	} else if (namesamen(pp, "directional", l) == 0 && l >= 1)
 	{
-		i = us_modarcbits((INTSML)((toggle != 0 ? 27 : (negate != 0 ? 11: 10))), 1, "", list);
-		if (i >= 0) ttyputverbose("%d %s %s", i, makeplural(_("arc"), i),
+		i = us_modarcbits((toggle != 0 ? 27 : (negate != 0 ? 11: 10)), TRUE, "", list);
+		if (i >= 0) ttyputverbose("%ld %s %s", i, makeplural(_("arc"), i),
 			(toggle != 0 ? _("toggle directionality") :
 				(negate != 0 ? _("given no direction") : _("given direction"))));
 	} else if (namesamen(pp, "negated", l) == 0 && l >= 2)
 	{
-		i = us_modarcbits((INTSML)((toggle != 0 ? 28 : (negate != 0 ? 13 : 12))), 1, "", list);
-		if (i >= 0) ttyputverbose("%d %s %s", i, makeplural(_("arc"), i),
+		i = us_modarcbits((toggle != 0 ? 28 : (negate != 0 ? 13 : 12)), TRUE, "", list);
+		if (i >= 0) ttyputverbose("%ld %s %s", i, makeplural(_("arc"), i),
 			(toggle != 0 ? _("toggle negation") : (negate != 0 ? _("not negated") : _("negated"))));
 	} else if (namesamen(pp, "skip-tail", l) == 0 && l >= 6)
 	{
-		i = us_modarcbits((INTSML)((toggle != 0 ? 29 : (negate != 0 ? 15 : 14))), 1, "", list);
-		if (i >= 0) ttyputverbose("%d %s %s", i, makeplural(_("arc"), i),
+		i = us_modarcbits((toggle != 0 ? 29 : (negate != 0 ? 15 : 14)), TRUE, "", list);
+		if (i >= 0) ttyputverbose("%ld %s %s", i, makeplural(_("arc"), i),
 			(toggle != 0 ? _("toggle tail use") : (negate!=0 ? _("use tail") : _("do not use tail"))));
 	} else if (namesamen(pp, "skip-head", l) == 0 && l >= 6)
 	{
-		i = us_modarcbits((INTSML)((toggle != 0 ? 30 : (negate != 0 ? 17 : 16))), 1, "", list);
-		if (i >= 0) ttyputverbose("%d %s %s", i, makeplural(_("arc"), i),
+		i = us_modarcbits((toggle != 0 ? 30 : (negate != 0 ? 17 : 16)), TRUE, "", list);
+		if (i >= 0) ttyputverbose("%ld %s %s", i, makeplural(_("arc"), i),
 			(toggle != 0 ? _("toggle head use") : (negate!=0 ? _("use head") : _("do not use head"))));
 	} else if (namesamen(pp, "reverse", l) == 0 && l >= 2)
 	{
 		if (negate != 0) ttyputerr(_("'arc reverse' is a relative notion, 'not' ignored"));
-		i = us_modarcbits(18, 1, "", list);
-		if (i >= 0) ttyputverbose(M_("%d %s direction reversed"), i, makeplural(_("arc"), i));
+		i = us_modarcbits(18, TRUE, "", list);
+		if (i >= 0) ttyputverbose(M_("%ld %s direction reversed"), i, makeplural(_("arc"), i));
 	} else if (namesamen(pp, "constraint", l) == 0 && l >= 2)
 	{
 		if (namesame(el_curconstraint->conname, "linear") != 0)
 		{
 			us_abortcommand(_("First switch to the linear inequalities constraint system"));
-			(void)us_pophighlight(0);
+			us_pophighlight(FALSE);
 			return;
 		}
 		if (count <= 1)
 		{
-			if (negate != 0) (void)us_modarcbits(19, 1, "", list); else
-				(void)us_modarcbits(20, 0, "", list);
+			if (negate != 0) (void)us_modarcbits(19, TRUE, "", list); else
+				(void)us_modarcbits(20, FALSE, "", list);
 		} else
 		{
 			if (count > 2 && namesamen(par[2], "add", strlen(par[2])) == 0)
-				i = us_modarcbits(22, 1, par[1], list); else
-					i = us_modarcbits(21, 1, par[1], list);
+				i = us_modarcbits(22, TRUE, par[1], list); else
+					i = us_modarcbits(21, TRUE, par[1], list);
 		}
 	} else if (namesamen(pp, "name", l) == 0 && l >= 2)
 	{
-		if (list[0]->entrytype != OBJARCINST || list[1] != NOGEOM)
+		if (list[0]->entryisnode || list[1] != NOGEOM)
 		{
 			us_abortcommand(_("Select only one arc when naming"));
-			(void)us_pophighlight(0);
+			us_pophighlight(FALSE);
 			return;
 		}
 		ai = list[0]->entryaddr.ai;
@@ -222,7 +223,7 @@ void us_arc(INTSML count, char *par[])
 				if (count == 1)
 				{
 					us_abortedmsg();
-					(void)us_pophighlight(0);
+					us_pophighlight(FALSE);
 					return;
 				}
 			}
@@ -238,11 +239,11 @@ void us_arc(INTSML count, char *par[])
 			us_setarcname(ai, pp);
 		} else
 		{
-			var = getvalkey((INTBIG)ai, VARCINST, VSTRING, el_arc_name);
+			var = getvalkey((INTBIG)ai, VARCINST, VSTRING, el_arc_name_key);
 			if (var == NOVARIABLE)
 			{
 				us_abortcommand(_("This arc has no name"));
-				(void)us_pophighlight(0);
+				us_pophighlight(FALSE);
 				return;
 			}
 			if (var != NOVARIABLE) us_setarcname(ai, (char *)0);
@@ -250,10 +251,10 @@ void us_arc(INTSML count, char *par[])
 		}
 	} else if (namesamen(pp, "center", l) == 0 && l >= 2)
 	{
-		if (list[0]->entrytype != OBJARCINST || list[1] != NOGEOM)
+		if (list[0]->entryisnode || list[1] != NOGEOM)
 		{
 			us_abortcommand(_("Select only one arc when changing curvature"));
-			(void)us_pophighlight(0);
+			us_pophighlight(FALSE);
 			return;
 		}
 		ai = list[0]->entryaddr.ai;
@@ -262,39 +263,46 @@ void us_arc(INTSML count, char *par[])
 		if ((ai->proto->userbits&CANCURVE) == 0 && negate == 0)
 		{
 			us_abortcommand(_("This arc cannot curve"));
-			(void)us_pophighlight(0);
+			us_pophighlight(FALSE);
 			return;
 		}
 
-		startobjectchange((INTBIG)ai, VARCINST);
+		/* see if curvature should be set interactively */
+		interactive = 0;
+		if (count >= 2 && namesamen(par[1], "interactive", strlen(par[1])) == 0)
+			interactive = 1;
 
 		/* change the arc center information */
 		if (negate == 0)
 		{
-			if (us_demandxy(&xcur, &ycur))
+			if (interactive != 0)
 			{
-				(void)us_pophighlight(0);
-				return;
+				us_arccurveinit(ai);
+				trackcursor(TRUE, us_ignoreup, us_nullvoid, us_arccenterdown, us_stoponchar,
+					us_nullvoid, TRACKDRAGGING);
+			} else
+			{
+				if (us_demandxy(&xcur, &ycur))
+				{
+					us_pophighlight(FALSE);
+					return;
+				}
+
+				/* get radius that lets arc curve about this point */
+				r = us_curvearcaboutpoint(ai, xcur, ycur);
+
+				startobjectchange((INTBIG)ai, VARCINST);
+				(void)setvalkey((INTBIG)ai, VARCINST, el_arc_radius_key, r, VINTEGER);
+				(void)modifyarcinst(ai, 0, 0, 0, 0, 0);
+				endobjectchange((INTBIG)ai, VARCINST);
 			}
-
-			/* get true center of arc through cursor */
-			ang = (INTSML)(((ai->userbits&AANGLE) >> AANGLESH) * 10);
-			acx = (ai->end[0].xpos + ai->end[1].xpos) / 2;
-			acy = (ai->end[0].ypos + ai->end[1].ypos) / 2;
-			(void)intersect(xcur, ycur, ang, acx, acy, (ang+900)%3600, &ix, &iy);
-			r = computedistance(ai->end[0].xpos, ai->end[0].ypos, ix, iy);
-
-			/* now see if this point will be re-created */
-			(void)findcenters(r, ai->end[0].xpos,ai->end[0].ypos,
-				ai->end[1].xpos, ai->end[1].ypos, ai->length, &x1,&y1, &x2,&y2);
-			if (abs(x1-ix)+abs(y1-iy) < abs(x2-ix)+abs(y2-iy)) r = -r;
-
-			(void)setvalkey((INTBIG)ai, VARCINST, el_arc_radius, r, VINTEGER);
-		} else (void)delvalkey((INTBIG)ai, VARCINST, el_arc_radius);
-		(void)modifyarcinst(ai, 0, 0, 0, 0, 0);
-
-		/* restore highlighting */
-		endobjectchange((INTBIG)ai, VARCINST);
+		} else
+		{
+			startobjectchange((INTBIG)ai, VARCINST);
+			(void)delvalkey((INTBIG)ai, VARCINST, el_arc_radius_key);
+			(void)modifyarcinst(ai, 0, 0, 0, 0, 0);
+			endobjectchange((INTBIG)ai, VARCINST);
+		}
 	} else if (namesamen(pp, "shorten", l) == 0 && l >= 2)
 	{
 		/* get the necessary polygon */
@@ -307,7 +315,7 @@ void us_arc(INTSML count, char *par[])
 			for(j=0; j<2; j++)
 			{
 				shapeportpoly(ai->end[j].nodeinst, ai->end[j].portarcinst->proto,
-					poly, 0);
+					poly, FALSE);
 				ix = ai->end[1-j].xpos;   iy = ai->end[1-j].ypos;
 				closestpoint(poly, &ix, &iy);
 				dx[j] = ix - ai->end[j].xpos;
@@ -316,18 +324,18 @@ void us_arc(INTSML count, char *par[])
 			if (dx[0] != 0 || dy[0] != 0 || dx[1] != 0 || dy[1] != 0)
 			{
 				startobjectchange((INTBIG)ai, VARCINST);
-				modifyarcinst(ai, 0, dx[0], dy[0], dx[1], dy[1]);
+				(void)modifyarcinst(ai, 0, dx[0], dy[0], dx[1], dy[1]);
 				endobjectchange((INTBIG)ai, VARCINST);
 				l++;
 			}
 		}
-		ttyputmsg("Shortened %d %s", l, makeplural(_("arc"), l));
+		ttyputmsg("Shortened %ld %s", l, makeplural(_("arc"), l));
 	} else if (namesamen(pp, "curve", l) == 0 && l >= 2)
 	{
-		if (list[0]->entrytype != OBJARCINST || list[1] != NOGEOM)
+		if (list[0]->entryisnode || list[1] != NOGEOM)
 		{
 			us_abortcommand(_("Select only one arc when changing curvature"));
-			(void)us_pophighlight(0);
+			us_pophighlight(FALSE);
 			return;
 		}
 		ai = list[0]->entryaddr.ai;
@@ -336,63 +344,61 @@ void us_arc(INTSML count, char *par[])
 		if ((ai->proto->userbits&CANCURVE) == 0 && negate == 0)
 		{
 			us_abortcommand(_("This arc cannot curve"));
-			(void)us_pophighlight(0);
+			us_pophighlight(FALSE);
 			return;
 		}
 
-		startobjectchange((INTBIG)ai, VARCINST);
+		/* see if curvature should be set interactively */
+		interactive = 0;
+		if (count >= 2 && namesamen(par[1], "interactive", strlen(par[1])) == 0)
+			interactive = 1;
 
 		/* change the arc center information */
 		if (negate == 0)
 		{
-			REGISTER INTBIG r0x, r0y, r1x, r1y, r2x, r2y, rpx, rpy, r02x, r02y, rcx, rcy;
-			REGISTER float u, v, t;
-
-			if (us_demandxy(&xcur, &ycur))
+			if (interactive != 0)
 			{
-				(void)us_pophighlight(0);
-				return;
+				us_arccurveinit(ai);
+				trackcursor(TRUE, us_ignoreup, us_nullvoid, us_arccurvedown, us_stoponchar,
+					us_nullvoid, TRACKDRAGGING);
+			} else
+			{
+				if (us_demandxy(&xcur, &ycur))
+				{
+					us_pophighlight(FALSE);
+					return;
+				}
+
+				/* get radius that lets arc curve through this point */
+				r = us_curvearcthroughpoint(ai, xcur, ycur);
+
+				startobjectchange((INTBIG)ai, VARCINST);
+				(void)setvalkey((INTBIG)ai, VARCINST, el_arc_radius_key, r, VINTEGER);
+				(void)modifyarcinst(ai, 0, 0, 0, 0, 0);
+				endobjectchange((INTBIG)ai, VARCINST);
 			}
-
-			/* compute the center position of the arc from three points */
-			r0x = ai->end[0].xpos;   r0y = ai->end[0].ypos;
-			r1x = ai->end[1].xpos;   r1y = ai->end[1].ypos;
-			r2x = xcur;              r2y = ycur;
-			r02x = r2x-r0x;          r02y = r2y-r0y;
-			rpx = r0y-r1y;           rpy = r1x-r0x;
-			u = (float)r02x;   u *= (r2x-r1x);
-			v = (float)r02y;   v *= (r2y-r1y);
-			t = u + v;
-			u = (float)r02x;   u *= rpx;
-			v = (float)r02y;   v *= rpy;
-			t /= (u + v) * 2.0f;
-			rcx = r0x + (INTBIG)((r1x-r0x)/2 + t*rpx);
-			rcy = r0y + (INTBIG)((r1y-r0y)/2 + t*rpy);
-
-			/* now see if this point will be re-created */
-			r = computedistance(r0x,r0y, rcx,rcy);
-			(void)findcenters(r, r0x,r0y, r1x,r1y, ai->length, &x1,&y1, &x2,&y2);
-			if (abs(x1-rcx)+abs(y1-rcy) < abs(x2-rcx)+abs(y2-rcy)) r = -r;
-
-			(void)setvalkey((INTBIG)ai, VARCINST, el_arc_radius, r, VINTEGER);
-		} else (void)delvalkey((INTBIG)ai, VARCINST, el_arc_radius);
-		(void)modifyarcinst(ai, 0, 0, 0, 0, 0);
-
-		/* highlight the new arc */
-		endobjectchange((INTBIG)ai, VARCINST);
+		} else
+		{
+			/* remove curvature */
+			startobjectchange((INTBIG)ai, VARCINST);
+			(void)delvalkey((INTBIG)ai, VARCINST, el_arc_radius_key);
+			(void)modifyarcinst(ai, 0, 0, 0, 0, 0);
+			endobjectchange((INTBIG)ai, VARCINST);
+		}
 	} else ttyputbadusage("arc");
 
 	/* clean-up */
-	(void)us_pophighlight(1);
+	us_pophighlight(TRUE);
 }
 
-void us_array(INTSML count, char *par[])
+void us_array(INTBIG count, char *par[])
 {
-	REGISTER INTSML xsize, ysize, flipx, flipy, staggerx, staggery, centerx, centery,
-		ro, tr, noname, l, diagonal, first;
-	REGISTER INTBIG x, y, xpos, ypos, nodecount, arccount, i, lx, hx, ly, hy, cx, cy,
+	REGISTER BOOLEAN flipx, flipy, first, staggerx, staggery, centerx, centery,
+		noname, diagonal;
+	REGISTER INTSML ro, tr;
+	REGISTER INTBIG x, y, xpos, ypos, nodecount, arccount, i, l, lx, hx, ly, hy, cx, cy,
 		cx0, cy0, cx1, cy1, xoff0, xoff1, yoff0, yoff1, xoff, yoff, keepbits, xindex,
-		yindex, originalx, originaly;
+		xsize, ysize, yindex, originalx, originaly;
 	REGISTER GEOM **list, *geom;
 	INTBIG xoverlap, yoverlap, plx, ply, phx, phy;
 	REGISTER char *pt1, *pt2;
@@ -411,7 +417,7 @@ void us_array(INTSML count, char *par[])
 	}
 
 	/* get the objects to be arrayed */
-	list = us_gethighlighted(OBJNODEINST|OBJARCINST, 0, 0);
+	list = us_gethighlighted(WANTNODEINST|WANTARCINST, 0, 0);
 	if (list[0] == NOGEOM)
 	{
 		us_abortcommand(_("Must select circuitry before arraying it"));
@@ -422,27 +428,27 @@ void us_array(INTSML count, char *par[])
 	/* disallow arraying if lock is on */
 	for(i=0; list[i] != NOGEOM; i++)
 	{
-		if (list[i]->entrytype == OBJARCINST)
+		if (!list[i]->entryisnode)
 		{
-			if (us_canedit(np, NONODEPROTO, 1) != 0) return;
+			if (us_cantedit(np, NONODEPROTO, TRUE)) return;
 		} else
 		{
-			if (us_canedit(np, list[i]->entryaddr.ni->proto, 1) != 0) return;
+			if (us_cantedit(np, list[i]->entryaddr.ni->proto, TRUE)) return;
 		}
 	}
 
 	/* see if the array is to be unnamed (last argument is "no-names") */
-	noname = diagonal = 0;
+	noname = diagonal = FALSE;
 	while (count > 0)
 	{
 		l = strlen(pt1 = par[count-1]);
 		if (namesamen(pt1, "no-names", l) == 0)
 		{
-			noname = 1;
+			noname = TRUE;
 			count--;
 		} else if (namesamen(pt1, "diagonal", l) == 0)
 		{
-			diagonal = 1;
+			diagonal = TRUE;
 			count--;
 		} else break;
 	}
@@ -454,25 +460,25 @@ void us_array(INTSML count, char *par[])
 		return;
 	}
 	pt1 = par[0];
-	xsize = (INTSML)myatoi(pt1);
-	flipx = staggerx = centerx = 0;
+	xsize = myatoi(pt1);
+	flipx = staggerx = centerx = FALSE;
 	for(i = strlen(pt1)-1; i > 0; i--)
 	{
-		if (pt1[i] == 'f') flipx = 1; else
-			if (pt1[i] == 's') staggerx = 1; else
-				if (pt1[i] == 'c') centerx = 1; else
+		if (pt1[i] == 'f') flipx = TRUE; else
+			if (pt1[i] == 's') staggerx = TRUE; else
+				if (pt1[i] == 'c') centerx = TRUE; else
 					break;
 	}
 
 	/* get the Y extent of the array */
 	if (count == 1) pt2 = "1"; else pt2 = par[1];
 	ysize = atoi(pt2);
-	flipy = staggery = centery = 0;
+	flipy = staggery = centery = FALSE;
 	for(i = strlen(pt2)-1; i > 0; i--)
 	{
-		if (pt2[i] == 'f') flipy = 1; else
-			if (pt2[i] == 's') staggery = 1; else
-				if (pt2[i] == 'c') centery = 1; else
+		if (pt2[i] == 'f') flipy = TRUE; else
+			if (pt2[i] == 's') staggery = TRUE; else
+				if (pt2[i] == 'c') centery = TRUE; else
 					break;
 	}
 
@@ -482,7 +488,7 @@ void us_array(INTSML count, char *par[])
 		us_abortcommand(_("One dimension of the array must be greater than 1"));
 		return;
 	}
-	if (diagonal != 0 && xsize != 1 && ysize != 1)
+	if (diagonal && xsize != 1 && ysize != 1)
 	{
 		us_abortcommand(_("Diagonal arrays need one dimension to be 1"));
 		return;
@@ -496,7 +502,7 @@ void us_array(INTSML count, char *par[])
 	for(i=0; list[i] != NOGEOM; i++)
 	{
 		geom = list[i];
-		if (geom->entrytype == OBJNODEINST)
+		if (geom->entryisnode)
 		{
 			ni = geom->entryaddr.ni;
 			ni->temp1 = 1;
@@ -522,6 +528,7 @@ void us_array(INTSML count, char *par[])
 		if (nodelist == 0) return;
 		for(ni = np->firstnodeinst, i=nodecount-1; ni != NONODEINST; ni = ni->nextnodeinst)
 			if (ni->temp1 != 0) nodelist[i--] = ni;
+		esort(nodelist, nodecount, sizeof (NODEINST *), us_sortnodesbyname);
 	}
 	if (arccount > 0)
 	{
@@ -533,18 +540,19 @@ void us_array(INTSML count, char *par[])
 		}
 		for(ai = np->firstarcinst, i=0; ai != NOARCINST; ai = ai->nextarcinst)
 			if (ai->temp1 != 0) arclist[i++] = ai;
+		esort(arclist, arccount, sizeof (ARCINST *), us_sortarcsbyname);
 	}
 
 	/* determine spacing between arrayed objects */
-	first = 1;
+	first = TRUE;
 	for(i=0; i<nodecount; i++)
 	{
 		ni = nodelist[i];
-		if (first != 0)
+		if (first)
 		{
 			lx = ni->geom->lowx;   hx = ni->geom->highx;
 			ly = ni->geom->lowy;   hy = ni->geom->highy;
-			first = 0;
+			first = FALSE;
 		} else
 		{
 			if (ni->geom->lowx < lx) lx = ni->geom->lowx;
@@ -556,11 +564,11 @@ void us_array(INTSML count, char *par[])
 	for(i=0; i<arccount; i++)
 	{
 		ai = arclist[i];
-		if (first != 0)
+		if (first)
 		{
 			lx = ai->geom->lowx;   hx = ai->geom->highx;
 			ly = ai->geom->lowy;   hy = ai->geom->highy;
-			first = 0;
+			first = FALSE;
 		} else
 		{
 			if (ai->geom->lowx < lx) lx = ai->geom->lowx;
@@ -580,13 +588,13 @@ void us_array(INTSML count, char *par[])
 	}
 
 	/* check to ensure the array doesn't overflow the address space */
-	if (centerx == 0)
+	if (!centerx)
 	{
 		for(x=0; x<xsize; x++)
 		{
 			plx = lx + xoverlap * x;
 			phx = hx + xoverlap * x;
-			if (staggery != 0) { plx += xoverlap/2;   phx += xoverlap/2; }
+			if (staggery) { plx += xoverlap/2;   phx += xoverlap/2; }
 			if (xoverlap > 0)
 			{
 				if (phx < lx) break;
@@ -603,13 +611,13 @@ void us_array(INTSML count, char *par[])
 			return;
 		}
 	}
-	if (centery == 0)
+	if (!centery)
 	{
 		for(y=0; y<ysize; y++)
 		{
 			ply = ly + yoverlap * y;
 			phy = hy + yoverlap * y;
-			if (staggerx != 0) { ply += yoverlap/2;   phy += yoverlap/2; }
+			if (staggerx) { ply += yoverlap/2;   phy += yoverlap/2; }
 			if (yoverlap > 0)
 			{
 				if (phy < ly) break;
@@ -632,12 +640,12 @@ void us_array(INTSML count, char *par[])
 	us_clearhighlightcount();
 
 	/* create the array */
-	for(x=0; x<xsize; x++) for(y=0; y<ysize; y++)
+	for(y=0; y<ysize; y++) for(x=0; x<xsize; x++)
 	{
 		if (stopping(STOPREASONARRAY)) break;
-		if (centerx == 0) xindex = x; else
+		if (!centerx) xindex = x; else
 			xindex = x - (xsize-1)/2;
-		if (centery == 0) yindex = y; else
+		if (!centery) yindex = y; else
 			yindex = y - (ysize-1)/2;
 		if (xindex == 0 && yindex == 0)
 		{
@@ -653,14 +661,14 @@ void us_array(INTSML count, char *par[])
 		for(i=0; i<nodecount; i++)
 		{
 			ni = nodelist[i];
-			if (diagonal != 0 && xsize == 1) xpos = cx + xoverlap * yindex; else
+			if (diagonal && xsize == 1) xpos = cx + xoverlap * yindex; else
 				xpos = cx + xoverlap * xindex;
-			if (diagonal != 0 && ysize == 1) ypos = cy + yoverlap * xindex; else
+			if (diagonal && ysize == 1) ypos = cy + yoverlap * xindex; else
 				ypos = cy + yoverlap * yindex;
 			xoff = (ni->lowx + ni->highx) / 2 - cx;
 			yoff = (ni->lowy + ni->highy) / 2 - cy;
-			if ((xindex&1) != 0 && staggerx != 0) ypos += yoverlap/2;
-			if ((yindex&1) != 0 && staggery != 0) xpos += xoverlap/2;
+			if ((xindex&1) != 0 && staggerx) ypos += yoverlap/2;
+			if ((yindex&1) != 0 && staggery) xpos += xoverlap/2;
 			ro = ni->rotation;  tr = ni->transpose;
 			if ((xindex&1) != 0 && flipx)
 			{
@@ -685,16 +693,16 @@ void us_array(INTSML count, char *par[])
 				ttyputerr(_("Problem creating array nodes"));
 				if (nodecount > 0) efree((char *)nodelist);
 				if (arccount > 0) efree((char *)arclist);
-				(void)us_pophighlight(0);
+				us_pophighlight(FALSE);
 				return;
 			}
 			keepbits = NEXPAND | HARDSELECTN | NTECHBITS;
 			newno->userbits = (newno->userbits & ~keepbits) | (ni->userbits & keepbits);
 			(void)us_copyvars((INTBIG)ni, VNODEINST, (INTBIG)newno, VNODEINST);
-			if (noname == 0)
+			if (!noname)
 			{
 				objname = "";
-				var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name);
+				var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
 				if (var != NOVARIABLE)
 				{
 					if (strcmp((char *)var->addr, "0") != 0 && strcmp((char *)var->addr, "0-0") != 0)
@@ -703,7 +711,7 @@ void us_array(INTSML count, char *par[])
 				if (xsize <= 1 || ysize <= 1)
 					(void)sprintf(totalname, "%s%ld", objname, x+y); else
 						(void)sprintf(totalname, "%s%ld-%ld", objname, x, y);
-				var = setvalkey((INTBIG)newno, VNODEINST, el_node_name,
+				var = setvalkey((INTBIG)newno, VNODEINST, el_node_name_key,
 					(INTBIG)totalname, VSTRING|VDISPLAY);
 				if (var != NOVARIABLE)
 				{
@@ -723,7 +731,7 @@ void us_array(INTSML count, char *par[])
 			{
 				for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
 				{
-					if (us_queuenewexport(newno, pe->proto, pe->exportproto) != 0) return;
+					if (us_queuenewexport(newno, pe->proto, pe->exportproto)) return;
 				}
 			}
 
@@ -771,14 +779,14 @@ void us_array(INTSML count, char *par[])
 				ttyputerr(_("Problem creating array arcs"));
 				if (nodecount > 0) efree((char *)nodelist);
 				if (arccount > 0) efree((char *)arclist);
-				(void)us_pophighlight(0);
+				us_pophighlight(FALSE);
 				return;
 			}
 			(void)us_copyvars((INTBIG)ai, VARCINST, (INTBIG)newai, VARCINST);
-			if (noname == 0)
+			if (!noname)
 			{
 				objname = "";
-				var = getvalkey((INTBIG)ai, VARCINST, VSTRING, el_arc_name);
+				var = getvalkey((INTBIG)ai, VARCINST, VSTRING, el_arc_name_key);
 				if (var != NOVARIABLE)
 				{
 					if (strcmp((char *)var->addr, "0") != 0 && strcmp((char *)var->addr, "0-0") != 0)
@@ -787,7 +795,7 @@ void us_array(INTSML count, char *par[])
 				if (xsize <= 1 || ysize <= 1)
 					(void)sprintf(totalname, "%s%ld", objname, x+y); else
 						(void)sprintf(totalname, "%s%ld-%ld", objname, x, y);
-				var = setvalkey((INTBIG)newai, VARCINST, el_arc_name,
+				var = setvalkey((INTBIG)newai, VARCINST, el_arc_name_key,
 					(INTBIG)totalname, VSTRING|VDISPLAY);
 				if (var != NOVARIABLE)
 					defaulttextsize(4, var->textdescript);
@@ -797,7 +805,7 @@ void us_array(INTSML count, char *par[])
 	}
 
 	/* rename the replicated objects */
-	if (noname == 0)
+	if (!noname)
 	{
 		for(i=0; i<nodecount; i++)
 		{
@@ -805,7 +813,7 @@ void us_array(INTSML count, char *par[])
 			startobjectchange((INTBIG)ni, VNODEINST);
 
 			/* get former name of node */
-			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name);
+			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
 			objname = "";
 			if (var != NOVARIABLE)
 			{
@@ -814,7 +822,7 @@ void us_array(INTSML count, char *par[])
 			}
 			if (xsize <= 1 || ysize <= 1) (void)sprintf(totalname, "%s%ld", objname, originalx+originaly); else
 				(void)sprintf(totalname, "%s%ld-%ld", objname, originalx, originaly);
-			var = setvalkey((INTBIG)ni, VNODEINST, el_node_name, (INTBIG)totalname, VSTRING|VDISPLAY);
+			var = setvalkey((INTBIG)ni, VNODEINST, el_node_name_key, (INTBIG)totalname, VSTRING|VDISPLAY);
 			if (var != NOVARIABLE)
 			{
 				defaulttextsize(3, var->textdescript);
@@ -833,8 +841,8 @@ void us_array(INTSML count, char *par[])
 			ai = arclist[i];
 			startobjectchange((INTBIG)ai, VARCINST);
 
-			/* get former name of node */
-			var = getvalkey((INTBIG)ai, VARCINST, VSTRING, el_arc_name);
+			/* get former name of arc */
+			var = getvalkey((INTBIG)ai, VARCINST, VSTRING, el_arc_name_key);
 			objname = "";
 			if (var != NOVARIABLE)
 			{
@@ -843,7 +851,7 @@ void us_array(INTSML count, char *par[])
 			}
 			if (xsize <= 1 || ysize <= 1) (void)sprintf(totalname, "%s%ld", objname, originalx+originaly); else
 				(void)sprintf(totalname, "%s%ld-%ld", objname, originalx, originaly);
-			var = setvalkey((INTBIG)ai, VARCINST, el_arc_name, (INTBIG)totalname, VSTRING|VDISPLAY);
+			var = setvalkey((INTBIG)ai, VARCINST, el_arc_name_key, (INTBIG)totalname, VSTRING|VDISPLAY);
 			if (var != NOVARIABLE)
 				defaulttextsize(4, var->textdescript);
 			endobjectchange((INTBIG)ai, VARCINST);
@@ -851,25 +859,27 @@ void us_array(INTSML count, char *par[])
 	}
 
 	/* restore highlighting */
-	(void)us_pophighlight(0);
+	us_pophighlight(FALSE);
 	if (nodecount > 0) efree((char *)nodelist);
 	if (arccount > 0) efree((char *)arclist);
 }
 
-void us_bind(INTSML count, char *par[])
+void us_bind(INTBIG count, char *par[])
 {
-	REGISTER INTSML i, j, l, negated, bindex, newcount, key, but, menu, popup,
-		x, y, backgroundcolor, swap, lastchar;
-	REGISTER INTBIG varkey;
-	INTSML important, menumessagesize;
+	REGISTER INTBIG i, j, l, negated, bindex, newcount, menu, popup,
+		x, y, backgroundcolor, swap, lastchar, varkey, formerquickkey, len;
+	INTBIG special;
+	INTSML key;
+	REGISTER INTBIG but;
+	INTBIG important, menumessagesize;
 	REGISTER USERCOM *rb;
-	REGISTER char *pp, *letter, *pt, *popname, *str;
+	REGISTER char *pp, *letter, *popname, *str;
 	NODEPROTO *nodeglyph;
 	ARCPROTO *arcglyph;
 	POPUPMENU *pm;
 	REGISTER VARIABLE *var;
-	COMMANDBINDING commandbinding;
-	char partial[80], *a[MAXPARS+1], *menumessage;
+	COMMANDBINDING commandbinding, oldcommandbinding;
+	char partial[80], *a[MAXPARS+1], *menumessage, *pt;
 	extern COMCOMP us_bindp, us_bindsetp, us_bindbuttonp, us_bindkeyp,
 		us_bindmenuryp, us_bindmenuxp, us_userp, us_bindpopnp, us_bindpoprep;
 
@@ -949,7 +959,7 @@ void us_bind(INTSML count, char *par[])
 				us_abortcommand(_("Button %s unknown"), pp);
 				return;
 			}
-			var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_binding_buttons);
+			var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_binding_buttons_key);
 			if (var == NOVARIABLE) return;
 			us_parsebinding(((char **)var->addr)[but], &commandbinding);
 			if (*commandbinding.command == 0) commandbinding.command = "-";
@@ -967,9 +977,9 @@ void us_bind(INTSML count, char *par[])
 			}
 			pp = par[3];
 			key = *pp & 255;
-			var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_binding_keys);
-			if (var == NOVARIABLE) return;
-			us_parsebinding(((char **)var->addr)[key], &commandbinding);
+			i = us_findboundkey(key, 0, &pt);
+			if (i < 0) return;
+			us_parsebinding(pt, &commandbinding);
 			if (*commandbinding.command == 0) commandbinding.command = "-";
 			(void)setval((INTBIG)us_tool, VTOOL, us_commandvarname(*letter),
 				(INTBIG)commandbinding.command, VSTRING|VDONTSAVE);
@@ -983,14 +993,14 @@ void us_bind(INTSML count, char *par[])
 				ttyputusage("bind get LETTER menu ROW COLUMN");
 				return;
 			}
-			y = (INTSML)myatoi(pp = par[3]);
-			x = (INTSML)myatoi(pp = par[4]);
+			y = myatoi(pp = par[3]);
+			x = myatoi(pp = par[4]);
 			if (x < 0 || y < 0 || x >= us_menux || y >= us_menuy)
 			{
 				us_abortcommand(_("Index of menu entry out of range"));
 				return;
 			}
-			var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_binding_menu);
+			var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_binding_menu_key);
 			if (var == NOVARIABLE) return;
 			if (us_menupos <= 1)
 				str = ((char **)var->addr)[y * us_menux + x]; else
@@ -1018,7 +1028,7 @@ void us_bind(INTSML count, char *par[])
 			popup = myatoi(par[4]) + 1;
 			if (popup <= 0 || popup > pm->total)
 			{
-				us_abortcommand(_("Popup menu entry must be from 0 to %d"), pm->total-1);
+				us_abortcommand(_("Popup menu entry must be from 0 to %ld"), pm->total-1);
 				return;
 			}
 			rb = pm->list[popup-1].response;
@@ -1053,6 +1063,7 @@ void us_bind(INTSML count, char *par[])
 		l = strlen(pp = par[1]);
 		important = 0;
 		popup = menu = key = 0;
+		special = 0;
 		nodeglyph = NONODEPROTO;
 		arcglyph = NOARCPROTO;
 		backgroundcolor = 0;
@@ -1088,7 +1099,7 @@ void us_bind(INTSML count, char *par[])
 				return;
 			}
 			important = 3;
-			varkey = us_binding_buttons;
+			varkey = us_binding_buttons_key;
 			bindex = but;
 		} else if (namesamen(pp, "key", l) == 0 && l >= 1)
 		{
@@ -1102,13 +1113,8 @@ void us_bind(INTSML count, char *par[])
 				}
 			}
 			pp = par[2];
-			if (namesamen(pp, "m", 1) == 0 && pp[1] == '-')
-			{
-				/* the form M-X implies the meta key (high bit) */
-				key = pp[2] | 0200;
-			} else key = *pp & 255;
-			varkey = us_binding_keys;
-			bindex = key;
+			(void)us_getboundkey(pp, &key, &special);
+			varkey = us_binding_keys_key;
 			important = 3;
 		} else if ((namesamen(pp, "popup", l) == 0 ||
 			namesamen(pp, "input-popup", l) == 0) && l >= 1)
@@ -1154,7 +1160,7 @@ void us_bind(INTSML count, char *par[])
 			popup = myatoi(par[3]) + 1;
 			if (popup <= 0 || popup > pm->total)
 			{
-				us_abortcommand(_("Popup menu entry must be from 0 to %d"), pm->total-1);
+				us_abortcommand(_("Popup menu entry must be from 0 to %ld"), pm->total-1);
 				return;
 			}
 			if (pp[0] == 'i') popup = -popup;
@@ -1187,7 +1193,7 @@ void us_bind(INTSML count, char *par[])
 				}
 				if (namesamen(pp, "textsize", l) == 0)
 				{
-					menumessagesize = (INTSML)us_gettextsize(par[3], TXTSETQLAMBDA(12));
+					menumessagesize = us_gettextsize(par[3], TXTSETQLAMBDA(12));
 					count -= 2;
 					par += 2;
 					continue;
@@ -1212,7 +1218,7 @@ void us_bind(INTSML count, char *par[])
 					return;
 				}
 			}
-			y = (INTSML)myatoi(pp = par[2]);
+			y = myatoi(pp = par[2]);
 			if (count < 4)
 			{
 				count = ttygetparam(M_("Menu column: "), &us_bindmenuxp, MAXPARS+3, &par[3])+3;
@@ -1222,7 +1228,7 @@ void us_bind(INTSML count, char *par[])
 					return;
 				}
 			}
-			x = (INTSML)myatoi(pp = par[3]);
+			x = myatoi(pp = par[3]);
 
 			/* reorder the meaning if the optional "w" character is appended */
 			lastchar = par[2][ strlen(par[2])-1 ];
@@ -1244,7 +1250,7 @@ void us_bind(INTSML count, char *par[])
 				us_abortcommand(_("Index of menu entry out of range"));
 				return;
 			}
-			varkey = us_binding_menu;
+			varkey = us_binding_menu_key;
 			if (us_menupos <= 1) bindex = y * us_menux + x; else
 				bindex = x * us_menuy + y;
 			important = 4;
@@ -1258,7 +1264,7 @@ void us_bind(INTSML count, char *par[])
 		}
 
 		if (count <= important)
-			count = ttygetparam(M_("Command: "), &us_userp, (INTSML)(MAXPARS-important),
+			count = ttygetparam(M_("Command: "), &us_userp, MAXPARS-important,
 				&par[important]) + important;
 		(void)initinfstr();
 		for(i=important; i<count; i++)
@@ -1275,14 +1281,16 @@ void us_bind(INTSML count, char *par[])
 		}
 
 		/* handle un-binding */
-		if (strcmp(a[0], "-") == 0)
+		if (strcmp(par[important], "-") == 0)
 		{
-			if (key != 0 && us_islasteval(key))
+			if (key != 0 && us_islasteval(key, special))
 			{
 				us_abortcommand(_("Cannot un-bind the last 'telltool user' key"));
 				return;
 			}
 			(void)initinfstr();
+			if (key != 0)
+				(void)formatinfstr("%c%c", key, (special == 0 ? '\\' : '/'));
 			if (popup != 0)
 			{
 				if (popup < 0) (void)addstringtoinfstr("inputpopup="); else
@@ -1301,11 +1309,18 @@ void us_bind(INTSML count, char *par[])
 				(void)addstringtoinfstr("\" ");
 			}
 			(void)addstringtoinfstr("command=");
+			if (key != 0)
+			{
+				bindex = us_findboundkey(key, special, &pt);
+				if (bindex < 0) return;
+			}
+
+			/* clear the entry in the array */
 			(void)setindkey((INTBIG)us_tool, VTOOL, varkey, bindex, (INTBIG)returninfstr());
 			return;
 		}
 
-		i = parse(a[0], &us_userp, 1);
+		i = parse(a[0], &us_userp, TRUE);
 		if (i < 0)
 		{
 			us_unknowncommand();
@@ -1316,7 +1331,7 @@ void us_bind(INTSML count, char *par[])
 		if (i >= us_longcount || strcmp(us_lcommand[i].name, "telltool") != 0 ||
 			newcount != 1 || strcmp(a[1], "user") != 0)
 		{
-			if (key != 0 && us_islasteval(key))
+			if (key != 0 && us_islasteval(key, special))
 			{
 				us_abortcommand(_("Cannot re-bind the last 'telltool user' key"));
 				return;
@@ -1333,6 +1348,8 @@ void us_bind(INTSML count, char *par[])
 
 		/* set the variable that describes this new binding */
 		(void)initinfstr();
+		if (key != 0 || special != 0)
+			(void)addstringtoinfstr(us_describeboundkey(key, special, 0));
 		if (nodeglyph != NONODEPROTO)
 		{
 			(void)addstringtoinfstr("node=");
@@ -1354,21 +1371,48 @@ void us_bind(INTSML count, char *par[])
 		}
 		if (backgroundcolor != 0)
 		{
-			(void)sprintf(partial, "background=%d ", backgroundcolor);
+			(void)sprintf(partial, "background=%ld ", backgroundcolor);
 			(void)addstringtoinfstr(partial);
 		}
 		if (menumessage != 0)
 		{
 			(void)addstringtoinfstr("message=\"");
+			formerquickkey = 0;
+			if (popup != 0)
+			{
+				/* check for defaulted quick-key in popup assignment */
+				len = strlen(menumessage) - 1;
+				if (menumessage[len] == '<') len--;
+				if (menumessage[len] == '/' || menumessage[len] == '\\')
+				{
+					/* defaulted: find the previous quick-key value */
+					var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, varkey);
+					if (var != NOVARIABLE)
+					{
+						us_parsebinding(((char **)var->addr)[bindex], &oldcommandbinding);
+						len = strlen(oldcommandbinding.menumessage) - 1;
+						if (oldcommandbinding.menumessage[len] == '<') len--;
+						if (oldcommandbinding.menumessage[len-1] == '/' ||
+							oldcommandbinding.menumessage[len-1] == '\\')
+								formerquickkey = oldcommandbinding.menumessage[len];
+						us_freebindingparse(&oldcommandbinding);
+					}
+				}
+			}
 			for(pt = menumessage; *pt != 0; pt++)
 			{
 				if (*pt == '"') (void)addtoinfstr('^');
 				(void)addtoinfstr(*pt);
+				if (formerquickkey != 0 && (*pt == '/' || *pt == '\\'))
+				{
+					(void)addtoinfstr((char)formerquickkey);
+					formerquickkey = 0;
+				}
 			}
 			(void)addstringtoinfstr("\" ");
 			if (menumessagesize != 0)
 			{
-				(void)sprintf(partial, "messagesize=%d ", menumessagesize);
+				(void)sprintf(partial, "messagesize=%ld ", menumessagesize);
 				(void)addstringtoinfstr(partial);
 			}
 		}
@@ -1385,7 +1429,13 @@ void us_bind(INTSML count, char *par[])
 			if (j != important) (void)addtoinfstr(' ');
 			(void)addstringtoinfstr(par[j]);
 		}
-		(void)setindkey((INTBIG)us_tool, VTOOL, varkey, bindex, (INTBIG)returninfstr());
+		if (key != 0 || special != 0)
+		{
+			us_setkeybinding(returninfstr(), key, special, FALSE);
+		} else
+		{
+			(void)setindkey((INTBIG)us_tool, VTOOL, varkey, bindex, (INTBIG)returninfstr());
+		}
 		if (popup > 0) us_setkeyequiv(pm, bindex);
 		return;
 	}
