@@ -32,9 +32,9 @@
 #include "usr.h"
 #include "egraphics.h"
 
-void us_offtool(INTSML count, char *par[])
+void us_offtool(INTBIG count, char *par[])
 {
-	REGISTER INTSML permanently;
+	REGISTER INTBIG permanently;
 
 	if (count == 2 && namesamen(par[1], "permanently", strlen(par[1])) == 0)
 	{
@@ -44,9 +44,9 @@ void us_offtool(INTSML count, char *par[])
 	us_settool(count, par, permanently);
 }
 
-void us_ontool(INTSML count, char *par[])
+void us_ontool(INTBIG count, char *par[])
 {
-	REGISTER INTSML catchup;
+	REGISTER INTBIG catchup;
 
 	if (count == 2 && namesamen(par[1], "no-catch-up", strlen(par[1])) == 0)
 	{
@@ -56,16 +56,17 @@ void us_ontool(INTSML count, char *par[])
 	us_settool(count, par, catchup);
 }
 
-void us_outhier(INTSML count, char *par[])
+void us_outhier(INTBIG count, char *par[])
 {
-	REGISTER INTSML total, i;
-	REGISTER INTBIG len;
+	REGISTER INTBIG len, found, total, i, haveview, vlx, vhx, vly, vhy, value;
 	INTBIG lx, hx, ly, hy;
-	REGISTER NODEPROTO *curnp, *hinp, *np, *inp;
+	REGISTER NODEPROTO *curnp, *hinp, *np;
+	REGISTER char *pt;
 	REGISTER NODEINST *ni, *hini;
-	REGISTER PORTPROTO *pp, *ipp, *curpp, *hipp;
+	REGISTER PORTPROTO *pp, *curpp, *hipp;
 	REGISTER PORTEXPINST *pe;
 	REGISTER VARIABLE *var;
+	XARRAY into, outof;
 	HIGHLIGHT high;
 
 	/* make sure repeat count is valid */
@@ -89,14 +90,14 @@ void us_outhier(INTSML count, char *par[])
 
 	/* see if a node with an export is highlighted */
 	curpp = NOPORTPROTO;
-	var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlighted);
+	var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlightedkey);
 	if (var != NOVARIABLE)
 	{
-		len = (INTSML)getlength(var);
+		len = getlength(var);
 		if (len == 1)
 		{
 			/* get the highlighted object */
-			if (us_makehighlight(((char **)var->addr)[0], &high) == 0)
+			if (!us_makehighlight(((char **)var->addr)[0], &high))
 			{
 				pp = NOPORTPROTO;
 				if ((high.status&HIGHTYPE) == HIGHTEXT)
@@ -105,8 +106,9 @@ void us_outhier(INTSML count, char *par[])
 						pp = high.fromport->subportproto;
 				} else
 				{
-					if ((high.status&HIGHTYPE) == HIGHFROM && high.fromport != NOPORTPROTO)
-						pp = high.fromport;
+					if ((high.status&HIGHTYPE) == HIGHFROM &&
+						high.fromgeom->entryisnode && high.fromport != NOPORTPROTO)
+							pp = high.fromport;
 				}
 				if (pp != NOPORTPROTO)
 				{
@@ -115,16 +117,11 @@ void us_outhier(INTSML count, char *par[])
 
 					/* see if port is an export */
 					for (pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
-						if (pe->proto == pp) break;
-					if (pe != NOPORTEXPINST)
 					{
-						/* find true parent */
-						pp = pe->exportproto;
-						if ((inp = iconview(ni->parent)) == NONODEPROTO) inp = ni->parent;
-						ipp = equivalentport(ni->parent, pp, inp);
-						if (ipp != NOPORTPROTO)
+						if (pe->proto == pp)
 						{
-							curpp = ipp;
+							curpp = pe->exportproto;
+							break;
 						}
 					}
 				}
@@ -133,12 +130,53 @@ void us_outhier(INTSML count, char *par[])
 	}
 
 	us_clearhighlightcount();
+	haveview = 0;
 	for(i=0; i<total; i++)
 	{
 		hinp = NONODEPROTO;
 
 		hini = descentparent(curnp);
-		if (hini != NONODEINST) hinp = hini->parent;
+		if (hini != NONODEINST)
+		{
+			hinp = hini->parent;
+			var = getvalkey((INTBIG)curnp, VNODEPROTO, VSTRING, us_descent_view_key);
+			if (var != NOVARIABLE)
+			{
+				pt = (char *)var->addr;
+				for(i=0; i<22; i++)
+				{
+					while (*pt == ' ') pt++;
+					value = atoi(pt);
+					while (*pt != 0 && *pt != ' ') pt++;
+					switch (i)
+					{
+						case 0:  vlx         = value;   break;
+						case 1:  vhx         = value;   break;
+						case 2:  vly         = value;   break;
+						case 3:  vhy         = value;   break;
+						case 4:  into[0][0]  = value;   break;
+						case 5:  into[0][1]  = value;   break;
+						case 6:  into[0][2]  = value;   break;
+						case 7:  into[1][0]  = value;   break;
+						case 8:  into[1][1]  = value;   break;
+						case 9:  into[1][2]  = value;   break;
+						case 10: into[2][0]  = value;   break;
+						case 11: into[2][1]  = value;   break;
+						case 12: into[2][2]  = value;   break;
+						case 13: outof[0][0] = value;   break;
+						case 14: outof[0][1] = value;   break;
+						case 15: outof[0][2] = value;   break;
+						case 16: outof[1][0] = value;   break;
+						case 17: outof[1][1] = value;   break;
+						case 18: outof[1][2] = value;   break;
+						case 19: outof[2][0] = value;   break;
+						case 20: outof[2][1] = value;   break;
+						case 21: outof[2][2] = value;   break;
+					}
+				}
+				haveview = 1;
+			}
+		}
 
 		/* if stack didn't tell where to go, see if upper facet is obvious */
 		if (hinp == NONODEPROTO)
@@ -148,25 +186,34 @@ void us_outhier(INTSML count, char *par[])
 			if (np == NONODEPROTO) np = curnp;
 
 			/* see if there is any instance of that facet */
-			ni = np->firstinst;
-			if (ni == NONODEINST)
+			found = 0;
+			hinp = NONODEPROTO;
+			for(ni = np->firstinst; ni != NONODEINST; ni = ni->nextinst)
+			{
+				if (ni->parent->cell == np->cell) continue;
+				if ((ni->parent->cell->lib->userbits&HIDDENLIBRARY) != 0) continue;
+				found = 1;
+				if (hinp != NONODEPROTO)
+				{
+					if (ni->parent == hinp) continue;
+					hinp = NONODEPROTO;
+					break;
+				}
+				hinp = ni->parent;
+				hini = ni;
+			}
+			if (found == 0)
 			{
 				if (i == 0)
 				{
 					us_abortcommand(_("Not in any facets"));
 					return;
 				}
-				ttyputerr(_("Only in %d deep"), i);
+				ttyputerr(_("Only in %ld deep"), i);
 				hinp = curnp;
 				break;
 			}
-			hinp = ni->parent;
-			for(; ni != NONODEINST; ni = ni->nextinst)
-				if (ni->parent != hinp) break;
-			if (ni == NONODEINST)
-			{
-				hini = np->firstinst;
-			} else
+			if (hinp == NONODEPROTO)
 			{
 				hini = us_pickhigherinstance(np);
 				if (hini == NONODEINST) return;
@@ -178,22 +225,32 @@ void us_outhier(INTSML count, char *par[])
 		hipp = NOPORTPROTO;
 		if (hini != NONODEINST && curpp != NOPORTPROTO)
 		{
-			np = iconview(curnp);
-			if (np == NONODEPROTO) np = curnp;
-			hipp = equivalentport(curnp, curpp, hini->proto);
+			if (hini->proto == curnp) np = curnp; else
+			{
+				np = iconview(curnp);
+				if (np == NONODEPROTO) np = curnp;
+			}
+			hipp = equivalentport(curnp, curpp, np);
 		}
 
 		/* adjust view of the facet */
-		if (hini != NONODEINST && hini->proto == curnp)
+		if (haveview != 0)
 		{
-			lx += hini->geom->lowx - curnp->lowx;
-			hx += hini->geom->lowx - curnp->lowx;
-			ly += hini->geom->lowy - curnp->lowy;
-			hy += hini->geom->lowy - curnp->lowy;
+			lx = vlx;   hx = vhx;
+			ly = vly;   hy = vhy;
 		} else
 		{
-			/* make a full view of the facet */
-			us_fullview(hinp, &lx, &hx, &ly, &hy);
+			if (hini != NONODEINST && hini->proto == curnp)
+			{
+				lx += hini->geom->lowx - curnp->lowx;
+				hx += hini->geom->lowx - curnp->lowx;
+				ly += hini->geom->lowy - curnp->lowy;
+				hy += hini->geom->lowy - curnp->lowy;
+			} else
+			{
+				/* make a full view of the facet */
+				us_fullview(hinp, &lx, &hx, &ly, &hy);
+			}
 		}
 
 		/* keep rolling up the hierarchy */
@@ -202,10 +259,18 @@ void us_outhier(INTSML count, char *par[])
 	}
 
 	/* display the final location */
-	us_switchtofacet(hinp, lx, hx, ly, hy, hini, hipp, 0, 1);
+	if (haveview != 0)
+	{
+		transcpy(into, el_curwindowpart->intofacet);
+		transcpy(outof, el_curwindowpart->outoffacet);
+		if (outof[2][0] == 0 && outof[2][1] == 0 && outof[2][2] == 0)
+			el_curwindowpart->state &= ~INPLACEEDIT; else
+				el_curwindowpart->state |= INPLACEEDIT;
+	}
+	us_switchtofacet(hinp, lx, hx, ly, hy, hini, hipp, FALSE, 1);
 }
 
-void us_package(INTSML count, char *par[])
+void us_package(INTBIG count, char *par[])
 {
 	INTBIG lx, hx, ly, hy;
 	REGISTER INTBIG search;
@@ -251,7 +316,7 @@ void us_package(INTSML count, char *par[])
 	}
 
 	/* create the new facet */
-	np = newnodeproto(par[0], lib);
+	np = us_newnodeproto(par[0], lib);
 	if (np == NONODEPROTO)
 	{
 		us_abortcommand(_("Cannot create facet %s"), par[0]);
@@ -265,7 +330,7 @@ void us_package(INTSML count, char *par[])
 	{
 		look = nextobject(search);
 		if (look == NOGEOM) break;
-		if (look->entrytype != OBJARCINST) continue;
+		if (look->entryisnode) continue;
 		ai = look->entryaddr.ai;
 		ni = NONODEINST;
 		ai->end[0].nodeinst->temp1 = (UINTBIG)ni;
@@ -278,7 +343,7 @@ void us_package(INTSML count, char *par[])
 	{
 		look = nextobject(search);
 		if (look == NOGEOM) break;
-		if (look->entrytype != OBJNODEINST) continue;
+		if (!look->entryisnode) continue;
 		ni = look->entryaddr.ni;
 		newni = newnodeinst(ni->proto, ni->lowx, ni->highx, ni->lowy,
 			ni->highy, ni->transpose, ni->rotation, np);
@@ -290,7 +355,7 @@ void us_package(INTSML count, char *par[])
 		ni->temp1 = (INTBIG)newni;
 		newni->userbits = ni->userbits;
 		TDCOPY(newni->textdescript, ni->textdescript);
-		if (copyvars((INTBIG)ni, VNODEINST, (INTBIG)newni, VNODEINST) != 0)
+		if (copyvars((INTBIG)ni, VNODEINST, (INTBIG)newni, VNODEINST))
 		{
 			ttyputnomemory();
 			return;
@@ -306,7 +371,7 @@ void us_package(INTSML count, char *par[])
 			{
 				npt->userbits = (npt->userbits & ~STATEBITS) | (ppt->userbits & STATEBITS);
 				TDCOPY(npt->textdescript, ppt->textdescript);
-				if (copyvars((INTBIG)ppt, VPORTPROTO, (INTBIG)npt, VPORTPROTO) != 0)
+				if (copyvars((INTBIG)ppt, VPORTPROTO, (INTBIG)npt, VPORTPROTO))
 				{
 					ttyputnomemory();
 					return;
@@ -321,7 +386,7 @@ void us_package(INTSML count, char *par[])
 	{
 		look = nextobject(search);
 		if (look == NOGEOM) break;
-		if (look->entrytype != OBJARCINST) continue;
+		if (look->entryisnode) continue;
 		ai = look->entryaddr.ai;
 		if (ai->end[0].nodeinst->temp1 == (UINTBIG)-1 ||
 			ai->end[1].nodeinst->temp1 == (UINTBIG)-1) continue;
@@ -334,11 +399,11 @@ void us_package(INTSML count, char *par[])
 			us_abortcommand(_("Cannot create arc in new facet"));
 			return;
 		}
-		if (copyvars((INTBIG)ai, VARCINST, (INTBIG)newar, VARCINST) != 0 ||
+		if (copyvars((INTBIG)ai, VARCINST, (INTBIG)newar, VARCINST) ||
 			copyvars((INTBIG)ai->end[0].portarcinst, VPORTARCINST,
-				(INTBIG)newar->end[0].portarcinst, VPORTARCINST) != 0 ||
+				(INTBIG)newar->end[0].portarcinst, VPORTARCINST) ||
 			copyvars((INTBIG)ai->end[1].portarcinst, VPORTARCINST,
-				(INTBIG)newar->end[1].portarcinst, VPORTARCINST) != 0)
+				(INTBIG)newar->end[1].portarcinst, VPORTARCINST))
 		{
 			ttyputnomemory();
 			return;
@@ -351,10 +416,11 @@ void us_package(INTSML count, char *par[])
 	ttyputmsg(_("Facet %s created"), describenodeproto(np));
 }
 
-void us_port(INTSML count, char *par[])
+void us_port(INTBIG count, char *par[])
 {
 	REGISTER INTBIG i, l, labels, total, reducehighlighting;
 	INTBIG lx, hx, ly, hy, mlx, mly, mhx, mhy, bits, mask, newbits, x, y, deleted;
+	REGISTER BOOLEAN nodegood;
 	REGISTER NODEINST *ni, *oni;
 	REGISTER NODEPROTO *np;
 	REGISTER PORTPROTO *pp, *ppt;
@@ -365,6 +431,7 @@ void us_port(INTSML count, char *par[])
 	PORTPROTO *fromport, *toport;
 	REGISTER char *pt;
 	char *portname;
+	NODEINST **nilist;
 	REGISTER HIGHLIGHT *high;
 	HIGHLIGHT newhigh;
 	extern COMCOMP us_portp, us_portep;
@@ -388,22 +455,20 @@ void us_port(INTSML count, char *par[])
 		if (count > 1)
 		{
 			l = strlen(pt = par[1]);
-			if (namesamen(pt, "none", l) == 0 && l >= 2) labels = PORTSOFF; else
 			if (namesamen(pt, "crosses", l) == 0 && l >= 1) labels = PORTSCROSS; else
 			if (namesamen(pt, "short", l) == 0 && l >= 2) labels = PORTSSHORT; else
 			if (namesamen(pt, "long", l) == 0 && l >= 1) labels = PORTSFULL; else
 			{
-				ttyputusage("port labels none|short|long|crosses");
+				ttyputusage("port labels short|long|crosses");
 				return;
 			}
 			startobjectchange((INTBIG)us_tool, VTOOL);
-			(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflags,
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflagskey,
 				(us_useroptions & ~PORTLABELS) | labels, VINTEGER);
 			endobjectchange((INTBIG)us_tool, VTOOL);
 		}
 		switch (us_useroptions&PORTLABELS)
 		{
-			case PORTSOFF:   ttyputverbose(M_("No ports are indicated"));     break;
 			case PORTSCROSS: ttyputverbose(M_("Ports shown as crosses"));     break;
 			case PORTSFULL:  ttyputverbose(M_("Long port names displayed"));  break;
 			case PORTSSHORT: ttyputverbose(M_("Short port names displayed")); break;
@@ -416,22 +481,20 @@ void us_port(INTSML count, char *par[])
 		if (count > 1)
 		{
 			l = strlen(pt = par[1]);
-			if (namesamen(pt, "none", l) == 0 && l >= 2) labels = EXPORTSOFF; else
 			if (namesamen(pt, "crosses", l) == 0 && l >= 1) labels = EXPORTSCROSS; else
 			if (namesamen(pt, "short", l) == 0 && l >= 2) labels = EXPORTSSHORT; else
 			if (namesamen(pt, "long", l) == 0 && l >= 1) labels = EXPORTSFULL; else
 			{
-				ttyputusage("port export-labels none|short|long|crosses");
+				ttyputusage("port export-labels short|long|crosses");
 				return;
 			}
 			startobjectchange((INTBIG)us_tool, VTOOL);
-			(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflags,
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflagskey,
 				(us_useroptions & ~EXPORTLABELS) | labels, VINTEGER);
 			endobjectchange((INTBIG)us_tool, VTOOL);
 		}
 		switch (us_useroptions&EXPORTLABELS)
 		{
-			case EXPORTSOFF:   ttyputverbose(M_("No exports are indicated"));     break;
 			case EXPORTSCROSS: ttyputverbose(M_("Exports shown as crosses"));     break;
 			case EXPORTSFULL:  ttyputverbose(M_("Long export names displayed"));  break;
 			case EXPORTSSHORT: ttyputverbose(M_("Short export names displayed")); break;
@@ -471,27 +534,37 @@ void us_port(INTSML count, char *par[])
 			us_abortcommand(_("Cannot show exports in a 3D window"));
 			return;
 		}
-		us_identifyports(NONODEINST, np, LAYERA, 0);
+		us_identifyports(0, 0, np, LAYERA, FALSE);
 		return;
 	}
 
 	if (namesamen(pt, "identify-node", l) == 0 && l >= 10)
 	{
 		/* make sure there is a current node */
-		ni = (NODEINST *)us_getobject(OBJNODEINST, 0);
-		if (ni == NONODEINST) return;
 		if ((el_curwindowpart->state&WINDOWTYPE) == DISP3DWINDOW)
 		{
 			us_abortcommand(_("Cannot show ports in a 3D window"));
 			return;
 		}
-		us_identifyports(ni, ni->proto, LAYERA, 0);
+		g = us_gethighlighted(WANTNODEINST, 0, 0);
+		for(i=0; g[i] != NOGEOM; i++) ;
+		if (i <= 0)
+		{
+			us_abortcommand(_("Must select one or more nodes"));
+			return;
+		}
+		nilist = (NODEINST **)emalloc(i * (sizeof (NODEINST *)), el_tempcluster);
+		if (nilist == 0) return;
+		for(i=0; g[i] != NOGEOM; i++)
+			nilist[i] = g[i]->entryaddr.ni;
+		us_identifyports(i, nilist, nilist[0]->proto, LAYERA, FALSE);
+		efree((char *)nilist);
 		return;
 	}
 
 	if (namesamen(pt, "move", l) == 0 && l >= 1)
 	{
-		if (us_gettwoobjects(&fromgeom, &fromport, &togeom, &toport) != 0)
+		if (us_gettwoobjects(&fromgeom, &fromport, &togeom, &toport))
 		{
 			us_abortcommand(_("Must select two nodes"));
 			return;
@@ -511,7 +584,7 @@ void us_port(INTSML count, char *par[])
 		}
 
 		/* disallow port action if lock is on */
-		if (us_canedit(np, NONODEPROTO, 1) != 0) return;
+		if (us_cantedit(np, NONODEPROTO, TRUE)) return;
 
 		reducehighlighting = 1;
 		if (count > 1)
@@ -547,7 +620,7 @@ void us_port(INTSML count, char *par[])
 		pt = pe->exportproto->protoname;
 		startobjectchange((INTBIG)ni, VNODEINST);
 		startobjectchange((INTBIG)oni, VNODEINST);
-		if (moveportproto(np, pe->exportproto, ni, toport) != 0) ttyputerr(_("Port not moved")); else
+		if (moveportproto(np, pe->exportproto, ni, toport)) ttyputerr(_("Port not moved")); else
 		{
 			endobjectchange((INTBIG)ni, VNODEINST);
 			endobjectchange((INTBIG)oni, VNODEINST);
@@ -556,13 +629,13 @@ void us_port(INTSML count, char *par[])
 		}
 
 		/* restore highlighting */
-		if (reducehighlighting == 0) (void)us_pophighlight(0); else
+		if (reducehighlighting == 0) us_pophighlight(FALSE); else
 		{
 			newhigh.status = HIGHFROM;
 			newhigh.facet = np;
 			newhigh.fromgeom = fromgeom;
 			newhigh.fromport = fromport;
-			(void)us_addhighlight(&newhigh);
+			us_addhighlight(&newhigh);
 		}
 		return;
 	}
@@ -574,7 +647,7 @@ void us_port(INTSML count, char *par[])
 		if (np == NONODEPROTO) return;
 
 		/* disallow port action if lock is on */
-		if (us_canedit(np, NONODEPROTO, 1) != 0) return;
+		if (us_cantedit(np, NONODEPROTO, TRUE)) return;
 
 		/* save highlighting */
 		us_pushhighlight();
@@ -600,23 +673,46 @@ void us_port(INTSML count, char *par[])
 			for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
 				pe->proto->temp1++;
 
+#if 1
+			/* initialize for queueing creation of new exports */
+			us_initqueuedexports();
+#endif
+
 			/* now export the remaining ports */
+			nodegood = FALSE;
 			for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 				if (pp->temp1 == 0)
 			{
-				if (us_reexportport(pp, ni) != 0)
+#if 1
+				if (!nodegood)
 				{
-					(void)us_pophighlight(0);
+					startobjectchange((INTBIG)ni, VNODEINST);
+					nodegood = TRUE;
+				}
+				if (us_queuenewexport(ni, pp, pp))
+#else
+				if (us_reexportport(pp, ni))
+#endif
+				{
+					us_pophighlight(FALSE);
 					return;
 				}
 				total++;
 			}
+#if 1
+			if (nodegood)
+			{
+				/* create any queued exports */
+				us_createqueuedexports();
+				endobjectchange((INTBIG)ni, VNODEINST);
+			}
+#endif
 		}
 		if (total == 0) ttyputmsg(_("No ports to export")); else
-			ttyputmsg(_("%d ports exported"), total);
+			ttyputmsg(_("%ld ports exported"), total);
 
 		/* restore highlighting */
-		(void)us_pophighlight(0);
+		us_pophighlight(FALSE);
 		return;
 	}
 
@@ -634,10 +730,10 @@ void us_port(INTSML count, char *par[])
 		}
 
 		/* disallow port action if lock is on */
-		if (us_canedit(np, NONODEPROTO, 1) != 0) return;
+		if (us_cantedit(np, NONODEPROTO, TRUE)) return;
 
 		/* get list of nodes in the selected area */
-		g = us_gethighlighted(OBJNODEINST, 0, 0);
+		g = us_gethighlighted(WANTNODEINST, 0, 0);
 		if (g[0] == NOGEOM)
 		{
 			us_abortcommand(_("Must select some nodes for making exports"));
@@ -648,6 +744,11 @@ void us_port(INTSML count, char *par[])
 		us_pushhighlight();
 		us_clearhighlightcount();
 
+#if 1
+		/* initialize for queueing creation of new exports */
+		us_initqueuedexports();
+#endif
+
 		/* re-export the requested ports */
 		total = 0;
 		for(i=0; g[i] != NOGEOM; i++)
@@ -668,25 +769,106 @@ void us_port(INTSML count, char *par[])
 				pe->proto->temp1++;
 
 			/* now export the remaining ports that are in the area */
+			nodegood = FALSE;
 			for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 				if (pp->temp1 == 0)
 			{
-				shapeportpoly(ni, pp, poly, 0);
+				shapeportpoly(ni, pp, poly, FALSE);
 				getbbox(poly, &mlx, &mhx, &mly, &mhy);
 				if (mlx > hx || mhx < lx || mly > hy || mhy < ly) continue;
-				if (us_reexportport(pp, ni) != 0)
+#if 1
+				if (!nodegood)
 				{
-					(void)us_pophighlight(0);
+					startobjectchange((INTBIG)ni, VNODEINST);
+					nodegood = TRUE;
+				}
+				if (us_queuenewexport(ni, pp, pp))
+#else
+				if (us_reexportport(pp, ni))
+#endif
+				{
+					us_pophighlight(FALSE);
 					return;
 				}
 				total++;
 			}
 		}
+
+#if 1
+		/* create any queued exports */
+		us_createqueuedexports();
+		for(i=0; g[i] != NOGEOM; i++)
+		{
+			ni = g[i]->entryaddr.ni;
+			if (ni->proto->primindex != 0) continue;
+			for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+			{
+				if (pp->temp1 != 0) continue;
+				endobjectchange((INTBIG)ni, VNODEINST);
+				break;
+			}
+		}
+#endif
 		if (total == 0) ttyputmsg(_("No ports to export")); else
-			ttyputmsg(_("%d ports exported"), total);
+			ttyputmsg(_("%ld ports exported"), total);
 
 		/* restore highlighting */
-		(void)us_pophighlight(0);
+		us_pophighlight(FALSE);
+		return;
+	}
+
+	if (namesamen(pt, "power-ground-re-export", l) == 0 && l >= 1)
+	{
+		/* make sure there is a current facet */
+		np = us_needfacet();
+		if (np == NONODEPROTO) return;
+
+		/* disallow port action if lock is on */
+		if (us_cantedit(np, NONODEPROTO, TRUE)) return;
+
+		/* save highlighting */
+		us_pushhighlight();
+		us_clearhighlightcount();
+
+		/* look at every node in this facet */
+		total = 0;
+		for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+		{
+			/* only look for facets, not primitives */
+			if (ni->proto->primindex != 0) continue;
+
+			/* ignore recursive references (showing icon in contents) */
+			if (ni->proto->cell == np->cell) continue;
+
+			/* clear marks on the ports of this node */
+			for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+				pp->temp1 = 0;
+
+			/* mark the connected and exports */
+			for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
+				pi->proto->temp1++;
+			for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
+				pe->proto->temp1++;
+
+			/* now export the remaining power and ground ports */
+			for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+			{
+				if (pp->temp1 != 0) continue;
+				if (!portispower(pp) && !portisground(pp)) continue;
+
+				if (us_reexportport(pp, ni))
+				{
+					us_pophighlight(FALSE);
+					return;
+				}
+				total++;
+			}
+		}
+		if (total == 0) ttyputmsg(_("No power and ground ports to export")); else
+			ttyputmsg(_("%ld power and ground ports exported"), total);
+
+		/* restore highlighting */
+		us_pophighlight(FALSE);
 		return;
 	}
 
@@ -721,7 +903,7 @@ void us_port(INTSML count, char *par[])
 				for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = nextpe)
 				{
 					nextpe = pe->nextportexpinst;
-					shapeportpoly(ni, pe->proto, poly, 0);
+					shapeportpoly(ni, pe->proto, poly, FALSE);
 					getcenter(poly, &x, &y);
 					if (x < lx || x > hx || y < ly || y > hy) continue;
 					ttyputmsg(_("Deleting port %s"), pe->exportproto->protoname);
@@ -735,13 +917,13 @@ void us_port(INTSML count, char *par[])
 			}
 
 			/* restore highlighting */
-			(void)us_pophighlight(0);
+			us_pophighlight(FALSE);
 			if (deleted == 0) ttyputmsg(_("No exports are in the selected area"));
 			return;
 		}
 		if (count == 3 && namesame(par[2], "all") == 0)
 		{
-			g = us_gethighlighted(OBJNODEINST, 0, 0);
+			g = us_gethighlighted(WANTNODEINST, 0, 0);
 			if (g[0] == NOGEOM)
 			{
 				us_abortcommand(_("Must first select nodes with exports"));
@@ -773,7 +955,7 @@ void us_port(INTSML count, char *par[])
 			}
 
 			/* restore highlighting */
-			(void)us_pophighlight(0);
+			us_pophighlight(FALSE);
 			if (deleted == 0) ttyputmsg(_("No exports are on the selected nodes"));
 			return;
 		}
@@ -792,7 +974,7 @@ void us_port(INTSML count, char *par[])
 			ppt = high->fromport;
 		} else
 		{
-			ni = (NODEINST *)us_getobject(OBJNODEINST, 0);
+			ni = (NODEINST *)us_getobject(VNODEINST, FALSE);
 			if (ni == NONODEINST) return;
 			ppt = NOPORTPROTO;
 		}
@@ -805,10 +987,10 @@ void us_port(INTSML count, char *par[])
 		}
 
 		/* disallow port action if lock is on */
-		if (us_canedit(ni->parent, NONODEPROTO, 1) != 0) return;
+		if (us_cantedit(ni->parent, NONODEPROTO, TRUE)) return;
 
 		/* get the specification details */
-		pp = us_portdetails(ppt, (INTSML)(count-2), &par[2], ni, &bits, &mask, 1, "");
+		pp = us_portdetails(ppt, count-2, &par[2], ni, &bits, &mask, TRUE, "");
 		if (pp == NOPORTPROTO) return;
 
 		/* remove highlighting */
@@ -821,7 +1003,7 @@ void us_port(INTSML count, char *par[])
 		endobjectchange((INTBIG)ni, VNODEINST);
 
 		/* restore highlighting */
-		(void)us_pophighlight(0);
+		us_pophighlight(FALSE);
 
 		ttyputverbose(M_("Port %s deleted"), pp->protoname);
 		return;
@@ -829,11 +1011,11 @@ void us_port(INTSML count, char *par[])
 
 	if (namesamen(pt, "export", l) == 0 && l >= 1)
 	{
-		ni = (NODEINST *)us_getobject(OBJNODEINST, 0);
+		ni = (NODEINST *)us_getobject(VNODEINST, FALSE);
 		if (ni == NONODEINST) return;
 
 		/* disallow port action if lock is on */
-		if (us_canedit(ni->parent, NONODEPROTO, 1) != 0) return;
+		if (us_cantedit(ni->parent, NONODEPROTO, TRUE)) return;
 
 		if (count <= 1)
 		{
@@ -860,7 +1042,7 @@ void us_port(INTSML count, char *par[])
 			ttyputmsg(_("Already a port called %s, calling this %s"), pt, portname);
 
 		/* get the specification details */
-		pp = us_portdetails(NOPORTPROTO, (INTSML)(count-2), &par[2], ni, &bits, &mask, 0, pt);
+		pp = us_portdetails(NOPORTPROTO, count-2, &par[2], ni, &bits, &mask, FALSE, pt);
 		if (pp == NOPORTPROTO) return;
 
 		/* save highlighting */
@@ -871,7 +1053,7 @@ void us_port(INTSML count, char *par[])
 		us_makenewportproto(ni->parent, ni, pp, portname, mask, bits, pp->textdescript);
 
 		/* restore highlighting */
-		(void)us_pophighlight(0);
+		us_pophighlight(FALSE);
 
 		ttyputverbose(M_("Port %s created"), pp->protoname);
 		return;
@@ -892,16 +1074,16 @@ void us_port(INTSML count, char *par[])
 			ppt = high->fromport;
 		} else
 		{
-			ni = (NODEINST *)us_getobject(OBJNODEINST, 0);
+			ni = (NODEINST *)us_getobject(VNODEINST, FALSE);
 			if (ni == NONODEINST) return;
 			ppt = NOPORTPROTO;
 		}
 
 		/* disallow port action if lock is on */
-		if (us_canedit(ni->parent, NONODEPROTO, 1) != 0) return;
+		if (us_cantedit(ni->parent, NONODEPROTO, TRUE)) return;
 
 		/* get the specification details */
-		pp = us_portdetails(ppt, (INTSML)(count-1), &par[1], ni, &bits, &mask, 1, "");
+		pp = us_portdetails(ppt, count-1, &par[1], ni, &bits, &mask, TRUE, "");
 		if (pp == NOPORTPROTO) return;
 
 		/* change the port characteristics */
@@ -935,8 +1117,8 @@ void us_port(INTSML count, char *par[])
 	ttyputbadusage("port");
 }
 
-void us_quit(INTSML count, char *par[])
+void us_quit(INTBIG count, char *par[])
 {
-	if (us_preventloss(NOLIBRARY, "quit", 1)) return;
+	if (us_preventloss(NOLIBRARY, 0, TRUE)) return;
 	bringdown();
 }
