@@ -61,15 +61,15 @@ static struct
 	{0,0,0}
 };
 
-void us_window(INTSML count, char *par[])
+void us_window(INTBIG count, char *par[])
 {
 	REGISTER WINDOWPART *w, *oldw, *nextw, *neww;
 	REGISTER INTBIG i, dist, curwx, curwy, size, x, y, diffx, diffy, lambda;
-	REGISTER INTSML l, nogood, splitkey, lineno, startper, endper;
+	REGISTER INTBIG l, nogood, splitkey, lineno, startper, endper;
 	INTBIG lx, hx, ly, hy, xcur, ycur, windowView[8];
 	static POLYGON *poly = NOPOLYGON;
 	REGISTER STATUSFIELD *sf, **whichstatus;
-	char *newpar[4], *fieldname, line[50];
+	char *newpar[4], *fieldname;
 	WINDOWFRAME *wf;
 #if SIMTOOL
 	extern TOOL *sim_tool;
@@ -92,7 +92,7 @@ void us_window(INTSML count, char *par[])
 			return;
 		}
 	}
-	l = (INTSML)strlen(pp = par[0]);
+	l = strlen(pp = par[0]);
 
 	if (namesamen(pp, "adjust", l) == 0 && l >= 2)
 	{
@@ -101,7 +101,7 @@ void us_window(INTSML count, char *par[])
 			ttyputusage("window adjust STYLE");
 			return;
 		}
-		l = (INTSML)strlen(pp = par[1]);
+		l = strlen(pp = par[1]);
 		if (namesamen(pp, "horizontal-tile", l) == 0)
 		{
 			adjustwindowframe(0);
@@ -132,7 +132,7 @@ void us_window(INTSML count, char *par[])
 			newpar[0] = "window";
 			newpar[1] = "zoom";
 			newpar[2] = "all-displayed";
-			(void)telltool(sim_tool, 3, newpar);
+			telltool(sim_tool, 3, newpar);
 			return;
 		}
 #endif
@@ -161,7 +161,9 @@ void us_window(INTSML count, char *par[])
 
 		/* make the facet fill the window */
 		us_fullview(np, &lx, &hx, &ly, &hy);
-		us_squarescreen(el_curwindowpart, NOWINDOWPART, 0, &lx, &hx, &ly, &hy);
+		if ((el_curwindowpart->state&INPLACEEDIT) != 0)
+			xformbox(&lx, &hx, &ly, &hy, el_curwindowpart->outoffacet);
+		us_squarescreen(el_curwindowpart, NOWINDOWPART, FALSE, &lx, &hx, &ly, &hy, 0);
 
 		startobjectchange((INTBIG)el_curwindowpart, VWINDOWPART);
 		(void)setval((INTBIG)el_curwindowpart, VWINDOWPART, "screenlx", lx, VINTEGER);
@@ -172,7 +174,7 @@ void us_window(INTSML count, char *par[])
 		endobjectchange((INTBIG)el_curwindowpart, VWINDOWPART);
 
 		/* restore highlighting */
-		(void)us_pophighlight(0);
+		us_pophighlight(FALSE);
 		return;
 	}
 
@@ -214,6 +216,9 @@ void us_window(INTSML count, char *par[])
 		x = (hx + lx) / 2;     y = (hy + ly) / 2;
 		lx = x - curwx/2;      ly = y - curwy/2;
 		hx = lx + curwx;       hy = ly + curwy;
+		if ((el_curwindowpart->state&INPLACEEDIT) != 0)
+			xformbox(&lx, &hx, &ly, &hy, el_curwindowpart->outoffacet);
+		us_squarescreen(el_curwindowpart, NOWINDOWPART, FALSE, &lx, &hx, &ly, &hy, 1);
 
 		/* save and erase highlighting */
 		us_pushhighlight();
@@ -228,7 +233,7 @@ void us_window(INTSML count, char *par[])
 		endobjectchange((INTBIG)w, VWINDOWPART);
 
 		/* restore highlighting */
-		(void)us_pophighlight(0);
+		us_pophighlight(FALSE);
 		return;
 	}
 
@@ -251,6 +256,9 @@ void us_window(INTSML count, char *par[])
 		curwy = el_curwindowpart->screenhy - el_curwindowpart->screenly;
 		lx = xcur - curwx/2;   ly = ycur - curwy/2;
 		hx = lx + curwx;       hy = ly + curwy;
+		if ((el_curwindowpart->state&INPLACEEDIT) != 0)
+			xformbox(&lx, &hx, &ly, &hy, el_curwindowpart->outoffacet);
+		us_squarescreen(el_curwindowpart, NOWINDOWPART, FALSE, &lx, &hx, &ly, &hy, 1);
 
 		/* save and erase highlighting */
 		us_pushhighlight();
@@ -265,7 +273,7 @@ void us_window(INTSML count, char *par[])
 		endobjectchange((INTBIG)el_curwindowpart, VWINDOWPART);
 
 		/* restore highlighting */
-		(void)us_pophighlight(0);
+		us_pophighlight(FALSE);
 		return;
 	}
 
@@ -273,18 +281,18 @@ void us_window(INTSML count, char *par[])
 	if (namesamen(pp, "delete", l) == 0 && l >= 2)
 	{
 		/* close the messages window if in front and can be closed */
-		if (closefrontmostmessages() != 0) return;
+		if (closefrontmostmessages()) return;
 
 		/* delete split if there are no multiple window frames */
-		if (graphicshas(CANUSEFRAMES) == 0)
+		if (!graphicshas(CANUSEFRAMES))
 		{
 			if (us_needwindow()) return;
-			us_killcurrentwindow(1);
+			us_killcurrentwindow(TRUE);
 			return;
 		}
 
 		/* disallow if this is the last window and it must remain */
-		if (graphicshas(CANHAVENOWINDOWS) == 0)
+		if (!graphicshas(CANHAVENOWINDOWS))
 		{
 			/* disallow deletion if this is the last window */
 			i = 0;
@@ -298,7 +306,7 @@ void us_window(INTSML count, char *par[])
 		}
 
 		/* get the current frame */
-		wf = getwindowframe(0);
+		wf = getwindowframe(FALSE);
 		if (wf == NOWINDOWFRAME)
 		{
 			us_abortcommand(_("No current window to delete"));
@@ -329,12 +337,12 @@ void us_window(INTSML count, char *par[])
 
 		/* if (neww == NOWINDOWPART) */
 		el_curwindowpart = NOWINDOWPART;
-		(void)setvalkey((INTBIG)us_tool, VTOOL, us_current_window, (INTBIG)neww, VWINDOWPART|VDONTSAVE);
+		(void)setvalkey((INTBIG)us_tool, VTOOL, us_current_window_key, (INTBIG)neww, VWINDOWPART|VDONTSAVE);
 		if (neww != NOWINDOWPART) np = neww->curnodeproto; else np = NONODEPROTO;
 		(void)setval((INTBIG)el_curlib, VLIBRARY, "curnodeproto", (INTBIG)np, VNODEPROTO);
 
 		/* restore highlighting */
-		(void)us_pophighlight(0);
+		us_pophighlight(FALSE);
 		return;
 	}
 
@@ -361,9 +369,7 @@ void us_window(INTSML count, char *par[])
 				newpar[0] = "window";
 				newpar[1] = "move";
 				newpar[2] = "down";
-				sprintf(line, "%ld", (INTBIG)(atof(pp)*20.0));
-				newpar[3] = line;
-				(void)telltool(sim_tool, 4, newpar);
+				telltool(sim_tool, 3, newpar);
 				return;
 #endif
 			case EXPLORERWINDOW:
@@ -406,7 +412,7 @@ void us_window(INTSML count, char *par[])
 		{
 			/* the explorer is up, delete it */
 			el_curwindowpart = w;
-			us_killcurrentwindow(1);
+			us_killcurrentwindow(TRUE);
 			return;
 		}
 
@@ -423,7 +429,7 @@ void us_window(INTSML count, char *par[])
 		}
 		if (strcmp(w->location, "entire") == 0)
 		{
-			w = us_splitcurrentwindow(2, 0, 0);
+			w = us_splitcurrentwindow(2, FALSE, 0);
 			if (w == NOWINDOWPART) return;
 		}
 
@@ -446,23 +452,13 @@ void us_window(INTSML count, char *par[])
 
 		if (oldw != NOWINDOWPART)
 		{
-			(void)setvalkey((INTBIG)us_tool, VTOOL, us_current_window, (INTBIG)oldw,
+			(void)setvalkey((INTBIG)us_tool, VTOOL, us_current_window_key, (INTBIG)oldw,
 				VWINDOWPART|VDONTSAVE);
 			us_setfacetname(oldw);
 		}
 		return;
 	}
 
-	if (namesamen(pp, "hide-attributes", l) == 0 && l >= 3)
-	{
-		if ((us_useroptions&HIDEATTRIBUTES) != 0) return;
-		startobjectchange((INTBIG)us_tool, VTOOL);
-		(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflags,
-			us_useroptions | HIDEATTRIBUTES, VINTEGER);
-		endobjectchange((INTBIG)us_tool, VTOOL);
-		return;
-	}
-
 	if (namesamen(pp, "highlight-displayed", l) == 0 && l >= 3)
 	{
 		if (us_needwindow()) return;
@@ -474,7 +470,7 @@ void us_window(INTSML count, char *par[])
 			newpar[0] = "window";
 			newpar[1] = "zoom";
 			newpar[2] = "cursor";
-			(void)telltool(sim_tool, 3, newpar);
+			telltool(sim_tool, 3, newpar);
 			return;
 		}
 #endif
@@ -505,6 +501,8 @@ void us_window(INTSML count, char *par[])
 			return;
 		}
 
+		if ((el_curwindowpart->state&INPLACEEDIT) != 0)
+			xformbox(&lx, &hx, &ly, &hy, el_curwindowpart->outoffacet);
 		if (lx == hx && ly == hy)
 		{
 			lambda = lambdaoffacet(np);
@@ -514,16 +512,12 @@ void us_window(INTSML count, char *par[])
 			hy += lambda;
 		}
 
-		/* pre-compute current window size */
-		curwx = w->screenhx - w->screenlx;
-		curwy = w->screenhy - w->screenly;
-
 		/* save and erase highlighting */
 		us_pushhighlight();
 		us_clearhighlightcount();
 
 		/* make sure the new window has square pixels */
-		us_squarescreen(w, NOWINDOWPART, 0, &lx, &hx, &ly, &hy);
+		us_squarescreen(w, NOWINDOWPART, FALSE, &lx, &hx, &ly, &hy, 0);
 
 		startobjectchange((INTBIG)w, VWINDOWPART);
 		(void)setval((INTBIG)w, VWINDOWPART, "screenlx", lx, VINTEGER);
@@ -534,7 +528,7 @@ void us_window(INTSML count, char *par[])
 		endobjectchange((INTBIG)w, VWINDOWPART);
 
 		/* restore highlighting */
-		(void)us_pophighlight(0);
+		us_pophighlight(FALSE);
 		return;
 	}
 
@@ -549,7 +543,7 @@ void us_window(INTSML count, char *par[])
 			newpar[0] = "window";
 			newpar[1] = "zoom";
 			newpar[2] = "in";
-			(void)telltool(sim_tool, 3, newpar);
+			telltool(sim_tool, 3, newpar);
 			return;
 		}
 #endif
@@ -591,7 +585,7 @@ void us_window(INTSML count, char *par[])
 		ly = el_curwindowpart->screenly;   hy = el_curwindowpart->screenhy;
 		lx = (hx+lx-diffx)/2;   hx = lx + diffx;
 		ly = (hy+ly-diffy)/2;   hy = ly + diffy;
-		us_squarescreen(el_curwindowpart, NOWINDOWPART, 0, &lx, &hx, &ly, &hy);
+		us_squarescreen(el_curwindowpart, NOWINDOWPART, FALSE, &lx, &hx, &ly, &hy, 1);
 
 		startobjectchange((INTBIG)el_curwindowpart, VWINDOWPART);
 		(void)setval((INTBIG)el_curwindowpart, VWINDOWPART, "screenlx", lx, VINTEGER);
@@ -602,7 +596,7 @@ void us_window(INTSML count, char *par[])
 		endobjectchange((INTBIG)el_curwindowpart, VWINDOWPART);
 
 		/* restore highlighting */
-		(void)us_pophighlight(0);
+		us_pophighlight(FALSE);
 		return;
 	}
 
@@ -610,7 +604,7 @@ void us_window(INTSML count, char *par[])
 	if (namesamen(pp, "join", l) == 0 && l >= 1)
 	{
 		if (us_needwindow()) return;
-		us_killcurrentwindow(0);
+		us_killcurrentwindow(FALSE);
 		return;
 	}
 
@@ -618,7 +612,7 @@ void us_window(INTSML count, char *par[])
 	if (namesamen(pp, "kill", l) == 0 && l >= 1)
 	{
 		if (us_needwindow()) return;
-		us_killcurrentwindow(1);
+		us_killcurrentwindow(TRUE);
 		return;
 	}
 
@@ -645,9 +639,7 @@ void us_window(INTSML count, char *par[])
 				newpar[0] = "window";
 				newpar[1] = "move";
 				newpar[2] = "left";
-				sprintf(line, "%ld", (INTBIG)(atof(pp)*20.0));
-				newpar[3] = line;
-				(void)telltool(sim_tool, 4, newpar);
+				telltool(sim_tool, 3, newpar);
 				return;
 #endif
 		}
@@ -743,7 +735,7 @@ void us_window(INTSML count, char *par[])
 		endobjectchange((INTBIG)el_curwindowpart, VWINDOWPART);
 
 		/* restore highlighting */
-		(void)us_pophighlight(0);
+		us_pophighlight(FALSE);
 		return;
 	}
 
@@ -759,19 +751,30 @@ void us_window(INTSML count, char *par[])
 			us_abortcommand(_("No facet in this window to measure"));
 			return;
 		}
-		us_clearhighlightcount();
-		ttyputmsg(_("Type ENTER when done measuring distances"));
-		ttyputmsg(_("Type 'x' to set a new starting point"));
-		us_distanceinit();
-		for(;;)
+		if ((us_state&MEASURINGDISTANCE) != 0)
 		{
-			trackcursor(1, us_ignoreup, us_distancebegin, us_distancedown,
-				us_distancechar, us_distanceup, TRACKDRAGGING);
-			if (us_distanceaborted() != 0) break;
+			us_state &= ~(MEASURINGDISTANCE | MEASURINGDISTANCEINI);
+			ttyputmsg(_("Exiting distance measurement mode"));
+		} else
+		{
+			us_clearhighlightcount();
+			us_state |= MEASURINGDISTANCE | MEASURINGDISTANCEINI;
+			ttyputmsg(_("Entering distance measurement mode"));
 		}
 		return;
 	}
 
+	if (namesamen(pp, "move-display", l) == 0 && l >= 2)
+	{
+		if (us_needwindow()) return;
+#ifdef USEQT
+		movedisplay();
+#else
+		ttyputmsg(_("(Display move works only on Qt"));
+#endif
+		return;
+	}
+
 	if (namesamen(pp, "name", l) == 0 && l >= 2)
 	{
 		if (us_needwindow()) return;
@@ -799,7 +802,7 @@ void us_window(INTSML count, char *par[])
 		if (((INTBIG *)var->addr)[5] - ((INTBIG *)var->addr)[4] != el_curwindowpart->usehx - el_curwindowpart->uselx ||
 			((INTBIG *)var->addr)[7] - ((INTBIG *)var->addr)[6] != el_curwindowpart->usehy - el_curwindowpart->usely)
 		{
-			us_squarescreen(el_curwindowpart, NOWINDOWPART, 0, &lx, &hx, &ly, &hy);
+			us_squarescreen(el_curwindowpart, NOWINDOWPART, FALSE, &lx, &hx, &ly, &hy, 0);
 		}
 
 		/* save and erase highlighting */
@@ -815,7 +818,7 @@ void us_window(INTSML count, char *par[])
 		endobjectchange((INTBIG)el_curwindowpart, VWINDOWPART);
 
 		/* restore highlighting */
-		(void)us_pophighlight(0);
+		us_pophighlight(FALSE);
 		return;
 	}
 
@@ -858,7 +861,7 @@ void us_window(INTSML count, char *par[])
 			newpar[0] = "window";
 			newpar[1] = "zoom";
 			newpar[2] = "out";
-			(void)telltool(sim_tool, 3, newpar);
+			telltool(sim_tool, 3, newpar);
 			return;
 		}
 #endif
@@ -898,7 +901,7 @@ void us_window(INTSML count, char *par[])
 		lx = (lx+hx-i)/2;   hx = lx + i;
 		i = muldiv(el_curwindowpart->screenhy - el_curwindowpart->screenly, dist, lambda);
 		ly = (ly+hy-i)/2;   hy = ly + i;
-		us_squarescreen(el_curwindowpart, NOWINDOWPART, 0, &lx, &hx, &ly, &hy);
+		us_squarescreen(el_curwindowpart, NOWINDOWPART, FALSE, &lx, &hx, &ly, &hy, 1);
 
 		startobjectchange((INTBIG)el_curwindowpart, VWINDOWPART);
 		(void)setval((INTBIG)el_curwindowpart, VWINDOWPART, "screenlx", lx, VINTEGER);
@@ -909,7 +912,7 @@ void us_window(INTSML count, char *par[])
 		endobjectchange((INTBIG)el_curwindowpart, VWINDOWPART);
 
 		/* restore highlighting */
-		(void)us_pophighlight(0);
+		us_pophighlight(FALSE);
 		return;
 	}
 
@@ -980,7 +983,7 @@ void us_window(INTSML count, char *par[])
 		us_arbit.col = 0;
 		us_arbit.bits = LAYERO;
 		poly->style = FILLEDRECT;
-		(void)us_showpoly(poly, w);
+		us_showpoly(poly, w);
 
 		/* get new window to describe sub-area */
 		w = us_subwindow(lx, hx, ly, hy, w);
@@ -989,7 +992,7 @@ void us_window(INTSML count, char *par[])
 		us_dopeek(lx, hx, ly, hy, np, w);
 
 		/* restore highlighting */
-		(void)us_pophighlight(0);
+		us_pophighlight(FALSE);
 		return;
 	}
 
@@ -1016,9 +1019,7 @@ void us_window(INTSML count, char *par[])
 				newpar[0] = "window";
 				newpar[1] = "move";
 				newpar[2] = "right";
-				sprintf(line, "%ld", (INTBIG)(atof(pp)*20.0));
-				newpar[3] = line;
-				(void)telltool(sim_tool, 4, newpar);
+				telltool(sim_tool, 3, newpar);
 				return;
 #endif
 		}
@@ -1051,16 +1052,6 @@ void us_window(INTSML count, char *par[])
 		return;
 	}
 
-	if (namesamen(pp, "show-attributes", l) == 0 && l >= 3)
-	{
-		if ((us_useroptions&HIDEATTRIBUTES) == 0) return;
-		startobjectchange((INTBIG)us_tool, VTOOL);
-		(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflags,
-			us_useroptions & ~HIDEATTRIBUTES, VINTEGER);
-		endobjectchange((INTBIG)us_tool, VTOOL);
-		return;
-	}
-
 	if (namesamen(pp, "split", l) == 0 && l >= 2)
 	{
 		if (us_needwindow()) return;
@@ -1077,7 +1068,7 @@ void us_window(INTSML count, char *par[])
 		}
 
 		/* split the window */
-		(void)us_splitcurrentwindow(splitkey, 1, 0);
+		(void)us_splitcurrentwindow(splitkey, TRUE, 0);
 		return;
 	}
 
@@ -1092,7 +1083,7 @@ void us_window(INTSML count, char *par[])
 				if (sf == 0) continue;
 				if (sf->line == 0)
 					ttyputmsg(M_("Window title has %s"), us_statusfields[i].fieldaddr); else
-						ttyputmsg(M_("Line %d from %3d%% to %3d%% is %s"), sf->line, sf->startper,
+						ttyputmsg(M_("Line %ld from %3ld%% to %3ld%% is %s"), sf->line, sf->startper,
 							sf->endper, us_statusfields[i].fieldaddr);
 			}
 			return;
@@ -1164,7 +1155,7 @@ void us_window(INTSML count, char *par[])
 			lineno = atoi(par[3]);
 			if (lineno < 0 || lineno > ttynumstatuslines())
 			{
-				us_abortcommand(_("Line number must range from 0 to %d"), ttynumstatuslines());
+				us_abortcommand(_("Line number must range from 0 to %ld"), ttynumstatuslines());
 				return;
 			}
 			startper = atoi(par[4]);
@@ -1176,7 +1167,7 @@ void us_window(INTSML count, char *par[])
 			endper = atoi(par[5]);
 			if (endper <= startper || endper > 100)
 			{
-				us_abortcommand(_("Ending percentage must range from %d to 100"), startper+1);
+				us_abortcommand(_("Ending percentage must range from %ld to 100"), startper+1);
 				return;
 			}
 			if (count == 7) fieldname = par[6]; else fieldname = "";
@@ -1198,19 +1189,19 @@ void us_window(INTSML count, char *par[])
 			if (namesamen(pp, "draw", l) == 0)
 			{
 				startobjectchange((INTBIG)us_tool, VTOOL);
-				(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflags,
+				(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflagskey,
 					us_useroptions | DRAWTINYFACETS, VINTEGER);
 				if (count >= 3)
 				{
 					i = atofr(par[2]);
-					(void)setvalkey((INTBIG)us_tool, VTOOL, us_tinylambdaperpixel,
+					(void)setvalkey((INTBIG)us_tool, VTOOL, us_tinylambdaperpixelkey,
 						i, VFRACT);
 				}
 				endobjectchange((INTBIG)us_tool, VTOOL);
 			} else if (namesamen(pp, "hash-out", l) == 0)
 			{
 				startobjectchange((INTBIG)us_tool, VTOOL);
-				(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflags,
+				(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflagskey,
 					us_useroptions & ~DRAWTINYFACETS, VINTEGER);
 				endobjectchange((INTBIG)us_tool, VTOOL);
 			} else
@@ -1258,7 +1249,7 @@ void us_window(INTSML count, char *par[])
 		{
 			x = ((INTBIG *)var->addr)[i*2];
 			y = ((INTBIG *)var->addr)[i*2+1];
-			nogood += us_setxy((INTSML)x, (INTSML)y);
+			if (us_setxy(x, y)) nogood++;
 			(void)getxy(&xcur, &ycur);
 			if (i == 0)
 			{
@@ -1280,7 +1271,7 @@ void us_window(INTSML count, char *par[])
 		us_clearhighlightcount();
 
 		/* set the new window size */
-		us_squarescreen(el_curwindowpart, NOWINDOWPART, 0, &lx, &hx, &ly, &hy);
+		us_squarescreen(el_curwindowpart, NOWINDOWPART, FALSE, &lx, &hx, &ly, &hy, 0);
 
 		startobjectchange((INTBIG)el_curwindowpart, VWINDOWPART);
 		(void)setval((INTBIG)el_curwindowpart, VWINDOWPART, "screenlx", lx, VINTEGER);
@@ -1291,7 +1282,7 @@ void us_window(INTSML count, char *par[])
 		endobjectchange((INTBIG)el_curwindowpart, VWINDOWPART);
 
 		/* restore highlighting */
-		(void)us_pophighlight(0);
+		us_pophighlight(FALSE);
 		return;
 	}
 
@@ -1318,9 +1309,7 @@ void us_window(INTSML count, char *par[])
 				newpar[0] = "window";
 				newpar[1] = "move";
 				newpar[2] = "up";
-				sprintf(line, "%ld", (INTBIG)(atof(pp)*20.0));
-				newpar[3] = line;
-				(void)telltool(sim_tool, 4, newpar);
+				telltool(sim_tool, 3, newpar);
 				return;
 #endif
 			case EXPLORERWINDOW:
@@ -1356,7 +1345,7 @@ void us_window(INTSML count, char *par[])
 			us_abortcommand(_("No window named '%s'"), par[1]);
 			return;
 		}
-		(void)setvalkey((INTBIG)us_tool, VTOOL, us_current_window, (INTBIG)w, VWINDOWPART|VDONTSAVE);
+		(void)setvalkey((INTBIG)us_tool, VTOOL, us_current_window_key, (INTBIG)w, VWINDOWPART|VDONTSAVE);
 		(void)setval((INTBIG)el_curlib, VLIBRARY, "curnodeproto", (INTBIG)w->curnodeproto, VNODEPROTO);
 		return;
 	}
@@ -1398,7 +1387,8 @@ void us_window(INTSML count, char *par[])
 		/* turn off highlighting */
 		us_pushhighlight();
 		us_clearhighlightcount();
-		(void)setvalkey((INTBIG)us_tool, VTOOL, us_current_window, (INTBIG)NOWINDOWPART, VWINDOWPART|VDONTSAVE);
+		(void)setvalkey((INTBIG)us_tool, VTOOL, us_current_window_key, (INTBIG)NOWINDOWPART,
+			VWINDOWPART|VDONTSAVE);
 
 		startobjectchange((INTBIG)us_tool, VTOOL);
 
@@ -1427,12 +1417,13 @@ void us_window(INTSML count, char *par[])
 		}
 
 		/* set the window extents */
-		us_windowfit(NOWINDOWFRAME, 0, 1);
+		us_windowfit(NOWINDOWFRAME, FALSE, 1);
 		endobjectchange((INTBIG)us_tool, VTOOL);
 
 		/* restore highlighting */
-		(void)setvalkey((INTBIG)us_tool, VTOOL, us_current_window, (INTBIG)neww, VWINDOWPART|VDONTSAVE);
-		(void)us_pophighlight(0);
+		(void)setvalkey((INTBIG)us_tool, VTOOL, us_current_window_key, (INTBIG)neww,
+			VWINDOWPART|VDONTSAVE);
+		us_pophighlight(FALSE);
 		return;
 	}
 
@@ -1446,7 +1437,7 @@ void us_window(INTSML count, char *par[])
 			return;
 		}
 
-		l = (INTSML)strlen(pp = par[1]);
+		l = strlen(pp = par[1]);
 		if (namesamen(pp, "begin", l) == 0 && l >= 1)
 		{
 			if ((w->state&WINDOWTYPE) == DISP3DWINDOW)
@@ -1469,7 +1460,7 @@ void us_window(INTSML count, char *par[])
 
 			/* make the facet fill the window */
 			us_fullview(np, &lx, &hx, &ly, &hy);
-			us_squarescreen(w, NOWINDOWPART, 0, &lx, &hx, &ly, &hy);
+			us_squarescreen(w, NOWINDOWPART, FALSE, &lx, &hx, &ly, &hy, 0);
 
 			/* set the window extents */
 			startobjectchange((INTBIG)w, VWINDOWPART);
@@ -1501,7 +1492,7 @@ void us_window(INTSML count, char *par[])
 			/* set the window extents */
 			lx = w->screenlx;   hx = w->screenhx;
 			ly = w->screenly;   hy = w->screenhy;
-			us_squarescreen(w, NOWINDOWPART, 0, &lx, &hx, &ly, &hy);
+			us_squarescreen(w, NOWINDOWPART, FALSE, &lx, &hx, &ly, &hy, 0);
 			startobjectchange((INTBIG)w, VWINDOWPART);
 			(void)setval((INTBIG)w, VWINDOWPART, "state", (w->state & ~WINDOWTYPE) | DISPWINDOW,
 				VINTEGER);
@@ -1535,14 +1526,15 @@ void us_window(INTSML count, char *par[])
 	ttyputbadusage("window");
 }
 
-void us_yanknode(INTSML count, char *par[])
+void us_yanknode(INTBIG count, char *par[])
 {
-	REGISTER INTSML found, total;
+	REGISTER BOOLEAN found;
+	REGISTER INTBIG total;
 	REGISTER NODEINST *topno;
 	REGISTER NODEPROTO *np;
 	REGISTER GEOM **list;
 
-	list = us_gethighlighted(OBJNODEINST, 0, 0);
+	list = us_gethighlighted(WANTNODEINST, 0, 0);
 	if (list[0] == NOGEOM)
 	{
 		us_abortcommand(_("Must highlight facet(s) to be yanked"));
@@ -1550,22 +1542,22 @@ void us_yanknode(INTSML count, char *par[])
 	}
 
 	np = geomparent(list[0]);
-	found = 0;
+	found = FALSE;
 	for(total=0; list[total] != NOGEOM; total++)
 	{
 		topno = list[total]->entryaddr.ni;
 		if (topno->proto->primindex != 0) continue;
 
 		/* disallow yanking if lock is on */
-		if (us_canedit(np, topno->proto, 1) != 0) return;
+		if (us_cantedit(np, topno->proto, TRUE)) return;
 
 		/* turn off highlighting for the first facet */
-		if (found == 0) us_clearhighlightcount();
+		if (!found) us_clearhighlightcount();
 
 		/* yank this facet */
 		us_yankonenode(topno);
-		found++;
+		found = TRUE;
 	}
 
-	if (found == 0) us_abortcommand(_("Can only yank facets"));
+	if (!found) us_abortcommand(_("Can only yank facets"));
 }
