@@ -45,11 +45,11 @@
 
 /* prototypes for local routines */
 static PORTPROTO *us_convport(NODEINST*, NODEINST*, PORTPROTO*);
-static void       us_dumpfields(char***, INTSML, INTSML, FILE*, char*);
+static void       us_dumpfields(char***, INTBIG, INTBIG, FILE*, char*);
 static ARCPROTO  *us_figurenewaproto(ARCPROTO*, TECHNOLOGY*);
 static NODEPROTO *us_figurenewnproto(NODEINST*, TECHNOLOGY*);
 static PORTPROTO *us_tranconvpp(NODEINST*, PORTPROTO*);
-static PORTPROTO *us_trangetproto(NODEINST*, INTSML);
+static PORTPROTO *us_trangetproto(NODEINST*, INTBIG);
 static INTBIG     us_tranismos(NODEINST*);
 static void       us_tranplacenode(NODEINST*, NODEPROTO*, NODEPROTO*, TECHNOLOGY*, TECHNOLOGY*);
 static NODEPROTO *us_tran_linkage(char*, VIEW*, NODEPROTO*);
@@ -57,7 +57,7 @@ static void       us_tran_logmakearcs(NODEPROTO*, NODEPROTO*);
 static NODEINST  *us_tran_logmakenode(NODEPROTO*, NODEINST*, INTSML, INTSML, NODEPROTO*, TECHNOLOGY*);
 static void       us_tran_logmakenodes(NODEPROTO*, NODEPROTO*, TECHNOLOGY*);
 static NODEPROTO *us_tran_makelayoutfacets(NODEPROTO*, char*, TECHNOLOGY*, TECHNOLOGY*, VIEW*);
-static INTSML     us_tran_makelayoutparts(NODEPROTO*, NODEPROTO*, TECHNOLOGY*, TECHNOLOGY*, VIEW*);
+static BOOLEAN    us_tran_makelayoutparts(NODEPROTO*, NODEPROTO*, TECHNOLOGY*, TECHNOLOGY*, VIEW*);
 static void       us_tran_makemanhattan(NODEPROTO*);
 
 /*
@@ -152,7 +152,7 @@ NODEPROTO *us_tran_linkage(char *newfacetname, VIEW *newfacetview, NODEPROTO *fa
 		(void)addtoinfstr('}');
 		facetname = returninfstr();
 	}
-	newfacet = newnodeproto(facetname, facet->cell->lib);
+	newfacet = us_newnodeproto(facetname, facet->cell->lib);
 	if (newfacet == NONODEPROTO)
 		ttyputmsg(_("Could not create facet: %s"), facetname); else
 			ttyputmsg(_("Creating new facet: %s"), facetname);
@@ -170,7 +170,7 @@ void us_tran_logmakenodes(NODEPROTO *facet, NODEPROTO *newfacet, TECHNOLOGY *new
 	REGISTER PORTARCINST *pi;
 	REGISTER VARIABLE *var;
 	INTSML rotate, trans;
-	INTBIG type, len, wid, lambda, xoff, yoff;
+	INTBIG type, len, wid, lambda, xoff, yoff, i, size;
 	UINTBIG descript[TEXTDESCRIPTSIZE];
 
 	/*
@@ -244,26 +244,34 @@ void us_tran_logmakenodes(NODEPROTO *facet, NODEPROTO *newfacet, TECHNOLOGY *new
 					{
 						/* set length/width */
 						us_getlenwidoffset(schemni, descript, &xoff, &yoff);
-						var = setvalkey((INTBIG)schemni, VNODEINST, el_attr_length,
+						var = setvalkey((INTBIG)schemni, VNODEINST, el_attrkey_length,
 							len*WHOLE/lambda, VFRACT|VDISPLAY);
 						if (var != NOVARIABLE)
+						{
+							TDCOPY(var->textdescript, descript);
+							size = TDGETSIZE(var->textdescript);
+							i = TXTGETPOINTS(size);
+							if (i > 3) size = TXTSETPOINTS(i-2); else
+							{
+								i = TXTGETQLAMBDA(size);
+								if (i > 3) size = TXTSETQLAMBDA(i-2);
+							}
+							TDSETSIZE(var->textdescript, size);
+							TDSETOFF(var->textdescript, TDGETXOFF(descript)-xoff,
+								TDGETYOFF(descript)-yoff);
+						}
+						var = setvalkey((INTBIG)schemni, VNODEINST, el_attrkey_width,
+							wid*WHOLE/lambda, VFRACT|VDISPLAY);
+						if (var != NOVARIABLE)
 						{
 							TDCOPY(var->textdescript, descript);
 							TDSETOFF(var->textdescript, TDGETXOFF(descript)+xoff,
 								TDGETYOFF(descript)+yoff);
 						}
-						var = setvalkey((INTBIG)schemni, VNODEINST, el_attr_width,
-							wid*WHOLE/lambda, VFRACT|VDISPLAY);
-						if (var != NOVARIABLE)
-						{
-							TDCOPY(var->textdescript, descript);
-							TDSETOFF(var->textdescript, TDGETXOFF(descript)-xoff,
-								TDGETYOFF(descript)-yoff);
-						}
 					} else
 					{
 						/* set area */
-						var = setvalkey((INTBIG)schemni, VNODEINST, el_attr_area,
+						var = setvalkey((INTBIG)schemni, VNODEINST, el_attrkey_area,
 							len*WHOLE/lambda, VFRACT|VDISPLAY);
 						if (var != NOVARIABLE)
 							TDCOPY(var->textdescript, descript);
@@ -286,7 +294,7 @@ void us_tran_logmakenodes(NODEPROTO *facet, NODEPROTO *newfacet, TECHNOLOGY *new
 				pp2->userbits = (pp2->userbits & ~STATEBITS) |
 					(pexp->exportproto->userbits & STATEBITS);
 				TDCOPY(pp2->textdescript, pexp->exportproto->textdescript);
-				if (copyvars((INTBIG)pexp->exportproto, VPORTPROTO, (INTBIG)pp2, VPORTPROTO) != 0)
+				if (copyvars((INTBIG)pexp->exportproto, VPORTPROTO, (INTBIG)pp2, VPORTPROTO))
 					return;
 			}
 			endobjectchange((INTBIG)schemni, VNODEINST);
@@ -359,7 +367,7 @@ void us_tran_makemanhattan(NODEPROTO *newfacet)
 	REGISTER NODEINST *ni;
 	REGISTER PORTARCINST *pi;
 	REGISTER ARCINST *ai;
-	REGISTER INTSML e, count, i, j;
+	REGISTER INTBIG e, count, i, j;
 	REGISTER INTBIG dist, bestdist, bestx, besty, xp, yp;
 	INTBIG x[MAXADJUST], y[MAXADJUST];
 
@@ -407,7 +415,7 @@ PORTPROTO *us_tranconvpp(NODEINST *ni, PORTPROTO *mospp)
 {
 	PORTPROTO *schempp, *pp;
 	NODEINST *schemni;
-	INTSML port;
+	INTBIG port;
 
 	schemni = (NODEINST *)ni->temp1;
 
@@ -467,10 +475,10 @@ INTBIG us_tranismos(NODEINST *ni)
 	return(NPUNKNOWN);
 }
 
-PORTPROTO *us_trangetproto(NODEINST *ni, INTSML port)
+PORTPROTO *us_trangetproto(NODEINST *ni, INTBIG port)
 {
 	PORTPROTO *pp;
-	INTSML count = port, i;
+	INTBIG count = port, i;
 
 	if (count == 4) count = 3; else
 		if (count == 3) count = 1;
@@ -523,7 +531,7 @@ NODEPROTO *us_tran_makelayoutfacets(NODEPROTO *oldfacet, char *newfacetname,
 	/* create the facet and fill it with parts */
 	newfacet = us_tran_linkage(newfacetname, nview, oldfacet);
 	if (newfacet == NONODEPROTO) return(NONODEPROTO);
-	if (us_tran_makelayoutparts(oldfacet, newfacet, oldtech, newtech, nview) != 0)
+	if (us_tran_makelayoutparts(oldfacet, newfacet, oldtech, newtech, nview))
 	{
 		/* adjust for maximum Manhattan-ness */
 		us_tran_makemanhattan(newfacet);
@@ -534,7 +542,7 @@ NODEPROTO *us_tran_makelayoutfacets(NODEPROTO *oldfacet, char *newfacetname,
 			bits = us_makearcuserbits(ai->proto);
 			if ((bits&FIXED) != 0) ai->userbits |= FIXED;
 			if ((bits&FIXANG) != 0) ai->userbits |= FIXANG;
-			(void)setshrinkvalue(ai, 0);
+			(void)setshrinkvalue(ai, FALSE);
 		}
 	}
 
@@ -546,7 +554,7 @@ NODEPROTO *us_tran_makelayoutfacets(NODEPROTO *oldfacet, char *newfacetname,
  * in "oldfacet".  The technology for the old facet is "oldtech" and the
  * technology to use for the new facet is "newtech".
  */
-INTSML us_tran_makelayoutparts(NODEPROTO *oldfacet, NODEPROTO *newfacet,
+BOOLEAN us_tran_makelayoutparts(NODEPROTO *oldfacet, NODEPROTO *newfacet,
 	TECHNOLOGY *oldtech, TECHNOLOGY *newtech, VIEW *nview)
 {
 	REGISTER NODEPROTO *newnp;
@@ -556,7 +564,8 @@ INTSML us_tran_makelayoutparts(NODEPROTO *oldfacet, NODEPROTO *newfacet,
 	REGISTER PORTPROTO *mospp1, *mospp2, *schempp1, *schempp2;
 	INTBIG x1, y1, x2, y2, lx1, hx1, ly1, hy1, lx2, hx2, ly2, hy2, tx1, ty1, tx2, ty2;
 	REGISTER INTBIG newwid, newbits, oldlambda, newlambda;
-	REGISTER INTSML badarcs, i, j, univarcs;
+	REGISTER INTBIG badarcs, i, j;
+	REGISTER BOOLEAN univarcs;
 	static POLYGON *poly1 = NOPOLYGON, *poly2 = NOPOLYGON;
 
 	/* get a polygon */
@@ -568,6 +577,8 @@ INTSML us_tran_makelayoutparts(NODEPROTO *oldfacet, NODEPROTO *newfacet,
 	newlambda = el_curlib->lambda[newtech->techindex];
 
 	/* first convert the nodes */
+	for(ni = oldfacet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+		ni->temp1 = 0;
 	for(ni = oldfacet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		/* handle sub-facets */
@@ -575,7 +586,7 @@ INTSML us_tran_makelayoutparts(NODEPROTO *oldfacet, NODEPROTO *newfacet,
 		{
 			for(newnp = ni->proto->cell->firstincell; newnp != NONODEPROTO; newnp = newnp->nextincell)
 				if (newnp->cellview == nview) break;
-			if (newnp != NONODEPROTO)
+			if (newnp == NONODEPROTO)
 			{
 				ttyputerr(_("No equivalent facet for %s"), describenodeproto(ni->proto));
 				continue;
@@ -593,7 +604,8 @@ INTSML us_tran_makelayoutparts(NODEPROTO *oldfacet, NODEPROTO *newfacet,
 	 * for each arc in facet, find the ends in the new technology, and
 	 * make a new arc to connect them in the new facet
 	 */
-	badarcs = univarcs = 0;
+	badarcs = 0;
+	univarcs = FALSE;
 	for(ai = oldfacet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 	{
 		/* get the nodes and ports on the two ends of the arc */
@@ -635,7 +647,7 @@ INTSML us_tran_makelayoutparts(NODEPROTO *oldfacet, NODEPROTO *newfacet,
 		if (newap == gen_universalarc)
 		{
 			newwid = 0;
-			univarcs++;
+			univarcs = TRUE;
 			newbits &= ~(FIXED | FIXANG);
 		} else
 		{
@@ -647,13 +659,13 @@ INTSML us_tran_makelayoutparts(NODEPROTO *oldfacet, NODEPROTO *newfacet,
 		/* find the endpoints of the arc */
 		x1 = muldiv(ai->end[0].xpos, newlambda, oldlambda);
 		y1 = muldiv(ai->end[0].ypos, newlambda, oldlambda);
-		shapeportpoly(end1, schempp1, poly1, 0);
+		shapeportpoly(end1, schempp1, poly1, FALSE);
 		x2 = muldiv(ai->end[1].xpos, newlambda, oldlambda);
 		y2 = muldiv(ai->end[1].ypos, newlambda, oldlambda);
-		shapeportpoly(end2, schempp2, poly2, 0);
+		shapeportpoly(end2, schempp2, poly2, FALSE);
 
 		/* see if the new arc can connect without end adjustment */
-		if (isinside(x1, y1, poly1) == 0 || isinside(x2, y2, poly2) == 0)
+		if (!isinside(x1, y1, poly1) || !isinside(x2, y2, poly2))
 		{
 			/* arc cannot be run exactly ... presume port centers */
 			portposition(end1, schempp1, &x1, &y1);
@@ -661,12 +673,12 @@ INTSML us_tran_makelayoutparts(NODEPROTO *oldfacet, NODEPROTO *newfacet,
 			if ((newbits & FIXANG) != 0)
 			{
 				/* old arc was fixed-angle so look for a similar-angle path */
-				reduceportpoly(poly1, end1, schempp1, newwid-arcprotowidthoffset(newap));
+				reduceportpoly(poly1, end1, schempp1, newwid-arcprotowidthoffset(newap), -1);
 				getbbox(poly1, &lx1, &hx1, &ly1, &hy1);
-				reduceportpoly(poly2, end2, schempp2, newwid-arcprotowidthoffset(newap));
+				reduceportpoly(poly2, end2, schempp2, newwid-arcprotowidthoffset(newap), -1);
 				getbbox(poly2, &lx2, &hx2, &ly2, &hy2);
-				if (arcconnects((INTSML)(((ai->userbits&AANGLE) >> AANGLESH) * 10), lx1, hx1, ly1, hy1,
-					lx2, hx2, ly2, hy2, &tx1, &ty1, &tx2, &ty2) == 0) badarcs++; else
+				if (!arcconnects(((ai->userbits&AANGLE) >> AANGLESH) * 10, lx1, hx1, ly1, hy1,
+					lx2, hx2, ly2, hy2, &tx1, &ty1, &tx2, &ty2)) badarcs++; else
 				{
 					x1 = tx1;   y1 = ty1;
 					x2 = tx2;   y2 = ty2;
@@ -687,7 +699,7 @@ INTSML us_tran_makelayoutparts(NODEPROTO *oldfacet, NODEPROTO *newfacet,
 
 	/* print warning if arcs were made nonmanhattan */
 	if (badarcs != 0)
-		ttyputmsg(_("WARNING: %d %s made not-fixed-angle in facet %s"), badarcs,
+		ttyputmsg(_("WARNING: %ld %s made not-fixed-angle in facet %s"), badarcs,
 			makeplural(_("arc"), badarcs), describenodeproto(newfacet));
 	return(univarcs);
 }
@@ -695,11 +707,11 @@ INTSML us_tran_makelayoutparts(NODEPROTO *oldfacet, NODEPROTO *newfacet,
 void us_tranplacenode(NODEINST *ni, NODEPROTO *newnp, NODEPROTO *newfacet,
 	TECHNOLOGY *oldtech, TECHNOLOGY *newtech)
 {
-	INTBIG lx, ly, hx, hy, nlx, nly, nhx, nhy, bx, by;
-	REGISTER INTBIG newsx, newsy, x1, y1, newlx, newhx, newly, newhy, *newtrace,
+	INTBIG lx, ly, hx, hy, nlx, nly, nhx, nhy, bx, by, length, width;
+	REGISTER INTBIG i, len, newsx, newsy, x1, y1, newlx, newhx, newly, newhy, *newtrace,
 		oldlambda, newlambda;
 	XARRAY trans;
-	REGISTER INTSML i, len, trn;
+	REGISTER INTSML trn;
 	REGISTER PORTEXPINST *pexp;
 	REGISTER NODEINST *newni;
 	REGISTER PORTPROTO *pp, *pp2;
@@ -718,13 +730,13 @@ void us_tranplacenode(NODEINST *ni, NODEPROTO *newnp, NODEPROTO *newfacet,
 		/* special case for schematic transistors: get size from description */
 		if (((ni->proto->userbits&NFUNCTION) >> NFUNCTIONSH) == NPTRANS)
 		{
-			transistorsize(ni, &bx, &by);
-			if (bx < 0) bx = newnp->highx - newnp->lowx - nlx - nhx;
-			if (by < 0) by = newnp->highy - newnp->lowy - nly - nhy;
-			lx = (ni->lowx + ni->highx - bx) / 2;
-			hx = (ni->lowx + ni->highx + bx) / 2;
-			ly = (ni->lowy + ni->highy - by) / 2;
-			hy = (ni->lowy + ni->highy + by) / 2;
+			transistorsize(ni, &length, &width);
+			if (length < 0) length = newnp->highy - newnp->lowy - nly - nhy;
+			if (width < 0) width = newnp->highx - newnp->lowx - nlx - nhx;
+			lx = (ni->lowx + ni->highx - width) / 2;
+			hx = (ni->lowx + ni->highx + width) / 2;
+			ly = (ni->lowy + ni->highy - length) / 2;
+			hy = (ni->lowy + ni->highy + length) / 2;
 			trn = 1 - trn;
 
 			/* compute scaled size for new node */
@@ -773,12 +785,12 @@ void us_tranplacenode(NODEINST *ni, NODEPROTO *newnp, NODEPROTO *newfacet,
 	var = gettrace(ni);
 	if (var != NOVARIABLE)
 	{
-		len = (INTSML)getlength(var);
+		len = getlength(var);
 		newtrace = emalloc((len * SIZEOFINTBIG), el_tempcluster);
 		if (newtrace == 0) return;
 		for(i=0; i<len; i++)
 			newtrace[i] = muldiv(((INTBIG *)var->addr)[i], newlambda, oldlambda);
-		(void)setvalkey((INTBIG)newni, VNODEINST, el_trace, (INTBIG)newtrace,
+		(void)setvalkey((INTBIG)newni, VNODEINST, el_trace_key, (INTBIG)newtrace,
 			VINTEGER|VISARRAY|(len<<VLENGTHSH));
 		efree((char *)newtrace);
 	}
@@ -791,7 +803,7 @@ void us_tranplacenode(NODEINST *ni, NODEPROTO *newnp, NODEPROTO *newfacet,
 		if (pp2 == NOPORTPROTO) return;
 		pp2->userbits = (pp2->userbits & ~STATEBITS) | (pexp->exportproto->userbits & STATEBITS);
 		TDCOPY(pp2->textdescript, pexp->exportproto->textdescript);
-		if (copyvars((INTBIG)pexp->exportproto, VPORTPROTO, (INTBIG)pp2, VPORTPROTO) != 0)
+		if (copyvars((INTBIG)pexp->exportproto, VPORTPROTO, (INTBIG)pp2, VPORTPROTO))
 			return;
 	}
 }
@@ -803,7 +815,7 @@ void us_tranplacenode(NODEINST *ni, NODEPROTO *newnp, NODEPROTO *newfacet,
 PORTPROTO *us_convport(NODEINST *ni, NODEINST *newni, PORTPROTO *oldpp)
 {
 	REGISTER PORTPROTO *pp, *npp;
-	REGISTER INTSML oldfun, newfun;
+	REGISTER INTBIG oldfun, newfun;
 
 	if (newni->proto->primindex == 0)
 	{
@@ -813,8 +825,8 @@ PORTPROTO *us_convport(NODEINST *ni, NODEINST *newni, PORTPROTO *oldpp)
 	}
 
 	/* if functions are different, handle some special cases */
-	oldfun = (INTSML)((ni->proto->userbits&NFUNCTION) >> NFUNCTIONSH);
-	newfun = (INTSML)((newni->proto->userbits&NFUNCTION) >> NFUNCTIONSH);
+	oldfun = (ni->proto->userbits&NFUNCTION) >> NFUNCTIONSH;
+	newfun = (newni->proto->userbits&NFUNCTION) >> NFUNCTIONSH;
 	if (oldfun != newfun)
 	{
 		if (oldfun == NPTRANS && isfet(newni->geom))
@@ -914,7 +926,7 @@ NODEPROTO *us_figurenewnproto(NODEINST *oldni, TECHNOLOGY *newtech)
 
 	/* see if one node in the new technology has the same function */
 	for(i = 0, np = newtech->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-		if ((INTSML)((np->userbits&NFUNCTION) >> NFUNCTIONSH) == type)
+		if ((INTBIG)((np->userbits&NFUNCTION) >> NFUNCTIONSH) == type)
 	{
 		rnp = np;   i++;
 	}
@@ -925,7 +937,7 @@ NODEPROTO *us_figurenewnproto(NODEINST *oldni, TECHNOLOGY *newtech)
 	{
 		for(np = newtech->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 		{
-			if ((INTSML)((np->userbits&NFUNCTION) >> NFUNCTIONSH) != type) continue;
+			if ((INTBIG)((np->userbits&NFUNCTION) >> NFUNCTIONSH) != type) continue;
 
 			/* see if this node has equivalent arcs */
 			for(j=0; oldnp->firstportproto->connects[j] != NOARCPROTO; j++)
@@ -967,7 +979,6 @@ NODEPROTO *us_figurenewnproto(NODEINST *oldni, TECHNOLOGY *newtech)
 
 extern LIST us_teclayer_functions[];
 extern LIST us_tecarc_functions[];
-extern LIST us_tecnode_functions[];
 
 #define MAXCOLS 10
 
@@ -979,7 +990,7 @@ void us_printtechnology(TECHNOLOGY *tech)
 		**funcs, **layers, **layersizes, **extensions, **angles, **wipes, **ports,
 		**portsizes, **portangles, **connections;
 	REGISTER INTBIG i, j, k, l, m, tot, base;
-	REGISTER INTSML saveunit;
+	REGISTER INTBIG saveunit;
 	REGISTER INTBIG func, area, bits, lambda;
 	INTBIG lx, hx, ly, hy;
 	REGISTER ARCINST *ai;
@@ -1041,7 +1052,7 @@ void us_printtechnology(TECHNOLOGY *tech)
 		(void)allocstring(&names[i+1], layername(tech, i), el_tempcluster);
 
 		gra = tech->layers[i];
-		if (ecolorname(gra->col, &fieldname, &colorsymbol) != 0) fieldname = "?";
+		if (ecolorname(gra->col, &fieldname, &colorsymbol)) fieldname = "?";
 		(void)allocstring(&colors[i+1], fieldname, el_tempcluster);
 
 		if (el_curwindowpart == NOWINDOWPART) fieldname = "unkwn."; else
@@ -1080,7 +1091,7 @@ void us_printtechnology(TECHNOLOGY *tech)
 	/* write the layer information */
 	fields[0] = names;   fields[1] = colors;   fields[2] = styles;
 	fields[3] = cifs;    fields[4] = gdss;     fields[5] = funcs;
-	us_dumpfields(fields, 6, (INTSML)(tech->layercount+1), f, "LAYERS");
+	us_dumpfields(fields, 6, tech->layercount+1, f, "LAYERS");
 	for(i=0; i<=tech->layercount; i++)
 	{
 		efree(names[i]);
@@ -1137,7 +1148,7 @@ void us_printtechnology(TECHNOLOGY *tech)
 	{
 		(void)allocstring(&names[tot], ap->protoname, el_tempcluster);
 
-		var = getvalkey((INTBIG)ap, VARCPROTO, VINTEGER, us_arcstyle);
+		var = getvalkey((INTBIG)ap, VARCPROTO, VINTEGER, us_arcstylekey);
 		if (var != NOVARIABLE) bits = var->addr; else
 			bits = ap->userbits;
 		if ((bits&WANTNOEXTEND) == 0) fieldname = "yes"; else fieldname = "no";
@@ -1184,7 +1195,7 @@ void us_printtechnology(TECHNOLOGY *tech)
 	fields[0] = names;        fields[1] = layers;   fields[2] = layersizes;
 	fields[3] = extensions;   fields[4] = angles;   fields[5] = wipes;
 	fields[6] = funcs;
-	us_dumpfields(fields, 7, (INTSML)tot, f, "ARCS");
+	us_dumpfields(fields, 7, tot, f, "ARCS");
 	for(i=0; i<tot; i++)
 	{
 		efree(names[i]);
@@ -1222,7 +1233,7 @@ void us_printtechnology(TECHNOLOGY *tech)
 			if (m == 0) m = 1;
 			l += m;
 		}
-		tot += (INTSML)maxi(j, l);
+		tot += maxi(j, l);
 	}
 	names = (char **)emalloc(tot * (sizeof (char *)), el_tempcluster);
 	funcs = (char **)emalloc(tot * (sizeof (char *)), el_tempcluster);
@@ -1252,7 +1263,7 @@ void us_printtechnology(TECHNOLOGY *tech)
 		(void)allocstring(&names[tot], np->primname, el_tempcluster);
 
 		func = (np->userbits&NFUNCTION) >> NFUNCTIONSH;
-		(void)allocstring(&funcs[tot], us_tecnode_functions[func].name, el_tempcluster);
+		(void)allocstring(&funcs[tot], nodefunctionname(func, NONODEINST), el_tempcluster);
 
 		ni->proto = np;
 		ni->lowx = np->lowx;   ni->highx = np->highx;
@@ -1292,9 +1303,9 @@ void us_printtechnology(TECHNOLOGY *tech)
 		for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		{
 			(void)allocstring(&ports[base], pp->protoname, el_tempcluster);
-			shapeportpoly(ni, pp, poly, 0);
+			shapeportpoly(ni, pp, poly, FALSE);
 			getbbox(poly, &lx, &hx, &ly, &hy);
-			saveunit = (INTSML)(el_curtech->userbits & DISPLAYUNITS);
+			saveunit = el_curtech->userbits & DISPLAYUNITS;
 			el_units = (el_units & ~DISPLAYUNITS) | DISPUNITMIC;
 			(void)sprintf(thefield, "%s x %s", latoa(hx-lx), latoa(hy-ly));
 			(void)allocstring(&portsizes[base], thefield, el_tempcluster);
@@ -1338,7 +1349,7 @@ void us_printtechnology(TECHNOLOGY *tech)
 	fields[0] = names;        fields[1] = funcs;    fields[2] = layers;
 	fields[3] = layersizes;   fields[4] = ports;    fields[5] = portsizes;
 	fields[6] = portangles;   fields[7] = connections;
-	us_dumpfields(fields, 8, (INTSML)tot, f, "NODES");
+	us_dumpfields(fields, 8, tot, f, "NODES");
 	for(i=0; i<tot; i++)
 	{
 		efree(names[i]);
@@ -1362,10 +1373,10 @@ void us_printtechnology(TECHNOLOGY *tech)
 	xclose(f);
 }
 
-void us_dumpfields(char ***fields, INTSML count, INTSML length, FILE *f, char *title)
+void us_dumpfields(char ***fields, INTBIG count, INTBIG length, FILE *f, char *title)
 {
-	INTSML widths[MAXCOLS];
-	REGISTER INTSML len, i, j, k, totwid, stars;
+	INTBIG widths[MAXCOLS];
+	REGISTER INTBIG len, i, j, k, totwid, stars;
 
 	totwid = 0;
 	for(i=0; i<count; i++)
