@@ -105,18 +105,18 @@
 extern GRAPHICS us_ebox, us_menutext, us_menufigs;
 
 INTBIG          us_lastemacschar;		/* state of last character typed */
-static INTSML   us_twid, us_thei;		/* size of a single letter */
+static INTBIG   us_twid, us_thei;		/* size of a single letter */
 static INTBIG   us_editemacsfont;		/* font size for editor */
 static char    *us_killbuf;				/* saved line when ^K is done */
 static INTBIG   us_killbufchars = 0;	/* characters in kill buffer */
 static char    *us_searchbuf = 0;		/* search string for ^S and ^R */
 
 /* prototypes for local routines */
-static void us_editemacsgotbutton(WINDOWPART*, INTSML, INTSML, INTSML);
+static void us_editemacsgotbutton(WINDOWPART*, INTBIG, INTBIG, INTBIG);
 static void us_editemacsredraweditor(WINDOWPART*);
-static INTSML us_editemacsimplementchar(WINDOWPART*, INTBIG, INTSML, INTSML);
-static INTSML us_editemacsbackupchar(WINDOWPART*, INTSML);
-static INTSML us_editemacsadvancechar(WINDOWPART*, INTSML);
+static BOOLEAN us_editemacsimplementchar(WINDOWPART*, INTBIG, BOOLEAN, BOOLEAN);
+static BOOLEAN us_editemacsbackupchar(WINDOWPART*, BOOLEAN);
+static BOOLEAN us_editemacsadvancechar(WINDOWPART*, BOOLEAN);
 static void us_editemacsdeletechar(WINDOWPART*);
 static void us_editemacsshiftscreenup(WINDOWPART*);
 static void us_editemacsshiftscreendown(WINDOWPART*);
@@ -135,8 +135,8 @@ static void us_editemacsmovebox(WINDOWPART*, INTBIG, INTBIG, INTBIG, INTBIG, INT
 static void us_editemacsclearbox(WINDOWPART*, INTBIG, INTBIG, INTBIG, INTBIG);
 static void us_editemacsinvertbox(WINDOWPART*, INTBIG, INTBIG, INTBIG, INTBIG);
 static void us_editemacstext(WINDOWPART*, char*, INTBIG, INTBIG);
-static void us_editemacsdosearch(WINDOWPART *win, char *str, INTSML reverse,
-			INTSML fromtop, INTSML casesensitive, INTSML fromuser);
+static void us_editemacsdosearch(WINDOWPART *win, char *str, BOOLEAN reverse,
+			BOOLEAN fromtop, BOOLEAN casesensitive, BOOLEAN fromuser);
 
 /******************** INTERFACE FOR TEXT WINDOW ********************/
 
@@ -146,11 +146,11 @@ static void us_editemacsdosearch(WINDOWPART *win, char *str, INTSML reverse,
  * "header".  The number of characters and lines are placed in "chars" and
  * "lines".  Returns the window (NOWINDOWPART if the editor cannot be started).
  */
-WINDOWPART *us_editemacsmakeeditor(WINDOWPART *oriwin, char *header, INTSML *chars, INTSML *lines)
+WINDOWPART *us_editemacsmakeeditor(WINDOWPART *oriwin, char *header, INTBIG *chars, INTBIG *lines)
 {
 	INTBIG i, x, y;
 	UINTBIG descript[TEXTDESCRIPTSIZE];
-	INTSML swid, shei, pwid;
+	INTBIG swid, shei, pwid;
 	REGISTER EDITOR *e;
 	REGISTER VARIABLE *var;
 	REGISTER WINDOWPART *win;
@@ -176,10 +176,10 @@ WINDOWPART *us_editemacsmakeeditor(WINDOWPART *oriwin, char *header, INTSML *cha
 		/* create a window that covers the popup */
 		startobjectchange((INTBIG)us_tool, VTOOL);
 		win = newwindowpart("popup", el_curwindowpart);
-		win->uselx = (INTSML)maxi(x-200, 0);
-		win->usely = (INTSML)maxi(y-us_thei-1, 0);
-		win->usehx = (INTSML)mini(win->uselx+400, swid-1);
-		win->usehy = (INTSML)mini(win->usely+us_thei*(HEADERLINES+1)+3, shei-1);
+		win->uselx = maxi(x-200, 0);
+		win->usely = maxi(y-us_thei-1, 0);
+		win->usehx = mini(win->uselx+400, swid-1);
+		win->usehy = mini(win->usely+us_thei*(HEADERLINES+1)+3, shei-1);
 		win->screenlx = win->uselx;
 		win->screenhx = win->usehx;
 		win->screenly = win->usely;
@@ -249,7 +249,7 @@ WINDOWPART *us_editemacsmakeeditor(WINDOWPART *oriwin, char *header, INTSML *cha
 		e->textarray = (char **)emalloc((e->maxlines * (sizeof (char *))),
 			us_tool->cluster);
 		if (e->textarray == 0) ttyputnomemory();
-		e->maxchars = (INTSML *)emalloc((e->maxlines * SIZEOFINTSML), us_tool->cluster);
+		e->maxchars = (INTBIG *)emalloc((e->maxlines * SIZEOFINTBIG), us_tool->cluster);
 		if (e->maxchars == 0) ttyputnomemory();
 		us_editemacsgetbuffers(e);
 		for(i=0; i<e->maxlines; i++)
@@ -283,9 +283,9 @@ WINDOWPART *us_editemacsmakeeditor(WINDOWPART *oriwin, char *header, INTSML *cha
 	} else
 	{
 		/* finish initializing window if it is a new popup one */
-		e->savedbox = screensavebox(win, (INTSML)maxi(e->offx-2,0),
-			(INTSML)(e->offx+e->swid+2), (INTSML)maxi(e->revy-e->shei-2,0),
-				(INTSML)(e->revy+us_thei*HEADERLINES+1));
+		e->savedbox = screensavebox(win, maxi(e->offx-2,0),
+			e->offx+e->swid+2, maxi(e->revy-e->shei-2,0),
+				e->revy+us_thei*HEADERLINES+1);
 		endobjectchange((INTBIG)us_tool, VTOOL);
 	}
 	return(win);
@@ -355,10 +355,10 @@ void us_editemacsaddline(WINDOWPART *win, INTBIG lindex, char *str)
 	us_editemacsflashcursor(win);
 	savedchar = e->curchar;   savedline = e->curline;
 	e->curline = lindex;   e->curchar = 0;
-	(void)us_editemacsimplementchar(win, CTLO, 0, 0);
-	if (str[0] == 0) (void)us_editemacsimplementchar(win, ' ', 0, 0); else
+	(void)us_editemacsimplementchar(win, CTLO, FALSE, FALSE);
+	if (str[0] == 0) (void)us_editemacsimplementchar(win, ' ', FALSE, FALSE); else
 		for(pt = str; *pt != 0; pt++)
-			(void)us_editemacsimplementchar(win, *pt, 0, 0);
+			(void)us_editemacsimplementchar(win, *pt, FALSE, FALSE);
 	e->curchar = savedchar;   e->curline = savedline;
 	us_editemacsflashcursor(win);
 }
@@ -379,9 +379,9 @@ void us_editemacsreplaceline(WINDOWPART *win, INTBIG lindex, char *str)
 	if (e->curline == lindex) savedchar = 0;
 	e->curline = lindex;   e->curchar = 0;
 	if (e->textarray[lindex][0] != 0)
-		(void)us_editemacsimplementchar(win, CTLK, 0, 0);
+		(void)us_editemacsimplementchar(win, CTLK, FALSE, FALSE);
 	for(pt = str; *pt != 0; pt++)
-		(void)us_editemacsimplementchar(win, *pt, 0, 0);
+		(void)us_editemacsimplementchar(win, *pt, FALSE, FALSE);
 	e->curchar = savedchar;   e->curline = savedline;
 	us_editemacsflashcursor(win);
 }
@@ -401,8 +401,8 @@ void us_editemacsdeleteline(WINDOWPART *win, INTBIG lindex)
 	if (e->curline == lindex) { savedline++;   savedchar = 0; }
 	e->curline = lindex;   e->curchar = 0;
 	if (e->textarray[lindex][0] != 0)
-		(void)us_editemacsimplementchar(win, CTLK, 0, 0);
-	(void)us_editemacsimplementchar(win, CTLK, 0, 0);
+		(void)us_editemacsimplementchar(win, CTLK, FALSE, FALSE);
+	(void)us_editemacsimplementchar(win, CTLK, FALSE, FALSE);
 	e->curchar = savedchar;   e->curline = savedline;
 	us_editemacsflashcursor(win);
 }
@@ -521,7 +521,7 @@ void us_editemacsreadtextfile(WINDOWPART *win, char *file)
 	{
 		c = xgetc(f);
 		if (c == EOF) break;
-		(void)us_editemacsimplementchar(win, c&0177, 0, 0);
+		(void)us_editemacsimplementchar(win, c&0177, FALSE, FALSE);
 	}
 	xclose(f);
 
@@ -551,17 +551,17 @@ void us_editemacseditorterm(WINDOWPART *win)
 	us_editemacsshipchanges(win);
 	if ((win->state&WINDOWTYPE) == POPTEXTWINDOW)
 	{
-		(void)screenrestorebox(e->savedbox, 0);
+		screenrestorebox(e->savedbox, 0);
 	}
 }
 
-void us_editemacsgotbutton(WINDOWPART *win, INTSML but, INTSML x, INTSML y)
+void us_editemacsgotbutton(WINDOWPART *win, INTBIG but, INTBIG x, INTBIG y)
 {
 	REGISTER EDITOR *e;
 	REGISTER INTBIG xc, yc, len;
 
 	/* changes to the mouse-wheel are handled by the user interface */
-	if (wheelbutton(but) != 0)
+	if (wheelbutton(but))
 	{
 		us_buttonhandler(win, but, x, y);
 		return;
@@ -613,39 +613,39 @@ void us_editemacsredraweditor(WINDOWPART *win)
 /*
  * keyboard interrupt routine for the text window
  */
-INTSML us_editemacsgotchar(WINDOWPART *win, INTSML i)
+BOOLEAN us_editemacsgotchar(WINDOWPART *win, INTSML i, INTBIG special)
 {
 	REGISTER EDITOR *e;
 
 	e = win->editor;
-	if (e == NOEDITOR) return(1);
-	if ((i & 0200) != 0)
+	if (e == NOEDITOR) return(TRUE);
+	if ((special&ACCELERATORDOWN) != 0)
 	{
 		us_editemacsflashcursor(win);
 #ifndef MACOS
 		i = i - 'a' + CTLA;
-		if (us_editemacsimplementchar(win, i&0177, 0, 1) != 0) return(1);
+		if (us_editemacsimplementchar(win, i, FALSE, TRUE)) return(TRUE);
 #else
-		if (us_editemacsimplementchar(win, i&0177, 1, 1) != 0) return(1);
+		if (us_editemacsimplementchar(win, i, TRUE, TRUE)) return(TRUE);
 #endif
 		us_editemacsflashcursor(win);
 	} else
 	{
 		us_editemacsflashcursor(win);
-		if (us_editemacsimplementchar(win, i, 0, 1) != 0) return(1);
+		if (us_editemacsimplementchar(win, i, FALSE, TRUE)) return(TRUE);
 		us_editemacsflashcursor(win);
 	}
 	setactivity(_("EMACS Editing"));
-	return(0);
+	return(FALSE);
 }
 
-void us_editemacscut(WINDOWPART *w) { ttybeep(); }
+void us_editemacscut(WINDOWPART *w) { ttybeep(1); }
 
-void us_editemacscopy(WINDOWPART *w) { ttybeep(); }
+void us_editemacscopy(WINDOWPART *w) { ttybeep(1); }
 
-void us_editemacspaste(WINDOWPART *w) { ttybeep(); }
+void us_editemacspaste(WINDOWPART *w) { ttybeep(1); }
 
-void us_editemacsundo(WINDOWPART *w) { ttybeep(); }
+void us_editemacsundo(WINDOWPART *w) { ttybeep(1); }
 
 /*
  * routine to search and/or replace text.  If "replace" is nonzero, this is
@@ -657,18 +657,18 @@ void us_editemacsundo(WINDOWPART *w) { ttybeep(); }
  */
 void us_editemacssearch(WINDOWPART *w, char *str, char *replace, INTBIG bits)
 {
-	REGISTER INTSML fromtop, reverse, casesensitive;
+	REGISTER BOOLEAN fromtop, reverse, casesensitive;
 
 	if (replace != 0)
 	{
 		ttyputerr(_("EMACS cannot replace yet"));
 		return;
 	}
-	if ((bits&1) != 0) fromtop = 1; else fromtop = 0;
-	if ((bits&4) != 0) casesensitive = 1; else casesensitive = 0;
-	if ((bits&8) != 0) reverse = 1; else reverse = 0;
+	if ((bits&1) != 0) fromtop = TRUE; else fromtop = FALSE;
+	if ((bits&4) != 0) casesensitive = TRUE; else casesensitive = FALSE;
+	if ((bits&8) != 0) reverse = TRUE; else reverse = FALSE;
 	us_editemacsflashcursor(w);
-	us_editemacsdosearch(w, str, reverse, fromtop, casesensitive, 1);
+	us_editemacsdosearch(w, str, reverse, fromtop, casesensitive, TRUE);
 	us_editemacsflashcursor(w);
 }
 
@@ -700,16 +700,16 @@ void us_editemacspan(WINDOWPART *win, INTBIG dx, INTBIG dy)
 /*
  * routine to implement EMACS character "i", with meta key held down if "m" is
  * 1.  The key is issued internally if "fromuser" is zero.  Routine returns
- * nonzero if the editor window has been terminated.
+ * true if the editor window has been terminated.
  */
-INTSML us_editemacsimplementchar(WINDOWPART *win, INTBIG i, INTSML m, INTSML fromuser)
+BOOLEAN us_editemacsimplementchar(WINDOWPART *win, INTBIG i, BOOLEAN m, BOOLEAN fromuser)
 {
 	REGISTER EDITOR *e;
 	INTBIG j, k, savecur;
 	char s[2], *pt, *nextline;
 
 	e = win->editor;
-	if (e == NOEDITOR) return(1);
+	if (e == NOEDITOR) return(TRUE);
 
 	/* make sure line highlighting is off */
 	us_editemacsoffhighlight(win);
@@ -717,7 +717,7 @@ INTSML us_editemacsimplementchar(WINDOWPART *win, INTBIG i, INTSML m, INTSML fro
 	/* if ESCAPE was typed, set meta bit */
 	if ((us_lastemacschar&ESCAPE) != 0)
 	{
-		m = 1;
+		m = TRUE;
 		us_lastemacschar &= ~ESCAPE;
 	}
 
@@ -727,51 +727,51 @@ INTSML us_editemacsimplementchar(WINDOWPART *win, INTBIG i, INTSML m, INTSML fro
 		us_lastemacschar &= ~CONTROLX;
 
 		/* save the text in a disk file */
-		if (i == CTLW && m == 0)
+		if (i == CTLW && !m)
 		{
-			if (fromuser != 0) us_editemacsshipchanges(win);
+			if (fromuser) us_editemacsshipchanges(win);
 			us_editemacswritetextfile(win, "EMACSbuffer");
-			return(0);
+			return(FALSE);
 		}
 
 		/* read a text from a disk file */
-		if (i == CTLV && m == 0)
+		if (i == CTLV && !m)
 		{
-			if (fromuser != 0) us_editemacsshipchanges(win);
+			if (fromuser) us_editemacsshipchanges(win);
 			pt = (char *)fileselect(_("File name: "), el_filetypetext, "");
 			if (pt == 0 || *pt == 0)
 			{
 				us_abortedmsg();
-				return(0);
+				return(FALSE);
 			}
 			us_editemacsreadtextfile(win, pt);
-			return(0);
+			return(FALSE);
 		}
 
 		ttyputerr(_("The sequence '^X%s' is not valid in EMACS"),
-			us_keyname((INTSML)(i+(m==0?0:0200))));
-		return(0);
+			us_describeboundkey((INTSML)i, (!m ? 0 : ACCELERATORDOWN), 1));
+		return(FALSE);
 	}
 
 	/* ESCAPE prefix for the next character */
-	if (i == ESCKEY && m == 0)
+	if (i == ESCKEY && !m)
 	{
 		us_lastemacschar |= ESCAPE;
-		return(0);
+		return(FALSE);
 	}
 
 	/* ^X prefix for the next character */
-	if (i == CTLX && m == 0)
+	if (i == CTLX && !m)
 	{
 		us_lastemacschar |= CONTROLX;
-		return(0);
+		return(FALSE);
 	}
 
 	/* self-insert of normal characters */
 	if (i == '\t') i = ' ';
-	if (i >= ' ' && i <= '~' && m == 0)
+	if (i >= ' ' && i <= '~' && !m)
 	{
-		if (fromuser != 0) us_editemacsworkingoncurline(e);
+		if (fromuser) us_editemacsworkingoncurline(e);
 
 		/* see if line needs to be extended */
 		if ((INTBIG)strlen(e->textarray[e->curline]) >= e->maxchars[e->curline])
@@ -809,11 +809,11 @@ INTSML us_editemacsimplementchar(WINDOWPART *win, INTBIG i, INTSML m, INTSML fro
 
 		/* advance the character pointer */
 		e->curchar++;
-		return(0);
+		return(FALSE);
 	}
 
 	/* search for a string */
-	if (i == CTLS && m == 0)
+	if (i == CTLS && !m)
 	{
 		if (us_searchbuf == 0)
 		{
@@ -824,13 +824,13 @@ INTSML us_editemacsimplementchar(WINDOWPART *win, INTBIG i, INTSML m, INTSML fro
 			(void)formatinfstr(_("Search for [%s]: "), us_searchbuf);
 			pt = ttygetlinemessages(returninfstr());
 		}
-		if (pt == 0) return(0);
+		if (pt == 0) return(FALSE);
 		if (*pt == 0)
 		{
 			if (us_searchbuf == 0)
 			{
 				ttyputmsg(_("No previous search string"));
-				return(0);
+				return(FALSE);
 			}
 			pt = us_searchbuf;
 		} else
@@ -838,12 +838,12 @@ INTSML us_editemacsimplementchar(WINDOWPART *win, INTBIG i, INTSML m, INTSML fro
 			if (us_searchbuf != 0) efree(us_searchbuf);
 			(void)allocstring(&us_searchbuf, pt, us_tool->cluster);
 		}
-		us_editemacsdosearch(win, us_searchbuf, 0, 0, 0, fromuser);
-		return(0);
+		us_editemacsdosearch(win, us_searchbuf, FALSE, FALSE, FALSE, fromuser);
+		return(FALSE);
 	}
 
 	/* reverse search for a string */
-	if (i == CTLR && m == 0)
+	if (i == CTLR && !m)
 	{
 		if (us_searchbuf == 0)
 		{
@@ -854,13 +854,13 @@ INTSML us_editemacsimplementchar(WINDOWPART *win, INTBIG i, INTSML m, INTSML fro
 			(void)formatinfstr(_("Reverse search for [%s]: "), us_searchbuf);
 			pt = ttygetlinemessages(returninfstr());
 		}
-		if (pt == 0) return(0);
+		if (pt == 0) return(FALSE);
 		if (*pt == 0)
 		{
 			if (us_searchbuf == 0)
 			{
 				ttyputmsg(_("No previous search string"));
-				return(0);
+				return(FALSE);
 			}
 			pt = us_searchbuf;
 		} else
@@ -868,27 +868,27 @@ INTSML us_editemacsimplementchar(WINDOWPART *win, INTBIG i, INTSML m, INTSML fro
 			if (us_searchbuf != 0) efree(us_searchbuf);
 			(void)allocstring(&us_searchbuf, pt, us_tool->cluster);
 		}
-		us_editemacsdosearch(win, us_searchbuf, 1, 0, 0, fromuser);
-		return(0);
+		us_editemacsdosearch(win, us_searchbuf, TRUE, FALSE, FALSE, fromuser);
+		return(FALSE);
 	}
 
 	/* delete next character on a line (cannot delete line break) */
-	if (i == CTLD && m == 0)
+	if (i == CTLD && !m)
 	{
 		if (e->textarray[e->curline][e->curchar] == 0)
 		{
 			ttyputerr(_("Can only delete characters within a line.  Use ^K to remove lines."));
-			return(0);
+			return(FALSE);
 		}
-		if (fromuser != 0) us_editemacsworkingoncurline(e);
+		if (fromuser) us_editemacsworkingoncurline(e);
 		us_editemacsdeletechar(win);
-		return(0);
+		return(FALSE);
 	}
 
 	/* delete next word on a line (cannot delete line break) */
-	if (i == 'd' && m == 1)
+	if (i == 'd' && m)
 	{
-		if (fromuser != 0) us_editemacsworkingoncurline(e);
+		if (fromuser) us_editemacsworkingoncurline(e);
 
 		/* first delete all nonalphanumeric characters */
 		while (!isalnum(e->textarray[e->curline][e->curchar]) &&
@@ -899,33 +899,33 @@ INTSML us_editemacsimplementchar(WINDOWPART *win, INTBIG i, INTSML m, INTSML fro
 		if (e->textarray[e->curline][e->curchar] == 0)
 		{
 			ttyputerr(_("Can only delete characters within a line.  Use ^K to remove lines."));
-			return(0);
+			return(FALSE);
 		}
 
 		/* now delete alphanumeric characters */
 		while (isalnum(e->textarray[e->curline][e->curchar]))
 			us_editemacsdeletechar(win);
-		return(0);
+		return(FALSE);
 	}
 
 	/* delete previous character on a line (cannot delete line break) */
-	if ((i == CTLH || i == DELETEKEY) && m == 0)
+	if ((i == CTLH || i == DELETEKEY) && !m)
 	{
 		if (e->curchar <= 0)
 		{
 			ttyputerr(_("Can only delete characters within a line.  Use ^K to remove lines."));
-			return(0);
+			return(FALSE);
 		}
-		if (fromuser != 0) us_editemacsworkingoncurline(e);
+		if (fromuser) us_editemacsworkingoncurline(e);
 		e->curchar--;
 		us_editemacsdeletechar(win);
-		return(0);
+		return(FALSE);
 	}
 
 	/* delete previous word on a line (cannot delete line break) */
-	if ((i == 'h' || i == DELETEKEY) && m == 1)
+	if ((i == 'h' || i == DELETEKEY) && m)
 	{
-		if (fromuser != 0) us_editemacsworkingoncurline(e);
+		if (fromuser) us_editemacsworkingoncurline(e);
 
 		/* first backwards delete all nonalphanumeric characters */
 		for(;;)
@@ -940,7 +940,7 @@ INTSML us_editemacsimplementchar(WINDOWPART *win, INTBIG i, INTSML m, INTSML fro
 		if (e->curchar <= 0)
 		{
 			ttyputerr(_("Can only delete characters in a single line"));
-			return(0);
+			return(FALSE);
 		}
 
 		/* now backwards delete alphanumeric characters */
@@ -951,39 +951,39 @@ INTSML us_editemacsimplementchar(WINDOWPART *win, INTBIG i, INTSML m, INTSML fro
 			if (e->curchar <= 0) break;
 			if (!isalnum(e->textarray[e->curline][e->curchar-1])) break;
 		}
-		return(0);
+		return(FALSE);
 	}
 
 	/* kill to end of line (delete line if at beginning of empty line) */
-	if (i == CTLK && m == 0)
+	if (i == CTLK && !m)
 	{
 		if (e->curchar == 0 && e->textarray[e->curline][e->curchar] == 0)
 		{
 			/* exit editor if only editing one line */
 			if ((win->state&WINDOWTYPE) == POPTEXTWINDOW)
 			{
-				if (fromuser != 0) us_editemacsshipchanges(win);
-				return(1);
+				if (fromuser) us_editemacsshipchanges(win);
+				return(TRUE);
 			}
 
 			/* cannot change number of lines if not allowed */
-			if (fromuser != 0 && (e->state&LINESFIXED) != 0)
+			if (fromuser && (e->state&LINESFIXED) != 0)
 			{
 				ttyputerr(_("Cannot delete lines in this edit session"));
-				return(0);
+				return(FALSE);
 			}
 
 			/* delete line in memory */
-			if (fromuser != 0) us_editemacsshipchanges(win);
+			if (fromuser) us_editemacsshipchanges(win);
 			savecur = e->curline;
 			for(; e->curline < e->maxlines; e->curline++)
 			{
 				if (e->curline == e->maxlines-1) nextline = ""; else
 					nextline = e->textarray[e->curline+1];
 				if (strcmp(e->textarray[e->curline], nextline) == 0) continue;
-				if (fromuser != 0) us_editemacsworkingoncurline(e);
+				if (fromuser) us_editemacsworkingoncurline(e);
 				(void)strcpy(e->textarray[e->curline], nextline);
-				if (fromuser != 0) us_editemacsshipchanges(win);
+				if (fromuser) us_editemacsshipchanges(win);
 			}
 			e->curline = savecur;
 
@@ -1005,11 +1005,11 @@ INTSML us_editemacsimplementchar(WINDOWPART *win, INTBIG i, INTSML m, INTSML fro
 			if (e->textarray[e->curline][e->curchar] == 0)
 			{
 				ttyputerr(_("Can only delete entire lines"));
-				return(0);
+				return(FALSE);
 			}
 
 			/* kill to end of line */
-			if (fromuser != 0) us_editemacsworkingoncurline(e);
+			if (fromuser) us_editemacsworkingoncurline(e);
 			(void)strcpy(us_killbuf, &e->textarray[e->curline][e->curchar]);
 			if (e->curline-e->firstline < e->screenlines &&
 				e->curline >= e->firstline && (e->state&EGRAPHICSOFF) == 0)
@@ -1017,36 +1017,36 @@ INTSML us_editemacsimplementchar(WINDOWPART *win, INTBIG i, INTSML m, INTSML fro
 						e->swid-e->curchar*us_twid, us_thei);
 			e->textarray[e->curline][e->curchar] = 0;
 		}
-		return(0);
+		return(FALSE);
 	}
 
-	if (i == CTLY && m == 0)
+	if (i == CTLY && !m)
 	{
 		for(pt = us_killbuf; *pt != 0; pt++)
 		{
 			if (*pt == CTLY || *pt == CTLK) continue;
-			(void)us_editemacsimplementchar(win, *pt, 0, fromuser);
+			(void)us_editemacsimplementchar(win, *pt, FALSE, fromuser);
 		}
-		return(0);
+		return(FALSE);
 	}
 
-	if (i == CTLL && m == 0)
+	if (i == CTLL && !m)
 	{
 		us_editemacsredrawscreen(win);
-		return(0);
+		return(FALSE);
 	}
 
-	if (i == CTLB && m == 0)
+	if (i == CTLB && !m)
 	{
 		(void)us_editemacsbackupchar(win, fromuser);
-		return(0);
+		return(FALSE);
 	}
 
-	if (i == 'b' && m == 1)
+	if (i == 'b' && m)
 	{
 		for(;;)
 		{
-			if (us_editemacsbackupchar(win, fromuser) != 0) break;
+			if (us_editemacsbackupchar(win, fromuser)) break;
 			if (isalnum(e->textarray[e->curline][e->curchar])) break;
 		}
 		for(;;)
@@ -1055,77 +1055,77 @@ INTSML us_editemacsimplementchar(WINDOWPART *win, INTBIG i, INTSML m, INTSML fro
 			if (!isalnum(e->textarray[e->curline][e->curchar-1])) break;
 			(void)us_editemacsbackupchar(win, fromuser);
 		}
-		return(0);
+		return(FALSE);
 	}
 
-	if (i == CTLF && m == 0)
+	if (i == CTLF && !m)
 	{
 		/* exit editor if at end of line and only editing one line */
 		if (e->textarray[e->curline][e->curchar] == 0 &&
 			(win->state&WINDOWTYPE) == POPTEXTWINDOW)
 		{
-			if (fromuser != 0) us_editemacsshipchanges(win);
-			return(1);
+			if (fromuser) us_editemacsshipchanges(win);
+			return(TRUE);
 		}
 
 		(void)us_editemacsadvancechar(win, fromuser);
-		return(0);
+		return(FALSE);
 	}
 
-	if (i == 'f' && m == 1)
+	if (i == 'f' && m)
 	{
 		/* exit editor if at end of line and only editing one line */
 		if (e->textarray[e->curline][e->curchar] == 0 &&
 			(win->state&WINDOWTYPE) == POPTEXTWINDOW)
 		{
-			if (fromuser != 0) us_editemacsshipchanges(win);
-			return(1);
+			if (fromuser) us_editemacsshipchanges(win);
+			return(TRUE);
 		}
 
 		for(;;)
 		{
 			if (isalnum(e->textarray[e->curline][e->curchar])) break;
-			if (us_editemacsadvancechar(win, fromuser) != 0) break;
+			if (us_editemacsadvancechar(win, fromuser)) break;
 		}
 		for(;;)
 		{
-			if (us_editemacsadvancechar(win, fromuser) != 0) break;
+			if (us_editemacsadvancechar(win, fromuser)) break;
 			if (!isalnum(e->textarray[e->curline][e->curchar])) break;
 		}
-		return(0);
+		return(FALSE);
 	}
 
-	if (i == CTLA && m == 0)
+	if (i == CTLA && !m)
 	{
 		e->curchar = 0;
-		return(0);
+		return(FALSE);
 	}
 
-	if (i == CTLE && m == 0)
+	if (i == CTLE && !m)
 	{
 		for(j=0; e->textarray[e->curline][j] != 0; j++) ;
 		e->curchar = j;
-		return(0);
+		return(FALSE);
 	}
 
-	if (i == CTLG && m == 0)
+	if (i == CTLG && !m)
 	{
 		ttyputmsg(_("Analyzing this line"));
-		if (fromuser != 0) us_editemacsshipchanges(win);
-		return(0);
+		if (fromuser) us_editemacsshipchanges(win);
+		return(FALSE);
 	}
 
-	if (i == CTLP && m == 0)
+	if (i == CTLP && !m)
 	{
 		/* exit editor if only editing one line */
 		if ((win->state&WINDOWTYPE) == POPTEXTWINDOW)
 		{
-			if (fromuser != 0) us_editemacsshipchanges(win);
-			return(1);
+			if (fromuser) us_editemacsshipchanges(win);
+			return(TRUE);
 		}
 
-		if (e->curline <= 0) return(0);
-		if (fromuser != 0)
+		if (e->curline <= 0) return(FALSE);
+		if (fromuser)
 		{
 			us_editemacsshipchanges(win);
 			if (e->curline == e->firstline && e->firstline > 0)
@@ -1134,20 +1134,20 @@ INTSML us_editemacsimplementchar(WINDOWPART *win, INTBIG i, INTSML m, INTSML fro
 		e->curline--;
 		for(j=0; e->textarray[e->curline][j] != 0; j++) ;
 		if (e->curchar > j) e->curchar = j;
-		return(0);
+		return(FALSE);
 	}
 
-	if (i == CTLN && m == 0)
+	if (i == CTLN && !m)
 	{
 		/* exit editor if only editing one line */
 		if ((win->state&WINDOWTYPE) == POPTEXTWINDOW)
 		{
-			if (fromuser != 0) us_editemacsshipchanges(win);
-			return(1);
+			if (fromuser) us_editemacsshipchanges(win);
+			return(TRUE);
 		}
 
 		if (e->curline >= e->maxlines-1) us_editemacsaddmorelines(e);
-		if (fromuser != 0)
+		if (fromuser)
 		{
 			us_editemacsshipchanges(win);
 			if (e->curline == e->firstline+e->screenlines-1)
@@ -1156,46 +1156,46 @@ INTSML us_editemacsimplementchar(WINDOWPART *win, INTBIG i, INTSML m, INTSML fro
 		e->curline++;
 		for(j=0; e->textarray[e->curline][j] != 0; j++) ;
 		if (e->curchar > j) e->curchar = j;
-		return(0);
+		return(FALSE);
 	}
 
-	if (i == CTLZ && m == 0)
+	if (i == CTLZ && !m)
 	{
 		/* exit editor if only editing one line */
 		if ((win->state&WINDOWTYPE) == POPTEXTWINDOW)
 		{
-			if (fromuser != 0) us_editemacsshipchanges(win);
-			return(1);
+			if (fromuser) us_editemacsshipchanges(win);
+			return(TRUE);
 		}
 
 		us_editemacsshiftscreenup(win);
-		if (fromuser != 0 && e->curline == e->firstline) e->curline++;
-		return(0);
+		if (fromuser && e->curline == e->firstline) e->curline++;
+		return(FALSE);
 	}
 
-	if (i == 'z' && m == 1)
+	if (i == 'z' && m)
 	{
 		/* exit editor if only editing one line */
 		if ((win->state&WINDOWTYPE) == POPTEXTWINDOW)
 		{
-			if (fromuser != 0) us_editemacsshipchanges(win);
-			return(1);
+			if (fromuser) us_editemacsshipchanges(win);
+			return(TRUE);
 		}
 
-		if (e->firstline <= 0) return(0);
+		if (e->firstline <= 0) return(FALSE);
 		us_editemacsshiftscreendown(win);
-		if (fromuser != 0 && e->curline == e->firstline+e->screenlines-1)
+		if (fromuser && e->curline == e->firstline+e->screenlines-1)
 			e->curline--;
-		return(0);
+		return(FALSE);
 	}
 
-	if (i == CTLV && m == 0)
+	if (i == CTLV && !m)
 	{
 		/* exit editor if only editing one line */
 		if ((win->state&WINDOWTYPE) == POPTEXTWINDOW)
 		{
-			if (fromuser != 0) us_editemacsshipchanges(win);
-			return(1);
+			if (fromuser) us_editemacsshipchanges(win);
+			return(TRUE);
 		}
 
 		j = e->screenlines / 5 * 4;
@@ -1210,24 +1210,24 @@ INTSML us_editemacsimplementchar(WINDOWPART *win, INTBIG i, INTSML m, INTSML fro
 					us_editemacsredrawline(win, e->screenlines-j+k);
 			}
 		}
-		if (fromuser != 0 && e->curline < e->firstline)
+		if (fromuser && e->curline < e->firstline)
 		{
 			us_editemacsshipchanges(win);
 			e->curline = e->firstline + e->screenlines/2;
 		}
-		return(0);
+		return(FALSE);
 	}
 
-	if (i == 'v' && m == 1)
+	if (i == 'v' && m)
 	{
 		/* exit editor if only editing one line */
 		if ((win->state&WINDOWTYPE) == POPTEXTWINDOW)
 		{
-			if (fromuser != 0) us_editemacsshipchanges(win);
-			return(1);
+			if (fromuser) us_editemacsshipchanges(win);
+			return(TRUE);
 		}
 
-		if (e->firstline == 0) return(0);
+		if (e->firstline == 0) return(FALSE);
 		j = e->screenlines / 5 * 4;
 		if (j > e->firstline) j = e->firstline;
 		e->firstline -= j;
@@ -1240,31 +1240,31 @@ INTSML us_editemacsimplementchar(WINDOWPART *win, INTBIG i, INTSML m, INTSML fro
 				if (e->firstline+k < e->maxlines) us_editemacsredrawline(win, k);
 			}
 		}
-		if (fromuser != 0 && e->curline >= e->screenlines+e->firstline)
+		if (fromuser && e->curline >= e->screenlines+e->firstline)
 		{
 			us_editemacsshipchanges(win);
 			e->curline = e->firstline + e->screenlines/2;
 		}
-		return(0);
+		return(FALSE);
 	}
 
-	if (i == '>' && m == 1)
+	if (i == '>' && m)
 	{
-		if (fromuser != 0) us_editemacsshipchanges(win);
+		if (fromuser) us_editemacsshipchanges(win);
 		for(j=e->maxlines-1; j>=0; j--) if (e->textarray[j][0] != 0) break;
 		e->curline = j+1;
-		if (fromuser != 0 && e->curline >= e->firstline+e->screenlines)
+		if (fromuser && e->curline >= e->firstline+e->screenlines)
 		{
 			e->firstline = e->curline - e->screenlines/2;
 			us_editemacsredrawscreen(win);
 		}
 		e->curchar = 0;
-		return(0);
+		return(FALSE);
 	}
 
-	if (i == '<' && m == 1)
+	if (i == '<' && m)
 	{
-		if (fromuser != 0)
+		if (fromuser)
 		{
 			us_editemacsshipchanges(win);
 			if (e->firstline != 0)
@@ -1275,30 +1275,30 @@ INTSML us_editemacsimplementchar(WINDOWPART *win, INTBIG i, INTSML m, INTSML fro
 		}
 		e->curline = 0;
 		e->curchar = 0;
-		return(0);
+		return(FALSE);
 	}
 
-	if (i == CTLO && m == 0)
+	if (i == CTLO && !m)
 	{
 		/* exit editor if only editing one line */
 		if ((win->state&WINDOWTYPE) == POPTEXTWINDOW)
 		{
-			if (fromuser != 0) us_editemacsshipchanges(win);
-			return(1);
+			if (fromuser) us_editemacsshipchanges(win);
+			return(TRUE);
 		}
 
 		/* cannot change number of lines if not allowed */
-		if (fromuser != 0 && (e->state&LINESFIXED) != 0)
+		if (fromuser && (e->state&LINESFIXED) != 0)
 		{
 			ttyputerr(_("Cannot insert lines in this edit session"));
-			return(0);
+			return(FALSE);
 		}
 
 		/* must be at the beginning of a line */
 		if (e->curchar != 0)
 		{
 			ttyputerr(_("Can only create new blank lines (use ^A first)"));
-			return(0);
+			return(FALSE);
 		}
 
 		/* see if there is room in the file */
@@ -1306,16 +1306,16 @@ INTSML us_editemacsimplementchar(WINDOWPART *win, INTBIG i, INTSML m, INTSML fro
 		if (i >= e->maxlines-1) us_editemacsaddmorelines(e);
 
 		/* shift lines down */
-		if (fromuser != 0) us_editemacsshipchanges(win);
+		if (fromuser) us_editemacsshipchanges(win);
 		savecur = e->curline;
 		for(e->curline = i+1; e->curline >= savecur; e->curline--)
 		{
 			if (e->curline == savecur) nextline = ""; else
 				nextline = e->textarray[e->curline-1];
 			if (strcmp(e->textarray[e->curline], nextline) == 0) continue;
-			if (fromuser != 0) us_editemacsworkingoncurline(e);
+			if (fromuser) us_editemacsworkingoncurline(e);
 			(void)strcpy(e->textarray[e->curline], nextline);
-			if (fromuser != 0) us_editemacsshipchanges(win);
+			if (fromuser) us_editemacsshipchanges(win);
 		}
 		e->curline = savecur;
 		if (e->curline-e->firstline < e->screenlines-1 &&
@@ -1329,36 +1329,36 @@ INTSML us_editemacsimplementchar(WINDOWPART *win, INTBIG i, INTSML m, INTSML fro
 		if (e->curline-e->firstline < e->screenlines &&
 			e->curline >= e->firstline && (e->state&EGRAPHICSOFF) == 0)
 				us_editemacsclearbox(win, 0, e->curline-e->firstline, e->swid, us_thei);
-		return(0);
+		return(FALSE);
 	}
 
-	if ((i == '\n' || i == '\r') && m == 0)
+	if ((i == '\n' || i == '\r') && !m)
 	{
 		/* exit editor if only editing one line */
 		if ((win->state&WINDOWTYPE) == POPTEXTWINDOW)
 		{
-			if (fromuser != 0) us_editemacsshipchanges(win);
-			return(1);
+			if (fromuser) us_editemacsshipchanges(win);
+			return(TRUE);
 		}
 
 		/* cannot change number of lines if not allowed */
-		if (fromuser != 0 && (e->state&LINESFIXED) != 0)
+		if (fromuser && (e->state&LINESFIXED) != 0)
 		{
 			ttyputerr(_("Cannot insert lines in this edit session"));
-			return(0);
+			return(FALSE);
 		}
 
 		/* must be at the end of a line */
 		if (e->textarray[e->curline][e->curchar] != 0)
 		{
 			ttyputmsg(_("Can only create new blank lines (use ^E first)"));
-			return(0);
+			return(FALSE);
 		}
 
 		/* see if there is room in the file */
 		if (e->curline >= e->maxlines-1) us_editemacsaddmorelines(e);
 
-		if (fromuser != 0)
+		if (fromuser)
 		{
 			us_editemacsshipchanges(win);
 			if (e->curline == e->firstline+e->screenlines-1)
@@ -1375,9 +1375,9 @@ INTSML us_editemacsimplementchar(WINDOWPART *win, INTBIG i, INTSML m, INTSML fro
 			if (e->curline == savecur) nextline = ""; else
 				nextline = e->textarray[e->curline-1];
 			if (strcmp(e->textarray[e->curline], nextline) == 0) continue;
-			if (fromuser != 0) us_editemacsworkingoncurline(e);
+			if (fromuser) us_editemacsworkingoncurline(e);
 			(void)strcpy(e->textarray[e->curline], nextline);
-			if (fromuser != 0) us_editemacsshipchanges(win);
+			if (fromuser) us_editemacsshipchanges(win);
 		}
 		e->curline = savecur;
 		if (e->curline-e->firstline < e->screenlines-1 &&
@@ -1391,35 +1391,35 @@ INTSML us_editemacsimplementchar(WINDOWPART *win, INTBIG i, INTSML m, INTSML fro
 		if (e->curline-e->firstline < e->screenlines &&
 			e->curline >= e->firstline && (e->state&EGRAPHICSOFF) == 0)
 				us_editemacsclearbox(win, 0, e->curline-e->firstline, e->swid, us_thei);
-		return(0);
+		return(FALSE);
 	}
 
 	/* flash the display */
 	ttyputerr(_("The key '%s' is not valid in EMACS"),
-		us_keyname((INTSML)(i+(m==0?0:0200))));
-	return(0);
+		us_describeboundkey((INTSML)i, (!m ? 0 : ACCELERATORDOWN), 1));
+	return(FALSE);
 }
 
 /*
- * routine to back the cursor by one character.  Returns nonzero if at the
+ * routine to back the cursor by one character.  Returns true if at the
  * start of the file
  */
-INTSML us_editemacsbackupchar(WINDOWPART *win, INTSML fromuser)
+BOOLEAN us_editemacsbackupchar(WINDOWPART *win, BOOLEAN fromuser)
 {
 	REGISTER EDITOR *e;
 	REGISTER INTBIG j;
 
 	e = win->editor;
-	if (e == NOEDITOR) return(1);
+	if (e == NOEDITOR) return(TRUE);
 
 	if (e->curchar > 0)
 	{
 		e->curchar--;
-		return(0);
+		return(FALSE);
 	}
-	if (e->curline <= 0) return(1);
+	if (e->curline <= 0) return(TRUE);
 
-	if (fromuser != 0)
+	if (fromuser)
 	{
 		us_editemacsshipchanges(win);
 		if (e->curline == e->firstline && e->firstline > 0)
@@ -1428,37 +1428,37 @@ INTSML us_editemacsbackupchar(WINDOWPART *win, INTSML fromuser)
 	e->curline--;
 	for(j=0; e->textarray[e->curline][j] != 0; j++) ;
 	e->curchar = j;
-	return(0);
+	return(FALSE);
 }
 
 /*
- * routine to advance the cursor by one character.  Returns nonzero if at the
+ * routine to advance the cursor by one character.  Returns true if at the
  * end of the file
  */
-INTSML us_editemacsadvancechar(WINDOWPART *win, INTSML fromuser)
+BOOLEAN us_editemacsadvancechar(WINDOWPART *win, BOOLEAN fromuser)
 {
 	REGISTER EDITOR *e;
-	REGISTER INTSML atend;
+	REGISTER BOOLEAN atend;
 	REGISTER INTBIG j;
 
 	e = win->editor;
-	if (e == NOEDITOR) return(1);
+	if (e == NOEDITOR) return(TRUE);
 
 	if (e->textarray[e->curline][e->curchar] != 0)
 	{
 		e->curchar++;
-		return(0);
+		return(FALSE);
 	}
 
-	atend = 1;
+	atend = TRUE;
 	for(j=e->curline+1; j < e->maxlines; j++)
 	{
 		if (e->textarray[j][0] == 0) continue;
-		atend = 0;
+		atend = FALSE;
 		break;
 	}
 	if (e->curline >= e->maxlines-1) us_editemacsaddmorelines(e);
-	if (fromuser != 0)
+	if (fromuser)
 	{
 		us_editemacsshipchanges(win);
 		if (e->curline == e->firstline+e->screenlines-1)
@@ -1501,12 +1501,12 @@ void us_editemacsdeletechar(WINDOWPART *win)
 }
 
 /*
- * Routine to search for "str" (search in the reverse direction if "reverse" is nonzero).
- * Start search from the top if "fromtop" is nonzero.  Issue proper calls if this was
- * made by the user ("fromuser" nonzero).
+ * Routine to search for "str" (search in the reverse direction if "reverse" is true).
+ * Start search from the top if "fromtop" is true.  Issue proper calls if this was
+ * made by the user ("fromuser" true).
  */
-void us_editemacsdosearch(WINDOWPART *win, char *str, INTSML reverse,
-	INTSML fromtop, INTSML casesensitive, INTSML fromuser)
+void us_editemacsdosearch(WINDOWPART *win, char *str, BOOLEAN reverse,
+	BOOLEAN fromtop, BOOLEAN casesensitive, BOOLEAN fromuser)
 {
 	REGISTER EDITOR *e;
 	REGISTER INTBIG i, j, k, startchr, startlne, match;
@@ -1514,7 +1514,7 @@ void us_editemacsdosearch(WINDOWPART *win, char *str, INTSML reverse,
 	/* search for the string */
 	e = win->editor;
 	i = strlen(str);
-	if (fromtop != 0)
+	if (fromtop)
 	{
 		/* search from the top of the buffer */
 		startchr = 0;   startlne = 0;
@@ -1527,7 +1527,7 @@ void us_editemacsdosearch(WINDOWPART *win, char *str, INTSML reverse,
 	k = startchr;
 	for(;;)
 	{
-		if (reverse != 0)
+		if (reverse)
 		{
 			/* reverse search: backup one place */
 			k--;
@@ -1557,7 +1557,7 @@ void us_editemacsdosearch(WINDOWPART *win, char *str, INTSML reverse,
 		}
 
 		/* if string matches, set cursor pointers */
-		if (casesensitive != 0)
+		if (casesensitive)
 		{
 			match = strncmp(str, &e->textarray[j][k], i);
 		} else
@@ -1566,8 +1566,8 @@ void us_editemacsdosearch(WINDOWPART *win, char *str, INTSML reverse,
 		}
 		if (match == 0)
 		{
-			if (fromuser != 0) us_editemacsshipchanges(win);
-			if (reverse != 0) e->curchar = k; else e->curchar = k+i;
+			if (fromuser) us_editemacsshipchanges(win);
+			if (reverse) e->curchar = k; else e->curchar = k+i;
 			e->curline = j;
 			us_editemacsensuretextshown(win, e->curline);
 			break;
@@ -1693,21 +1693,21 @@ void us_editemacssetheader(WINDOWPART *win, char *header)
 		if (strcmp(win->location, "entire") != 0)
 			us_editemacstext(win, _("EMACS editor: type ^Xd when done"), 0, -1); else
 		{
-			if (graphicshas(CANUSEFRAMES) != 0)
+			if (graphicshas(CANUSEFRAMES))
 				us_editemacstext(win, _("EMACS editor: close the window when done"), 0, -1); else
 					us_editemacstext(win, _("EMACS editor: text-only facet"), 0, -1);
 		}
 	}
 	if (save != 0) header[e->screenchars] = (char)save;
-	screeninvertbox(win, (INTSML)(e->offx-1), (INTSML)(e->offx+e->swid),
-		(INTSML)(e->revy+1), (INTSML)(e->revy+us_thei*HEADERLINES));
+	screeninvertbox(win, e->offx-1, e->offx+e->swid,
+		e->revy+1, e->revy+us_thei*HEADERLINES);
 	us_menufigs.col = el_colmengly;
-	screendrawline(win, (INTSML)(e->offx-1), e->revy, (INTSML)(e->offx-1),
-		(INTSML)(e->revy-e->shei-1), &us_menufigs, 0);
-	screendrawline(win, (INTSML)(e->offx+e->swid+1), e->revy,
-		(INTSML)(e->offx+e->swid+1), (INTSML)(e->revy-e->shei-1), &us_menufigs, 0);
-	screendrawline(win, (INTSML)(e->offx-1), (INTSML)(e->revy-e->shei-1),
-		(INTSML)(e->offx+e->swid+1), (INTSML)(e->revy-e->shei-1), &us_menufigs, 0);
+	screendrawline(win, e->offx-1, e->revy, e->offx-1,
+		e->revy-e->shei-1, &us_menufigs, 0);
+	screendrawline(win, e->offx+e->swid+1, e->revy,
+		e->offx+e->swid+1, e->revy-e->shei-1, &us_menufigs, 0);
+	screendrawline(win, e->offx-1, e->revy-e->shei-1,
+		e->offx+e->swid+1, e->revy-e->shei-1, &us_menufigs, 0);
 }
 
 /*
@@ -1801,7 +1801,7 @@ void us_editemacsshipchanges(WINDOWPART *win)
 void us_editemacsaddmorelines(EDITOR *e)
 {
 	REGISTER INTBIG oldlines, i;
-	REGISTER INTSML *maxchars;
+	REGISTER INTBIG *maxchars;
 	REGISTER char **textarray;
 
 	/* save former buffer size, double it */
@@ -1809,7 +1809,7 @@ void us_editemacsaddmorelines(EDITOR *e)
 	e->maxlines *= 2;
 
 	/* allocate new arrays */
-	maxchars = (INTSML *)emalloc((e->maxlines * SIZEOFINTSML), us_tool->cluster);
+	maxchars = (INTBIG *)emalloc((e->maxlines * SIZEOFINTBIG), us_tool->cluster);
 	if (maxchars == 0) ttyputnomemory();
 	textarray = (char **)emalloc((e->maxlines * (sizeof (char *))), us_tool->cluster);
 	if (textarray == 0) ttyputnomemory();
@@ -1890,9 +1890,8 @@ void us_editemacsmovebox(WINDOWPART *win, INTBIG dx, INTBIG dy, INTBIG wid,
 
 	e = win->editor;
 	if (e == NOEDITOR) return;
-	screenmovebox(win, (INTSML)(sx*us_twid+e->offx),
-		(INTSML)(e->revy-(sy*us_thei+hei-1)), (INTSML)wid, (INTSML)hei,
-			(INTSML)(dx*us_twid+e->offx), (INTSML)(e->revy-(dy*us_thei+hei-1)));
+	screenmovebox(win, sx*us_twid+e->offx, e->revy-(sy*us_thei+hei-1), wid, hei,
+		dx*us_twid+e->offx, e->revy-(dy*us_thei+hei-1));
 }
 
 /*
@@ -1907,8 +1906,7 @@ void us_editemacsclearbox(WINDOWPART *win, INTBIG dx, INTBIG dy, INTBIG wid, INT
 
 	dx = (dx * us_twid) + e->offx;
 	dy *= us_thei;
-	screendrawbox(win, (INTSML)dx, (INTSML)(dx+wid-1), (INTSML)(e->revy-(dy+hei-1)),
-		(INTSML)(e->revy-dy), &us_ebox);
+	screendrawbox(win, dx, dx+wid-1, e->revy-(dy+hei-1), e->revy-dy, &us_ebox);
 }
 
 /*
@@ -1923,8 +1921,7 @@ void us_editemacsinvertbox(WINDOWPART *win, INTBIG dx, INTBIG dy, INTBIG wid, IN
 
 	dx = (dx * us_twid) + e->offx;
 	dy *= us_thei;
-	screeninvertbox(win, (INTSML)dx, (INTSML)(dx+wid-1), (INTSML)(e->revy-(dy+hei-1)),
-		(INTSML)(e->revy-dy));
+	screeninvertbox(win, dx, dx+wid-1, e->revy-(dy+hei-1), e->revy-dy);
 }
 
 /*
@@ -1942,6 +1939,6 @@ void us_editemacstext(WINDOWPART *win, char *str, INTBIG x, INTBIG y)
 	TDSETSIZE(descript, us_editemacsfont);
 	screensettextinfo(win, NOTECHNOLOGY, descript);
 	us_menutext.col = el_colmentxt;
-	screendrawtext(win, (INTSML)(x*us_twid + e->offx), (INTSML)(e->revy-(y+1)*us_thei),
+	screendrawtext(win, x*us_twid + e->offx, e->revy-(y+1)*us_thei,
 		str, &us_menutext);
 }
