@@ -51,12 +51,12 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 	REGISTER LIBRARY *lib;
 	REGISTER char *lay, *dxf, **sequence, **varnames, *fname;
 	REGISTER INTBIG i, j, k, total, e, xs, ys, oldlam, *newmap, *mapptr,
-		tcon, func, serp, gds, nodexpos, bits,
+		tcon, func, gds, nodexpos, bits,
 		height3d, thick3d, lambda, min2x, min2y;
-	REGISTER INTSML first;
+	REGISTER BOOLEAN serp, square, wipes, lockable;
+	REGISTER BOOLEAN first;
 	INTBIG lx, hx, ly, hy, xpos[4], ypos[4], xsc[4], ysc[4], lxo, hxo, lyo, hyo,
 		lxp, hxp, lyp, hyp;
-	UINTBIG portdescript[TEXTDESCRIPTSIZE];
 	REGISTER NODEPROTO *np, **nplist, *pnp, **aplist;
 	float spires, spicap, spiecap;
 	REGISTER VARIABLE *var, *var2, *var3, *var5, *var6, *var7, *var8,
@@ -77,7 +77,7 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 	if ((net_tool->toolstate&TOOLON) == 0)
 	{
 		ttyputerr(_("Network tool must be running...turning it on"));
-		toolturnon(net_tool, 0);
+		toolturnon(net_tool, FALSE);
 		ttyputerr(_("...now reissue the technology editing command"));
 		return(NOLIBRARY);
 	}
@@ -147,7 +147,7 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 		desc = tech->layers[i];
 		(void)initinfstr();
 		(void)addstringtoinfstr("layer-");
-		(void)addstringtoinfstr(us_tecedstripdash(layername(tech, i)));
+		(void)addstringtoinfstr(layername(tech, i));
 		fname = returninfstr();
 
 		/* make sure the layer doesn't exist */
@@ -186,8 +186,8 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 
 		/* build the layer facet */
 		us_tecedmakelayer(np, desc->col, desc->raster,
-			(INTSML)(desc->colstyle&(NATURE|OUTLINEPAT)), lay, layerfunction(tech, i),
-				us_layerletters(tech, (INTSML)i), dxf, gds, spires, spicap, spiecap,
+			desc->colstyle&(NATURE|OUTLINEPAT), lay, layerfunction(tech, i),
+				us_layerletters(tech, i), dxf, gds, spires, spicap, spiecap,
 					height3d, thick3d);
 	}
 
@@ -205,9 +205,9 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 	/* create the color map information */
 	ttyputmsg(_("Adding color map and design rules..."));
 	var2 = getval((INTBIG)tech, VTECHNOLOGY, VCHAR|VISARRAY, "USER_color_map");
-	varred = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_red);
-	vargreen = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_green);
-	varblue = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_blue);
+	varred = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_red_key);
+	vargreen = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_green_key);
+	varblue = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER|VISARRAY, us_colormap_blue_key);
 	if (varred != NOVARIABLE && vargreen != NOVARIABLE && varblue != NOVARIABLE &&
 		var2 != NOVARIABLE)
 	{
@@ -236,7 +236,7 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 	rules = dr_allocaterules(total, tech->techname);
 	if (rules == NODRCRULES) return(NOLIBRARY);
 	for(i=0; i<total; i++)
-		(void)allocstring(&rules->layernames[i], us_tecedstripdash(layername(tech, i)), el_tempcluster);
+		(void)allocstring(&rules->layernames[i], layername(tech, i), el_tempcluster);
 	var = getvalkey((INTBIG)tech, VTECHNOLOGY, VFRACT|VISARRAY, dr_min_widthkey);
 	if (var != NOVARIABLE)
 		for(i=0; i<rules->numlayers; i++) rules->minwidth[i] = ((INTBIG *)var->addr)[i];
@@ -306,7 +306,7 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 	{
 		(void)initinfstr();
 		(void)addstringtoinfstr("arc-");
-		(void)addstringtoinfstr(us_tecedstripdash(ap->protoname));
+		(void)addstringtoinfstr(ap->protoname);
 		fname = returninfstr();
 
 		/* make sure the arc doesn't exist */
@@ -320,7 +320,7 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 		np = newnodeproto(fname, lib);
 		if (np == NONODEPROTO) return(NOLIBRARY);
 		ap->temp1 = (INTBIG)np;
-		var = getvalkey((INTBIG)ap, VARCPROTO, VINTEGER, us_arcstyle);
+		var = getvalkey((INTBIG)ap, VARCPROTO, VINTEGER, us_arcstylekey);
 		if (var != NOVARIABLE) bits = var->addr; else
 			bits = ap->userbits;
 		us_tecedmakearc(np, (ap->userbits&AFUNCTION)>>AFUNCTIONSH,
@@ -339,7 +339,7 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 		j = arcpolys(ai, NOWINDOWPART);
 		for(i=0; i<j; i++)
 		{
-			shapearcpoly(ai, (INTSML)i, poly);
+			shapearcpoly(ai, i, poly);
 			if (poly->layer < 0) continue;
 			desc = tech->layers[poly->layer];
 			if (desc->bits == LAYERN) continue;
@@ -366,6 +366,7 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 		(void)setvalkey((INTBIG)ni, VNODEINST, art_colorkey, HIGHLIT, VINTEGER);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_layer", (INTBIG)NONODEPROTO, VNODEPROTO);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYERPATCH, VINTEGER);
+		endobjectchange((INTBIG)ni, VNODEINST);
 		total++;
 	}
 
@@ -381,13 +382,11 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 
 	/* create the node nodes */
 	ttyputmsg(_("Creating the nodes..."));
-	TDCLEAR(portdescript);
-	defaulttextdescript(portdescript, NOGEOM);
 	total = 0;
 	for(pnp = tech->firstnodeproto; pnp != NONODEPROTO; pnp = pnp->nextnodeproto)
 	{
 		pnp->temp1 = 0;
-		first = 1;
+		first = TRUE;
 
 		/* create the node layers */
 		oni = dummynode();
@@ -427,7 +426,7 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 		for(e=0; e<4; e++)
 		{
 			/* do not create node if main example had no polygons */
-			if (e != 0 && first != 0) continue;
+			if (e != 0 && first) continue;
 
 			/* square nodes have only two examples */
 			if ((pnp->userbits&NSQUARE) != 0 && (e == 1 || e == 2)) continue;
@@ -452,12 +451,12 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 				}
 
 				/* create the node facet on the first valid layer */
-				if (first != 0)
+				if (first)
 				{
-					first = 0;
+					first = FALSE;
 					(void)initinfstr();
 					(void)addstringtoinfstr("node-");
-					(void)addstringtoinfstr(us_tecedstripdash(pnp->primname));
+					(void)addstringtoinfstr(pnp->primname);
 					fname = returninfstr();
 
 					/* make sure the node doesn't exist */
@@ -471,12 +470,17 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 					np = newnodeproto(fname, lib);
 					if (np == NONODEPROTO) return(NOLIBRARY);
 					func = (pnp->userbits&NFUNCTION)>>NFUNCTIONSH;
-					serp = 0;
+					serp = FALSE;
 					if ((func == NPTRANMOS || func == NPTRAPMOS || func == NPTRADMOS) &&
 						(pnp->userbits&HOLDSTRACE) != 0)
-							serp = 1;
-					us_tecedmakenode(np, func, (INTSML)serp, (INTSML)(pnp->userbits&NSQUARE),
-						(INTSML)(pnp->userbits&WIPEON1OR2), (INTSML)(pnp->userbits&LOCKEDPRIM));
+							serp = TRUE;
+					if ((pnp->userbits&NSQUARE) != 0) square = TRUE; else
+						square = FALSE;
+					if ((pnp->userbits&WIPEON1OR2) != 0) wipes = TRUE; else
+						wipes = FALSE;
+					if ((pnp->userbits&LOCKEDPRIM) != 0) lockable = TRUE; else
+						lockable = FALSE;
+					us_tecedmakenode(np, func, serp, square, wipes, lockable);
 					total++;
 					pnp->temp1 = (INTBIG)np;
 				}
@@ -501,7 +505,7 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 				if (var != NOVARIABLE)
 					defaulttextsize(3, var->textdescript);
 			}
-			if (first != 0) continue;
+			if (first) continue;
 
 			/* create the highlight node */
 			lx = (xpos[e]-xsc[e]/2) * lambda / oldlam;
@@ -513,11 +517,12 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 			(void)setvalkey((INTBIG)ni, VNODEINST, art_colorkey, HIGHLIT, VINTEGER);
 			(void)setval((INTBIG)ni, VNODEINST, "EDTEC_layer", (INTBIG)NONODEPROTO, VNODEPROTO);
 			(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYERPATCH, VINTEGER);
+			endobjectchange((INTBIG)ni, VNODEINST);
 
 			/* create a grab node (only in main example) */
 			if (e == 0)
 			{
-				var = getvalkey((INTBIG)pnp, VNODEPROTO, VINTEGER|VISARRAY, el_prototype_center);
+				var = getvalkey((INTBIG)pnp, VNODEPROTO, VINTEGER|VISARRAY, el_prototype_center_key);
 				if (var != NOVARIABLE)
 				{
 					lx = hx = xpos[0] + ((INTBIG *)var->addr)[0];
@@ -529,13 +534,14 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 					nodeprotosizeoffset(gen_facetcenterprim, &lxo, &lyo, &hxo, &hyo);
 					ni = newnodeinst(gen_facetcenterprim, lx-lxo, hx+hxo, ly-lyo, hy+hyo, 0, 0, np);
 					if (ni == NONODEINST) return(NOLIBRARY);
+					endobjectchange((INTBIG)ni, VNODEINST);
 				}
 			}
 
 			/* also draw ports */
 			for(pp = pnp->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 			{
-				shapeportpoly(oni, pp, poly, 0);
+				shapeportpoly(oni, pp, poly, FALSE);
 				getbbox(poly, &lx, &hx, &ly, &hy);
 				lx = lx * lambda / oldlam;
 				hx = hx * lambda / oldlam;
@@ -549,7 +555,8 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 				var = setval((INTBIG)ni, VNODEINST, "EDTEC_portname", (INTBIG)pp->protoname,
 					VSTRING|VDISPLAY);
 				if (var != NOVARIABLE)
-					TDCOPY(var->textdescript, portdescript);
+					defaulttextsize(3, var->textdescript);
+				endobjectchange((INTBIG)ni, VNODEINST);
 
 				/* on the first sample, also show angle and connection */
 				if (e != 0) continue;
@@ -622,7 +629,7 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
  * the SPICE capacitance is in "spicap", the SPICE edge capacitance is in "spiecap",
  * the 3D height is in "height3d", and the 3D thickness is in "thick3d".
  */
-void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML style,
+void us_tecedmakelayer(NODEPROTO *np, INTBIG colorindex, UINTSML stip[8], INTBIG style,
 	char *ciflayer, INTBIG functionindex, char *layerletters, char *dxf,
 	INTBIG gds, float spires, float spicap, float spiecap,
 	INTBIG height3d, INTBIG thick3d)
@@ -630,7 +637,7 @@ void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML
 	REGISTER NODEINST *nicolor, *ni, *laycolor, *laystipple, *laystyle, *laycif,
 		*laydxf, *laycalma, *layfunction, *layletters, *layspires, *layspicap,
 		*layspiecap, *lay3dheight, *lay3dthick;
-	REGISTER INTSML i, x, y;
+	REGISTER INTBIG i, x, y;
 	REGISTER VARIABLE *var;
 	char line[20], *colorname, *colorsymbol;
 	UINTBIG pattern[8];
@@ -683,19 +690,21 @@ void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML
 					VSHORT|VISARRAY|(8<<VLENGTHSH));
 			}
 		}
+		endobjectchange((INTBIG)nicolor, VNODEINST);
 
 		/* create the text color object */
-		ni = newnodeinst(gen_invispinprim, 0, 40000, 22000, 26000, 0, 0, np);
+		ni = newnodeinst(gen_invispinprim, 20000, 20000, 24000, 24000, 0, 0, np);
 		if (ni == NONODEINST) return;
 		(void)initinfstr();
 		(void)addstringtoinfstr(TECEDNODETEXTCOLOR);
-		if (ecolorname(colorindex, &colorname, &colorsymbol) != 0) colorname = "unknown";
+		if (ecolorname(colorindex, &colorname, &colorsymbol)) colorname = "unknown";
 		(void)addstringtoinfstr(colorname);
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)returninfstr(),
 			VSTRING|VDISPLAY);
 		if (var != NOVARIABLE)
 			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYERCOLOR, VINTEGER);
+		endobjectchange((INTBIG)ni, VNODEINST);
 	}
 
 	/* create the stipple pattern objects if it is not there */
@@ -717,19 +726,21 @@ void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML
 			}
 			if (ni == NONODEINST) return;
 			(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYERPATTERN, VINTEGER);
+			endobjectchange((INTBIG)ni, VNODEINST);
 		}
-		ni = newnodeinst(gen_invispinprim, -40000, -8000, 6000, 8000, 0, 0, np);
+		ni = newnodeinst(gen_invispinprim, -24000, -24000, 7000, 7000, 0, 0, np);
 		if (ni == NONODEINST) return;
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)"Stipple Pattern",
 			VSTRING|VDISPLAY);
 		if (var != NOVARIABLE)
-			defaulttextsize(2, var->textdescript);
+			TDSETSIZE(var->textdescript, TXTSETQLAMBDA(2));
+		endobjectchange((INTBIG)ni, VNODEINST);
 	}
 
 	/* create the color style object */
 	if (laystyle == NONODEINST)
 	{
-		ni = newnodeinst(gen_invispinprim, 0, 40000, 16000, 20000, 0, 0, np);
+		ni = newnodeinst(gen_invispinprim, 20000, 20000, 18000, 18000, 0, 0, np);
 		if (ni == NONODEINST) return;
 		(void)initinfstr();
 		(void)addstringtoinfstr(TECEDNODETEXTSTYLE);
@@ -743,12 +754,13 @@ void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML
 		if (var != NOVARIABLE)
 			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYERSTYLE, VINTEGER);
+		endobjectchange((INTBIG)ni, VNODEINST);
 	}
 
 	/* create the CIF layer object */
 	if (laycif == NONODEINST)
 	{
-		ni = newnodeinst(gen_invispinprim, 0, 40000, 10000, 14000, 0, 0, np);
+		ni = newnodeinst(gen_invispinprim, 20000, 20000, 12000, 12000, 0, 0, np);
 		if (ni == NONODEINST) return;
 		(void)initinfstr();
 		(void)addstringtoinfstr(TECEDNODETEXTCIF);
@@ -758,12 +770,13 @@ void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML
 		if (var != NOVARIABLE)
 			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYERCIF, VINTEGER);
+		endobjectchange((INTBIG)ni, VNODEINST);
 	}
 
 	/* create the DXF layer object */
 	if (laydxf == NONODEINST)
 	{
-		ni = newnodeinst(gen_invispinprim, 0, 40000, 4000, 8000, 0, 0, np);
+		ni = newnodeinst(gen_invispinprim, 20000, 20000, 6000, 6000, 0, 0, np);
 		if (ni == NONODEINST) return;
 		(void)initinfstr();
 		(void)addstringtoinfstr(TECEDNODETEXTDXF);
@@ -773,12 +786,13 @@ void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML
 		if (var != NOVARIABLE)
 			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYERDXF, VINTEGER);
+		endobjectchange((INTBIG)ni, VNODEINST);
 	}
 
 	/* create the Calma GDS-II layer object */
 	if (laycalma == NONODEINST)
 	{
-		ni = newnodeinst(gen_invispinprim, 0, 40000, -2000, 2000, 0, 0, np);
+		ni = newnodeinst(gen_invispinprim, 20000, 20000, 0, 0, 0, 0, np);
 		if (ni == NONODEINST) return;
 		(void)initinfstr();
 		(void)addstringtoinfstr(TECEDNODETEXTGDS);
@@ -789,12 +803,13 @@ void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML
 		if (var != NOVARIABLE)
 			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYERGDS, VINTEGER);
+		endobjectchange((INTBIG)ni, VNODEINST);
 	}
 
 	/* create the Function object */
 	if (layfunction == NONODEINST)
 	{
-		ni = newnodeinst(gen_invispinprim, 0, 40000, -8000, -4000, 0, 0, np);
+		ni = newnodeinst(gen_invispinprim, 20000, 20000, -6000, -6000, 0, 0, np);
 		if (ni == NONODEINST) return;
 		(void)initinfstr();
 		(void)addstringtoinfstr(TECEDNODETEXTFUNCTION);
@@ -804,12 +819,13 @@ void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML
 		if (var != NOVARIABLE)
 			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYERFUNCTION, VINTEGER);
+		endobjectchange((INTBIG)ni, VNODEINST);
 	}
 
 	/* create the Layer Letters object */
 	if (layletters == NONODEINST)
 	{
-		ni = newnodeinst(gen_invispinprim, 0, 40000, -14000, -10000, 0, 0, np);
+		ni = newnodeinst(gen_invispinprim, 20000, 20000, -12000, -12000, 0, 0, np);
 		if (ni == NONODEINST) return;
 		(void)initinfstr();
 		(void)addstringtoinfstr(TECEDNODETEXTLETTERS);
@@ -819,12 +835,13 @@ void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML
 		if (var != NOVARIABLE)
 			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYERLETTERS, VINTEGER);
+		endobjectchange((INTBIG)ni, VNODEINST);
 	}
 
 	/* create the SPICE resistance object */
 	if (layspires == NONODEINST)
 	{
-		ni = newnodeinst(gen_invispinprim, 0, 40000, -20000, -16000, 0, 0, np);
+		ni = newnodeinst(gen_invispinprim, 20000, 20000, -18000, -18000, 0, 0, np);
 		if (ni == NONODEINST) return;
 		(void)initinfstr();
 		(void)addstringtoinfstr(TECEDNODETEXTSPICERES);
@@ -835,12 +852,13 @@ void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML
 		if (var != NOVARIABLE)
 			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYERSPIRES, VINTEGER);
+		endobjectchange((INTBIG)ni, VNODEINST);
 	}
 
 	/* create the SPICE capacitance object */
 	if (layspicap == NONODEINST)
 	{
-		ni = newnodeinst(gen_invispinprim, 0, 40000, -26000, -22000, 0, 0, np);
+		ni = newnodeinst(gen_invispinprim, 20000, 20000, -24000, -24000, 0, 0, np);
 		if (ni == NONODEINST) return;
 		(void)initinfstr();
 		(void)addstringtoinfstr(TECEDNODETEXTSPICECAP);
@@ -851,12 +869,13 @@ void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML
 		if (var != NOVARIABLE)
 			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYERSPICAP, VINTEGER);
+		endobjectchange((INTBIG)ni, VNODEINST);
 	}
 
 	/* create the SPICE edge capacitance object */
 	if (layspiecap == NONODEINST)
 	{
-		ni = newnodeinst(gen_invispinprim, 0, 40000, -32000, -28000, 0, 0, np);
+		ni = newnodeinst(gen_invispinprim, 20000, 20000, -30000, -30000, 0, 0, np);
 		if (ni == NONODEINST) return;
 		(void)initinfstr();
 		(void)addstringtoinfstr(TECEDNODETEXTSPICEECAP);
@@ -867,12 +886,13 @@ void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML
 		if (var != NOVARIABLE)
 			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYERSPIECAP, VINTEGER);
+		endobjectchange((INTBIG)ni, VNODEINST);
 	}
 
 	/* create the 3D height object */
 	if (lay3dheight == NONODEINST)
 	{
-		ni = newnodeinst(gen_invispinprim, 0, 40000, -38000, -34000, 0, 0, np);
+		ni = newnodeinst(gen_invispinprim, 20000, 20000, -36000, -36000, 0, 0, np);
 		if (ni == NONODEINST) return;
 		(void)initinfstr();
 		(void)addstringtoinfstr(TECEDNODETEXT3DHEIGHT);
@@ -883,12 +903,13 @@ void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML
 		if (var != NOVARIABLE)
 			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYER3DHEIGHT, VINTEGER);
+		endobjectchange((INTBIG)ni, VNODEINST);
 	}
 
 	/* create the 3D thickness object */
 	if (lay3dthick == NONODEINST)
 	{
-		ni = newnodeinst(gen_invispinprim, 0, 40000, -44000, -40000, 0, 0, np);
+		ni = newnodeinst(gen_invispinprim, 20000, 20000, -42000, -42000, 0, 0, np);
 		if (ni == NONODEINST) return;
 		(void)initinfstr();
 		(void)addstringtoinfstr(TECEDNODETEXT3DTHICK);
@@ -899,6 +920,7 @@ void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML
 		if (var != NOVARIABLE)
 			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYER3DTHICK, VINTEGER);
+		endobjectchange((INTBIG)ni, VNODEINST);
 	}
 }
 
@@ -908,7 +930,7 @@ void us_tecedmakelayer(NODEPROTO *np, INTSML colorindex, UINTSML stip[8], INTSML
  */
 void us_tecedaddfunstring(INTBIG func)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 
 	(void)addstringtoinfstr(us_teclayer_functions[func&LFTYPE].name);
 	for(i=0; us_teclayer_functions[i].name != 0; i++)
@@ -937,7 +959,7 @@ void us_tecedmakearc(NODEPROTO *np, INTBIG func, INTBIG fixang, INTBIG wipes, IN
 	char line[50];
 
 	/* create the Function object */
-	ni = newnodeinst(gen_invispinprim, 0, 40000, -2000, 2000, 0, 0, np);
+	ni = newnodeinst(gen_invispinprim, 20000, 20000, 0, 0, 0, 0, np);
 	if (ni == NONODEINST) return;
 	(void)initinfstr();
 	(void)addstringtoinfstr(TECEDNODETEXTFUNCTION);
@@ -946,53 +968,58 @@ void us_tecedmakearc(NODEPROTO *np, INTBIG func, INTBIG fixang, INTBIG wipes, IN
 	if (var != NOVARIABLE)
 		defaulttextsize(2, var->textdescript);
 	(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", ARCFUNCTION, VINTEGER);
+	endobjectchange((INTBIG)ni, VNODEINST);
 
 	/* create the Fixed-angle object */
-	ni = newnodeinst(gen_invispinprim, 0, 40000, -8000, -4000, 0, 0, np);
+	ni = newnodeinst(gen_invispinprim, 20000, 20000, -6000, -6000, 0, 0, np);
 	if (ni == NONODEINST) return;
 	if (fixang != 0) str = "Fixed-angle: Yes"; else str = "Fixed-angle: No";
 	var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)str, VSTRING|VDISPLAY);
 	if (var != NOVARIABLE)
 		defaulttextsize(2, var->textdescript);
 	(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", ARCFIXANG, VINTEGER);
+	endobjectchange((INTBIG)ni, VNODEINST);
 
 	/* create the Wipe object */
-	ni = newnodeinst(gen_invispinprim, 0, 40000, -14000, -10000, 0, 0, np);
+	ni = newnodeinst(gen_invispinprim, 20000, 20000, -12000, -12000, 0, 0, np);
 	if (ni == NONODEINST) return;
 	if (wipes != 0) str = "Wipes pins: Yes"; else str = "Wipes pins: No";
 	var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)str, VSTRING|VDISPLAY);
 	if (var != NOVARIABLE)
 		defaulttextsize(2, var->textdescript);
 	(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", ARCWIPESPINS, VINTEGER);
+	endobjectchange((INTBIG)ni, VNODEINST);
 
 	/* create the Noextend object */
-	ni = newnodeinst(gen_invispinprim, 0, 40000, -20000, -16000, 0, 0, np);
+	ni = newnodeinst(gen_invispinprim, 20000, 20000, -18000, -18000, 0, 0, np);
 	if (ni == NONODEINST) return;
 	if (noextend == 0) str = "Extend arcs: Yes"; else str = "Extend arcs: No";
 	var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)str, VSTRING|VDISPLAY);
 	if (var != NOVARIABLE)
 		defaulttextsize(2, var->textdescript);
 	(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", ARCNOEXTEND, VINTEGER);
+	endobjectchange((INTBIG)ni, VNODEINST);
 
 	/* create the Angle Increment object */
-	ni = newnodeinst(gen_invispinprim, 0, 40000, -26000, -22000, 0, 0, np);
+	ni = newnodeinst(gen_invispinprim, 20000, 20000, -24000, -24000, 0, 0, np);
 	if (ni == NONODEINST) return;
 	(void)sprintf(line, "Angle increment: %ld", anginc);
 	var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)line, VSTRING|VDISPLAY);
 	if (var != NOVARIABLE)
 		defaulttextsize(2, var->textdescript);
 	(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", ARCINC, VINTEGER);
+	endobjectchange((INTBIG)ni, VNODEINST);
 }
 
 /*
  * routine to build the appropriate descriptive information for a node into
  * facet "np".  The function is in "func", the serpentine transistor factor
- * is in "serp", the node is square if "square" is nonzero, the node
- * is invisible on 1 or 2 arcs if "wipes" is nonzero, and the node is lockable
- * if "lockable" is nonzero.
+ * is in "serp", the node is square if "square" is true, the node
+ * is invisible on 1 or 2 arcs if "wipes" is true, and the node is lockable
+ * if "lockable" is true.
  */
-void us_tecedmakenode(NODEPROTO *np, INTBIG func, INTSML serp, INTSML square, INTSML wipes,
-	INTSML lockable)
+void us_tecedmakenode(NODEPROTO *np, INTBIG func, BOOLEAN serp, BOOLEAN square, BOOLEAN wipes,
+	BOOLEAN lockable)
 {
 	REGISTER NODEINST *ni, *nifunc, *niserp, *nisquare, *niwipes, *nilockable;
 	REGISTER char *str;
@@ -1016,67 +1043,72 @@ void us_tecedmakenode(NODEPROTO *np, INTBIG func, INTSML serp, INTSML square, IN
 	/* create the Function object if it is not there */
 	if (nifunc == NONODEINST)
 	{
-		ni = newnodeinst(gen_invispinprim, 0, 40000, -2000, 2000, 0, 0, np);
+		ni = newnodeinst(gen_invispinprim, 20000, 20000, 0, 0, 0, 0, np);
 		if (ni == NONODEINST) return;
 		(void)initinfstr();
 		(void)addstringtoinfstr(TECEDNODETEXTFUNCTION);
-		(void)addstringtoinfstr(us_tecnode_functions[func].name);
+		(void)addstringtoinfstr(nodefunctionname(func, NONODEINST));
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)returninfstr(),
 			VSTRING|VDISPLAY);
 		if (var != NOVARIABLE)
 			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", NODEFUNCTION, VINTEGER);
+		endobjectchange((INTBIG)ni, VNODEINST);
 	}
 
 	/* create the Serpentine Transistor object if it is not there */
 	if (niserp == NONODEINST)
 	{
-		ni = newnodeinst(gen_invispinprim, 0, 40000, -8000, -4000, 0, 0, np);
+		ni = newnodeinst(gen_invispinprim, 20000, 20000, -6000, -6000, 0, 0, np);
 		if (ni == NONODEINST) return;
-		if (serp != 0) str = "Serpentine transistor: yes"; else
+		if (serp) str = "Serpentine transistor: yes"; else
 			str = "Serpentine transistor: no";
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)str, VSTRING|VDISPLAY);
 		if (var != NOVARIABLE)
 			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", NODESERPENTINE, VINTEGER);
+		endobjectchange((INTBIG)ni, VNODEINST);
 	}
 
 	/* create the Square Node object if it is not there */
 	if (nisquare == NONODEINST)
 	{
-		ni = newnodeinst(gen_invispinprim, 0, 40000, -14000, -10000, 0, 0, np);
+		ni = newnodeinst(gen_invispinprim, 20000, 20000, -12000, -12000, 0, 0, np);
 		if (ni == NONODEINST) return;
-		if (square != 0) str = "Square node: yes"; else
+		if (square) str = "Square node: yes"; else
 			str = "Square node: no";
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)str, VSTRING|VDISPLAY);
 		if (var != NOVARIABLE)
 			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", NODESQUARE, VINTEGER);
+		endobjectchange((INTBIG)ni, VNODEINST);
 	}
 
 	/* create the Wipes Node object if it is not there */
 	if (niwipes == NONODEINST)
 	{
-		ni = newnodeinst(gen_invispinprim, 0, 40000, -20000, -16000, 0, 0, np);
+		ni = newnodeinst(gen_invispinprim, 20000, 20000, -18000, -18000, 0, 0, np);
 		if (ni == NONODEINST) return;
-		if (wipes != 0) str = "Invisible with 1 or 2 arcs: yes"; else
+		if (wipes) str = "Invisible with 1 or 2 arcs: yes"; else
 			str = "Invisible with 1 or 2 arcs: no";
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)str, VSTRING|VDISPLAY);
 		if (var != NOVARIABLE)
 			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", NODEWIPES, VINTEGER);
+		endobjectchange((INTBIG)ni, VNODEINST);
 	}
 
 	/* create the Lockable Node object if it is not there */
 	if (nilockable == NONODEINST)
 	{
-		ni = newnodeinst(gen_invispinprim, 0, 40000, -26000, -22000, 0, 0, np);
+		ni = newnodeinst(gen_invispinprim, 20000, 20000, -24000, -24000, 0, 0, np);
 		if (ni == NONODEINST) return;
-		if (lockable != 0) str = "Lockable: yes"; else str = "Lockable: no";
+		if (lockable) str = "Lockable: yes"; else str = "Lockable: no";
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)str, VSTRING|VDISPLAY);
 		if (var != NOVARIABLE)
 			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", NODELOCKABLE, VINTEGER);
+		endobjectchange((INTBIG)ni, VNODEINST);
 	}
 }
 
@@ -1105,19 +1137,20 @@ void us_tecedmakeinfo(NODEPROTO *np, INTBIG lambda, char *description)
 	/* create the Lambda object if it is not there */
 	if (nilambda == NONODEINST)
 	{
-		ni = newnodeinst(gen_invispinprim, 0, 40000, -2000, 2000, 0, 0, np);
+		ni = newnodeinst(gen_invispinprim, 20000, 20000, 0, 0, 0, 0, np);
 		if (ni == NONODEINST) return;
 		(void)sprintf(line, "Lambda: %ld", lambda);
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)line, VSTRING|VDISPLAY);
 		if (var != NOVARIABLE)
 			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", TECHLAMBDA, VINTEGER);
+		endobjectchange((INTBIG)ni, VNODEINST);
 	}
 
 	/* create the Description object if it is not there */
 	if (nidescript == NONODEINST)
 	{
-		ni = newnodeinst(gen_invispinprim, 0, 40000, -8000, -4000, 0, 0, np);
+		ni = newnodeinst(gen_invispinprim, 20000, 20000, -6000, -6000, 0, 0, np);
 		if (ni == NONODEINST) return;
 		(void)initinfstr();
 		(void)addstringtoinfstr("Description: ");
@@ -1127,30 +1160,10 @@ void us_tecedmakeinfo(NODEPROTO *np, INTBIG lambda, char *description)
 		if (var != NOVARIABLE)
 			defaulttextsize(2, var->textdescript);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", TECHDESCRIPT, VINTEGER);
+		endobjectchange((INTBIG)ni, VNODEINST);
 	}
 }
 
-/*
- * routine to convert the dashes and other illegal characters in "str" to
- * the underscore character, then return the string
- */
-char *us_tecedstripdash(char *str)
-{
-	(void)initinfstr();
-	for( ; *str != 0; str++)
-	{
-		if (isalnum(*str)) (void)addtoinfstr(*str); else
-		{
-			switch (*str)
-			{
-				case '+': (void)addtoinfstr('P');   break;
-				default:  (void)addtoinfstr('_');   break;
-			}
-		}
-	}
-	return(returninfstr());
-}
-
 NODEINST *us_tecedplacegeom(POLYGON *poly, NODEPROTO *np)
 {
 	INTBIG lx, hx, ly, hy, dummy;
@@ -1161,7 +1174,7 @@ NODEINST *us_tecedplacegeom(POLYGON *poly, NODEPROTO *np)
 	switch (poly->style)
 	{
 		case FILLED:
-			if (isbox(poly, &dummy, &dummy, &dummy, &dummy) == 0)
+			if (!isbox(poly, &dummy, &dummy, &dummy, &dummy))
 			{
 				nni = newnodeinst(art_filledpolygonprim, lx, hx, ly, hy, 0, 0, np);
 				if (nni == NONODEINST) return(NONODEINST);
@@ -1176,7 +1189,7 @@ NODEINST *us_tecedplacegeom(POLYGON *poly, NODEPROTO *np)
 			endobjectchange((INTBIG)nni, VNODEINST);
 			return(nni);
 		case CLOSED:
-			if (isbox(poly, &dummy, &dummy, &dummy, &dummy) == 0)
+			if (!isbox(poly, &dummy, &dummy, &dummy, &dummy))
 			{
 				nni = newnodeinst(art_closedpolygonprim, lx, hx, ly, hy, 0, 0, np);
 				if (nni == NONODEINST) return(NONODEINST);
@@ -1224,6 +1237,11 @@ NODEINST *us_tecedplacegeom(POLYGON *poly, NODEPROTO *np)
 			if (nni == NONODEINST) return(NONODEINST);
 			endobjectchange((INTBIG)nni, VNODEINST);
 			return(nni);
+		case THICKCIRCLE:
+			nni = newnodeinst(art_thickcircleprim, lx, hx, ly, hy, 0, 0, np);
+			if (nni == NONODEINST) return(NONODEINST);
+			endobjectchange((INTBIG)nni, VNODEINST);
+			return(nni);
 		case DISC:
 			nni = newnodeinst(art_filledcircleprim, lx, hx, ly, hy, 0, 0, np);
 			if (nni == NONODEINST) return(NONODEINST);
@@ -1235,6 +1253,12 @@ NODEINST *us_tecedplacegeom(POLYGON *poly, NODEPROTO *np)
 			setarcdegrees(nni, 0.0, 45.0*EPI/180.0);
 			endobjectchange((INTBIG)nni, VNODEINST);
 			return(nni);
+		case THICKCIRCLEARC:
+			nni = newnodeinst(art_thickcircleprim, lx, hx, ly, hy, 0, 0, np);
+			if (nni == NONODEINST) return(NONODEINST);
+			setarcdegrees(nni, 0.0, 45.0*EPI/180.0);
+			endobjectchange((INTBIG)nni, VNODEINST);
+			return(nni);
 		case TEXTCENT:
 			nni = newnodeinst(gen_invispinprim, lx, hx, ly, hy, 0, 0, np);
 			if (nni == NONODEINST) return(NONODEINST);
@@ -1274,7 +1298,7 @@ NODEINST *us_tecedplacegeom(POLYGON *poly, NODEPROTO *np)
 void us_tecedsetlist(NODEINST *ni, POLYGON *poly, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy)
 {
 	REGISTER INTBIG *list;
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 
 	list = emalloc((poly->count*2*SIZEOFINTBIG), el_tempcluster);
 	if (list == 0) return;
@@ -1283,7 +1307,7 @@ void us_tecedsetlist(NODEINST *ni, POLYGON *poly, INTBIG lx, INTBIG hx, INTBIG l
 		list[i*2] = poly->xv[i] - (hx+lx)/2;
 		list[i*2+1] = poly->yv[i] - (hy+ly)/2;
 	}
-	(void)setvalkey((INTBIG)ni, VNODEINST, el_trace, (INTBIG)list,
+	(void)setvalkey((INTBIG)ni, VNODEINST, el_trace_key, (INTBIG)list,
 		VINTEGER|VISARRAY|((poly->count*2)<<VLENGTHSH));
 	efree((char *)list);
 }
