@@ -36,28 +36,32 @@
 
 /****************************** LIBRARY GRAPHING *****************************/
 
-typedef struct
+#define NONODEDESCR ((NODEDESCR *)-1)
+
+typedef struct Inodedescr
 {
-	INTBIG x, y;
-	INTBIG yoff;
-	NODEINST *pin;
+	INTBIG             x, y;
+	INTBIG             yoff;
+	NODEINST          *pin;
+	struct Inodedescr *main;
 } NODEDESCR;
 
 static NODEPROTO *us_graphmainview(NODEPROTO *np);
 
-void us_graphfacets(void)
+void us_graphfacets(NODEPROTO *top)
 {
 	REGISTER NODEPROTO *np, *sub, *graphnp, *truenp, *truesubnp;
 	REGISTER NODEINST *ni, *nibot, *toppin;
 	REGISTER ARCINST *ai;
 	REGISTER LIBRARY *lib;
-	REGISTER INTSML more, maxdepth, color;
+	REGISTER INTBIG more, maxdepth, color;
 	REGISTER INTBIG *xval, *yoff, i, x, y, xe, ye, clock, maxwidth, xsc, lambda, xscale, yscale, yoffset;
 	REGISTER PORTPROTO *pinpp;
 	REGISTER VARIABLE *var;
 	REGISTER NODEDESCR *nd, *ndsub;
+	float spread;
 
-	pinpp = art_pinprim->firstportproto;
+	pinpp = gen_invispinprim->firstportproto;
 
 	/* create the graph facet */
 	graphnp = newnodeproto("FacetStructure", el_curlib);
@@ -72,9 +76,12 @@ void us_graphfacets(void)
 			np->temp1 = -1;
 
 	/* find all top-level facets */
-	for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+	if (top != NONODEPROTO) top->temp1 = 0; else
 	{
-		if (np->firstinst == NONODEINST) np->temp1 = 0;
+		for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+		{
+			if (np->firstinst == NONODEINST) np->temp1 = 0;
+		}
 	}
 
 	/* now place all facets at their proper depth */
@@ -97,7 +104,7 @@ void us_graphfacets(void)
 				if (sub->temp1 <= np->temp1)
 				{
 					sub->temp1 = np->temp1 + 1;
-					if (sub->temp1 > maxdepth) maxdepth = (INTSML)sub->temp1;
+					if (sub->temp1 > maxdepth) maxdepth = sub->temp1;
 					more++;
 				}
 				truenp = contentsview(ni->proto);
@@ -105,14 +112,14 @@ void us_graphfacets(void)
 				if (truenp->temp1 <= np->temp1)
 				{
 					truenp->temp1 = np->temp1 + 1;
-					if (truenp->temp1 > maxdepth) maxdepth = (INTSML)truenp->temp1;
+					if (truenp->temp1 > maxdepth) maxdepth = truenp->temp1;
 					more++;
 				}
 			}
 		}
 
 		/* add in any facets referenced from other libraries */
-		if (more == 0)
+		if (more == 0 && top == NONODEPROTO)
 		{
 			for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 			{
@@ -149,6 +156,7 @@ void us_graphfacets(void)
 
 		nd = (NODEDESCR *)emalloc(sizeof (NODEDESCR), us_tool->cluster);
 		nd->pin = NONODEINST;
+		nd->main = NONODEDESCR;
 
 		nd->x = xval[np->temp1];
 		xval[np->temp1] += strlen(describenodeproto(np));
@@ -166,7 +174,6 @@ void us_graphfacets(void)
 		nd = (NODEDESCR *)np->temp1;
 		if (xval[nd->y] < maxwidth)
 		{
-			float spread;
 			spread = (float)maxwidth / (float)xval[nd->y];
 			nd->x = roundfloat(nd->x * spread);
 		}
@@ -189,22 +196,26 @@ void us_graphfacets(void)
 	}
 
 	/* make unattached facets sit with their contents view */
-	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
-		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+	if (top == NONODEPROTO)
 	{
-		if (np->temp1 != -1) continue;
-		if (np->firstnodeinst != NONODEINST && np->cellview != el_iconview &&
-				np->cellview != el_skeletonview) continue;
-		truenp = us_graphmainview(np);
-		if (truenp == NONODEPROTO) continue;
-		if (truenp->temp1 == -1) continue;
+		for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
+			for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+		{
+			if (np->temp1 != -1) continue;
+			if (np->firstnodeinst != NONODEINST && np->cellview != el_iconview &&
+					np->cellview != el_skeletonview) continue;
+			truenp = us_graphmainview(np);
+			if (truenp == NONODEPROTO) continue;
+			if (truenp->temp1 == -1) continue;
 
-		nd = (NODEDESCR *)truenp->temp1;
-		ndsub = (NODEDESCR *)emalloc(sizeof (NODEDESCR), us_tool->cluster);
-		ndsub->pin = NONODEINST;
-		nd->yoff += yoffset*2;
-		ndsub->x = nd->x;   ndsub->y = nd->y + nd->yoff;
-		np->temp1 = (INTBIG)ndsub;
+			nd = (NODEDESCR *)truenp->temp1;
+			ndsub = (NODEDESCR *)emalloc(sizeof (NODEDESCR), us_tool->cluster);
+			ndsub->pin = NONODEINST;
+			ndsub->main = nd;
+			nd->yoff += yoffset*2;
+			ndsub->x = nd->x;   ndsub->y = nd->y + nd->yoff;
+			np->temp1 = (INTBIG)ndsub;
+		}
 	}
 
 	/* write the header message */
@@ -213,7 +224,13 @@ void us_graphfacets(void)
 	if (ni == NONODEINST) return;
 	endobjectchange((INTBIG)ni, VNODEINST);
 	(void)initinfstr();
-	(void)formatinfstr(_("Structure of library %s"), el_curlib->libname);
+	if (top != NONODEPROTO)
+	{
+		(void)formatinfstr(_("Structure below facet %s"), describenodeproto(top));
+	} else
+	{
+		(void)formatinfstr(_("Structure of library %s"), el_curlib->libname);
+	}
 	var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)returninfstr(),
 		VSTRING|VDISPLAY);
 	if (var != NOVARIABLE)
@@ -227,9 +244,6 @@ void us_graphfacets(void)
 		if (np->temp1 == -1) continue;
 		nd = (NODEDESCR *)np->temp1;
 
-		/* always use the contents facet, not the icon */
-		truenp = np;
-
 		x = nd->x;   y = nd->y;
 		ni = newnodeinst(gen_invispinprim, x, x, y, y, 0, 0, graphnp);
 		if (ni == NONODEINST) return;
@@ -237,12 +251,30 @@ void us_graphfacets(void)
 		nd->pin = ni;
 
 		/* write the facet name in the node */
-		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)describenodeproto(truenp),
+		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)describenodeproto(np),
 			VSTRING|VDISPLAY);
 		if (var != NOVARIABLE)
 			TDSETSIZE(var->textdescript, TXTSETQLAMBDA(4));
 	}
 
+	/* attach related components with rigid arcs */
+	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
+		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+	{
+		if (np == graphnp) continue;
+		if (np->temp1 == -1) continue;
+		nd = (NODEDESCR *)np->temp1;
+		if (nd->main == NONODEDESCR) continue;
+
+		ai = newarcinst(art_solidarc, 0, FIXED, nd->pin, pinpp, nd->x, nd->y,
+			nd->main->pin, pinpp, nd->main->x, nd->main->y, graphnp);
+		if (ai == NOARCINST) return;
+		endobjectchange((INTBIG)ai, VARCINST);
+
+		/* set an invisible color on the arc */
+		(void)setvalkey((INTBIG)ai, VARCINST, art_colorkey, 0, VINTEGER);
+	}
+
 	/* build wires between the hierarchical levels */
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
@@ -277,23 +309,14 @@ void us_graphfacets(void)
 
 			/* draw a line from facet "truenp" to facet "truesubnp" */
 			x = nd->x;
-			y = nd->y + gen_invispinprim->highy;
+			y = nd->y;
 
 			if (truesubnp->temp1 == -1) continue;
 			ndsub = (NODEDESCR *)truesubnp->temp1;
 			xe = ndsub->x;
-			ye = ndsub->y + gen_invispinprim->highy;
-			if (toppin == NONODEINST)
-			{
-				toppin = newnodeinst(art_pinprim, x+art_pinprim->lowx, x+art_pinprim->highx,
-					y+art_pinprim->lowy, y+art_pinprim->highy, 0, 0, graphnp);
-				if (toppin == NONODEINST) return;
-				endobjectchange((INTBIG)toppin, VNODEINST);
-			}
-			nibot = newnodeinst(art_pinprim, xe+art_pinprim->lowx, xe+art_pinprim->highx,
-				ye+art_pinprim->lowy, ye+art_pinprim->highy, 0, 0, graphnp);
-			if (nibot == NONODEINST) return;
-			endobjectchange((INTBIG)nibot, VNODEINST);
+			ye = ndsub->y;
+			toppin = nd->pin;
+			nibot = ndsub->pin;
 			ai = newarcinst(art_solidarc, defaultarcwidth(art_solidarc), 0, toppin,
 				pinpp, x, y, nibot, pinpp, xe, ye, graphnp);
 			if (ai == NOARCINST) return;
@@ -365,8 +388,8 @@ typedef struct Icomill
 	char *name;
 	INTBIG  x, y;
 	INTBIG  realx;
-	INTSML  children;
-	INTSML  depth;
+	INTBIG  children;
+	INTBIG  depth;
 	struct Icomill *parent;
 	struct Icomill *nextcomill;
 	NODEINST *real;
@@ -375,16 +398,16 @@ typedef struct Icomill
 static COMILL *us_comilllist[MAXILLUSTRATEWIDTH];
 static COMILL *us_allcomill;
 
-static INTSML us_maxillustratedepth, us_maxcommandentries;
+static INTBIG us_maxillustratedepth, us_maxcommandentries;
 static INTBIG us_illustrateXpos[MAXILLUSTRATEDEPTH];		/* current build-out X position */
 static COMCOMP *us_illustrateparam[MAXILLUSTRATEDEPTH];	/* current parameter type */
 
 /* prototypes for local routines */
-static COMILL *us_illustratecommand(char*, INTSML, COMILL*);
+static COMILL *us_illustratecommand(char*, INTBIG, COMILL*);
 
 void us_illustratecommandset(void)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 	REGISTER INTBIG j;
 	char *newmessage[1];
 	REGISTER NODEPROTO *graphnp;
@@ -413,10 +436,10 @@ void us_illustratecommandset(void)
 		for(j=0; j<us_lcommand[i].params; j++)
 			us_illustrateparam[j] = us_lcommand[i].par[j];
 		us_illustrateparam[us_lcommand[i].params] = NOCOMCOMP;
-		us_comilllist[i] = us_illustratecommand(us_lcommand[i].name, 0,NOCOMILL);
+		us_comilllist[i] = us_illustratecommand(us_lcommand[i].name, 0, NOCOMILL);
 	}
 
-	ttyputmsg(_("%d entries in command graph"), us_maxcommandentries);
+	ttyputmsg(_("%ld entries in command graph"), us_maxcommandentries);
 
 	/* count the breadth information */
 	j = 0;
@@ -493,13 +516,13 @@ void us_illustratecommandset(void)
 	us_editfacet(1, newmessage);
 }
 
-COMILL *us_illustratecommand(char *name, INTSML depth, COMILL *thisci)
+COMILL *us_illustratecommand(char *name, INTBIG depth, COMILL *thisci)
 {
 	static COMCOMP us_recursioncomcomp = {
 		NOKEYWORD, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP, 0, "", ""};
 	REGISTER COMCOMP *cc;
 	REGISTER COMILL *ci, *subci;
-	REGISTER INTSML i, j, k;
+	REGISTER INTBIG i, j, k;
 	REGISTER char *arg;
 
 	/* put this name at the appropriate depth */
@@ -523,7 +546,7 @@ COMILL *us_illustratecommand(char *name, INTSML depth, COMILL *thisci)
 	{
 		/* force extension of the tree to a specified depth */
 		if (depth < FORCEDDEPTH)
-			(void)us_illustratecommand((char *)0, (INTSML)(depth+1), ci);
+			(void)us_illustratecommand((char *)0, depth+1, ci);
 		return(ci);
 	}
 
@@ -561,7 +584,7 @@ COMILL *us_illustratecommand(char *name, INTSML depth, COMILL *thisci)
 		if (cc->toplist == us_topofallthings) arg = "ANY"; else
 		if (cc->toplist == us_topofvars) arg = "VAR"; else
 		if (cc == &us_recursioncomcomp) arg = "***"; else arg = "ARG";
-		subci = us_illustratecommand(arg, (INTSML)(depth+1), ci);
+		subci = us_illustratecommand(arg, depth+1, ci);
 		if (subci == NOCOMILL) return(NOCOMILL);
 		return(ci);
 	}
@@ -579,7 +602,7 @@ COMILL *us_illustratecommand(char *name, INTSML depth, COMILL *thisci)
 			us_illustrateparam[depth+j+1] = &us_recursioncomcomp;
 		}
 
-		subci = us_illustratecommand(cc->ifmatch[i].name, (INTSML)(depth+1), ci);
+		subci = us_illustratecommand(cc->ifmatch[i].name, depth+1, ci);
 		if (subci == NOCOMILL) return(NOCOMILL);
 
 		/* remove the inserted options */
@@ -604,10 +627,10 @@ void us_dumppulldownmenus(void)
 	REGISTER INTBIG i;
 	REGISTER POPUPMENU *pm;
 
-	io = xcreate("pulldowns.txt", el_filetypetext, _("Menu dump file"), &truename);
+	io = xcreate("pulldowns.txt", el_filetypetext, M_("Menu dump file"), &truename);
 	if (io == NULL) return;
 
-	xprintf(io, _("Pulldown menus in Electric as of %s\n"),
+	xprintf(io, M_("Pulldown menus in Electric as of %s\n"),
 		timetostring(getcurrenttime()));
 	for(i=0; i<us_pulldownmenucount; i++)
 	{
@@ -617,7 +640,7 @@ void us_dumppulldownmenus(void)
 	}
 
 	xclose(io);
-	ttyputmsg(_("Pulldown menus dumped to %s"), truename);
+	ttyputmsg(M_("Pulldown menus dumped to %s"), truename);
 }
 
 void us_dumppulldownmenu(FILE *io, POPUPMENU *pm, char *name, char *prefix)
