@@ -53,11 +53,11 @@ GRAPHICS us_menutext = {LAYERA, MENTXT, SOLIDC, SOLIDC,
 #define MENUSHADOW      2	/* size of shadow around popup menus */
 
 /* prototypes for local routines */
-static INTSML us_groupfunction(NODEPROTO*);
+static INTBIG us_groupfunction(NODEPROTO*);
 static void us_pmfirst(void);
 static void us_pmdone(void);
-static INTSML us_pmeachchar(INTBIG, INTBIG, INTSML);
-static INTSML us_pmeachdown(INTBIG, INTBIG);
+static BOOLEAN us_pmeachchar(INTBIG, INTBIG, INTSML);
+static BOOLEAN us_pmeachdown(INTBIG, INTBIG);
 static void us_pminvertline(void);
 
 /****************************** MENU DISPLAY ******************************/
@@ -67,18 +67,21 @@ static void us_pminvertline(void);
  * each window will be rescaled to fit properly.  If "scaletofit" is negative,
  * each window will be adjusted to fit (but not shrunk back from edges).
  */
-void us_drawmenu(INTSML scaletofit, WINDOWFRAME *mw)
+void us_drawmenu(INTBIG scaletofit, WINDOWFRAME *mw)
 {
 	REGISTER INTBIG x, y;
-	REGISTER INTSML i;
-	INTSML swid, shei;
+	REGISTER INTBIG i;
+	BOOLEAN placemenu;
+	INTBIG swid, shei;
 	REGISTER WINDOWPART *w;
 	REGISTER VARIABLE *var;
 	static POLYGON *poly = NOPOLYGON;
 	WINDOWPART ww;
 
 	/* re-draw windows */
-	us_windowfit(mw, scaletofit, scaletofit);
+	if (scaletofit != 0) placemenu = TRUE; else
+		placemenu = FALSE;
+	us_windowfit(mw, placemenu, scaletofit);
 	us_erasescreen(mw);
 	for(w = el_topwindowpart; w != NOWINDOWPART; w = w->nextwindowpart)
 	{
@@ -87,7 +90,7 @@ void us_drawmenu(INTSML scaletofit, WINDOWFRAME *mw)
 		us_drawwindow(w, el_colwinbor);
 		if (w->redisphandler != 0) (*w->redisphandler)(w);
 	}
-	if (el_curwindowpart != NOWINDOWPART) us_highlightwindow(el_curwindowpart, 1);
+	if (el_curwindowpart != NOWINDOWPART) us_highlightwindow(el_curwindowpart, TRUE);
 
 	/* draw menu bar if it exists */
 	if (us_menubarsize != 0 && el_curwindowpart != NOWINDOWPART)
@@ -112,7 +115,7 @@ void us_drawmenu(INTSML scaletofit, WINDOWFRAME *mw)
 		poly->style = OPENED;
 		poly->desc = &us_box;
 		us_box.col = el_colmengly;
-		(void)us_showpoly(poly, &ww);
+		us_showpoly(poly, &ww);
 
 		/* draw the menu entries */
 		x = 0;
@@ -126,7 +129,7 @@ void us_drawmenu(INTSML scaletofit, WINDOWFRAME *mw)
 		{
 			maketruerectpoly(x, us_pulldownmenupos[i], shei-us_menubarsize, shei, poly);
 			poly->string = us_stripampersand(us_pulldowns[i]->header);
-			(void)us_showpoly(poly, &ww);
+			us_showpoly(poly, &ww);
 			x = us_pulldownmenupos[i];
 		}
 	}
@@ -138,7 +141,7 @@ void us_drawmenu(INTSML scaletofit, WINDOWFRAME *mw)
 			us_menuframe != mw) return;
 
 		/* draw the menu entries */
-		var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_binding_menu);
+		var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_binding_menu_key);
 		if (var == NOVARIABLE) return;
 
 		if (us_menupos <= 1)
@@ -173,7 +176,7 @@ void us_drawmenuentry(INTBIG x, INTBIG y, char *str)
 	WINDOWPART ww;
 	XARRAY trans;
 	char line[100];
-	INTSML swid, shei, pangle;
+	INTBIG swid, shei, pangle;
 	INTBIG pxs, pys;
 	static POLYGON *poly = NOPOLYGON;
 	WINDOWFRAME *menuframe;
@@ -210,7 +213,7 @@ void us_drawmenuentry(INTBIG x, INTBIG y, char *str)
 	maketruerectpoly(xl, xh, yl, yh, poly);
 	poly->desc = &us_ebox;
 	poly->style = FILLEDRECT;
-	(void)us_showpoly(poly, &ww);
+	us_showpoly(poly, &ww);
 
 	if (commandbinding.nodeglyph != NONODEPROTO || commandbinding.arcglyph != NOARCPROTO)
 	{
@@ -222,11 +225,11 @@ void us_drawmenuentry(INTBIG x, INTBIG y, char *str)
 			commandbinding.arcglyph == us_curarcproto)
 		{
 			maketruerectpoly(xl+2, xh-2, yl+2, yh-2, poly);
-			(void)us_showpoly(poly, &ww);
+			us_showpoly(poly, &ww);
 			maketruerectpoly(xl+3, xh-3, yl+3, yh-3, poly);
-			(void)us_showpoly(poly, &ww);
+			us_showpoly(poly, &ww);
 			maketruerectpoly(xl+4, xh-4, yl+4, yh-4, poly);
-			(void)us_showpoly(poly, &ww);
+			us_showpoly(poly, &ww);
 		}
 		maketruerectpoly(xl+1, xh-1, yl+1, yh-1, poly);
 	} else
@@ -236,13 +239,13 @@ void us_drawmenuentry(INTBIG x, INTBIG y, char *str)
 		us_box.col = commandbinding.backgroundcolor;
 		poly->style = FILLEDRECT;
 	}
-	(void)us_showpoly(poly, &ww);
+	us_showpoly(poly, &ww);
 
 	maketruerectpoly(xl, xh, yl, yh, poly);
 	poly->desc = &us_nmbox;
 	us_nmbox.col = el_colmenbor;
 	poly->style = CLOSEDRECT;
-	(void)us_showpoly(poly, &ww);
+	us_showpoly(poly, &ww);
 
 	/* stop now if there is no entry in this menu square */
 	if (*commandbinding.command == 0)
@@ -414,13 +417,14 @@ void us_drawmenuentry(INTBIG x, INTBIG y, char *str)
 		TDCLEAR(poly->textdescript);
 		TDSETSIZE(poly->textdescript, commandbinding.menumessagesize);
 		poly->tech = el_curtech;
-		if (commandbinding.menumessage != 0) poly->string = commandbinding.menumessage; else
+		if (commandbinding.menumessage != 0)
+			poly->string = commandbinding.menumessage; else
 		{
 			(void)strncpy(line, commandbinding.command, 99);
 			poly->string = line;
 			if (islower(line[0])) line[0] = toupper(line[0]);
 		}
-		(void)us_showpoly(poly, &ww);
+		us_showpoly(poly, &ww);
 	}
 	us_freebindingparse(&commandbinding);
 }
@@ -429,11 +433,11 @@ void us_drawmenuentry(INTBIG x, INTBIG y, char *str)
  * routine to return the function of nodeproto "np", grouped according to its
  * general function (i.e. all transistors return the same value).
  */
-INTSML us_groupfunction(NODEPROTO *np)
+INTBIG us_groupfunction(NODEPROTO *np)
 {
-	REGISTER INTSML fun;
+	REGISTER INTBIG fun;
 
-	fun = (INTSML)((np->userbits&NFUNCTION) >> NFUNCTIONSH);
+	fun = (np->userbits&NFUNCTION) >> NFUNCTIONSH;
 	switch (fun)
 	{
 		/* combine all transistors */
@@ -476,16 +480,6 @@ INTSML us_groupfunction(NODEPROTO *np)
 		case NPCONPOWER:   fun = NPCONGROUND;   break;
 
 		/* combine all SPICE parts */
-		case NPSOURCEV:
-		case NPSOURCEC:
-		case NPSOURCECM:
-		case NPSOURCET:
-		case NPSOURCEDC:
-		case NPSOURCEAC:
-		case NPSOURCEN:
-		case NPSOURCEX:
-		case NPSOURCEB:
-		case NPSOURCES:
 		case NPMETER:      fun = NPSOURCE;      break;
 
 		/* combine all bias parts */
@@ -512,7 +506,7 @@ void us_setmenunodearcs(void)
 	extern COMCOMP us_userp;
 
 	/* bind menu entries for arcs */
-	var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_binding_menu);
+	var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_binding_menu_key);
 	if (var == NOVARIABLE) return;
 	ap = el_curtech->firstarcproto;
 	np = el_curtech->firstnodeproto;
@@ -574,7 +568,7 @@ void us_setmenunodearcs(void)
 				if (didinst == 0)
 				{
 					didinst = 1;
-					if (parse("pmgetproto", &us_userp, 0) >= 0)
+					if (parse("pmgetproto", &us_userp, FALSE) >= 0)
 					{
 						par[2] = "message";
 						par[3] = _("Inst.");
@@ -591,7 +585,8 @@ void us_setmenunodearcs(void)
 				{
 					while (np != NONODEPROTO && (np->userbits & NNOTUSED) != 0)
 						np = np->nextnodeproto;
-					if (np != NONODEPROTO)
+					if (np != NONODEPROTO &&
+						((np->userbits&NFUNCTION)>>NFUNCTIONSH) != NPNODE)
 					{
 						par[7] = "node";   par[8] = describenodeproto(np);
 						us_bind(9, par);
@@ -601,7 +596,8 @@ void us_setmenunodearcs(void)
 					}
 				}
 
-				/* no nodes or arcs left: make it a dummy entry */
+				/* no nodes or arcs left: make it a blank entry */
+				par[6] = "-";
 				us_bind(7, par);
 			}
 		}
@@ -612,13 +608,12 @@ void us_setmenunodearcs(void)
 /*
  * routine to set the number of entries in the menu to "x" by "y", and to
  * place the menu on the proper side of the screen according to "position":
- * 0: top,  1: bottom,  2: left,  3: right.  If "allgetproto" is nonzero,
+ * 0: top,  1: bottom,  2: left,  3: right.  If "allgetproto" is true,
  * set every entry to the appropriate "getproto" command.
- * routine returns nonzero upon error.
  */
-INTSML us_setmenusize(INTSML x, INTSML y, INTSML position, INTSML allgetproto)
+void us_setmenusize(INTBIG x, INTBIG y, INTBIG position, BOOLEAN allgetproto)
 {
-	REGISTER INTSML i, oldlen;
+	REGISTER INTBIG i, oldlen;
 	REGISTER char **temp, *last;
 	REGISTER VARIABLE *oldvar;
 	COMMANDBINDING commandbinding;
@@ -633,18 +628,18 @@ INTSML us_setmenusize(INTSML x, INTSML y, INTSML position, INTSML allgetproto)
 		/* menu runs vertically down the left or right */
 		if (y < x) { i = x;  x = y;  y = i; }
 	}
-	if (us_menux == x && us_menuy == y && us_menupos == position && allgetproto == 0)
-		return(0);
+	if (us_menux == x && us_menuy == y && us_menupos == position && !allgetproto)
+		return;
 
 	/* set new size, position */
-	(void)setvalkey((INTBIG)us_tool, VTOOL, us_menu_x, x, VINTEGER|VDONTSAVE);
-	(void)setvalkey((INTBIG)us_tool, VTOOL, us_menu_y, y, VINTEGER|VDONTSAVE);
-	(void)setvalkey((INTBIG)us_tool, VTOOL, us_menu_position, position, VINTEGER|VDONTSAVE);
+	(void)setvalkey((INTBIG)us_tool, VTOOL, us_menu_x_key, x, VINTEGER|VDONTSAVE);
+	(void)setvalkey((INTBIG)us_tool, VTOOL, us_menu_y_key, y, VINTEGER|VDONTSAVE);
+	(void)setvalkey((INTBIG)us_tool, VTOOL, us_menu_position_key, position, VINTEGER|VDONTSAVE);
 
 	/* rebuild the binding array size */
 	temp = (char **)emalloc(x*y * (sizeof (char *)), el_tempcluster);
-	if (temp == 0) return(1);
-	if (allgetproto != 0)
+	if (temp == 0) return;
+	if (allgetproto)
 	{
 		for(i=0; i<x*y; i++) temp[i] = "command=getproto";
 		oldlen = 0;
@@ -652,8 +647,8 @@ INTSML us_setmenusize(INTSML x, INTSML y, INTSML position, INTSML allgetproto)
 	} else
 	{
 		for(i=0; i<x*y; i++) temp[i] = "";
-		oldvar = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_binding_menu);
-		if (oldvar == NOVARIABLE) oldlen = 0; else oldlen = (INTSML)getlength(oldvar);
+		oldvar = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_binding_menu_key);
+		if (oldvar == NOVARIABLE) oldlen = 0; else oldlen = getlength(oldvar);
 		last = NOSTRING;
 		for(i=0; i<mini(oldlen, x*y); i++)
 		{
@@ -673,12 +668,11 @@ INTSML us_setmenusize(INTSML x, INTSML y, INTSML position, INTSML allgetproto)
 			us_freebindingparse(&commandbinding);
 		}
 	}
-	(void)setvalkey((INTBIG)us_tool, VTOOL, us_binding_menu, (INTBIG)temp,
+	(void)setvalkey((INTBIG)us_tool, VTOOL, us_binding_menu_key, (INTBIG)temp,
 		VSTRING|VISARRAY|VDONTSAVE|((x*y)<<VLENGTHSH));
 	for(i=0; i<mini(oldlen, x*y); i++) efree(temp[i]);
 	efree((char *)temp);
 	if (last != NOSTRING) us_setmenunodearcs();
-	return(0);
 }
 
 /******************** POPUP MENUS ********************/
@@ -689,16 +683,16 @@ INTSML us_setmenusize(INTSML x, INTSML y, INTSML position, INTSML allgetproto)
 typedef struct
 {
 	WINDOWPART     popupwindow;		/* window in which popup resides */
-	INTSML         hline;			/* currently highlighted line in popup menu (-1 if none) */
-	INTSML         posx, posy;		/* position of lower-left corner of popup menu */
-	INTSML         sizex, sizey;	/* size of popup menu */
-	INTSML         txthei;			/* height of a line of the popup menu */
-	INTSML         yshift;			/* shift up amount when menu bumps bottom */
-	INTSML         attlen, vallen;	/* width of attribute and value fields in popup menu */
-	INTSML         curpos;			/* current character position in value field */
-	INTSML         header;			/* nonzero if a header is to be displayed in popup menu */
-	INTSML         quitline;		/* nonzero if menu should abort when it crosses a line */
-	INTSML         inarea;			/* global flag for being inside an area */
+	INTBIG         hline;			/* currently highlighted line in popup menu (-1 if none) */
+	INTBIG         posx, posy;		/* position of lower-left corner of popup menu */
+	INTBIG         sizex, sizey;	/* size of popup menu */
+	INTBIG         txthei;			/* height of a line of the popup menu */
+	INTBIG         yshift;			/* shift up amount when menu bumps bottom */
+	INTBIG         attlen, vallen;	/* width of attribute and value fields in popup menu */
+	INTBIG         curpos;			/* current character position in value field */
+	BOOLEAN        header;			/* true if a header is to be displayed in popup menu */
+	INTBIG         quitline;		/* nonzero if menu should abort when it crosses a line */
+	INTBIG         inarea;			/* global flag for being inside an area */
 	POPUPMENUITEM *retval;			/* return item */
 	POPUPMENU     *retmenu;			/* menu of returned item */
 	POPUPMENU     *current;			/* current popup menu structure */
@@ -709,7 +703,7 @@ static POPUPINST us_pmcur;
 /*
  * routine to display the popup menu "menu" and allow picking.  The menu
  * terminates when any button is clicked (a down-click is necessary if "*waitfordown"
- * is nonzero).  If "header" is nonzero, display a header.  If "top" and "left" are not
+ * is true).  If "header" is true, display a header.  If "top" and "left" are not
  * negative, they are used as the coordinates of the upper-left of the menu.  If
  * "quitline" is nonzero, then exit the menu when the cursor moves over that line
  * (1: left side, 2: right side, 3: pulldown menu extent, 4: popup menu extent).
@@ -717,16 +711,17 @@ static POPUPINST us_pmcur;
  * the menu (if a submenu in a hierarchy was used).  Returns NOPOPUPMENUITEM
  * if no entry was selected.  Returns zero if this function cannot be done.  If the
  * mouse is still down (because it crossed the quit line) then "waitfordown" is set
- * nonzero.  Also sets the "changed" items to nonzero for any entries that are modified.
+ * true.  Also sets the "changed" items to nonzero for any entries that are modified.
  */
-POPUPMENUITEM *us_popupmenu(POPUPMENU **cmenu, INTSML *waitfordown, INTSML header,
-	INTSML left, INTSML top, INTSML quitline)
+POPUPMENUITEM *us_popupmenu(POPUPMENU **cmenu, BOOLEAN *waitfordown, BOOLEAN header,
+	INTBIG left, INTBIG top, INTBIG quitline)
 {
-	REGISTER INTSML i, yp, waitdown, startfont;
+	REGISTER INTBIG i, yp, startfont;
+	BOOLEAN waitdown;
 	REGISTER char *savepos, *pt;
 	REGISTER INTBIG textscale, save_pix;
 	UINTBIG descript[TEXTDESCRIPTSIZE];
-	INTSML x, y, chwid, swid, shei;
+	INTBIG x, y, chwid, swid, shei;
 	REGISTER POPUPMENU *menu;
 	POPUPMENU *whichmenu;
 	REGISTER POPUPMENUITEM *mi;
@@ -744,7 +739,7 @@ POPUPMENUITEM *us_popupmenu(POPUPMENU **cmenu, INTSML *waitfordown, INTSML heade
 	if (i >= menu->total)
 	{
 		/* no type-in entries: see if OS can draw this simple popup menu */
-		if (graphicshas(CANSHOWPOPUP) != 0)
+		if (graphicshas(CANSHOWPOPUP))
 		{
 			whichmenu = menu;
 			i = nativepopupmenu(&whichmenu, header, left, top);
@@ -758,7 +753,7 @@ POPUPMENUITEM *us_popupmenu(POPUPMENU **cmenu, INTSML *waitfordown, INTSML heade
 
 	/* determine width of attribute and value halves in menu */
 	waitdown = *waitfordown;
-	*waitfordown = 0;
+	*waitfordown = FALSE;
 	us_pmcur.header = header;
 	us_pmcur.current = menu;
 	us_pmcur.inarea = 0;
@@ -768,7 +763,7 @@ POPUPMENUITEM *us_popupmenu(POPUPMENU **cmenu, INTSML *waitfordown, INTSML heade
 	us_pmcur.yshift = 0;
 
 	/* get size of current window */
-	frame = getwindowframe(0);
+	frame = getwindowframe(FALSE);
 	getwindowframesize(frame, &swid, &shei);
 	us_pmcur.popupwindow.screenlx = us_pmcur.popupwindow.screenly = 0;
 	us_pmcur.popupwindow.uselx = us_pmcur.popupwindow.usely = 0;
@@ -796,7 +791,7 @@ POPUPMENUITEM *us_popupmenu(POPUPMENU **cmenu, INTSML *waitfordown, INTSML heade
 		for(i=0; i<us_pmcur.current->total; i++)
 		{
 			mi = &us_pmcur.current->list[i];
-			mi->changed = 0;
+			mi->changed = FALSE;
 			pt = us_stripampersand(mi->attribute);
 			screengettextsize(&us_pmcur.popupwindow, pt, &x, &y);
 			if (x > us_pmcur.attlen) us_pmcur.attlen = x;
@@ -807,7 +802,7 @@ POPUPMENUITEM *us_popupmenu(POPUPMENU **cmenu, INTSML *waitfordown, INTSML heade
 		}
 
 		/* make sure the header will fit in the menu */
-		if (header != 0)
+		if (header)
 		{
 			pt = us_stripampersand(us_pmcur.current->header);
 			screengettextsize(&us_pmcur.popupwindow, pt, &x, &y);
@@ -829,7 +824,7 @@ POPUPMENUITEM *us_popupmenu(POPUPMENU **cmenu, INTSML *waitfordown, INTSML heade
 		us_pmcur.sizex = us_pmcur.attlen + 4;
 		if (us_pmcur.vallen != 0) us_pmcur.sizex += us_pmcur.vallen + ATTVALGAP;
 		us_pmcur.sizey = us_pmcur.current->total * us_pmcur.txthei + 3;
-		if (header != 0) us_pmcur.sizey += us_pmcur.txthei;
+		if (header) us_pmcur.sizey += us_pmcur.txthei;
 
 		/* if the menu fits, quit */
 		if (us_pmcur.sizex+MENUSHADOW <= swid &&
@@ -864,54 +859,53 @@ POPUPMENUITEM *us_popupmenu(POPUPMENU **cmenu, INTSML *waitfordown, INTSML heade
 
 	/* save the display under the menu */
 	save_pix = screensavebox(&us_pmcur.popupwindow, us_pmcur.posx,
-		(INTSML)(us_pmcur.posx+us_pmcur.sizex+MENUSHADOW),
-		(INTSML)(us_pmcur.posy-MENUSHADOW-1), (INTSML)(us_pmcur.posy+us_pmcur.sizey-1));
+		us_pmcur.posx+us_pmcur.sizex+MENUSHADOW,
+		us_pmcur.posy-MENUSHADOW-1, us_pmcur.posy+us_pmcur.sizey-1);
 
 	/* write the menu on the screen */
 	us_menufigs.col = el_colmengly;
 	us_menutext.col = el_colmentxt;
 	screendrawbox(&us_pmcur.popupwindow, us_pmcur.posx,
-		(INTSML)(us_pmcur.posx+us_pmcur.sizex-1),
-		us_pmcur.posy, (INTSML)(us_pmcur.posy+us_pmcur.sizey-1), &us_ebox);
+		us_pmcur.posx+us_pmcur.sizex-1,
+		us_pmcur.posy, us_pmcur.posy+us_pmcur.sizey-1, &us_ebox);
 	screendrawline(&us_pmcur.popupwindow, us_pmcur.posx, us_pmcur.posy,
-		(INTSML)(us_pmcur.posx+us_pmcur.sizex-1), us_pmcur.posy, &us_menufigs, 0);
-	screendrawline(&us_pmcur.popupwindow, (INTSML)(us_pmcur.posx+us_pmcur.sizex-1),
-		us_pmcur.posy, (INTSML)(us_pmcur.posx+us_pmcur.sizex-1),
-		(INTSML)(us_pmcur.posy+us_pmcur.sizey-1), &us_menufigs, 0);
-	screendrawline(&us_pmcur.popupwindow, (INTSML)(us_pmcur.posx+us_pmcur.sizex-1),
-		(INTSML)(us_pmcur.posy+us_pmcur.sizey-1), us_pmcur.posx,
-			(INTSML)(us_pmcur.posy+us_pmcur.sizey-1), &us_menufigs, 0);
+		us_pmcur.posx+us_pmcur.sizex-1, us_pmcur.posy, &us_menufigs, 0);
+	screendrawline(&us_pmcur.popupwindow, us_pmcur.posx+us_pmcur.sizex-1,
+		us_pmcur.posy, us_pmcur.posx+us_pmcur.sizex-1,
+		us_pmcur.posy+us_pmcur.sizey-1, &us_menufigs, 0);
+	screendrawline(&us_pmcur.popupwindow, us_pmcur.posx+us_pmcur.sizex-1,
+		us_pmcur.posy+us_pmcur.sizey-1, us_pmcur.posx,
+			us_pmcur.posy+us_pmcur.sizey-1, &us_menufigs, 0);
 	screendrawline(&us_pmcur.popupwindow, us_pmcur.posx,
-		(INTSML)(us_pmcur.posy+us_pmcur.sizey-1),
+		us_pmcur.posy+us_pmcur.sizey-1,
 		us_pmcur.posx, us_pmcur.posy, &us_menufigs, 0);
 
 	/* now draw a shadow */
 	us_shadowdesc.col = el_colmengly;
-	screendrawbox(&us_pmcur.popupwindow, (INTSML)(us_pmcur.posx+MENUSHADOW),
-		(INTSML)(us_pmcur.posx+us_pmcur.sizex), (INTSML)(us_pmcur.posy-MENUSHADOW-1),
-		(INTSML)(us_pmcur.posy-1), &us_shadowdesc);
+	screendrawbox(&us_pmcur.popupwindow, us_pmcur.posx+MENUSHADOW,
+		us_pmcur.posx+us_pmcur.sizex, us_pmcur.posy-MENUSHADOW-1,
+		us_pmcur.posy-1, &us_shadowdesc);
 	if (quitline != 2)
-		screendrawbox(&us_pmcur.popupwindow, (INTSML)(us_pmcur.posx+us_pmcur.sizex),
-			(INTSML)(us_pmcur.posx+us_pmcur.sizex+MENUSHADOW),
-			(INTSML)(us_pmcur.posy-MENUSHADOW-1),
-			(INTSML)(us_pmcur.posy+us_pmcur.sizey-MENUSHADOW), &us_shadowdesc);
+		screendrawbox(&us_pmcur.popupwindow, us_pmcur.posx+us_pmcur.sizex,
+			us_pmcur.posx+us_pmcur.sizex+MENUSHADOW, us_pmcur.posy-MENUSHADOW-1,
+			us_pmcur.posy+us_pmcur.sizey-MENUSHADOW, &us_shadowdesc);
 
 	/* write the header */
-	if (header != 0)
+	if (header)
 	{
 		screendrawline(&us_pmcur.popupwindow, us_pmcur.posx,
-			(INTSML)(us_pmcur.posy+us_pmcur.sizey-us_pmcur.txthei-2),
-			(INTSML)(us_pmcur.posx+us_pmcur.sizex-1),
-			(INTSML)(us_pmcur.posy+us_pmcur.sizey-us_pmcur.txthei-2),
+			us_pmcur.posy+us_pmcur.sizey-us_pmcur.txthei-2,
+			us_pmcur.posx+us_pmcur.sizex-1,
+			us_pmcur.posy+us_pmcur.sizey-us_pmcur.txthei-2,
 			&us_menufigs, 0);
 		pt = us_stripampersand(us_pmcur.current->header);
-		screendrawtext(&us_pmcur.popupwindow, (INTSML)(us_pmcur.posx+2),
-			(INTSML)(us_pmcur.posy+us_pmcur.sizey-us_pmcur.txthei-1),
+		screendrawtext(&us_pmcur.popupwindow, us_pmcur.posx+2,
+			us_pmcur.posy+us_pmcur.sizey-us_pmcur.txthei-1,
 			pt, &us_menutext);
-		screeninvertbox(&us_pmcur.popupwindow, (INTSML)(us_pmcur.posx+1),
-			(INTSML)(us_pmcur.posx+us_pmcur.sizex-2),
-			(INTSML)(us_pmcur.posy+us_pmcur.sizey-us_pmcur.txthei-1),
-			(INTSML)(us_pmcur.posy+us_pmcur.sizey-2));
+		screeninvertbox(&us_pmcur.popupwindow, us_pmcur.posx+1,
+			us_pmcur.posx+us_pmcur.sizex-2,
+			us_pmcur.posy+us_pmcur.sizey-us_pmcur.txthei-1,
+			us_pmcur.posy+us_pmcur.sizey-2);
 		yp = us_pmcur.posy+us_pmcur.sizey-us_pmcur.txthei*2-2;
 	} else yp = us_pmcur.posy+us_pmcur.sizey-us_pmcur.txthei-2;
 
@@ -922,8 +916,8 @@ POPUPMENUITEM *us_popupmenu(POPUPMENU **cmenu, INTSML *waitfordown, INTSML heade
 		if (*mi->attribute == 0 && mi->value == 0)
 		{
 			/* no entry: draw a dotted line */
-			screendrawline(&us_pmcur.popupwindow, us_pmcur.posx, (INTSML)(yp+us_pmcur.txthei/2),
-				(INTSML)(us_pmcur.posx+us_pmcur.sizex-1), (INTSML)(yp+us_pmcur.txthei/2),
+			screendrawline(&us_pmcur.popupwindow, us_pmcur.posx, yp+us_pmcur.txthei/2,
+				us_pmcur.posx+us_pmcur.sizex-1, yp+us_pmcur.txthei/2,
 				&us_menufigs, 1);
 		} else
 		{
@@ -932,13 +926,13 @@ POPUPMENUITEM *us_popupmenu(POPUPMENU **cmenu, INTSML *waitfordown, INTSML heade
 			if (mi->attribute[0] != '>' && *savepos == '<') *savepos = 0; else
 				savepos = 0;
 			pt = us_stripampersand(mi->attribute);
-			screendrawtext(&us_pmcur.popupwindow, (INTSML)(us_pmcur.posx+2), yp, pt,
+			screendrawtext(&us_pmcur.popupwindow, us_pmcur.posx+2, yp, pt,
 				&us_menutext);
 			if (savepos != 0) *savepos = '<';
 			if (mi->value != 0)
 			{
 				screendrawtext(&us_pmcur.popupwindow,
-					(INTSML)(us_pmcur.posx+us_pmcur.attlen+ATTVALGAP+2),
+					us_pmcur.posx+us_pmcur.attlen+ATTVALGAP+2,
 					yp, mi->value, &us_menutext);
 			}
 		}
@@ -958,13 +952,13 @@ POPUPMENUITEM *us_popupmenu(POPUPMENU **cmenu, INTSML *waitfordown, INTSML heade
 
 	/* do command completion while handling input to menu */
 	trackcursor(waitdown, us_pmeachdown, us_pmfirst, us_pmeachdown, us_pmeachchar,
-		us_pmdone, (INTSML)((quitline == 0 ? TRACKSELECTING : TRACKHSELECTING)));
+		us_pmdone, (quitline == 0 ? TRACKSELECTING : TRACKHSELECTING));
 
 	/* restore what was under the menu */
-	(void)screenrestorebox(save_pix, 1);
+	screenrestorebox(save_pix, 1);
 
 	/* report the menu entry selected */
-	if (us_pmcur.inarea < 0) *waitfordown = 1;
+	if (us_pmcur.inarea < 0) *waitfordown = TRUE;
 	if (us_pmcur.retval != NOPOPUPMENUITEM) *cmenu = us_pmcur.retmenu;
 	return(us_pmcur.retval);
 }
@@ -972,75 +966,75 @@ POPUPMENUITEM *us_popupmenu(POPUPMENU **cmenu, INTSML *waitfordown, INTSML heade
 void us_pmfirst(void) {}
 void us_pmdone(void) {}
 
-INTSML us_pmeachchar(INTBIG x, INTBIG y, INTSML chr)
+BOOLEAN us_pmeachchar(INTBIG x, INTBIG y, INTSML chr)
 {
 	REGISTER POPUPMENUITEM *mi;
-	REGISTER INTSML i;
-	INTSML xs, ys;
+	REGISTER INTBIG i;
+	INTBIG xs, ys;
 
 	/* set the cursor properly if it moved */
 	(void)us_pmeachdown(x, y);
 
 	/* quit now if carriage-return is typed */
-	if (chr == '\n' || chr == '\r') return(1);
+	if (chr == '\n' || chr == '\r') return(TRUE);
 
 	/* make sure there is a valid line */
-	if (us_pmcur.hline == -1) return(0);
+	if (us_pmcur.hline == -1) return(FALSE);
 	mi = &us_pmcur.current->list[us_pmcur.hline];
-	if (mi->value == 0 || mi->maxlen < 0) return(0);
+	if (mi->value == 0 || mi->maxlen < 0) return(FALSE);
 
 	/* handle deletion of a character */
 	if (chr == us_erasech)
 	{
-		if (us_pmcur.curpos <= 0) return(0);
+		if (us_pmcur.curpos <= 0) return(FALSE);
 		us_pmcur.curpos--;
 		mi->value[us_pmcur.curpos] = 0;
 		screengettextsize(&us_pmcur.popupwindow, mi->value, &xs, &ys);
 		us_pminvertline();
 		screendrawbox(&us_pmcur.popupwindow,
-			(INTSML)(us_pmcur.posx+2+us_pmcur.attlen+ATTVALGAP+xs),
-			(INTSML)(us_pmcur.posx+us_pmcur.sizex-1),
-			(INTSML)(us_pmcur.posy+us_pmcur.sizey-us_pmcur.txthei*(us_pmcur.hline+2)-2),
-			(INTSML)(us_pmcur.posy+us_pmcur.sizey-us_pmcur.txthei*(us_pmcur.hline+1)-3),
+			us_pmcur.posx+2+us_pmcur.attlen+ATTVALGAP+xs,
+			us_pmcur.posx+us_pmcur.sizex-1,
+			us_pmcur.posy+us_pmcur.sizey-us_pmcur.txthei*(us_pmcur.hline+2)-2,
+			us_pmcur.posy+us_pmcur.sizey-us_pmcur.txthei*(us_pmcur.hline+1)-3,
 			&us_ebox);
 		us_pminvertline();
-		return(0);
+		return(FALSE);
 	}
 
 	/* handle deletion of the entire line */
 	if (chr == us_killch)
 	{
-		if (us_pmcur.curpos <= 0) return(0);
+		if (us_pmcur.curpos <= 0) return(FALSE);
 		us_pmcur.curpos = 0;
 		mi->value[us_pmcur.curpos] = 0;
 		us_pminvertline();
 		screendrawbox(&us_pmcur.popupwindow,
-			(INTSML)(us_pmcur.posx+2+us_pmcur.attlen+ATTVALGAP),
-			(INTSML)(us_pmcur.posx+us_pmcur.sizex-1),
-			(INTSML)(us_pmcur.posy+us_pmcur.sizey-us_pmcur.txthei*(us_pmcur.hline+2)-2),
-			(INTSML)(us_pmcur.posy+us_pmcur.sizey-us_pmcur.txthei*(us_pmcur.hline+1)-3),
+			us_pmcur.posx+2+us_pmcur.attlen+ATTVALGAP,
+			us_pmcur.posx+us_pmcur.sizex-1,
+			us_pmcur.posy+us_pmcur.sizey-us_pmcur.txthei*(us_pmcur.hline+2)-2,
+			us_pmcur.posy+us_pmcur.sizey-us_pmcur.txthei*(us_pmcur.hline+1)-3,
 			&us_ebox);
 		us_pminvertline();
-		return(0);
+		return(FALSE);
 	}
 
 	/* see if the new character will fit */
-	if (us_pmcur.curpos >= us_pmcur.vallen || us_pmcur.curpos >= mi->maxlen) return(0);
+	if (us_pmcur.curpos >= us_pmcur.vallen || us_pmcur.curpos >= mi->maxlen) return(FALSE);
 
 	/* do not allow unprintable characters */
-	if (chr < 040) return(0);
+	if (chr < 040) return(FALSE);
 
 	/* on the first character, blank the line */
 	if (us_pmcur.curpos < 0)
 	{
 		us_pmcur.curpos = 0;
-		mi->changed++;
+		mi->changed = TRUE;
 		us_pminvertline();
 		screendrawbox(&us_pmcur.popupwindow,
-			(INTSML)(us_pmcur.posx+2+us_pmcur.attlen+ATTVALGAP),
-			(INTSML)(us_pmcur.posx+us_pmcur.sizex-1),
-			(INTSML)(us_pmcur.posy+us_pmcur.sizey-us_pmcur.txthei*(us_pmcur.hline+2)-2),
-			(INTSML)(us_pmcur.posy+us_pmcur.sizey-us_pmcur.txthei*(us_pmcur.hline+1)-3),
+			us_pmcur.posx+2+us_pmcur.attlen+ATTVALGAP,
+			us_pmcur.posx+us_pmcur.sizex-1,
+			us_pmcur.posy+us_pmcur.sizey-us_pmcur.txthei*(us_pmcur.hline+2)-2,
+			us_pmcur.posy+us_pmcur.sizey-us_pmcur.txthei*(us_pmcur.hline+1)-3,
 			&us_ebox);
 		us_pminvertline();
 		mi->value[0] = 0;
@@ -1054,27 +1048,28 @@ INTSML us_pmeachchar(INTBIG x, INTBIG y, INTSML chr)
 	mi->value[us_pmcur.curpos] = 0;
 	us_pminvertline();
 	screendrawtext(&us_pmcur.popupwindow, i,
-		(INTSML)(us_pmcur.posy+us_pmcur.sizey-us_pmcur.txthei*(us_pmcur.hline+2)-2),
+		us_pmcur.posy+us_pmcur.sizey-us_pmcur.txthei*(us_pmcur.hline+2)-2,
 			&mi->value[us_pmcur.curpos-1], &us_menutext);
 	us_pminvertline();
-	return(0);
+	return(FALSE);
 }
 
 /*
  * helper routine for popup menus to handle cursor movement
  */
-INTSML us_pmeachdown(INTBIG x, INTBIG y)
+BOOLEAN us_pmeachdown(INTBIG x, INTBIG y)
 {
-	REGISTER INTSML line, maxy, i, lx;
-	INTSML but, sx, sy, swid, shei, pwid;
+	REGISTER INTBIG line, maxy, i, lx;
+	INTBIG sx, sy, swid, shei, pwid;
 	REGISTER POPUPMENUITEM *pm;
 	POPUPMENU *cmenu;
 	REGISTER USERCOM *uc;
 	POPUPINST savepmcur;
+	BOOLEAN but;
 
 	/* determine top coordinate of menu */
 	maxy = us_pmcur.posy+us_pmcur.sizey-2;
-	if (us_pmcur.header != 0) maxy -= us_pmcur.txthei;
+	if (us_pmcur.header) maxy -= us_pmcur.txthei;
 
 	getpaletteparameters(&swid, &shei, &pwid);
 
@@ -1112,7 +1107,7 @@ INTSML us_pmeachdown(INTBIG x, INTBIG y)
 				if (uc != NOUSERCOM && uc->menu != NOPOPUPMENU)
 				{
 					savepmcur = us_pmcur;
-					but = 0;
+					but = FALSE;
 					i = 1;
 					lx = us_pmcur.posx+us_pmcur.sizex;
 					if (us_pmcur.posx > us_pmcur.popupwindow.usehx-lx)
@@ -1122,17 +1117,16 @@ INTSML us_pmeachdown(INTBIG x, INTBIG y)
 						if (us_pmcur.posx < us_pmcur.sizex)
 						{
 							i = us_pmcur.quitline;
-							lx = (INTSML)(x-2);
+							lx = x-2;
 						}
 					}
 					cmenu = uc->menu;
-					pm = us_popupmenu(&cmenu, &but, 0, lx,
-						(INTSML)(us_pmcur.posy+(us_pmcur.current->total-line)*
-							us_pmcur.txthei), i);
+					pm = us_popupmenu(&cmenu, &but, FALSE, lx,
+						us_pmcur.posy+(us_pmcur.current->total-line)*us_pmcur.txthei, i);
 					us_pmcur = savepmcur;
 					us_pmcur.retval = pm;
 					us_pmcur.retmenu = cmenu;
-					if (but == 0) return(1);
+					if (!but) return(TRUE);
 					readtablet(&sx, &sy);
 					x = sx;   y = sy;
 					continue;
@@ -1153,7 +1147,7 @@ INTSML us_pmeachdown(INTBIG x, INTBIG y)
 					y >= maxy-us_pmcur.yshift-us_pmcur.txthei-2) break;
 			}
 			us_pmcur.inarea = -1;
-			return(1);
+			return(TRUE);
 		case 2:			/* quit if off right side */
 			if (y < shei-us_menubarsize)
 			{
@@ -1162,10 +1156,10 @@ INTSML us_pmeachdown(INTBIG x, INTBIG y)
 					y >= maxy-us_pmcur.yshift-us_pmcur.txthei-2) break;
 			}
 			us_pmcur.inarea = -1;
-			return(1);
+			return(TRUE);
 		case 3:			/* quit if out of this pulldown menu's menubar location */
 			if (y <= maxy) break;
-			lx = (INTSML)x;
+			lx = x;
 			for(i=0; i<us_pulldownmenucount; i++)
 			{
 				if (us_pmcur.current == us_pulldowns[i]) break;
@@ -1174,14 +1168,14 @@ INTSML us_pmeachdown(INTBIG x, INTBIG y)
 			if (x >= lx && (x <= us_pulldownmenupos[i] || i == us_pulldownmenucount-1))
 				break;
 			us_pmcur.inarea = -1;
-			return(1);
+			return(TRUE);
 		case 4:			/* quit if out of this popup menu's location */
 			if (x >= us_pmcur.posx && x <= us_pmcur.posx+us_pmcur.sizex &&
 				y >= us_pmcur.posy && y <= us_pmcur.posy+us_pmcur.sizey) break;
 			us_pmcur.inarea = -1;
-			return(1);
+			return(TRUE);
 	}
-	return(0);
+	return(FALSE);
 }
 
 /*
@@ -1189,12 +1183,12 @@ INTSML us_pmeachdown(INTBIG x, INTBIG y)
  */
 void us_pminvertline(void)
 {
-	INTSML yp;
+	INTBIG yp;
 
 	yp = us_pmcur.posy+us_pmcur.sizey-us_pmcur.txthei*(us_pmcur.hline+1)-2;
-	if (us_pmcur.header != 0) yp -= us_pmcur.txthei;
-	screeninvertbox(&us_pmcur.popupwindow, (INTSML)(us_pmcur.posx+1),
-		(INTSML)(us_pmcur.posx+us_pmcur.sizex-2), yp, (INTSML)(yp+us_pmcur.txthei-1));
+	if (us_pmcur.header) yp -= us_pmcur.txthei;
+	screeninvertbox(&us_pmcur.popupwindow, us_pmcur.posx+1,
+		us_pmcur.posx+us_pmcur.sizex-2, yp, yp+us_pmcur.txthei-1);
 }
 
 /* 
@@ -1223,7 +1217,7 @@ char *us_stripampersand(char *msg)
 void us_scanforkeyequiv(POPUPMENU *pm)
 {
 	REGISTER POPUPMENUITEM *mi;
-	REGISTER INTSML j;
+	REGISTER INTBIG j;
 
 	for(j=0; j<pm->total; j++)
 	{
@@ -1235,14 +1229,15 @@ void us_scanforkeyequiv(POPUPMENU *pm)
 			us_scanforkeyequiv(mi->response->menu);
 			continue;
 		}
-		us_setkeyequiv(pm, (INTSML)(j+1));
+		us_setkeyequiv(pm, j+1);
 	}
 }
 
-void us_setkeyequiv(POPUPMENU *pm, INTSML i)
+void us_setkeyequiv(POPUPMENU *pm, INTBIG i)
 {
+	REGISTER INTBIG len, special;
 	REGISTER INTSML key;
-	REGISTER char *pt;
+	REGISTER char *pt, lastchar;
 	REGISTER POPUPMENUITEM *mi;
 
 	/* make sure it is a valid menu entry */
@@ -1251,19 +1246,39 @@ void us_setkeyequiv(POPUPMENU *pm, INTSML i)
 	if (mi->response->active < 0) return;
 	if (mi->response->menu != NOPOPUPMENU) return;
 
+	/* remove ending "<" for checkmarks */
+	len = strlen(mi->attribute);
+	lastchar = 0;
+	if (mi->attribute[len-1] == '<')
+	{
+		lastchar = mi->attribute[len-1];
+		mi->attribute[len-1] = 0;
+	}
+
 	/* see if it has a "/" or "\" in it */
 	for(pt = mi->attribute; *pt != 0 && *pt != '/' && *pt != '\\'; pt++) ;
 	if (*pt == 0) return;
 
 	/* make it the Meta key */
 	key = pt[1];
-	if (isupper(key)) key = tolower(key);
-	if (*pt == '/') key |= 0200;
-	(void)initinfstr();
-	(void)addstringtoinfstr("command=");
-	(void)addstringtoinfstr(mi->response->comname);
-	(void)us_appendargs(mi->response);
-	(void)setindkey((INTBIG)us_tool, VTOOL, us_binding_keys, key, (INTBIG)returninfstr());
+	if (key != 0)
+	{
+		if (*pt == '/')
+		{
+			special = ACCELERATORDOWN;
+			key = tolower(key);
+		} else special = 0;
+		(void)initinfstr();
+		(void)formatinfstr("%c%c", key, *pt);
+		(void)addstringtoinfstr("command=");
+		(void)addstringtoinfstr(mi->response->comname);
+		(void)us_appendargs(mi->response);
+		us_setkeybinding(returninfstr(), key, special, FALSE);
+	}
+
+	/* restore ending "<" checkmark */
+	len = strlen(mi->attribute);
+	mi->attribute[len] = lastchar;
 }
 
 /*
@@ -1272,7 +1287,7 @@ void us_setkeyequiv(POPUPMENU *pm, INTSML i)
  */
 void us_initpulldownmenu(POPUPMENU *pm)
 {
-	REGISTER INTSML i, slash;
+	REGISTER INTBIG i, slash;
 	REGISTER POPUPMENUITEM *mi;
 	REGISTER char *pt;
 	char keybuf[10], *acceleratorstring, *acceleratorprefix;
@@ -1298,7 +1313,7 @@ void us_initpulldownmenu(POPUPMENU *pm)
 		keybuf[0] = 0;
 		if (slash == '/') strcat(keybuf, acceleratorprefix);
 		strcat(keybuf, pt);
-		allocstring(&mi->value, keybuf, us_tool->cluster);
+		(void)allocstring(&mi->value, keybuf, us_tool->cluster);
 		mi->maxlen = -1;
 	}
 }
@@ -1333,3 +1348,38 @@ void us_termpulldownmenu(POPUPMENU *pm)
 		efree(mi->value);
 	}
 }
+
+/*
+ * Routine to examine popup menu "pm" and ensure that no two letters have the same
+ * "&"-invocation key.
+ */
+void us_validatemenu(POPUPMENU *pm)
+{
+	REGISTER INTBIG i, j, index;
+	REGISTER POPUPMENUITEM *mi;
+	REGISTER USERCOM *uc;
+	REGISTER char *pt;
+	char tagged[256];
+
+	for(i=0; i<256; i++) tagged[i] = 0;
+	for(j=0; j < pm->total; j++)
+	{
+		mi = &pm->list[j];
+		uc = mi->response;
+		if (uc->active < 0) continue;
+
+		if (uc->menu != NOPOPUPMENU)
+		{
+			us_validatemenu(uc->menu);
+		}
+		for(pt = mi->attribute; *pt != 0; pt++) if (*pt == '&') break;
+		if (*pt == 0) continue;
+		index = tolower(pt[1]) & 0xFF;
+		if (tagged[index] != 0)
+		{
+			ttyputerr(_("Warning: two entries share letter '%c' ('%s' and '%s')"),
+				index, mi->attribute, pm->list[tagged[index]-1].attribute);
+		}
+		tagged[index] = j+1;
+	}
+}
