@@ -34,6 +34,7 @@
 
 #include "global.h"
 #include "vhdl.h"
+#include "usr.h"
 
 extern INTBIG		vhdl_externentities, vhdl_warnflag, vhdl_target;
 extern DBUNITS		*vhdl_units;
@@ -41,11 +42,11 @@ extern SYMBOLLIST	*vhdl_gsymbols;
 static IDENTTABLE	*vhdl_ident_ground, *vhdl_ident_power;
 
 /* prototypes for local routines */
-static INTSML vhdl_addnetlist(LIBRARY*, char*);
-static void vhdl_genfunction(char*, INTSML, INTSML, INTSML);
-static void vhdl_dumpfunction(char*, char**);
-static void vhdl_genals_interface(DBINTERFACE*, char*);
-static void vhdl_genals_aport(INTBIG*, DBNAME*);
+static BOOLEAN vhdl_addnetlist(LIBRARY*, char*);
+static void    vhdl_genfunction(char*, BOOLEAN, BOOLEAN, INTBIG);
+static void    vhdl_dumpfunction(char*, char**);
+static void    vhdl_genals_interface(DBINTERFACE*, char*);
+static void    vhdl_genals_aport(INTBIG*, DBNAME*);
 
 /*
 Module:  vhdl_genals
@@ -59,9 +60,8 @@ Calling Sequence:  vhdl_genals(lib, basenp);
 */
 void vhdl_genals(LIBRARY *lib, NODEPROTO *basenp)
 {
-	char *strtime, *gate;
-	UINTBIG tsec;
-	INTSML total;
+	char *gate;
+	INTBIG total;
 	DBINTERFACE *top_interface, *interfacef;
 	UNRESLIST *ulist;
 	static char *power[] =
@@ -189,9 +189,10 @@ void vhdl_genals(LIBRARY *lib, NODEPROTO *basenp)
 	vhdl_printoneline("#*************************************************");
 	vhdl_printoneline("#  ALS Netlist file");
 	vhdl_printoneline("#");
-	tsec = getcurrenttime();
-	strtime = timetostring(tsec);
-	vhdl_printoneline("#  File Creation:    %s", strtime);
+	if ((us_useroptions&NODATEORVERSION) == 0)
+	{
+		vhdl_printoneline("#  File Creation:    %s", timetostring(getcurrenttime()));
+	}
 	vhdl_printoneline("#-------------------------------------------------");
 	vhdl_print("");
 
@@ -272,22 +273,22 @@ void vhdl_genals(LIBRARY *lib, NODEPROTO *basenp)
 			total--;
 		} else if (strncmp(gate, "and", 3) == 0 && isdigit(gate[3]))
 		{
-			vhdl_genfunction("and", 1, 0, (INTSML)atoi(&gate[3]));
+			vhdl_genfunction("and", TRUE, FALSE, atoi(&gate[3]));
 			ulist->numref = 0;
 			total--;
 		} else if (strncmp(gate, "nand", 4) == 0 && isdigit(gate[4]))
 		{
-			vhdl_genfunction("and", 1, 1, (INTSML)atoi(&gate[4]));
+			vhdl_genfunction("and", TRUE, TRUE, atoi(&gate[4]));
 			ulist->numref = 0;
 			total--;
 		} else if (strncmp(gate, "or", 2) == 0 && isdigit(gate[2]))
 		{
-			vhdl_genfunction("or", 0, 0, (INTSML)atoi(&gate[2]));
+			vhdl_genfunction("or", FALSE, FALSE, atoi(&gate[2]));
 			ulist->numref = 0;
 			total--;
 		} else if (strncmp(gate, "nor", 3) == 0 && isdigit(gate[3]))
 		{
-			vhdl_genfunction("or", 0, 1, (INTSML)atoi(&gate[3]));
+			vhdl_genfunction("or", FALSE, TRUE, atoi(&gate[3]));
 			ulist->numref = 0;
 			total--;
 		} else if (strcmp(gate, "xor2") == 0)
@@ -330,9 +331,9 @@ void vhdl_genals(LIBRARY *lib, NODEPROTO *basenp)
 
 /*
  * routine to search library "lib" for a netlist that matches "name".  If found,
- * add it to the current output netlist and return nonzero.  If not found, return zero.
+ * add it to the current output netlist and return nonzero.  If not found, return false.
  */
-INTSML vhdl_addnetlist(LIBRARY *lib, char *name)
+BOOLEAN vhdl_addnetlist(LIBRARY *lib, char *name)
 {
 	REGISTER NODEPROTO *np;
 	REGISTER char *pn, *key;
@@ -350,28 +351,28 @@ INTSML vhdl_addnetlist(LIBRARY *lib, char *name)
 		if (namesame(name, key) != 0) continue;
 
 		/* add it to the netlist */
-		var = getvalkey((INTBIG)np, VNODEPROTO, VSTRING|VISARRAY, el_facet_message);
+		var = getvalkey((INTBIG)np, VNODEPROTO, VSTRING|VISARRAY, el_facet_message_key);
 		if (var == NOVARIABLE) continue;
 		len = getlength(var);
 		vhdl_print("");
 		for(i=0; i<len; i++) vhdl_printoneline(((char **)var->addr)[i]);
-		return(1);
+		return(TRUE);
 	}
-	return(0);
+	return(FALSE);
 }
 
 /*
  * inputs cap = 0.xx pF, Tphl = T1 + T2*Cin, Tplh = T3 + T4*Cin
  */
-void vhdl_genfunction(char *name, INTSML isand, INTSML isneg, INTSML inputs)
+void vhdl_genfunction(char *name, BOOLEAN isand, BOOLEAN isneg, INTBIG inputs)
 {
 	char modelname[20], line[20];
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 
 	/* generate model name */
-	if (isneg == 0) modelname[0] = 0; else (void)strcpy(modelname, "n");
-	if (isand != 0) (void)strcat(modelname, "and"); else (void)strcat(modelname, "or");
-	(void)sprintf(line, "%d", inputs);
+	if (!isneg) modelname[0] = 0; else (void)strcpy(modelname, "n");
+	if (isand) (void)strcat(modelname, "and"); else (void)strcat(modelname, "or");
+	(void)sprintf(line, "%ld", inputs);
 	(void)strcat(modelname, line);
 
 	vhdl_print("");
@@ -388,7 +389,7 @@ void vhdl_genfunction(char *name, INTSML isand, INTSML isneg, INTSML inputs)
 	for(i=1; i<=inputs; i++)
 	{
 		if (i > 1) (void)addstringtoinfstr(",");
-		(void)sprintf(line, "a%d", i);
+		(void)sprintf(line, "a%ld", i);
 		(void)addstringtoinfstr(line);
 	}
 	(void)addstringtoinfstr(",z)");
@@ -402,15 +403,15 @@ void vhdl_genfunction(char *name, INTSML isand, INTSML isneg, INTSML inputs)
 	for(i=1; i<=inputs; i++)
 	{
 		if (i > 1) (void)addstringtoinfstr(",");
-		(void)sprintf(line, "a%d", i);
+		(void)sprintf(line, "a%ld", i);
 		(void)addstringtoinfstr(line);
 	}
-	if (isneg == 0) (void)addstringtoinfstr(",out)"); else
+	if (!isneg) (void)addstringtoinfstr(",out)"); else
 		(void)addstringtoinfstr(",z)");
 	vhdl_print(returninfstr());
 
 	/* write buffer line if not negated */
-	if (isneg == 0)
+	if (!isneg)
 	{
 		(void)initinfstr();
 		(void)addstringtoinfstr("g2: ");
@@ -427,7 +428,7 @@ void vhdl_genfunction(char *name, INTSML isand, INTSML isneg, INTSML inputs)
 	for(i=1; i<=inputs; i++)
 	{
 		if (i > 1) (void)addstringtoinfstr(",");
-		(void)sprintf(line, "a%d", i);
+		(void)sprintf(line, "a%ld", i);
 		(void)addstringtoinfstr(line);
 	}
 	(void)addstringtoinfstr(",z)");
@@ -436,9 +437,9 @@ void vhdl_genfunction(char *name, INTSML isand, INTSML isneg, INTSML inputs)
 	for(i=1; i<=inputs; i++)
 	{
 		(void)initinfstr();
-		(void)sprintf(line, "i: a%d", i);
+		(void)sprintf(line, "i: a%ld", i);
 		(void)addstringtoinfstr(line);
-		if (isand != 0) (void)addstringtoinfstr("=L o: z=H"); else
+		if (isand) (void)addstringtoinfstr("=L o: z=H"); else
 			(void)addstringtoinfstr("=H o: z=L");
 		vhdl_print(returninfstr());
 	}
@@ -447,11 +448,11 @@ void vhdl_genfunction(char *name, INTSML isand, INTSML isneg, INTSML inputs)
 	(void)addstringtoinfstr("i:");
 	for(i=1; i<=inputs; i++)
 	{
-		if (isand != 0) (void)sprintf(line, " a%d=H", i); else
-			(void)sprintf(line, " a%d=L", i);
+		if (isand) (void)sprintf(line, " a%ld=H", i); else
+			(void)sprintf(line, " a%ld=L", i);
 		(void)addstringtoinfstr(line);
 	}
-	if (isand != 0)  (void)addstringtoinfstr(" o: z=L"); else
+	if (isand)  (void)addstringtoinfstr(" o: z=L"); else
 		(void)addstringtoinfstr(" o: z=H");
 	vhdl_print(returninfstr());
 	vhdl_print("t: delta=0");
@@ -461,13 +462,13 @@ void vhdl_genfunction(char *name, INTSML isand, INTSML isneg, INTSML inputs)
 	(void)addstringtoinfstr("load:");
 	for(i=1; i<=inputs; i++)
 	{
-		(void)sprintf(line, " a%d=1.0", i);
+		(void)sprintf(line, " a%ld=1.0", i);
 		(void)addstringtoinfstr(line);
 	}
 	vhdl_print(returninfstr());
 
 	/* write buffer gate if not negated */
-	if (isneg == 0)
+	if (!isneg)
 	{
 		(void)initinfstr();
 		(void)addstringtoinfstr("gate ");
@@ -485,7 +486,7 @@ void vhdl_genfunction(char *name, INTSML isand, INTSML isneg, INTSML inputs)
 
 void vhdl_dumpfunction(char *name, char **model)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 
 	vhdl_print("");
 	(void)initinfstr();
