@@ -35,6 +35,7 @@
 #include "global.h"
 #include "vhdl.h"
 #include "sc1.h"
+#include "usr.h"
 
 extern INTBIG		vhdl_externentities, vhdl_warnflag;
 extern DBUNITS		*vhdl_units;
@@ -63,7 +64,7 @@ typedef struct Iqport
 {
 	char			*instname;	/* name of instance */
 	char			*portname;	/* name of port */
-	INTSML           namealloc;	/* nonzero if port name is allocated */
+	BOOLEAN          namealloc;	/* true if port name is allocated */
 	struct Iqport	*next;		/* next in port list */
 } QPORT;
 
@@ -89,9 +90,8 @@ Calling Sequence:  vhdl_genquisc();
 */
 void vhdl_genquisc(void)
 {
-	char *strtime, *pn, *key;
-	UINTBIG tsec;
-	INTSML total;
+	char *pn, *key;
+	INTBIG total;
 	REGISTER LIBRARY *celllib;
 	REGISTER CELL *cell;
 	DBINTERFACE *top_interface, *interfacef;
@@ -105,9 +105,8 @@ void vhdl_genquisc(void)
 	vhdl_printoneline("!*************************************************");
 	vhdl_printoneline("!  QUISC Command file");
 	vhdl_printoneline("!");
-	tsec = getcurrenttime();
-	strtime = timetostring(tsec);
-	vhdl_printoneline("!  File Creation:    %s", strtime);
+	if ((us_useroptions&NODATEORVERSION) == 0)
+		vhdl_printoneline("!  File Creation:    %s", timetostring(getcurrenttime()));
 	vhdl_printoneline("!-------------------------------------------------");
 	vhdl_print("");
 
@@ -572,7 +571,7 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 			{
 				qport = lastnode->table[i];
 				lastnode->table[i] = qport->next;
-				if (qport->namealloc != 0) efree((char *)qport->portname);
+				if (qport->namealloc) efree((char *)qport->portname);
 				efree((char *)qport);
 			}
 		}
@@ -581,7 +580,7 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 		{
 			qport = lastnode->ports;
 			lastnode->ports = qport->next;
-			if (qport->namealloc != 0) efree((char *)qport->portname);
+			if (qport->namealloc) efree((char *)qport->portname);
 			efree((char *)qport);
 		}
 		efree((char *)lastnode);
@@ -773,12 +772,12 @@ QPORT *vhdl_createqport(char *iname, DBPORTLIST *port, INTBIG offset)
 	if (port->type && port->type->type == DBTYPE_ARRAY)
 	{
 		sprintf(buff, "%s[%ld]", port->name->string, (INTBIG)offset);
-		allocstring(&(newport->portname), buff, vhdl_tool->cluster);
-		newport->namealloc = 1;
+		(void)allocstring(&(newport->portname), buff, vhdl_tool->cluster);
+		newport->namealloc = TRUE;
 	} else
 	{
 		newport->portname = port->name->string;
-		newport->namealloc = 0;
+		newport->namealloc = FALSE;
 	}
 
 	return(newport);
