@@ -37,7 +37,7 @@
 
 extern PTREE	*vhdl_ptree;
 extern INTBIG	vhdl_warnflag, vhdl_target;
-extern INTSML	vhdl_err;
+extern BOOLEAN	vhdl_err;
 extern TOKENLIST *vhdl_nexttoken;
 SYMBOLLIST		*vhdl_symbols = 0, *vhdl_gsymbols = 0;
 SYMBOLLIST      *vhdl_symbollists = 0;
@@ -57,13 +57,13 @@ static DBINTERFACE     *vhdl_seminterface(VINTERFACE*);
 static DBBODY          *vhdl_sembody(BODY*);
 static DBPORTLIST      *vhdl_semformal_port_list(FPORTLIST*);
 static DBBODYDECLARE   *vhdl_sembody_declare(BODYDECLARE*);
-static DBCOMPONENTS    *vhdl_semcomponent(COMPONENT*);
+static DBCOMPONENTS    *vhdl_semcomponent(VCOMPONENT*);
 static DBSIGNALS       *vhdl_sembasic_declare(BASICDECLARE*);
 static DBSIGNALS       *vhdl_semobject_declare(OBJECTDECLARE*);
 static DBSIGNALS       *vhdl_semsignal_declare(SIGNALDECLARE*);
 static void             vhdl_semconstant_declare(CONSTANTDECLARE*);
 static DBSTATEMENTS    *vhdl_semset_of_statements(STATEMENTS*);
-static DBINSTANCE      *vhdl_seminstance(INSTANCE*);
+static DBINSTANCE      *vhdl_seminstance(VINSTANCE*);
 static DBSTATEMENTS    *vhdl_semgenerate(GENERATE*);
 #ifdef VHDL50
   static void           vhdl_semwith(WITH*);
@@ -75,7 +75,7 @@ static SYMBOLTREE      *vhdl_addsymbol(IDENTTABLE*, INTBIG, char*, SYMBOLLIST*);
 static SYMBOLTREE      *vhdl_addsymboltree(IDENTTABLE*, INTBIG, char*, SYMBOLTREE*);
 static SYMBOLLIST      *vhdl_pushsymbols(SYMBOLLIST*);
 static SYMBOLLIST      *vhdl_popsymbols(SYMBOLLIST*);
-static void             vhdl_semaport_check(NAME*);
+static void             vhdl_semaport_check(VNAME*);
 static void             vhdl_semaport_check_single_name(SINGLENAME*);
 static char            *vhdl_parsescalar_type(void);
 static COMPOSITE       *vhdl_parsecomposite_type(void);
@@ -88,7 +88,7 @@ static DBLTYPE         *vhdl_semconstrained_array(CONSTRAINED*);
 static DBDISCRETERANGE *vhdl_semdiscrete_range(DISCRETERANGE*);
 static DBDISCRETERANGE *vhdl_semrange(RANGE*);
 static DBLTYPE         *vhdl_semsubtype_indication(SUBTYPEIND*);
-static DBLTYPE         *vhdl_semtype_mark(NAME*);
+static DBLTYPE         *vhdl_semtype_mark(VNAME*);
 static DBLTYPE         *vhdl_getsymboltype(SYMBOLTREE*);
 static void             vhdl_freesymboltree(SYMBOLTREE *tree);
 
@@ -254,7 +254,7 @@ Description:
 Calling Sequence:  err = vhdl_semantic();
 ------------------------------------------------------------------------
 */
-INTSML vhdl_semantic(void)
+BOOLEAN vhdl_semantic(void)
 {
 	PTREE *unit;
 	DBINTERFACE *interfacef, *endinterface;
@@ -685,7 +685,7 @@ DBBODYDECLARE *vhdl_sembody_declare(BODYDECLARE *declare)
 				}
 				break;
 			case BODYDECLARE_COMPONENT:
-				newcomponent = vhdl_semcomponent((COMPONENT *)declare->pointer /*, dbdeclare */);
+				newcomponent = vhdl_semcomponent((VCOMPONENT *)declare->pointer /*, dbdeclare */);
 				if (newcomponent)
 				{
 					if (endcomponent == 0)
@@ -718,11 +718,11 @@ Calling Sequence:  dbcomp = vhdl_semcomponent(compo);
 
 Name		Type			Description
 ----		----			-----------
-compo		*COMPONENT		Pointer to component parse.
+compo		*VCOMPONENT		Pointer to component parse.
 dbcomp		*DBCOMPONENTS	Pointer to created component.
 ------------------------------------------------------------------------
 */
-DBCOMPONENTS *vhdl_semcomponent(COMPONENT *compo)
+DBCOMPONENTS *vhdl_semcomponent(VCOMPONENT *compo)
 {
 	DBCOMPONENTS *dbcomp;
 
@@ -934,7 +934,7 @@ DBSTATEMENTS *vhdl_semset_of_statements(STATEMENTS *state)
 		switch (state->type)
 		{
 			case ARCHSTATE_INSTANCE:
-				newinstance = vhdl_seminstance((INSTANCE *)state->pointer);
+				newinstance = vhdl_seminstance((VINSTANCE *)state->pointer);
 				if (endinstance == 0)
 				{
 					dbstates->instances = endinstance = newinstance;
@@ -983,11 +983,11 @@ Calling Sequence:  dbinst = vhdl_seminstance(inst);
 
 Name		Type		Description
 ----		----		-----------
-inst		*INSTANCE	Pointer to instance structure.
+inst		*VINSTANCE	Pointer to instance structure.
 dbinst		*DBINSTANCE	Pointer to created instance.
 ------------------------------------------------------------------------
 */
-DBINSTANCE *vhdl_seminstance(INSTANCE *inst)
+DBINSTANCE *vhdl_seminstance(VINSTANCE *inst)
 {
 	DBINSTANCE *dbinst;
 	SYMBOLTREE *symbol;
@@ -1031,7 +1031,7 @@ DBINSTANCE *vhdl_seminstance(INSTANCE *inst)
 		/* add to global name space */
 		if ((ikey = vhdl_findidentkey(sbuffer)) == 0)
 		{
-			allocstring(&sptr, sbuffer, vhdl_tool->cluster);
+			(void)allocstring(&sptr, sbuffer, vhdl_tool->cluster);
 			ikey = vhdl_makeidentkey(sptr);
 			if (ikey == 0) return((DBINSTANCE *)0);
 		}
@@ -1079,7 +1079,7 @@ DBINSTANCE *vhdl_seminstance(INSTANCE *inst)
 		}
 		if (iport_num != cport_num)
 		{
-			vhdl_reporterrormsg(vhdl_getnametoken((NAME *)inst->ports->pointer),
+			vhdl_reporterrormsg(vhdl_getnametoken((VNAME *)inst->ports->pointer),
 				_("Instance has different number of ports that component"));
 			return((DBINSTANCE *)0);
 		}
@@ -1114,10 +1114,10 @@ DBINSTANCE *vhdl_seminstance(INSTANCE *inst)
 			enddbaport = dbaport;
 		}
 		if (aplist->pointer == 0) continue;
-		dbaport->name = vhdl_semname((NAME *)aplist->pointer);
+		dbaport->name = vhdl_semname((VNAME *)aplist->pointer);
 
 		/* check that name is reference to a signal or formal port */
-		vhdl_semaport_check((NAME *)aplist->pointer);
+		vhdl_semaport_check((VNAME *)aplist->pointer);
 	}
 
 	return(dbinst);
@@ -1605,10 +1605,10 @@ Calling Sequence:  vhdl_semaport_check(name);
 
 Name		Type		Description
 ----		----		-----------
-name		*NAME		Pointer to name parse structure.
+name		*VNAME		Pointer to name parse structure.
 ------------------------------------------------------------------------
 */
-void vhdl_semaport_check(NAME *name)
+void vhdl_semaport_check(VNAME *name)
 {
 	CONCATENATEDNAME *cat;
 
@@ -1705,7 +1705,7 @@ TYPE *vhdl_parsetype(void)
 	type = NULL;
 
 	/* should be at keyword TYPE */
-	if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_TYPE))
+	if (!vhdl_keysame(vhdl_nexttoken, KEY_TYPE))
 	{
 		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword TYPE"));
 		vhdl_getnexttoken();
@@ -1724,7 +1724,7 @@ TYPE *vhdl_parsetype(void)
 	vhdl_getnexttoken();
 
 	/* should be keyword IS */
-	if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_IS))
+	if (!vhdl_keysame(vhdl_nexttoken, KEY_IS))
 	{
 		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword IS"));
 		vhdl_getnexttoken();
@@ -1733,15 +1733,15 @@ TYPE *vhdl_parsetype(void)
 	vhdl_getnexttoken();
 
 	/* parse type definition */
-	if (vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_ARRAY))
+	if (vhdl_keysame(vhdl_nexttoken, KEY_ARRAY))
 	{
 		type_define = TYPE_COMPOSITE;
 		pointer = (char *)vhdl_parsecomposite_type();
-	} else if (vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_RECORD))
+	} else if (vhdl_keysame(vhdl_nexttoken, KEY_RECORD))
 	{
 		type_define = TYPE_COMPOSITE;
 		pointer = (char *)vhdl_parsecomposite_type();
-	} else if (vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_RANGE))
+	} else if (vhdl_keysame(vhdl_nexttoken, KEY_RANGE))
 	{
 		type_define = TYPE_SCALAR;
 		pointer = vhdl_parsescalar_type();
@@ -1795,11 +1795,11 @@ COMPOSITE *vhdl_parsecomposite_type(void)
 	compo = NULL;
 
 	/* should be ARRAY or RECORD keyword */
-	if (vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_ARRAY))
+	if (vhdl_keysame(vhdl_nexttoken, KEY_ARRAY))
 	{
 		type = COMPOSITE_ARRAY;
 		pointer = (char *)vhdl_parsearray_type();
-	} else if (vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_RECORD))
+	} else if (vhdl_keysame(vhdl_nexttoken, KEY_RECORD))
 	{
 		type = COMPOSITE_RECORD;
 		pointer = vhdl_parserecord_type();
@@ -1857,7 +1857,7 @@ ARRAY *vhdl_parsearray_type(void)
 	array = NULL;
 
 	/* should be keyword ARRAY */
-	if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_ARRAY))
+	if (!vhdl_keysame(vhdl_nexttoken, KEY_ARRAY))
 	{
 		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword ARRAY"));
 		vhdl_getnexttoken();
@@ -1902,7 +1902,7 @@ ARRAY *vhdl_parsearray_type(void)
 	vhdl_getnexttoken();
 
 	/* should be at keyword OF */
-	if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_OF))
+	if (!vhdl_keysame(vhdl_nexttoken, KEY_OF))
 	{
 		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword OF"));
 		vhdl_getnexttoken();
@@ -2180,7 +2180,7 @@ DBLTYPE *vhdl_semsubtype_indication(SUBTYPEIND *subtype)
 	DBLTYPE *dbtype;
 
 	dbtype = NULL;
-	if (subtype == NULL) return(dbtype);;
+	if (subtype == NULL) return(dbtype);
 	dbtype = vhdl_semtype_mark(subtype->type);
 	return(dbtype);
 }
@@ -2195,11 +2195,11 @@ Calling Sequence:  dbtype = vhdl_semtype_mark(name);
 
 Name		Type		Description
 ----		----		-----------
-name		*NAME		Pointer to type name.
+name		*VNAME		Pointer to type name.
 dbtype		*DBLTYPE	Pointer to db type.
 ------------------------------------------------------------------------
 */
-DBLTYPE *vhdl_semtype_mark(NAME *name)
+DBLTYPE *vhdl_semtype_mark(VNAME *name)
 {
 	DBLTYPE *dbtype;
 	SYMBOLTREE *symbol;
