@@ -34,6 +34,7 @@
 
 #include "global.h"
 #include "vhdl.h"
+#include "usr.h"
 
 extern INTBIG		vhdl_externentities, vhdl_warnflag;
 extern DBUNITS		*vhdl_units;
@@ -43,7 +44,7 @@ static DBINTERFACE  *vhdl_top_interface;
 /* prototypes for local routines */
 static void vhdl_gensilos_interface(DBINTERFACE*, char*);
 static void vhdl_gensilos_aport(DBINTERFACE*, DBNAME*);
-static INTSML vhdl_gensilos_isport(DBINTERFACE*, DBNAME*);
+static BOOLEAN vhdl_gensilos_isport(DBINTERFACE*, DBNAME*);
 
 /*
 Module:  vhdl_gensilos
@@ -57,8 +58,6 @@ Calling Sequence:  vhdl_gensilos();
 */
 void vhdl_gensilos(void)
 {
-	char *strtime;
-	UINTBIG tsec;
 	DBINTERFACE *interfacef;
 	UNRESLIST *ulist;
 
@@ -70,9 +69,8 @@ void vhdl_gensilos(void)
 	vhdl_printoneline("$*************************************************");
 	vhdl_printoneline("$  SILOS Netlist file");
 	vhdl_printoneline("$");
-	tsec = getcurrenttime();
-	strtime = timetostring(tsec);
-	vhdl_printoneline("$  File Creation:    %s", strtime);
+	if ((us_useroptions&NODATEORVERSION) == 0)
+		vhdl_printoneline("$  File Creation:    %s", timetostring(getcurrenttime()));
 	vhdl_printoneline("$-------------------------------------------------");
 	vhdl_print("");
 
@@ -89,8 +87,7 @@ void vhdl_gensilos(void)
 		{
 			interfacef->flags &= ~ENTITY_WRITTEN;
 		}
-		vhdl_print(".TITLE %s   (On: %s ",
-		   vhdl_top_interface->name->string, strtime);
+		vhdl_print(".TITLE %s", vhdl_top_interface->name->string);
 		vhdl_gensilos_interface(vhdl_top_interface, vhdl_top_interface->name->string);
 	}
 
@@ -260,13 +257,13 @@ void vhdl_gensilos_interface(DBINTERFACE *interfacef, char *name)
 						if (drange->start > drange->end)
 						{
 							for (i = drange->start; i >= drange->end; i--)
-								addstringtoinfstr(" .SKIP");
+								(void)addstringtoinfstr(" .SKIP");
 						} else
 						{
 							for (i = drange->start; i <= drange->end; i++)
-								addstringtoinfstr(" .SKIP");
+								(void)addstringtoinfstr(" .SKIP");
 						}
-					} else addstringtoinfstr(" .SKIP");
+					} else (void)addstringtoinfstr(" .SKIP");
 				}
 			}
 			vhdl_print(returninfstr());
@@ -350,7 +347,7 @@ Module: vhdl_gensilos_isport
 ----------------------------------------------------------------------
  Search for a match  in the identifier table  between the name of
  the port on an instance and
- a name used in the macro header , if so, return 1, else 0.
+ a name used in the macro header , if so, return true, else false.
 ----------------------------------------------------------------------
 Calling Sequence: vhdl_gensilos_isport(interfacef, name)
 
@@ -360,18 +357,18 @@ interfacef	*DBINTERFACE	Pointer to interface containing the instance
 name		*DBNAME			Pointer to name structure of this port
 ---------------------------------------------------------------------
 */
-INTSML vhdl_gensilos_isport(DBINTERFACE *interfacef, DBNAME *name)
+BOOLEAN vhdl_gensilos_isport(DBINTERFACE *interfacef, DBNAME *name)
 {
 	DBPORTLIST *port;
 
-	if (interfacef == vhdl_top_interface) return(0);	/* no header if this is the top entity */
+	if (interfacef == vhdl_top_interface) return(FALSE);	/* no header if this is the top entity */
 
 	/* we compare the IDENTTABLE pointers of the interface and the instance port */
 	for(port = interfacef->ports; port != NULL; port = port->next)
 	{
-		if((IDENTTABLE *)(name->name) == (IDENTTABLE *)(port->name)) return(1);
+		if((IDENTTABLE *)(name->name) == (IDENTTABLE *)(port->name)) return(TRUE);
 	}
-	return(0);
+	return(FALSE);
 }
 
 #endif  /* VHDLTOOL - at top */
